import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def edges_from_elem(ele) -> None: ...
def elems_depth_measure(ele_dst, ele_src, other_edges_over_cb) -> None:
    """Returns·ele_dst vert depths from ele_src, aligned with ele_dst verts."""

def elems_depth_search(
    ele_init, depths, other_edges_over_cb, results_init=None
) -> None:
    """List of depths -> List of elems that match those depths."""

def find_next(ele_dst, ele_src) -> None: ...
def other_edges_over_edge(e) -> None: ...
def other_edges_over_face(e) -> None: ...
def select_next(bm, report) -> None: ...
def select_prev(bm, report) -> None: ...
def verts_from_elem(ele) -> None: ...
