"""

--------------------

This example shows how an add-on can register custom keyboard shortcuts.
Keymaps are added to keyconfigs.addon

 and removed when unregistered.

Store (keymap, keymap_item)

 tuples for safe cleanup, as multiple add-ons may use the same keymap.

[NOTE]
Users can customize add-on shortcuts in the Keymap Preferences.
Add-on keymaps appear under their respective editors and can be
modified or disabled without editing the add-on code.
Add-ons should only manipulate keymaps in keyconfigs.addon

 and not manipulate the user's keymaps
because add-on keymaps serve as a default which users may customize.
Modifying user keymaps directly interferes with users' own preferences.

[WARNING]
Add-ons can add items to existing modal keymaps but cannot create
new modal keymaps via Python. Use modal=True

 when targeting
an existing modal keymap such as "Knife Tool Modal Map".

```../examples/bpy.types.KeyMaps.1.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyConfig.keymaps

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Area.spaces
* AreaSpaces.active
* Context.space_data

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesInput.walk_navigation

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ShaderNodeTexBrick.color_mapping
* ShaderNodeTexChecker.color_mapping
* ShaderNodeTexEnvironment.color_mapping
* ShaderNodeTexGabor.color_mapping
* ShaderNodeTexGradient.color_mapping
* ShaderNodeTexImage.color_mapping
* ShaderNodeTexMagic.color_mapping
* ShaderNodeTexNoise.color_mapping
* ShaderNodeTexSky.color_mapping
* ShaderNodeTexVoronoi.color_mapping
* ShaderNodeTexWave.color_mapping

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.brush
* BlendData.brushes
* BlendDataBrushes.create_gpencil_data
* BlendDataBrushes.new
* BlendDataBrushes.remove
* Paint.brush
* Paint.eraser_brush

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* FreestyleLineStyle.geometry_modifiers
* LineStyleGeometryModifiers.new
* LineStyleGeometryModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.movieclips

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* IDOverrideLibraryProperty.operations
* IDOverrideLibraryPropertyOperations.add
* IDOverrideLibraryPropertyOperations.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapBindings.find
* XrActionMapBindings.new
* XrActionMapBindings.new_from_binding
* XrActionMapBindings.new_from_binding
* XrActionMapBindings.remove
* XrActionMapItem.bindings
* XrSessionState.action_binding_create

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.edit

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.sculpt_capabilities

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleLineStyle.color_modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* DynamicPaintModifier.canvas_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Particle.particle_keys

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceDopeSheetEditor.dopesheet
* SpaceGraphEditor.dopesheet
* SpaceNLA.dopesheet

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeSpaceGradient.gradients

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSettings.fluid

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.exporters

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mask.layers
* MaskLayers.active
* MaskLayers.new
* MaskLayers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeEvaluateClosure.output_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* IDOverrideLibraryProperty.operations

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_nla_strip
* bpy.context.selected_nla_strips
* NlaStrip.strips
* NlaStrips.new
* NlaStrips.remove
* NlaTrack.strips

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ByteColorAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeFieldToList.list_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeBake.bake_items
* NodeGeometryBakeItems.new
* NodeGeometryBakeItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.particle_edit

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.plane_tracks
* MovieTrackingObject.plane_tracks
* MovieTrackingPlaneTracks.active

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingObject.plane_tracks

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeClosureOutput.output_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrSessionState.actionmaps

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Driver.variables

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* QuaternionAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementInput.pair_with_output
* GeometryNodeRepeatInput.pair_with_output
* GeometryNodeSimulationInput.pair_with_output
* NodeClosureInput.pair_with_output

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.objects

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderEngine.pass_by_index_get
* RenderLayer.passes
* RenderPasses.find_by_name

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.rigid_body

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.inputs

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMaps.find
* XrActionMaps.new
* XrActionMaps.new_from_actionmap
* XrActionMaps.new_from_actionmap
* XrActionMaps.remove
* XrSessionState.action_binding_create
* XrSessionState.action_create
* XrSessionState.action_set_create
* XrSessionState.actionmaps

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.tracks

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MetaStrip.strips

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleEdit.brush

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveProfile.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeFieldToList.active_item
* GeometryNodeFieldToList.list_items
* GeometryNodeFieldToListItems.new
* GeometryNodeFieldToListItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Node.inputs
* Node.outputs
* NodeInputs.new
* NodeInputs.remove
* NodeLink.from_socket
* NodeLink.to_socket
* NodeLinks.new
* NodeLinks.new
* NodeOutputs.new
* NodeOutputs.remove
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocketBool.from_socket
* NodeTreeInterfaceSocketBool.init_socket
* NodeTreeInterfaceSocketBundle.from_socket
* NodeTreeInterfaceSocketBundle.init_socket
* NodeTreeInterfaceSocketClosure.from_socket
* NodeTreeInterfaceSocketClosure.init_socket
* NodeTreeInterfaceSocketCollection.from_socket
* NodeTreeInterfaceSocketCollection.init_socket
* NodeTreeInterfaceSocketColor.from_socket
* NodeTreeInterfaceSocketColor.init_socket
* NodeTreeInterfaceSocketFloat.from_socket
* NodeTreeInterfaceSocketFloat.init_socket
* NodeTreeInterfaceSocketFloatAngle.from_socket
* NodeTreeInterfaceSocketFloatAngle.init_socket
* NodeTreeInterfaceSocketFloatColorTemperature.from_socket
* NodeTreeInterfaceSocketFloatColorTemperature.init_socket
* NodeTreeInterfaceSocketFloatDistance.from_socket
* NodeTreeInterfaceSocketFloatDistance.init_socket
* NodeTreeInterfaceSocketFloatFactor.from_socket
* NodeTreeInterfaceSocketFloatFactor.init_socket
* NodeTreeInterfaceSocketFloatFrequency.from_socket
* NodeTreeInterfaceSocketFloatFrequency.init_socket
* NodeTreeInterfaceSocketFloatMass.from_socket
* NodeTreeInterfaceSocketFloatMass.init_socket
* NodeTreeInterfaceSocketFloatPercentage.from_socket
* NodeTreeInterfaceSocketFloatPercentage.init_socket
* NodeTreeInterfaceSocketFloatTime.from_socket
* NodeTreeInterfaceSocketFloatTime.init_socket
* NodeTreeInterfaceSocketFloatTimeAbsolute.from_socket
* NodeTreeInterfaceSocketFloatTimeAbsolute.init_socket
* NodeTreeInterfaceSocketFloatUnsigned.from_socket
* NodeTreeInterfaceSocketFloatUnsigned.init_socket
* NodeTreeInterfaceSocketFloatWavelength.from_socket
* NodeTreeInterfaceSocketFloatWavelength.init_socket
* NodeTreeInterfaceSocketGeometry.from_socket
* NodeTreeInterfaceSocketGeometry.init_socket
* NodeTreeInterfaceSocketImage.from_socket
* NodeTreeInterfaceSocketImage.init_socket
* NodeTreeInterfaceSocketInt.from_socket
* NodeTreeInterfaceSocketInt.init_socket
* NodeTreeInterfaceSocketIntFactor.from_socket
* NodeTreeInterfaceSocketIntFactor.init_socket
* NodeTreeInterfaceSocketIntPercentage.from_socket
* NodeTreeInterfaceSocketIntPercentage.init_socket
* NodeTreeInterfaceSocketIntUnsigned.from_socket
* NodeTreeInterfaceSocketIntUnsigned.init_socket
* NodeTreeInterfaceSocketMaterial.from_socket
* NodeTreeInterfaceSocketMaterial.init_socket
* NodeTreeInterfaceSocketMatrix.from_socket
* NodeTreeInterfaceSocketMatrix.init_socket
* NodeTreeInterfaceSocketMenu.from_socket
* NodeTreeInterfaceSocketMenu.init_socket
* NodeTreeInterfaceSocketObject.from_socket
* NodeTreeInterfaceSocketObject.init_socket
* NodeTreeInterfaceSocketRotation.from_socket
* NodeTreeInterfaceSocketRotation.init_socket
* NodeTreeInterfaceSocketShader.from_socket
* NodeTreeInterfaceSocketShader.init_socket
* NodeTreeInterfaceSocketString.from_socket
* NodeTreeInterfaceSocketString.init_socket
* NodeTreeInterfaceSocketStringFilePath.from_socket
* NodeTreeInterfaceSocketStringFilePath.init_socket
* NodeTreeInterfaceSocketTexture.from_socket
* NodeTreeInterfaceSocketTexture.init_socket
* NodeTreeInterfaceSocketVector.from_socket
* NodeTreeInterfaceSocketVector.init_socket
* NodeTreeInterfaceSocketVector2D.from_socket
* NodeTreeInterfaceSocketVector2D.init_socket
* NodeTreeInterfaceSocketVector4D.from_socket
* NodeTreeInterfaceSocketVector4D.init_socket
* NodeTreeInterfaceSocketVectorAcceleration.from_socket
* NodeTreeInterfaceSocketVectorAcceleration.init_socket
* NodeTreeInterfaceSocketVectorAcceleration2D.from_socket
* NodeTreeInterfaceSocketVectorAcceleration2D.init_socket
* NodeTreeInterfaceSocketVectorAcceleration4D.from_socket
* NodeTreeInterfaceSocketVectorAcceleration4D.init_socket
* NodeTreeInterfaceSocketVectorDirection.from_socket
* NodeTreeInterfaceSocketVectorDirection.init_socket
* NodeTreeInterfaceSocketVectorDirection2D.from_socket
* NodeTreeInterfaceSocketVectorDirection2D.init_socket
* NodeTreeInterfaceSocketVectorDirection4D.from_socket
* NodeTreeInterfaceSocketVectorDirection4D.init_socket
* NodeTreeInterfaceSocketVectorEuler.from_socket
* NodeTreeInterfaceSocketVectorEuler.init_socket
* NodeTreeInterfaceSocketVectorEuler2D.from_socket
* NodeTreeInterfaceSocketVectorEuler2D.init_socket
* NodeTreeInterfaceSocketVectorEuler4D.from_socket
* NodeTreeInterfaceSocketVectorEuler4D.init_socket
* NodeTreeInterfaceSocketVectorFactor.from_socket
* NodeTreeInterfaceSocketVectorFactor.init_socket
* NodeTreeInterfaceSocketVectorFactor2D.from_socket
* NodeTreeInterfaceSocketVectorFactor2D.init_socket
* NodeTreeInterfaceSocketVectorFactor4D.from_socket
* NodeTreeInterfaceSocketVectorFactor4D.init_socket
* NodeTreeInterfaceSocketVectorPercentage.from_socket
* NodeTreeInterfaceSocketVectorPercentage.init_socket
* NodeTreeInterfaceSocketVectorPercentage2D.from_socket
* NodeTreeInterfaceSocketVectorPercentage2D.init_socket
* NodeTreeInterfaceSocketVectorPercentage4D.from_socket
* NodeTreeInterfaceSocketVectorPercentage4D.init_socket
* NodeTreeInterfaceSocketVectorTranslation.from_socket
* NodeTreeInterfaceSocketVectorTranslation.init_socket
* NodeTreeInterfaceSocketVectorTranslation2D.from_socket
* NodeTreeInterfaceSocketVectorTranslation2D.init_socket
* NodeTreeInterfaceSocketVectorTranslation4D.from_socket
* NodeTreeInterfaceSocketVectorTranslation4D.init_socket
* NodeTreeInterfaceSocketVectorVelocity.from_socket
* NodeTreeInterfaceSocketVectorVelocity.init_socket
* NodeTreeInterfaceSocketVectorVelocity2D.from_socket
* NodeTreeInterfaceSocketVectorVelocity2D.init_socket
* NodeTreeInterfaceSocketVectorVelocity4D.from_socket
* NodeTreeInterfaceSocketVectorVelocity4D.init_socket
* NodeTreeInterfaceSocketVectorXYZ.from_socket
* NodeTreeInterfaceSocketVectorXYZ.init_socket
* NodeTreeInterfaceSocketVectorXYZ2D.from_socket
* NodeTreeInterfaceSocketVectorXYZ2D.init_socket
* NodeTreeInterfaceSocketVectorXYZ4D.from_socket
* NodeTreeInterfaceSocketVectorXYZ4D.init_socket
* UILayout.template_node_link
* UILayout.template_node_view

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* NodeTree.color_tag
* NodeTree.default_group_node_width
* NodeTree.view_center
* NodeTree.description
* NodeTree.animation_data
* NodeTree.nodes
* NodeTree.links
* NodeTree.annotation
* NodeTree.type
* NodeTree.interface
* NodeTree.bl_idname
* NodeTree.bl_label
* NodeTree.bl_description
* NodeTree.bl_icon
* NodeTree.bl_use_group_interface

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* NodeTree.interface_update
* NodeTree.contains_tree
* NodeTree.poll
* NodeTree.update
* NodeTree.get_from_context
* NodeTree.valid_socket_type
* NodeTree.debug_lazy_function_graph
* NodeTree.bl_rna_get_subclass
* NodeTree.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Area.spaces

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.paint_mode

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.pointcloud
* BlendData.pointclouds
* BlendDataPointClouds.new
* BlendDataPointClouds.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeViewer.active_item
* GeometryNodeViewer.viewer_items
* NodeGeometryViewerItems.new
* NodeGeometryViewerItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* PropertyGroup.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* PropertyGroup.bl_system_properties_get
* PropertyGroup.bl_rna_get_subclass
* PropertyGroup.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskSplinePoint.parent

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.gpencil_paint

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.speaker
* BlendData.speakers
* BlendDataSpeakers.new
* BlendDataSpeakers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.packed_files

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionChannelbag.fcurves

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleSettings.modules

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.edit_text
* BlendData.texts
* BlendDataTexts.load
* BlendDataTexts.new
* BlendDataTexts.remove
* Camera.custom_shader
* FreestyleModuleSettings.script
* NodeFrame.text
* NodeSocketText.default_value
* NodeTreeInterfaceSocketText.default_value
* ShaderNodeScript.script
* ShaderNodeTexIES.ies
* SpaceTextEditor.text

:columns: 2


--------------------

* bpy_struct.id_data
* GreasePencilTreeNode.name
* GreasePencilTreeNode.hide
* GreasePencilTreeNode.lock
* GreasePencilTreeNode.select
* GreasePencilTreeNode.use_onion_skinning
* GreasePencilTreeNode.use_masks
* GreasePencilTreeNode.channel_color
* GreasePencilTreeNode.next_node
* GreasePencilTreeNode.prev_node
* GreasePencilTreeNode.parent_group

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* GreasePencilTreeNode.bl_rna_get_subclass
* GreasePencilTreeNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* GreasePencil.layers
* GreasePencilLayerMasks.add
* GreasePencilv3Layers.active
* GreasePencilv3Layers.move
* GreasePencilv3Layers.move_bottom
* GreasePencilv3Layers.move_to_layer_group
* GreasePencilv3Layers.move_top
* GreasePencilv3Layers.new
* GreasePencilv3Layers.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderResult.views

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

This example shows an implementation of USDHook

 to extend USD
export and import functionality.


--------------------

One may optionally define any or all of the following callback functions
in the USDHook

 subclass.


--------------------

Called before the USD export finalizes, allowing modifications to the USD
stage immediately before it is saved.

Args:

* export_context

 (USDSceneExportContext): Provides access to the stage and dependency graph

Returns:

* True

 on success or False

 if the operation was bypassed or otherwise failed to complete


--------------------

Called for each material that is exported, allowing modifications to the USD material,
such as shader generation.

Args:

* export_context

 (USDMaterialExportContext): Provides access to the stage and a texture export utility function
* bl_material

 (bpy.types.Material

): The source Blender material
* usd_material

 (pxr.UsdShade.Material

): The target USD material to be exported

Returns:

* True

 on success or False

 if the operation was bypassed or otherwise failed to complete

Note that the target USD material might already have connected shaders created by the USD exporter or
by other material export hooks.


--------------------

Called after the USD import finalizes.

Args:

* import_context

 (USDSceneImportContext):
Provides access to the stage and a map associating USD prim paths and Blender IDs

Returns:

* True

 on success or False

 if the operation was bypassed or otherwise failed to complete


--------------------

Called to determine if the USDHook

 implementation can convert a given USD material.

Args:

* import_context

 (USDMaterialImportContext): Provides access to the stage and a texture import utility function
* usd_material

 (pxr.UsdShade.Material

): The source USD material to be exported

Returns:

* True

 if the hook can convert the material or False

 otherwise

If any hook returns True

 from material_import_poll

, the USD importer will skip standard USD Preview Surface


or MaterialX

 import and invoke the hook's on_material_import method to convert the material instead.


--------------------

Called for each material that is imported, to allow converting the USD material to nodes on the Blender material.
To ensure that this function gets called, the hook must also implement the material_import_poll()


callback to return True

 for the given USD material.

Args:

* import_context

 (USDMaterialImportContext): Provides access to the stage and a texture import utility function
* bl_material

 (bpy.types.Material

): The target Blender material with an empty node tree
* usd_material

 (pxr.UsdShade.Material

): The source USD material to be imported

Returns:

* True

 on success or False

 if the conversion failed or otherwise did not complete


--------------------

Instances of the following built-in classes are provided as arguments to the callbacks.


--------------------

Argument for on_export.

Methods:

* get_stage()

: returns the USD stage to be saved
* get_depsgraph()

: returns the Blender scene dependency graph
* get_prim_map()

 returns a dict

 where the key is an exported USD Prim path and the value a list


of the IDs associated with that prim.


--------------------

Argument for on_material_export.

Methods:

* get_stage()

: returns the USD stage to be saved
* export_texture(image: bpy.types.Image)

: Returns the USD asset path for the given texture image

The export_texture

 function will save in-memory images and may copy texture assets,
depending on the current USD export options.
For example, by default calling export_texture(/foo/bar.png)

 will copy the file to a textures


directory next to the exported USD and will return the relative path ./textures/bar.png

.


--------------------

Argument for on_import.

Methods:

* get_prim_map()

 returns a dict

 where the key is an imported USD Prim path and the value a list


of the IDs created by the imported prim.
* get_stage()

 returns the USD stage which was imported.


--------------------

Argument for material_import_poll and on_material_import.

Methods:

* get_stage()

:
returns the USD stage to be saved.
* import_texture(asset_path: str)

:
for the given USD texture asset path, returns a tuple[str, bool]

,
containing the asset's local path and a bool indicating whether the path references a temporary file.

The import_texture

 function may copy the texture to the local file system if the given asset path is a
package-relative path for a USDZ archive, depending on the current USD Import Textures

 options.
When the Import Textures

 mode is Packed

, the texture is saved to a temporary location and the
second element of the returned tuple is True

, indicating that the file is temporary, in which
case it may be necessary to pack the image. The original asset path will be returned unchanged if it's
already a local file or if it could not be copied to a local destination.


--------------------

Exceptions raised by these functions will be reported in Blender with the exception details printed to the console.


--------------------

The USDHookExample

 class in the example below implements the following functions:

* on_export()

 function to add custom data to the stage's root layer.
* on_material_export()

 function to create a simple MaterialX

 shader on the given USD material.
* on_import()

 function to create a text object to display the stage's custom layer data.
* material_import_poll()

 returns True

 if the given USD material has an mtlx

 context.
* on_material_import()

 function to convert a simple MaterialX

 shader with a base_color

 input.

```../examples/bpy.types.USDHook.0.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceImageEditor.overlay

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpreadsheetTable.columns

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.image_paint

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapBinding.component_paths
* XrComponentPaths.find
* XrComponentPaths.new
* XrComponentPaths.remove

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.loop_triangles

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.sounds

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* IKParam.ik_solver

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* IKParam.bl_rna_get_subclass
* IKParam.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Linesets.active
* Linesets.new
* Linesets.remove
* FreestyleSettings.linesets

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSequenceEditor.timeline_overlay

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.loops

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* Object.local_view_get
* Object.local_view_set
* Object.visible_get
* Object.visible_in_viewport_get
* SpaceView3D.local_view

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.outliner

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceNodeEditor.path

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Armature.edit_bones

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Text.current_line
* Text.lines
* Text.select_end_line

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Node.inputs

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.tiles
* UDIMTiles.active
* UDIMTiles.get
* UDIMTiles.new
* UDIMTiles.remove

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.meta_ball
* BlendData.metaballs
* BlendDataMetaBalls.new
* BlendDataMetaBalls.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.line_style
* BlendData.linestyles
* BlendDataLineStyles.new
* BlendDataLineStyles.remove
* FreestyleLineSet.linestyle

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSpreadsheet.row_filters

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.generation_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.window_managers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.collection
* Context.layer_collection
* LayerCollection.children
* ViewLayer.active_layer_collection
* ViewLayer.layer_collection

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Event.xr

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mask.layers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Spline.bezier_points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.vertex_colors

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderEngine.begin_result
* RenderEngine.end_result
* RenderEngine.get_result
* RenderEngine.update_result

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesExtensions.repos
* UserExtensionRepoCollection.new
* UserExtensionRepoCollection.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Gizmo.target_set_operator
* KeyConfigurations.find_item_from_operator
* KeyMapItem.properties
* KeyMapItems.find_from_operator
* Macro.properties
* Operator.description
* Operator.properties
* OperatorMacro.properties
* UILayout.operator
* UILayout.operator_menu_enum
* UILayout.operator_menu_hold
* UILayout.template_popup_confirm
* WindowManager.operator_properties_last
* WorkSpaceTool.operator_properties
* XrActionMapItem.op_properties

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Spline.bezier_points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* LightProbe.type
* LightProbe.clip_start
* LightProbe.show_clip
* LightProbe.show_influence
* LightProbe.influence_distance
* LightProbe.visibility_buffer_bias
* LightProbe.visibility_bleed_bias
* LightProbe.visibility_blur
* LightProbe.visibility_collection
* LightProbe.invert_visibility_collection
* LightProbe.show_data
* LightProbe.use_data_display
* LightProbe.data_display_size
* LightProbe.animation_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* LightProbe.bl_rna_get_subclass
* LightProbe.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.view_3d

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothSettings.rest_shape_key
* Key.key_blocks
* Key.reference_key
* Object.active_shape_key
* Object.shape_key_add
* Object.shape_key_remove
* Object.shape_keys_selected
* ShapeKey.relative_key

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Camera.dof

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationStroke.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Volume.display

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Palette.colors
* PaletteColors.active
* PaletteColors.new
* PaletteColors.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.collections

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeClipEditor.space
* ThemeConsole.space
* ThemeDopeSheet.space
* ThemeFileBrowser.space
* ThemeGraphEditor.space
* ThemeImageEditor.space
* ThemeInfo.space
* ThemeNLAEditor.space
* ThemeNodeEditor.space
* ThemeOutliner.space
* ThemePreferences.space
* ThemeProperties.space
* ThemeSequenceEditor.space
* ThemeSpreadsheet.space
* ThemeStatusBar.space
* ThemeTextEditor.space
* ThemeTopBar.space

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.keying_sets_all

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewLayer.lightgroups

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingPlaneTrack.markers

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* FreestyleLineStyle.alpha_modifiers
* LineStyleAlphaModifiers.new
* LineStyleAlphaModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSequenceEditor.cache_overlay

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilFrames.copy
* GreasePencilFrames.move
* GreasePencilFrames.new
* GreasePencilLayer.current_frame
* GreasePencilLayer.frames
* GreasePencilLayer.get_frame_at

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.worlds

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeCommon.anim

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curves.attributes
* Curves.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothModifier.collision_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Struct.functions

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CacheFile.layers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeViewer.viewer_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMap.actionmap_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothModifier.settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.blend_data
* RenderEngine.update

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripColorBalanceData.correction_method
* StripColorBalanceData.lift
* StripColorBalanceData.gamma
* StripColorBalanceData.gain
* StripColorBalanceData.slope
* StripColorBalanceData.offset
* StripColorBalanceData.power
* StripColorBalanceData.invert_lift
* StripColorBalanceData.invert_gamma
* StripColorBalanceData.invert_gain
* StripColorBalanceData.invert_slope
* StripColorBalanceData.invert_offset
* StripColorBalanceData.invert_power

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripColorBalanceData.bl_rna_get_subclass
* StripColorBalanceData.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.particles

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleLineStyle.alpha_modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Volume.grids

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyingSet.type_info

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendImportContextItem.source_libraries

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PointCloud.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FCurve.sampled_points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.keyconfigs

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Int2Attribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.objects

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.windows

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeMenuSwitch.enum_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FCurve.modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2

Attributes are used to store data that corresponds to geometry elements.
Geometry elements are items in one of the geometry domains like points, curves, or faces.

An attribute has a name

, a type

, and is stored on a domain

.

name


    The name of this attribute. Names have to be unique within the same geometry.
    If the name starts with a .

    , the attribute is hidden from the UI.

type


    The type of data that this attribute stores, e.g. a float, integer, color, etc.
    See Attribute Type Items.

domain


    The geometry domain that the attribute is stored on.
    See Attribute Domain Items.


--------------------

Attributes can be stored on geometries like Mesh, Curves, PointCloud, etc.
These geometries have attribute groups (usually called attributes

).
Using the groups, attributes can then be accessed by their name:

```
radii = curves.attributes["radius"]
```

Creating and storing custom attributes is done using the attributes.new

 function:

```
# Add a new attribute named `my_attribute_name` of type `float` on the point domain of the geometry.
my_attribute = curves.attributes.new("my_attribute_name", 'FLOAT', 'POINT')
```

Removing attributes can be done like so:

```
attribute = drawing.attributes["some_attribute"]
drawing.attributes.remove(attribute)
```

[NOTE]
Some attributes are required and cannot be removed, like "position"

.

Attribute values are read by accessing their attribute.data

 collection property.
However, in cases where multiple values should be read at once,
it is better to use the bpy_prop_collection.foreach_get function and read the values into a numpy

 buffer.

```
import numpy as np

# Get the radius attribute.
radii = curves.attributes["radius"]
# Print the radius of the first point.
print(radii.data[0].value)
# Output: 0.005

# Get the total number of points.
num_points = attributes.domain_size('POINT')
# Create an empty buffer to read all the radii into.
radii_data = np.zeros(num_points, dtype=np.float32)
# Read all the radii of the curves into `radii_data` at once.
radii.data.foreach_get('value', radii_data)
# Print all the radii.
print(radii_data)
# Output: [0.1, 0.2, 0.3, 0.4, ... ]
```

[NOTE]
Some attribute types use different named properties to access their value.
Instead of value

, vectors use vector

, and colors use color

.

Writing to different attribute types is very similar. You can simply assign to a value directly.
Again, when writing to multiple values, it is recommended to use the bpy_prop_collection.foreach_set function
to write the values from a numpy

 buffer.

```
import numpy as np

radii = curves.attributes["radius"]
# Write a radius with a value of 0.5 to the first point.
radii.data[0].value = 0.5
print(radii.data[0].value)
# Output: 0.5

num_points = attributes.domain_size('POINT')
# Generate random radii with values between 0.001 and 0.05 using numpy.
new_radii = np.random.uniform(0.001, 0.05, num_points)
# Write the new radii to the radius attribute.
radii.data.foreach_set('value', new_radii)
```

The bpy_prop_collection.foreach_get / bpy_prop_collection.foreach_set methods require a flat array.
This is sometimes not desirable, e.g. when reading/writing positions, which are 3D vectors.
In these cases, it's possible to use np.ravel

 to pass the data as a flat array:

```
num_points = attributes.domain_size('POINT')
positions = curves.attributes['position']
# Here, we're using a numpy array with shape (num_points, 3) so that each
# element is a 3d vector.
positions_data = np.zeros((num_points, 3), dtype=np.float32)
# The `np.ravel` function will pass the `positions_data` as a flat array
# without changing the original shape.
positions.data.foreach_get('vector', np.ravel(positions_data))
print(positions_data)
# Output: [[0.1, 0.2, 0.3], [0.4, 0.5, 0.6], ...]
```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AttributeGroupCurves.active
* AttributeGroupCurves.new
* AttributeGroupCurves.remove
* AttributeGroupGreasePencil.active
* AttributeGroupGreasePencil.new
* AttributeGroupGreasePencil.remove
* AttributeGroupGreasePencilDrawing.active
* AttributeGroupGreasePencilDrawing.new
* AttributeGroupGreasePencilDrawing.remove
* AttributeGroupMesh.active
* AttributeGroupMesh.active_color
* AttributeGroupMesh.new
* AttributeGroupMesh.remove
* AttributeGroupPointCloud.active
* AttributeGroupPointCloud.new
* AttributeGroupPointCloud.remove
* Curves.attributes
* Curves.color_attributes
* GreasePencil.attributes
* GreasePencil.color_attributes
* GreasePencilDrawing.attributes
* GreasePencilDrawing.color_attributes
* Mesh.attributes
* Mesh.color_attributes
* PointCloud.attributes
* PointCloud.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.cache_files

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifier.node_warnings

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.sequence_editor
* Scene.sequence_editor_create

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.window_managers
* Context.window_manager

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.uv_layers

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.uv_sculpt

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Strip.modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeTree.links

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnimViz.motion_path

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Float4Attribute.data

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeIndexSwitch.index_switch_items
* NodeIndexSwitchItems.new
* NodeIndexSwitchItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curves.position_data
* FloatVectorAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieClip.metadata
* MovieStrip.metadata

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_strip
* bpy.context.selected_editable_strips
* bpy.context.selected_strips
* bpy.context.strip
* bpy.context.strips
* AddStrip.input_1
* AddStrip.input_2
* AlphaOverStrip.input_1
* AlphaOverStrip.input_2
* AlphaUnderStrip.input_1
* AlphaUnderStrip.input_2
* ColorMixStrip.input_1
* ColorMixStrip.input_2
* CompositorStrip.input_1
* CompositorStrip.input_2
* CrossStrip.input_1
* CrossStrip.input_2
* GammaCrossStrip.input_1
* GammaCrossStrip.input_2
* GaussianBlurStrip.input_1
* GlowStrip.input_1
* MetaStrip.strips
* MultiplyStrip.input_1
* MultiplyStrip.input_2
* SequenceEditor.active_strip
* SequenceEditor.display_stack
* SequenceEditor.meta_stack
* SequenceEditor.strips
* SequenceEditor.strips_all
* SpeedControlStrip.input_1
* Strip.connections
* Strip.move_to_meta
* Strip.parent_meta
* Strip.split
* Strip.swap
* StripModifier.input_mask_strip
* StripsMeta.new_clip
* StripsMeta.new_effect
* StripsMeta.new_effect
* StripsMeta.new_effect
* StripsMeta.new_image
* StripsMeta.new_mask
* StripsMeta.new_meta
* StripsMeta.new_movie
* StripsMeta.new_scene
* StripsMeta.new_sound
* StripsMeta.remove
* StripsTopLevel.new_clip
* StripsTopLevel.new_effect
* StripsTopLevel.new_effect
* StripsTopLevel.new_effect
* StripsTopLevel.new_image
* StripsTopLevel.new_mask
* StripsTopLevel.new_meta
* StripsTopLevel.new_movie
* StripsTopLevel.new_scene
* StripsTopLevel.new_sound
* StripsTopLevel.remove
* SubtractStrip.input_1
* SubtractStrip.input_2
* WipeStrip.input_1
* WipeStrip.input_2

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionChannelbags.new
* ActionChannelbags.remove
* ActionKeyframeStrip.channelbag
* ActionKeyframeStrip.channelbags

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.constraints

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FileAssetSelectParams.filter_asset_id

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.scenes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.selected_movieclip_tracks
* MovieTracking.tracks
* MovieTrackingObject.tracks
* MovieTrackingObjectPlaneTracks.active
* MovieTrackingObjectTracks.active
* MovieTrackingObjectTracks.new
* MovieTrackingStabilization.rotation_tracks
* MovieTrackingStabilization.tracks
* MovieTrackingTracks.active
* MovieTrackingTracks.new
* UILayout.template_marker

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.popover_begin__internal
* WindowManager.popover_end__internal

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ShapeKey.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AOVs.add
* AOVs.remove
* ViewLayer.active_aov
* ViewLayer.aovs

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSystem.active_particle_target
* ParticleSystem.targets

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ShapeKey.data

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* EffectStrip.transform
* ImageStrip.transform
* MaskStrip.transform
* MetaStrip.transform
* MovieClipStrip.transform
* MovieStrip.transform
* SceneStrip.transform

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.texture
* BlendData.textures
* BlendDataTextures.new
* BlendDataTextures.remove
* Brush.mask_texture
* Brush.texture
* DisplaceModifier.texture
* DynamicPaintSurface.init_texture
* FieldSettings.texture
* FluidFlowSettings.noise_texture
* FreestyleLineStyle.active_texture
* NodeSocketTexture.default_value
* NodeTreeInterfaceSocketTexture.default_value
* ParticleSettings.active_texture
* TextureNodeTexture.texture
* TextureSlot.texture
* VertexWeightEditModifier.mask_texture
* VertexWeightMixModifier.mask_texture
* VertexWeightProximityModifier.mask_texture
* VolumeDisplaceModifier.texture
* WarpModifier.texture
* WaveModifier.texture

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyingSet.paths

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Float4x4Attribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.statvis

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.node_groups

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.popmenu_begin__internal
* WindowManager.popmenu_end__internal

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceDopeSheetEditor.overlays

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Camera.stereo

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.armature
* BlendData.armatures
* BlendDataArmatures.new
* BlendDataArmatures.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeRepeatOutput.repeat_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Short2Attribute.data

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeRegions.sidebars

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Camera.background_images

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* IDOverrideLibrary.properties
* IDOverrideLibraryProperties.add
* IDOverrideLibraryProperties.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeRegions.channels

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.curves

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.common

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.edit_mask
* BlendData.masks
* BlendDataMasks.new
* BlendDataMasks.remove
* CompositorNodeMask.mask
* MaskStrip.mask
* NodeSocketMask.default_value
* NodeTreeInterfaceSocketMask.default_value
* SpaceClipEditor.mask
* SpaceImageEditor.mask
* StripModifier.input_mask_id
* StripsMeta.new_mask
* StripsTopLevel.new_mask

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* FreestyleLineStyle.thickness_modifiers
* LineStyleThicknessModifiers.new
* LineStyleThicknessModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderViews.active
* RenderViews.new
* RenderViews.remove
* RenderSettings.stereo_views
* RenderSettings.views

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeSeparateBundle.bundle_items
* NodeSeparateBundleItems.new
* NodeSeparateBundleItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* LatticePoint.groups
* MeshVertex.groups

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WorkSpace.tools
* wmTools.from_space_image_mode
* wmTools.from_space_node
* wmTools.from_space_sequencer
* wmTools.from_space_view3d_mode

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* NodeTree.color_tag
* NodeTree.default_group_node_width
* NodeTree.view_center
* NodeTree.description
* NodeTree.animation_data
* NodeTree.nodes
* NodeTree.links
* NodeTree.annotation
* NodeTree.type
* NodeTree.interface
* NodeTree.bl_idname
* NodeTree.bl_label
* NodeTree.bl_description
* NodeTree.bl_icon
* NodeTree.bl_use_group_interface

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* NodeTree.interface_update
* NodeTree.contains_tree
* NodeTree.poll
* NodeTree.update
* NodeTree.get_from_context
* NodeTree.valid_socket_type
* NodeTree.debug_lazy_function_graph
* NodeTree.bl_rna_get_subclass
* NodeTree.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSettings.active_instanceweight
* ParticleSettings.instance_weights

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WorkSpace.tools

:columns: 2


--------------------

* bpy_struct.id_data
* GreasePencilTreeNode.name
* GreasePencilTreeNode.hide
* GreasePencilTreeNode.lock
* GreasePencilTreeNode.select
* GreasePencilTreeNode.use_onion_skinning
* GreasePencilTreeNode.use_masks
* GreasePencilTreeNode.channel_color
* GreasePencilTreeNode.next_node
* GreasePencilTreeNode.prev_node
* GreasePencilTreeNode.parent_group

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* GreasePencilTreeNode.bl_rna_get_subclass
* GreasePencilTreeNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* GreasePencil.layer_groups
* GreasePencilTreeNode.parent_group
* GreasePencilv3LayerGroup.active
* GreasePencilv3LayerGroup.move
* GreasePencilv3LayerGroup.move_bottom
* GreasePencilv3LayerGroup.move_to_layer_group
* GreasePencilv3LayerGroup.move_to_layer_group
* GreasePencilv3LayerGroup.move_top
* GreasePencilv3LayerGroup.new
* GreasePencilv3LayerGroup.new
* GreasePencilv3LayerGroup.remove
* GreasePencilv3Layers.move_to_layer_group
* GreasePencilv3Layers.new

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionChannelbag.groups

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetMetaData.tags

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.experimental

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Material.grease_pencil

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Gizmo.properties

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* IDOverrideLibrary.properties

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeAlphaOver.input_template
* CompositorNodeAlphaOver.output_template
* CompositorNodeAntiAliasing.input_template
* CompositorNodeAntiAliasing.output_template
* CompositorNodeBilateralblur.input_template
* CompositorNodeBilateralblur.output_template
* CompositorNodeBlur.input_template
* CompositorNodeBlur.output_template
* CompositorNodeBokehBlur.input_template
* CompositorNodeBokehBlur.output_template
* CompositorNodeBokehImage.input_template
* CompositorNodeBokehImage.output_template
* CompositorNodeBoxMask.input_template
* CompositorNodeBoxMask.output_template
* CompositorNodeBrightContrast.input_template
* CompositorNodeBrightContrast.output_template
* CompositorNodeChannelMatte.input_template
* CompositorNodeChannelMatte.output_template
* CompositorNodeChromaMatte.input_template
* CompositorNodeChromaMatte.output_template
* CompositorNodeColorBalance.input_template
* CompositorNodeColorBalance.output_template
* CompositorNodeColorCorrection.input_template
* CompositorNodeColorCorrection.output_template
* CompositorNodeColorMatte.input_template
* CompositorNodeColorMatte.output_template
* CompositorNodeColorSpill.input_template
* CompositorNodeColorSpill.output_template
* CompositorNodeCombineColor.input_template
* CompositorNodeCombineColor.output_template
* CompositorNodeConvertColorSpace.input_template
* CompositorNodeConvertColorSpace.output_template
* CompositorNodeConvertToDisplay.input_template
* CompositorNodeConvertToDisplay.output_template
* CompositorNodeConvolve.input_template
* CompositorNodeConvolve.output_template
* CompositorNodeCornerPin.input_template
* CompositorNodeCornerPin.output_template
* CompositorNodeCrop.input_template
* CompositorNodeCrop.output_template
* CompositorNodeCryptomatte.input_template
* CompositorNodeCryptomatte.output_template
* CompositorNodeCryptomatteV2.input_template
* CompositorNodeCryptomatteV2.output_template
* CompositorNodeCurveRGB.input_template
* CompositorNodeCurveRGB.output_template
* CompositorNodeDBlur.input_template
* CompositorNodeDBlur.output_template
* CompositorNodeDefocus.input_template
* CompositorNodeDefocus.output_template
* CompositorNodeDenoise.input_template
* CompositorNodeDenoise.output_template
* CompositorNodeDespeckle.input_template
* CompositorNodeDespeckle.output_template
* CompositorNodeDiffMatte.input_template
* CompositorNodeDiffMatte.output_template
* CompositorNodeDilateErode.input_template
* CompositorNodeDilateErode.output_template
* CompositorNodeDisplace.input_template
* CompositorNodeDisplace.output_template
* CompositorNodeDistanceMatte.input_template
* CompositorNodeDistanceMatte.output_template
* CompositorNodeDoubleEdgeMask.input_template
* CompositorNodeDoubleEdgeMask.output_template
* CompositorNodeEllipseMask.input_template
* CompositorNodeEllipseMask.output_template
* CompositorNodeExposure.input_template
* CompositorNodeExposure.output_template
* CompositorNodeFilter.input_template
* CompositorNodeFilter.output_template
* CompositorNodeFlip.input_template
* CompositorNodeFlip.output_template
* CompositorNodeGamma.input_template
* CompositorNodeGamma.output_template
* CompositorNodeGlare.input_template
* CompositorNodeGlare.output_template
* CompositorNodeGroup.input_template
* CompositorNodeGroup.output_template
* CompositorNodeHueCorrect.input_template
* CompositorNodeHueCorrect.output_template
* CompositorNodeHueSat.input_template
* CompositorNodeHueSat.output_template
* CompositorNodeIDMask.input_template
* CompositorNodeIDMask.output_template
* CompositorNodeImage.input_template
* CompositorNodeImage.output_template
* CompositorNodeImageCoordinates.input_template
* CompositorNodeImageCoordinates.output_template
* CompositorNodeImageInfo.input_template
* CompositorNodeImageInfo.output_template
* CompositorNodeInpaint.input_template
* CompositorNodeInpaint.output_template
* CompositorNodeInvert.input_template
* CompositorNodeInvert.output_template
* CompositorNodeKeying.input_template
* CompositorNodeKeying.output_template
* CompositorNodeKeyingScreen.input_template
* CompositorNodeKeyingScreen.output_template
* CompositorNodeKuwahara.input_template
* CompositorNodeKuwahara.output_template
* CompositorNodeLensdist.input_template
* CompositorNodeLensdist.output_template
* CompositorNodeLevels.input_template
* CompositorNodeLevels.output_template
* CompositorNodeLumaMatte.input_template
* CompositorNodeLumaMatte.output_template
* CompositorNodeMapUV.input_template
* CompositorNodeMapUV.output_template
* CompositorNodeMask.input_template
* CompositorNodeMask.output_template
* CompositorNodeMaskToSDF.input_template
* CompositorNodeMaskToSDF.output_template
* CompositorNodeMovieClip.input_template
* CompositorNodeMovieClip.output_template
* CompositorNodeMovieDistortion.input_template
* CompositorNodeMovieDistortion.output_template
* CompositorNodeNormal.input_template
* CompositorNodeNormal.output_template
* CompositorNodeNormalize.input_template
* CompositorNodeNormalize.output_template
* CompositorNodeOutputFile.input_template
* CompositorNodeOutputFile.output_template
* CompositorNodePixelate.input_template
* CompositorNodePixelate.output_template
* CompositorNodePlaneTrackDeform.input_template
* CompositorNodePlaneTrackDeform.output_template
* CompositorNodePosterize.input_template
* CompositorNodePosterize.output_template
* CompositorNodePremulKey.input_template
* CompositorNodePremulKey.output_template
* CompositorNodeRGB.input_template
* CompositorNodeRGB.output_template
* CompositorNodeRGBToBW.input_template
* CompositorNodeRGBToBW.output_template
* CompositorNodeRLayers.input_template
* CompositorNodeRLayers.output_template
* CompositorNodeRelativeToPixel.input_template
* CompositorNodeRelativeToPixel.output_template
* CompositorNodeRotate.input_template
* CompositorNodeRotate.output_template
* CompositorNodeScale.input_template
* CompositorNodeScale.output_template
* CompositorNodeSceneTime.input_template
* CompositorNodeSceneTime.output_template
* CompositorNodeSeparateColor.input_template
* CompositorNodeSeparateColor.output_template
* CompositorNodeSequencerStripInfo.input_template
* CompositorNodeSequencerStripInfo.output_template
* CompositorNodeSetAlpha.input_template
* CompositorNodeSetAlpha.output_template
* CompositorNodeSplit.input_template
* CompositorNodeSplit.output_template
* CompositorNodeStabilize.input_template
* CompositorNodeStabilize.output_template
* CompositorNodeSwitch.input_template
* CompositorNodeSwitch.output_template
* CompositorNodeSwitchView.input_template
* CompositorNodeSwitchView.output_template
* CompositorNodeTime.input_template
* CompositorNodeTime.output_template
* CompositorNodeTonemap.input_template
* CompositorNodeTonemap.output_template
* CompositorNodeTrackPos.input_template
* CompositorNodeTrackPos.output_template
* CompositorNodeTransform.input_template
* CompositorNodeTransform.output_template
* CompositorNodeTranslate.input_template
* CompositorNodeTranslate.output_template
* CompositorNodeVecBlur.input_template
* CompositorNodeVecBlur.output_template
* CompositorNodeViewer.input_template
* CompositorNodeViewer.output_template
* CompositorNodeZcombine.input_template
* CompositorNodeZcombine.output_template
* FunctionNodeAlignEulerToVector.input_template
* FunctionNodeAlignEulerToVector.output_template
* FunctionNodeAlignRotationToVector.input_template
* FunctionNodeAlignRotationToVector.output_template
* FunctionNodeAxesToRotation.input_template
* FunctionNodeAxesToRotation.output_template
* FunctionNodeAxisAngleToRotation.input_template
* FunctionNodeAxisAngleToRotation.output_template
* FunctionNodeBitMath.input_template
* FunctionNodeBitMath.output_template
* FunctionNodeBooleanMath.input_template
* FunctionNodeBooleanMath.output_template
* FunctionNodeCombineColor.input_template
* FunctionNodeCombineColor.output_template
* FunctionNodeCombineMatrix.input_template
* FunctionNodeCombineMatrix.output_template
* FunctionNodeCombineTransform.input_template
* FunctionNodeCombineTransform.output_template
* FunctionNodeCompare.input_template
* FunctionNodeCompare.output_template
* FunctionNodeEulerToRotation.input_template
* FunctionNodeEulerToRotation.output_template
* FunctionNodeFindInString.input_template
* FunctionNodeFindInString.output_template
* FunctionNodeFloatToInt.input_template
* FunctionNodeFloatToInt.output_template
* FunctionNodeFormatString.input_template
* FunctionNodeFormatString.output_template
* FunctionNodeHashValue.input_template
* FunctionNodeHashValue.output_template
* FunctionNodeInputBool.input_template
* FunctionNodeInputBool.output_template
* FunctionNodeInputColor.input_template
* FunctionNodeInputColor.output_template
* FunctionNodeInputInt.input_template
* FunctionNodeInputInt.output_template
* FunctionNodeInputMenu.input_template
* FunctionNodeInputMenu.output_template
* FunctionNodeInputRotation.input_template
* FunctionNodeInputRotation.output_template
* FunctionNodeInputSpecialCharacters.input_template
* FunctionNodeInputSpecialCharacters.output_template
* FunctionNodeInputString.input_template
* FunctionNodeInputString.output_template
* FunctionNodeInputVector.input_template
* FunctionNodeInputVector.output_template
* FunctionNodeIntegerMath.input_template
* FunctionNodeIntegerMath.output_template
* FunctionNodeInvertMatrix.input_template
* FunctionNodeInvertMatrix.output_template
* FunctionNodeInvertRotation.input_template
* FunctionNodeInvertRotation.output_template
* FunctionNodeMatchString.input_template
* FunctionNodeMatchString.output_template
* FunctionNodeMatrixDeterminant.input_template
* FunctionNodeMatrixDeterminant.output_template
* FunctionNodeMatrixMultiply.input_template
* FunctionNodeMatrixMultiply.output_template
* FunctionNodeMatrixSVD.input_template
* FunctionNodeMatrixSVD.output_template
* FunctionNodeProjectPoint.input_template
* FunctionNodeProjectPoint.output_template
* FunctionNodeQuaternionToRotation.input_template
* FunctionNodeQuaternionToRotation.output_template
* FunctionNodeRandomValue.input_template
* FunctionNodeRandomValue.output_template
* FunctionNodeReplaceString.input_template
* FunctionNodeReplaceString.output_template
* FunctionNodeRotateEuler.input_template
* FunctionNodeRotateEuler.output_template
* FunctionNodeRotateRotation.input_template
* FunctionNodeRotateRotation.output_template
* FunctionNodeRotateVector.input_template
* FunctionNodeRotateVector.output_template
* FunctionNodeRotationToAxisAngle.input_template
* FunctionNodeRotationToAxisAngle.output_template
* FunctionNodeRotationToEuler.input_template
* FunctionNodeRotationToEuler.output_template
* FunctionNodeRotationToQuaternion.input_template
* FunctionNodeRotationToQuaternion.output_template
* FunctionNodeSeparateColor.input_template
* FunctionNodeSeparateColor.output_template
* FunctionNodeSeparateMatrix.input_template
* FunctionNodeSeparateMatrix.output_template
* FunctionNodeSeparateTransform.input_template
* FunctionNodeSeparateTransform.output_template
* FunctionNodeSliceString.input_template
* FunctionNodeSliceString.output_template
* FunctionNodeStringLength.input_template
* FunctionNodeStringLength.output_template
* FunctionNodeStringToValue.input_template
* FunctionNodeStringToValue.output_template
* FunctionNodeTransformDirection.input_template
* FunctionNodeTransformDirection.output_template
* FunctionNodeTransformPoint.input_template
* FunctionNodeTransformPoint.output_template
* FunctionNodeTransposeMatrix.input_template
* FunctionNodeTransposeMatrix.output_template
* FunctionNodeValueToString.input_template
* FunctionNodeValueToString.output_template
* GeometryNodeAccumulateField.input_template
* GeometryNodeAccumulateField.output_template
* GeometryNodeAttributeDomainSize.input_template
* GeometryNodeAttributeDomainSize.output_template
* GeometryNodeAttributeStatistic.input_template
* GeometryNodeAttributeStatistic.output_template
* GeometryNodeBake.input_template
* GeometryNodeBake.output_template
* GeometryNodeBlurAttribute.input_template
* GeometryNodeBlurAttribute.output_template
* GeometryNodeBoneInfo.input_template
* GeometryNodeBoneInfo.output_template
* GeometryNodeBoundBox.input_template
* GeometryNodeBoundBox.output_template
* GeometryNodeCameraInfo.input_template
* GeometryNodeCameraInfo.output_template
* GeometryNodeCaptureAttribute.input_template
* GeometryNodeCaptureAttribute.output_template
* GeometryNodeCollectionChildren.input_template
* GeometryNodeCollectionChildren.output_template
* GeometryNodeCollectionInfo.input_template
* GeometryNodeCollectionInfo.output_template
* GeometryNodeConvexHull.input_template
* GeometryNodeConvexHull.output_template
* GeometryNodeCornersOfEdge.input_template
* GeometryNodeCornersOfEdge.output_template
* GeometryNodeCornersOfFace.input_template
* GeometryNodeCornersOfFace.output_template
* GeometryNodeCornersOfVertex.input_template
* GeometryNodeCornersOfVertex.output_template
* GeometryNodeCubeGridTopology.input_template
* GeometryNodeCubeGridTopology.output_template
* GeometryNodeCurveArc.input_template
* GeometryNodeCurveArc.output_template
* GeometryNodeCurveEndpointSelection.input_template
* GeometryNodeCurveEndpointSelection.output_template
* GeometryNodeCurveHandleTypeSelection.input_template
* GeometryNodeCurveHandleTypeSelection.output_template
* GeometryNodeCurveLength.input_template
* GeometryNodeCurveLength.output_template
* GeometryNodeCurveOfPoint.input_template
* GeometryNodeCurveOfPoint.output_template
* GeometryNodeCurvePrimitiveBezierSegment.input_template
* GeometryNodeCurvePrimitiveBezierSegment.output_template
* GeometryNodeCurvePrimitiveCircle.input_template
* GeometryNodeCurvePrimitiveCircle.output_template
* GeometryNodeCurvePrimitiveLine.input_template
* GeometryNodeCurvePrimitiveLine.output_template
* GeometryNodeCurvePrimitiveQuadrilateral.input_template
* GeometryNodeCurvePrimitiveQuadrilateral.output_template
* GeometryNodeCurveQuadraticBezier.input_template
* GeometryNodeCurveQuadraticBezier.output_template
* GeometryNodeCurveSetHandles.input_template
* GeometryNodeCurveSetHandles.output_template
* GeometryNodeCurveSpiral.input_template
* GeometryNodeCurveSpiral.output_template
* GeometryNodeCurveSplineType.input_template
* GeometryNodeCurveSplineType.output_template
* GeometryNodeCurveStar.input_template
* GeometryNodeCurveStar.output_template
* GeometryNodeCurveToMesh.input_template
* GeometryNodeCurveToMesh.output_template
* GeometryNodeCurveToPoints.input_template
* GeometryNodeCurveToPoints.output_template
* GeometryNodeCurvesToGreasePencil.input_template
* GeometryNodeCurvesToGreasePencil.output_template
* GeometryNodeDeformCurvesOnSurface.input_template
* GeometryNodeDeformCurvesOnSurface.output_template
* GeometryNodeDeleteGeometry.input_template
* GeometryNodeDeleteGeometry.output_template
* GeometryNodeDistributePointsInGrid.input_template
* GeometryNodeDistributePointsInGrid.output_template
* GeometryNodeDistributePointsInVolume.input_template
* GeometryNodeDistributePointsInVolume.output_template
* GeometryNodeDistributePointsOnFaces.input_template
* GeometryNodeDistributePointsOnFaces.output_template
* GeometryNodeDualMesh.input_template
* GeometryNodeDualMesh.output_template
* GeometryNodeDuplicateElements.input_template
* GeometryNodeDuplicateElements.output_template
* GeometryNodeEdgePathsToCurves.input_template
* GeometryNodeEdgePathsToCurves.output_template
* GeometryNodeEdgePathsToSelection.input_template
* GeometryNodeEdgePathsToSelection.output_template
* GeometryNodeEdgesOfCorner.input_template
* GeometryNodeEdgesOfCorner.output_template
* GeometryNodeEdgesOfVertex.input_template
* GeometryNodeEdgesOfVertex.output_template
* GeometryNodeEdgesToFaceGroups.input_template
* GeometryNodeEdgesToFaceGroups.output_template
* GeometryNodeExtrudeMesh.input_template
* GeometryNodeExtrudeMesh.output_template
* GeometryNodeFaceOfCorner.input_template
* GeometryNodeFaceOfCorner.output_template
* GeometryNodeFieldAtIndex.input_template
* GeometryNodeFieldAtIndex.output_template
* GeometryNodeFieldAverage.input_template
* GeometryNodeFieldAverage.output_template
* GeometryNodeFieldMinAndMax.input_template
* GeometryNodeFieldMinAndMax.output_template
* GeometryNodeFieldOnDomain.input_template
* GeometryNodeFieldOnDomain.output_template
* GeometryNodeFieldToGrid.input_template
* GeometryNodeFieldToGrid.output_template
* GeometryNodeFieldToList.input_template
* GeometryNodeFieldToList.output_template
* GeometryNodeFieldVariance.input_template
* GeometryNodeFieldVariance.output_template
* GeometryNodeFillCurve.input_template
* GeometryNodeFillCurve.output_template
* GeometryNodeFilletCurve.input_template
* GeometryNodeFilletCurve.output_template
* GeometryNodeFlipFaces.input_template
* GeometryNodeFlipFaces.output_template
* GeometryNodeForeachGeometryElementInput.input_template
* GeometryNodeForeachGeometryElementInput.output_template
* GeometryNodeForeachGeometryElementOutput.input_template
* GeometryNodeForeachGeometryElementOutput.output_template
* GeometryNodeGeometryToInstance.input_template
* GeometryNodeGeometryToInstance.output_template
* GeometryNodeGetGeometryBundle.input_template
* GeometryNodeGetGeometryBundle.output_template
* GeometryNodeGetNamedGrid.input_template
* GeometryNodeGetNamedGrid.output_template
* GeometryNodeGizmoDial.input_template
* GeometryNodeGizmoDial.output_template
* GeometryNodeGizmoLinear.input_template
* GeometryNodeGizmoLinear.output_template
* GeometryNodeGizmoTransform.input_template
* GeometryNodeGizmoTransform.output_template
* GeometryNodeGreasePencilToCurves.input_template
* GeometryNodeGreasePencilToCurves.output_template
* GeometryNodeGridAdvect.input_template
* GeometryNodeGridAdvect.output_template
* GeometryNodeGridClip.input_template
* GeometryNodeGridClip.output_template
* GeometryNodeGridCurl.input_template
* GeometryNodeGridCurl.output_template
* GeometryNodeGridDilateAndErode.input_template
* GeometryNodeGridDilateAndErode.output_template
* GeometryNodeGridDivergence.input_template
* GeometryNodeGridDivergence.output_template
* GeometryNodeGridGradient.input_template
* GeometryNodeGridGradient.output_template
* GeometryNodeGridInfo.input_template
* GeometryNodeGridInfo.output_template
* GeometryNodeGridLaplacian.input_template
* GeometryNodeGridLaplacian.output_template
* GeometryNodeGridMean.input_template
* GeometryNodeGridMean.output_template
* GeometryNodeGridMedian.input_template
* GeometryNodeGridMedian.output_template
* GeometryNodeGridPrune.input_template
* GeometryNodeGridPrune.output_template
* GeometryNodeGridToMesh.input_template
* GeometryNodeGridToMesh.output_template
* GeometryNodeGridToPoints.input_template
* GeometryNodeGridToPoints.output_template
* GeometryNodeGridVoxelize.input_template
* GeometryNodeGridVoxelize.output_template
* GeometryNodeGroup.input_template
* GeometryNodeGroup.output_template
* GeometryNodeImageInfo.input_template
* GeometryNodeImageInfo.output_template
* GeometryNodeImageTexture.input_template
* GeometryNodeImageTexture.output_template
* GeometryNodeImportCSV.input_template
* GeometryNodeImportCSV.output_template
* GeometryNodeImportOBJ.input_template
* GeometryNodeImportOBJ.output_template
* GeometryNodeImportPLY.input_template
* GeometryNodeImportPLY.output_template
* GeometryNodeImportSTL.input_template
* GeometryNodeImportSTL.output_template
* GeometryNodeImportText.input_template
* GeometryNodeImportText.output_template
* GeometryNodeImportVDB.input_template
* GeometryNodeImportVDB.output_template
* GeometryNodeIndexOfNearest.input_template
* GeometryNodeIndexOfNearest.output_template
* GeometryNodeIndexSwitch.input_template
* GeometryNodeIndexSwitch.output_template
* GeometryNodeInputActiveCamera.input_template
* GeometryNodeInputActiveCamera.output_template
* GeometryNodeInputCollection.input_template
* GeometryNodeInputCollection.output_template
* GeometryNodeInputCurveHandlePositions.input_template
* GeometryNodeInputCurveHandlePositions.output_template
* GeometryNodeInputCurveTilt.input_template
* GeometryNodeInputCurveTilt.output_template
* GeometryNodeInputEdgeSmooth.input_template
* GeometryNodeInputEdgeSmooth.output_template
* GeometryNodeInputFont.input_template
* GeometryNodeInputFont.output_template
* GeometryNodeInputID.input_template
* GeometryNodeInputID.output_template
* GeometryNodeInputImage.input_template
* GeometryNodeInputImage.output_template
* GeometryNodeInputIndex.input_template
* GeometryNodeInputIndex.output_template
* GeometryNodeInputInstanceBounds.input_template
* GeometryNodeInputInstanceBounds.output_template
* GeometryNodeInputInstanceRotation.input_template
* GeometryNodeInputInstanceRotation.output_template
* GeometryNodeInputInstanceScale.input_template
* GeometryNodeInputInstanceScale.output_template
* GeometryNodeInputMaterial.input_template
* GeometryNodeInputMaterial.output_template
* GeometryNodeInputMaterialIndex.input_template
* GeometryNodeInputMaterialIndex.output_template
* GeometryNodeInputMeshEdgeAngle.input_template
* GeometryNodeInputMeshEdgeAngle.output_template
* GeometryNodeInputMeshEdgeNeighbors.input_template
* GeometryNodeInputMeshEdgeNeighbors.output_template
* GeometryNodeInputMeshEdgeVertices.input_template
* GeometryNodeInputMeshEdgeVertices.output_template
* GeometryNodeInputMeshFaceArea.input_template
* GeometryNodeInputMeshFaceArea.output_template
* GeometryNodeInputMeshFaceIsPlanar.input_template
* GeometryNodeInputMeshFaceIsPlanar.output_template
* GeometryNodeInputMeshFaceNeighbors.input_template
* GeometryNodeInputMeshFaceNeighbors.output_template
* GeometryNodeInputMeshIsland.input_template
* GeometryNodeInputMeshIsland.output_template
* GeometryNodeInputMeshVertexNeighbors.input_template
* GeometryNodeInputMeshVertexNeighbors.output_template
* GeometryNodeInputNamedAttribute.input_template
* GeometryNodeInputNamedAttribute.output_template
* GeometryNodeInputNamedLayerSelection.input_template
* GeometryNodeInputNamedLayerSelection.output_template
* GeometryNodeInputNormal.input_template
* GeometryNodeInputNormal.output_template
* GeometryNodeInputObject.input_template
* GeometryNodeInputObject.output_template
* GeometryNodeInputPosition.input_template
* GeometryNodeInputPosition.output_template
* GeometryNodeInputRadius.input_template
* GeometryNodeInputRadius.output_template
* GeometryNodeInputSceneTime.input_template
* GeometryNodeInputSceneTime.output_template
* GeometryNodeInputShadeSmooth.input_template
* GeometryNodeInputShadeSmooth.output_template
* GeometryNodeInputShortestEdgePaths.input_template
* GeometryNodeInputShortestEdgePaths.output_template
* GeometryNodeInputSplineCyclic.input_template
* GeometryNodeInputSplineCyclic.output_template
* GeometryNodeInputSplineResolution.input_template
* GeometryNodeInputSplineResolution.output_template
* GeometryNodeInputTangent.input_template
* GeometryNodeInputTangent.output_template
* GeometryNodeInputVoxelIndex.input_template
* GeometryNodeInputVoxelIndex.output_template
* GeometryNodeInstanceOnPoints.input_template
* GeometryNodeInstanceOnPoints.output_template
* GeometryNodeInstanceTransform.input_template
* GeometryNodeInstanceTransform.output_template
* GeometryNodeInstancesToPoints.input_template
* GeometryNodeInstancesToPoints.output_template
* GeometryNodeInterpolateCurves.input_template
* GeometryNodeInterpolateCurves.output_template
* GeometryNodeIsViewport.input_template
* GeometryNodeIsViewport.output_template
* GeometryNodeJoinGeometry.input_template
* GeometryNodeJoinGeometry.output_template
* GeometryNodeListGetItem.input_template
* GeometryNodeListGetItem.output_template
* GeometryNodeListLength.input_template
* GeometryNodeListLength.output_template
* GeometryNodeMaterialSelection.input_template
* GeometryNodeMaterialSelection.output_template
* GeometryNodeMenuSwitch.input_template
* GeometryNodeMenuSwitch.output_template
* GeometryNodeMergeByDistance.input_template
* GeometryNodeMergeByDistance.output_template
* GeometryNodeMergeLayers.input_template
* GeometryNodeMergeLayers.output_template
* GeometryNodeMeshBoolean.input_template
* GeometryNodeMeshBoolean.output_template
* GeometryNodeMeshCircle.input_template
* GeometryNodeMeshCircle.output_template
* GeometryNodeMeshCone.input_template
* GeometryNodeMeshCone.output_template
* GeometryNodeMeshCube.input_template
* GeometryNodeMeshCube.output_template
* GeometryNodeMeshCylinder.input_template
* GeometryNodeMeshCylinder.output_template
* GeometryNodeMeshFaceSetBoundaries.input_template
* GeometryNodeMeshFaceSetBoundaries.output_template
* GeometryNodeMeshGrid.input_template
* GeometryNodeMeshGrid.output_template
* GeometryNodeMeshIcoSphere.input_template
* GeometryNodeMeshIcoSphere.output_template
* GeometryNodeMeshLine.input_template
* GeometryNodeMeshLine.output_template
* GeometryNodeMeshToCurve.input_template
* GeometryNodeMeshToCurve.output_template
* GeometryNodeMeshToDensityGrid.input_template
* GeometryNodeMeshToDensityGrid.output_template
* GeometryNodeMeshToPoints.input_template
* GeometryNodeMeshToPoints.output_template
* GeometryNodeMeshToSDFGrid.input_template
* GeometryNodeMeshToSDFGrid.output_template
* GeometryNodeMeshToVolume.input_template
* GeometryNodeMeshToVolume.output_template
* GeometryNodeMeshUVSphere.input_template
* GeometryNodeMeshUVSphere.output_template
* GeometryNodeObjectInfo.input_template
* GeometryNodeObjectInfo.output_template
* GeometryNodeOffsetCornerInFace.input_template
* GeometryNodeOffsetCornerInFace.output_template
* GeometryNodeOffsetPointInCurve.input_template
* GeometryNodeOffsetPointInCurve.output_template
* GeometryNodePoints.input_template
* GeometryNodePoints.output_template
* GeometryNodePointsOfCurve.input_template
* GeometryNodePointsOfCurve.output_template
* GeometryNodePointsToCurves.input_template
* GeometryNodePointsToCurves.output_template
* GeometryNodePointsToSDFGrid.input_template
* GeometryNodePointsToSDFGrid.output_template
* GeometryNodePointsToVertices.input_template
* GeometryNodePointsToVertices.output_template
* GeometryNodePointsToVolume.input_template
* GeometryNodePointsToVolume.output_template
* GeometryNodeProximity.input_template
* GeometryNodeProximity.output_template
* GeometryNodeRaycast.input_template
* GeometryNodeRaycast.output_template
* GeometryNodeRealizeInstances.input_template
* GeometryNodeRealizeInstances.output_template
* GeometryNodeRemoveAttribute.input_template
* GeometryNodeRemoveAttribute.output_template
* GeometryNodeRepeatInput.input_template
* GeometryNodeRepeatInput.output_template
* GeometryNodeRepeatOutput.input_template
* GeometryNodeRepeatOutput.output_template
* GeometryNodeReplaceMaterial.input_template
* GeometryNodeReplaceMaterial.output_template
* GeometryNodeResampleCurve.input_template
* GeometryNodeResampleCurve.output_template
* GeometryNodeReverseCurve.input_template
* GeometryNodeReverseCurve.output_template
* GeometryNodeRotateInstances.input_template
* GeometryNodeRotateInstances.output_template
* GeometryNodeSDFGridBoolean.input_template
* GeometryNodeSDFGridBoolean.output_template
* GeometryNodeSDFGridFillet.input_template
* GeometryNodeSDFGridFillet.output_template
* GeometryNodeSDFGridLaplacian.input_template
* GeometryNodeSDFGridLaplacian.output_template
* GeometryNodeSDFGridMean.input_template
* GeometryNodeSDFGridMean.output_template
* GeometryNodeSDFGridMeanCurvature.input_template
* GeometryNodeSDFGridMeanCurvature.output_template
* GeometryNodeSDFGridMedian.input_template
* GeometryNodeSDFGridMedian.output_template
* GeometryNodeSDFGridOffset.input_template
* GeometryNodeSDFGridOffset.output_template
* GeometryNodeSampleCurve.input_template
* GeometryNodeSampleCurve.output_template
* GeometryNodeSampleGrid.input_template
* GeometryNodeSampleGrid.output_template
* GeometryNodeSampleGridIndex.input_template
* GeometryNodeSampleGridIndex.output_template
* GeometryNodeSampleIndex.input_template
* GeometryNodeSampleIndex.output_template
* GeometryNodeSampleNearest.input_template
* GeometryNodeSampleNearest.output_template
* GeometryNodeSampleNearestSurface.input_template
* GeometryNodeSampleNearestSurface.output_template
* GeometryNodeSampleUVSurface.input_template
* GeometryNodeSampleUVSurface.output_template
* GeometryNodeScaleElements.input_template
* GeometryNodeScaleElements.output_template
* GeometryNodeScaleInstances.input_template
* GeometryNodeScaleInstances.output_template
* GeometryNodeSelfObject.input_template
* GeometryNodeSelfObject.output_template
* GeometryNodeSeparateComponents.input_template
* GeometryNodeSeparateComponents.output_template
* GeometryNodeSeparateGeometry.input_template
* GeometryNodeSeparateGeometry.output_template
* GeometryNodeSetCurveHandlePositions.input_template
* GeometryNodeSetCurveHandlePositions.output_template
* GeometryNodeSetCurveNormal.input_template
* GeometryNodeSetCurveNormal.output_template
* GeometryNodeSetCurveOrder.input_template
* GeometryNodeSetCurveOrder.output_template
* GeometryNodeSetCurveRadius.input_template
* GeometryNodeSetCurveRadius.output_template
* GeometryNodeSetCurveTilt.input_template
* GeometryNodeSetCurveTilt.output_template
* GeometryNodeSetGeometryBundle.input_template
* GeometryNodeSetGeometryBundle.output_template
* GeometryNodeSetGeometryName.input_template
* GeometryNodeSetGeometryName.output_template
* GeometryNodeSetGreasePencilColor.input_template
* GeometryNodeSetGreasePencilColor.output_template
* GeometryNodeSetGreasePencilDepth.input_template
* GeometryNodeSetGreasePencilDepth.output_template
* GeometryNodeSetGreasePencilSoftness.input_template
* GeometryNodeSetGreasePencilSoftness.output_template
* GeometryNodeSetGridBackground.input_template
* GeometryNodeSetGridBackground.output_template
* GeometryNodeSetGridTransform.input_template
* GeometryNodeSetGridTransform.output_template
* GeometryNodeSetID.input_template
* GeometryNodeSetID.output_template
* GeometryNodeSetInstanceTransform.input_template
* GeometryNodeSetInstanceTransform.output_template
* GeometryNodeSetMaterial.input_template
* GeometryNodeSetMaterial.output_template
* GeometryNodeSetMaterialIndex.input_template
* GeometryNodeSetMaterialIndex.output_template
* GeometryNodeSetMeshNormal.input_template
* GeometryNodeSetMeshNormal.output_template
* GeometryNodeSetPointRadius.input_template
* GeometryNodeSetPointRadius.output_template
* GeometryNodeSetPosition.input_template
* GeometryNodeSetPosition.output_template
* GeometryNodeSetShadeSmooth.input_template
* GeometryNodeSetShadeSmooth.output_template
* GeometryNodeSetSplineCyclic.input_template
* GeometryNodeSetSplineCyclic.output_template
* GeometryNodeSetSplineResolution.input_template
* GeometryNodeSetSplineResolution.output_template
* GeometryNodeSimulationInput.input_template
* GeometryNodeSimulationInput.output_template
* GeometryNodeSimulationOutput.input_template
* GeometryNodeSimulationOutput.output_template
* GeometryNodeSortElements.input_template
* GeometryNodeSortElements.output_template
* GeometryNodeSplineLength.input_template
* GeometryNodeSplineLength.output_template
* GeometryNodeSplineParameter.input_template
* GeometryNodeSplineParameter.output_template
* GeometryNodeSplitEdges.input_template
* GeometryNodeSplitEdges.output_template
* GeometryNodeSplitToInstances.input_template
* GeometryNodeSplitToInstances.output_template
* GeometryNodeStoreNamedAttribute.input_template
* GeometryNodeStoreNamedAttribute.output_template
* GeometryNodeStoreNamedGrid.input_template
* GeometryNodeStoreNamedGrid.output_template
* GeometryNodeStringJoin.input_template
* GeometryNodeStringJoin.output_template
* GeometryNodeStringToCurves.input_template
* GeometryNodeStringToCurves.output_template
* GeometryNodeSubdivideCurve.input_template
* GeometryNodeSubdivideCurve.output_template
* GeometryNodeSubdivideMesh.input_template
* GeometryNodeSubdivideMesh.output_template
* GeometryNodeSubdivisionSurface.input_template
* GeometryNodeSubdivisionSurface.output_template
* GeometryNodeSwitch.input_template
* GeometryNodeSwitch.output_template
* GeometryNodeTool3DCursor.input_template
* GeometryNodeTool3DCursor.output_template
* GeometryNodeToolActiveElement.input_template
* GeometryNodeToolActiveElement.output_template
* GeometryNodeToolFaceSet.input_template
* GeometryNodeToolFaceSet.output_template
* GeometryNodeToolMousePosition.input_template
* GeometryNodeToolMousePosition.output_template
* GeometryNodeToolSelection.input_template
* GeometryNodeToolSelection.output_template
* GeometryNodeToolSetFaceSet.input_template
* GeometryNodeToolSetFaceSet.output_template
* GeometryNodeToolSetSelection.input_template
* GeometryNodeToolSetSelection.output_template
* GeometryNodeTransform.input_template
* GeometryNodeTransform.output_template
* GeometryNodeTranslateInstances.input_template
* GeometryNodeTranslateInstances.output_template
* GeometryNodeTriangulate.input_template
* GeometryNodeTriangulate.output_template
* GeometryNodeTrimCurve.input_template
* GeometryNodeTrimCurve.output_template
* GeometryNodeUVPackIslands.input_template
* GeometryNodeUVPackIslands.output_template
* GeometryNodeUVTangent.input_template
* GeometryNodeUVTangent.output_template
* GeometryNodeUVUnwrap.input_template
* GeometryNodeUVUnwrap.output_template
* GeometryNodeVertexOfCorner.input_template
* GeometryNodeVertexOfCorner.output_template
* GeometryNodeViewer.input_template
* GeometryNodeViewer.output_template
* GeometryNodeViewportTransform.input_template
* GeometryNodeViewportTransform.output_template
* GeometryNodeVolumeCube.input_template
* GeometryNodeVolumeCube.output_template
* GeometryNodeVolumeToMesh.input_template
* GeometryNodeVolumeToMesh.output_template
* GeometryNodeWarning.input_template
* GeometryNodeWarning.output_template
* NodeClosureInput.input_template
* NodeClosureInput.output_template
* NodeClosureOutput.input_template
* NodeClosureOutput.output_template
* NodeCombineBundle.input_template
* NodeCombineBundle.output_template
* NodeEnableOutput.input_template
* NodeEnableOutput.output_template
* NodeEvaluateClosure.input_template
* NodeEvaluateClosure.output_template
* NodeFrame.input_template
* NodeFrame.output_template
* NodeGetBundleItem.input_template
* NodeGetBundleItem.output_template
* NodeGroup.input_template
* NodeGroup.output_template
* NodeGroupInput.input_template
* NodeGroupInput.output_template
* NodeGroupOutput.input_template
* NodeGroupOutput.output_template
* NodeImplicitConversion.input_template
* NodeImplicitConversion.output_template
* NodeJoinBundle.input_template
* NodeJoinBundle.output_template
* NodeReroute.input_template
* NodeReroute.output_template
* NodeSeparateBundle.input_template
* NodeSeparateBundle.output_template
* NodeStoreBundleItem.input_template
* NodeStoreBundleItem.output_template
* ShaderNodeAddShader.input_template
* ShaderNodeAddShader.output_template
* ShaderNodeAmbientOcclusion.input_template
* ShaderNodeAmbientOcclusion.output_template
* ShaderNodeAttribute.input_template
* ShaderNodeAttribute.output_template
* ShaderNodeBackground.input_template
* ShaderNodeBackground.output_template
* ShaderNodeBevel.input_template
* ShaderNodeBevel.output_template
* ShaderNodeBlackbody.input_template
* ShaderNodeBlackbody.output_template
* ShaderNodeBrightContrast.input_template
* ShaderNodeBrightContrast.output_template
* ShaderNodeBsdfAnisotropic.input_template
* ShaderNodeBsdfAnisotropic.output_template
* ShaderNodeBsdfDiffuse.input_template
* ShaderNodeBsdfDiffuse.output_template
* ShaderNodeBsdfGlass.input_template
* ShaderNodeBsdfGlass.output_template
* ShaderNodeBsdfHair.input_template
* ShaderNodeBsdfHair.output_template
* ShaderNodeBsdfHairPrincipled.input_template
* ShaderNodeBsdfHairPrincipled.output_template
* ShaderNodeBsdfMetallic.input_template
* ShaderNodeBsdfMetallic.output_template
* ShaderNodeBsdfPrincipled.input_template
* ShaderNodeBsdfPrincipled.output_template
* ShaderNodeBsdfRayPortal.input_template
* ShaderNodeBsdfRayPortal.output_template
* ShaderNodeBsdfRefraction.input_template
* ShaderNodeBsdfRefraction.output_template
* ShaderNodeBsdfSheen.input_template
* ShaderNodeBsdfSheen.output_template
* ShaderNodeBsdfToon.input_template
* ShaderNodeBsdfToon.output_template
* ShaderNodeBsdfTranslucent.input_template
* ShaderNodeBsdfTranslucent.output_template
* ShaderNodeBsdfTransparent.input_template
* ShaderNodeBsdfTransparent.output_template
* ShaderNodeBump.input_template
* ShaderNodeBump.output_template
* ShaderNodeCameraData.input_template
* ShaderNodeCameraData.output_template
* ShaderNodeClamp.input_template
* ShaderNodeClamp.output_template
* ShaderNodeCombineColor.input_template
* ShaderNodeCombineColor.output_template
* ShaderNodeCombineXYZ.input_template
* ShaderNodeCombineXYZ.output_template
* ShaderNodeDisplacement.input_template
* ShaderNodeDisplacement.output_template
* ShaderNodeEeveeSpecular.input_template
* ShaderNodeEeveeSpecular.output_template
* ShaderNodeEmission.input_template
* ShaderNodeEmission.output_template
* ShaderNodeFloatCurve.input_template
* ShaderNodeFloatCurve.output_template
* ShaderNodeFresnel.input_template
* ShaderNodeFresnel.output_template
* ShaderNodeGamma.input_template
* ShaderNodeGamma.output_template
* ShaderNodeGroup.input_template
* ShaderNodeGroup.output_template
* ShaderNodeHairInfo.input_template
* ShaderNodeHairInfo.output_template
* ShaderNodeHoldout.input_template
* ShaderNodeHoldout.output_template
* ShaderNodeHueSaturation.input_template
* ShaderNodeHueSaturation.output_template
* ShaderNodeInvert.input_template
* ShaderNodeInvert.output_template
* ShaderNodeLayerWeight.input_template
* ShaderNodeLayerWeight.output_template
* ShaderNodeLightFalloff.input_template
* ShaderNodeLightFalloff.output_template
* ShaderNodeLightPath.input_template
* ShaderNodeLightPath.output_template
* ShaderNodeMapRange.input_template
* ShaderNodeMapRange.output_template
* ShaderNodeMapping.input_template
* ShaderNodeMapping.output_template
* ShaderNodeMath.input_template
* ShaderNodeMath.output_template
* ShaderNodeMix.input_template
* ShaderNodeMix.output_template
* ShaderNodeMixRGB.input_template
* ShaderNodeMixRGB.output_template
* ShaderNodeMixShader.input_template
* ShaderNodeMixShader.output_template
* ShaderNodeNewGeometry.input_template
* ShaderNodeNewGeometry.output_template
* ShaderNodeNormal.input_template
* ShaderNodeNormal.output_template
* ShaderNodeNormalMap.input_template
* ShaderNodeNormalMap.output_template
* ShaderNodeObjectInfo.input_template
* ShaderNodeObjectInfo.output_template
* ShaderNodeOutputAOV.input_template
* ShaderNodeOutputAOV.output_template
* ShaderNodeOutputLight.input_template
* ShaderNodeOutputLight.output_template
* ShaderNodeOutputLineStyle.input_template
* ShaderNodeOutputLineStyle.output_template
* ShaderNodeOutputMaterial.input_template
* ShaderNodeOutputMaterial.output_template
* ShaderNodeOutputWorld.input_template
* ShaderNodeOutputWorld.output_template
* ShaderNodeParticleInfo.input_template
* ShaderNodeParticleInfo.output_template
* ShaderNodePointInfo.input_template
* ShaderNodePointInfo.output_template
* ShaderNodeRGB.input_template
* ShaderNodeRGB.output_template
* ShaderNodeRGBCurve.input_template
* ShaderNodeRGBCurve.output_template
* ShaderNodeRGBToBW.input_template
* ShaderNodeRGBToBW.output_template
* ShaderNodeRadialTiling.input_template
* ShaderNodeRadialTiling.output_template
* ShaderNodeRaycast.input_template
* ShaderNodeRaycast.output_template
* ShaderNodeScript.input_template
* ShaderNodeScript.output_template
* ShaderNodeSeparateColor.input_template
* ShaderNodeSeparateColor.output_template
* ShaderNodeSeparateXYZ.input_template
* ShaderNodeSeparateXYZ.output_template
* ShaderNodeShaderToRGB.input_template
* ShaderNodeShaderToRGB.output_template
* ShaderNodeSqueeze.input_template
* ShaderNodeSqueeze.output_template
* ShaderNodeSubsurfaceScattering.input_template
* ShaderNodeSubsurfaceScattering.output_template
* ShaderNodeTangent.input_template
* ShaderNodeTangent.output_template
* ShaderNodeTexBrick.input_template
* ShaderNodeTexBrick.output_template
* ShaderNodeTexChecker.input_template
* ShaderNodeTexChecker.output_template
* ShaderNodeTexCoord.input_template
* ShaderNodeTexCoord.output_template
* ShaderNodeTexEnvironment.input_template
* ShaderNodeTexEnvironment.output_template
* ShaderNodeTexGabor.input_template
* ShaderNodeTexGabor.output_template
* ShaderNodeTexGradient.input_template
* ShaderNodeTexGradient.output_template
* ShaderNodeTexIES.input_template
* ShaderNodeTexIES.output_template
* ShaderNodeTexImage.input_template
* ShaderNodeTexImage.output_template
* ShaderNodeTexMagic.input_template
* ShaderNodeTexMagic.output_template
* ShaderNodeTexNoise.input_template
* ShaderNodeTexNoise.output_template
* ShaderNodeTexSky.input_template
* ShaderNodeTexSky.output_template
* ShaderNodeTexVoronoi.input_template
* ShaderNodeTexVoronoi.output_template
* ShaderNodeTexWave.input_template
* ShaderNodeTexWave.output_template
* ShaderNodeTexWhiteNoise.input_template
* ShaderNodeTexWhiteNoise.output_template
* ShaderNodeUVAlongStroke.input_template
* ShaderNodeUVAlongStroke.output_template
* ShaderNodeUVMap.input_template
* ShaderNodeUVMap.output_template
* ShaderNodeValToRGB.input_template
* ShaderNodeValToRGB.output_template
* ShaderNodeValue.input_template
* ShaderNodeValue.output_template
* ShaderNodeVectorCurve.input_template
* ShaderNodeVectorCurve.output_template
* ShaderNodeVectorDisplacement.input_template
* ShaderNodeVectorDisplacement.output_template
* ShaderNodeVectorMath.input_template
* ShaderNodeVectorMath.output_template
* ShaderNodeVectorRotate.input_template
* ShaderNodeVectorRotate.output_template
* ShaderNodeVectorTransform.input_template
* ShaderNodeVectorTransform.output_template
* ShaderNodeVertexColor.input_template
* ShaderNodeVertexColor.output_template
* ShaderNodeVolumeAbsorption.input_template
* ShaderNodeVolumeAbsorption.output_template
* ShaderNodeVolumeCoefficients.input_template
* ShaderNodeVolumeCoefficients.output_template
* ShaderNodeVolumeInfo.input_template
* ShaderNodeVolumeInfo.output_template
* ShaderNodeVolumePrincipled.input_template
* ShaderNodeVolumePrincipled.output_template
* ShaderNodeVolumeScatter.input_template
* ShaderNodeVolumeScatter.output_template
* ShaderNodeWavelength.input_template
* ShaderNodeWavelength.output_template
* ShaderNodeWireframe.input_template
* ShaderNodeWireframe.output_template
* TextureNodeAt.input_template
* TextureNodeAt.output_template
* TextureNodeBricks.input_template
* TextureNodeBricks.output_template
* TextureNodeChecker.input_template
* TextureNodeChecker.output_template
* TextureNodeCombineColor.input_template
* TextureNodeCombineColor.output_template
* TextureNodeCompose.input_template
* TextureNodeCompose.output_template
* TextureNodeCoordinates.input_template
* TextureNodeCoordinates.output_template
* TextureNodeCurveRGB.input_template
* TextureNodeCurveRGB.output_template
* TextureNodeCurveTime.input_template
* TextureNodeCurveTime.output_template
* TextureNodeDecompose.input_template
* TextureNodeDecompose.output_template
* TextureNodeDistance.input_template
* TextureNodeDistance.output_template
* TextureNodeGroup.input_template
* TextureNodeGroup.output_template
* TextureNodeHueSaturation.input_template
* TextureNodeHueSaturation.output_template
* TextureNodeImage.input_template
* TextureNodeImage.output_template
* TextureNodeInvert.input_template
* TextureNodeInvert.output_template
* TextureNodeMath.input_template
* TextureNodeMath.output_template
* TextureNodeMixRGB.input_template
* TextureNodeMixRGB.output_template
* TextureNodeOutput.input_template
* TextureNodeOutput.output_template
* TextureNodeRGBToBW.input_template
* TextureNodeRGBToBW.output_template
* TextureNodeRotate.input_template
* TextureNodeRotate.output_template
* TextureNodeScale.input_template
* TextureNodeScale.output_template
* TextureNodeSeparateColor.input_template
* TextureNodeSeparateColor.output_template
* TextureNodeTexBlend.input_template
* TextureNodeTexBlend.output_template
* TextureNodeTexClouds.input_template
* TextureNodeTexClouds.output_template
* TextureNodeTexDistNoise.input_template
* TextureNodeTexDistNoise.output_template
* TextureNodeTexMagic.input_template
* TextureNodeTexMagic.output_template
* TextureNodeTexMarble.input_template
* TextureNodeTexMarble.output_template
* TextureNodeTexMusgrave.input_template
* TextureNodeTexMusgrave.output_template
* TextureNodeTexNoise.input_template
* TextureNodeTexNoise.output_template
* TextureNodeTexStucci.input_template
* TextureNodeTexStucci.output_template
* TextureNodeTexVoronoi.input_template
* TextureNodeTexVoronoi.output_template
* TextureNodeTexWood.input_template
* TextureNodeTexWood.output_template
* TextureNodeTexture.input_template
* TextureNodeTexture.output_template
* TextureNodeTranslate.input_template
* TextureNodeTranslate.output_template
* TextureNodeValToNor.input_template
* TextureNodeValToNor.output_template
* TextureNodeValToRGB.input_template
* TextureNodeValToRGB.output_template
* TextureNodeViewer.input_template
* TextureNodeViewer.output_template

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilLayer.mask_layers
* GreasePencilLayerMasks.add
* GreasePencilLayerMasks.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.preferences

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ColorRamp.elements

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderSettings.bake

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Curve.shape_keys
* Curve.splines
* Curve.path_duration
* Curve.use_path
* Curve.use_path_follow
* Curve.use_path_clamp
* Curve.use_stretch
* Curve.use_deform_bounds
* Curve.use_radius
* Curve.bevel_mode
* Curve.bevel_profile
* Curve.bevel_resolution
* Curve.offset
* Curve.extrude
* Curve.bevel_depth
* Curve.resolution_u
* Curve.resolution_v
* Curve.render_resolution_u
* Curve.render_resolution_v
* Curve.eval_time
* Curve.bevel_object
* Curve.taper_object
* Curve.dimensions
* Curve.fill_mode
* Curve.fill_solver
* Curve.fill_rule
* Curve.twist_mode
* Curve.taper_radius_mode
* Curve.bevel_factor_mapping_start
* Curve.bevel_factor_mapping_end
* Curve.twist_smooth
* Curve.use_fill_caps
* Curve.use_map_taper
* Curve.use_auto_texspace
* Curve.texspace_location
* Curve.texspace_size
* Curve.materials
* Curve.bevel_factor_start
* Curve.bevel_factor_end
* Curve.is_editmode
* Curve.animation_data
* Curve.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Curve.transform
* Curve.validate_material_indices
* Curve.update_gpu_tag
* Curve.bl_rna_get_subclass
* Curve.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleLineStyle.texture_slots

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Window.stereo_3d_display

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieClip.proxy

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FloatAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.libraries

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.collection_children

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CacheFile.active_index
* CacheFile.object_paths

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationLayer.frames

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.annotations

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.shader_effects
* ObjectShaderFx.new
* ObjectShaderFx.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.gizmo_group
* Gizmo.group

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeConvertToDisplay.display_settings
* ImageFormatSettings.display_settings
* Scene.display_settings

:columns: 2


--------------------

The mesh data is accessed in object mode and intended for compact storage,
for more flexible mesh editing from Python see bmesh.

Blender stores 4 main arrays to define mesh geometry.

* Mesh.vertices (3 points in space)
* Mesh.edges (reference 2 vertices)
* Mesh.loops (reference a single vertex and edge)
* Mesh.polygons: (reference a range of loops)

Each polygon references a slice in the loop array, this way,
polygons do not store vertices or corner data such as UVs directly,
only a reference to loops that the polygon uses.

Mesh.loops, Mesh.uv_layers Mesh.vertex_colors are all aligned so the same polygon loop
indices can be used to find the UVs and vertex colors as with as the vertices.

To compare mesh API options see: NGons and Tessellation Faces <info_gotcha_mesh_faces>

This example script prints the vertices and UVs for each polygon, assumes the active object is a mesh with UVs.

```../examples/bpy.types.Mesh.0.py```


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.mesh
* BlendData.meshes
* BlendDataMeshes.new
* BlendDataMeshes.new_from_object
* BlendDataMeshes.remove
* Mesh.texco_mesh
* Mesh.texture_mesh
* Mesh.unit_test_compare
* Object.to_mesh

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.screens
* Context.screen
* Window.screen
* WorkSpace.screens

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* DriverVariable.targets

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.sculpt

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlenderRNA.structs
* CollectionProperty.fixed_type
* PointerProperty.fixed_type
* Property.srna
* Struct.base
* Struct.nested

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.annotation_data
* bpy.context.gpencil
* bpy.context.grease_pencil
* BlendData.grease_pencils
* BlendDataGreasePencilsV3.new
* BlendDataGreasePencilsV3.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeUserInterface.wcol_box
* ThemeUserInterface.wcol_curve
* ThemeUserInterface.wcol_list_item
* ThemeUserInterface.wcol_menu
* ThemeUserInterface.wcol_menu_back
* ThemeUserInterface.wcol_menu_item
* ThemeUserInterface.wcol_num
* ThemeUserInterface.wcol_numslider
* ThemeUserInterface.wcol_option
* ThemeUserInterface.wcol_pie_menu
* ThemeUserInterface.wcol_progress
* ThemeUserInterface.wcol_pulldown
* ThemeUserInterface.wcol_radio
* ThemeUserInterface.wcol_regular
* ThemeUserInterface.wcol_scroll
* ThemeUserInterface.wcol_tab
* ThemeUserInterface.wcol_text
* ThemeUserInterface.wcol_toggle
* ThemeUserInterface.wcol_tool
* ThemeUserInterface.wcol_toolbar_item
* ThemeUserInterface.wcol_tooltip

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_pose_bone
* bpy.context.pose_bone
* bpy.context.selected_pose_bones
* bpy.context.selected_pose_bones_from_active_object
* bpy.context.visible_pose_bones
* Object.convert_space
* Pose.bones
* PoseBone.bbone_custom_handle_end
* PoseBone.bbone_custom_handle_start
* PoseBone.child
* PoseBone.custom_shape_transform
* PoseBone.parent

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationFrame.strokes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesFilePaths.script_directories

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMap.actionmap_items
* XrActionMapItems.find
* XrActionMapItems.new
* XrActionMapItems.new_from_item
* XrActionMapItems.new_from_item
* XrActionMapItems.remove
* XrSessionState.action_binding_create
* XrSessionState.action_create

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.lights

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.field
* ParticleSettings.force_field_1
* ParticleSettings.force_field_2

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Camera.background_images
* CameraBackgroundImages.new
* CameraBackgroundImages.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeOutputFile.format
* NodeCompositorFileOutputItem.format
* BakeSettings.image_settings
* RenderSettings.image_settings
* UILayout.template_image_settings
* UILayout.template_image_views

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothModifier.point_cache
* DynamicPaintSurface.point_cache
* ParticleSystem.point_cache
* RigidBodyWorld.point_cache
* SoftBodyModifier.point_cache

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Light.type
* Light.use_temperature
* Light.color
* Light.temperature
* Light.temperature_color
* Light.specular_factor
* Light.diffuse_factor
* Light.transmission_factor
* Light.volume_factor
* Light.use_custom_distance
* Light.cutoff_distance
* Light.use_shadow
* Light.exposure
* Light.normalize
* Light.node_tree
* Light.use_nodes
* Light.animation_data
* Light.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Light.area
* Light.inline_shader_nodes
* Light.bl_rna_get_subclass
* Light.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ImageStrip.retiming_keys
* MovieStrip.retiming_keys
* RetimingKeys.add
* SceneStrip.retiming_keys
* SoundStrip.retiming_keys

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FileSelectParams.filter_id

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.lineart

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifier.panels

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ID.preview
* ID.preview_ensure

:columns: 2


--------------------

The NodeTree.poll function determines if a node tree is visible
in the given context (similar to how Panel.poll
and Menu.poll define visibility). If it returns False,
the node tree type will not be selectable in the node editor.

A typical condition for shader nodes would be to check the active render engine
of the scene and only show nodes of the renderer they are designed for.

```../examples/bpy.types.NodeTree.0.py```


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.node_groups
* BlendDataNodeTrees.new
* BlendDataNodeTrees.remove
* CompositorNodeCustomGroup.node_tree
* CompositorNodeGroup.node_tree
* CompositorStrip.node_group
* EvaluateClosureNodeViewerPathElem.source_node_tree
* FreestyleLineStyle.node_tree
* GeometryNodeCustomGroup.node_tree
* GeometryNodeGroup.node_tree
* Light.node_tree
* Material.node_tree
* Node.poll
* Node.poll_instance
* NodeCustomGroup.node_tree
* NodeGroup.node_tree
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeTree.contains_tree
* NodeTree.get_from_context
* NodeTreePath.node_tree
* NodesModifier.node_group
* Scene.compositing_node_group
* SequencerCompositorModifierData.node_group
* ShaderNodeCustomGroup.node_tree
* ShaderNodeGroup.node_tree
* SpaceNodeEditor.edit_tree
* SpaceNodeEditor.node_tree
* SpaceNodeEditor.selected_node_group
* SpaceNodeEditorPath.append
* SpaceNodeEditorPath.start
* Texture.node_tree
* TextureNodeGroup.node_tree
* UILayout.template_node_link
* UILayout.template_node_view
* World.node_tree

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencil.attributes
* GreasePencil.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.sequencer_colorspace_settings

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.lightprobe
* BlendData.lightprobes
* BlendDataProbes.new
* BlendDataProbes.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeCombineBundle.bundle_items
* NodeCombineBundleItems.new
* NodeCombineBundleItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.shape_keys
* Curve.shape_keys
* Lattice.shape_keys
* Mesh.shape_keys

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyConfig.preferences

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencil.layer_groups

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.console

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskSplinePoint.feather_points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.masks

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.material
* BlendData.materials
* BlendDataMaterials.create_gpencil_data
* BlendDataMaterials.new
* BlendDataMaterials.remove
* BlendDataMaterials.remove_gpencil_data
* BrushGpencilSettings.material
* BrushGpencilSettings.material_alt
* Curve.materials
* Curves.materials
* GeometryNodeInputMaterial.material
* GreasePencil.materials
* GreasePencilArrayModifier.material_filter
* GreasePencilBuildModifier.material_filter
* GreasePencilColorModifier.material_filter
* GreasePencilDashModifierData.material_filter
* GreasePencilEnvelopeModifier.material_filter
* GreasePencilHookModifier.material_filter
* GreasePencilLatticeModifier.material_filter
* GreasePencilLengthModifier.material_filter
* GreasePencilLineartModifier.target_material
* GreasePencilMirrorModifier.material_filter
* GreasePencilMultiplyModifier.material_filter
* GreasePencilNoiseModifier.material_filter
* GreasePencilOffsetModifier.material_filter
* GreasePencilOpacityModifier.material_filter
* GreasePencilOutlineModifier.material_filter
* GreasePencilOutlineModifier.outline_material
* GreasePencilShrinkwrapModifier.material_filter
* GreasePencilSimplifyModifier.material_filter
* GreasePencilSmoothModifier.material_filter
* GreasePencilSubdivModifier.material_filter
* GreasePencilTextureModifier.material_filter
* GreasePencilThickModifierData.material_filter
* GreasePencilTintModifier.material_filter
* GreasePencilWeightAngleModifier.material_filter
* GreasePencilWeightProximityModifier.material_filter
* IDMaterials.append
* IDMaterials.pop
* MaterialSlot.material
* Mesh.materials
* MetaBall.materials
* NodeSocketMaterial.default_value
* NodeTreeInterfaceSocketMaterial.default_value
* Object.active_material
* PointCloud.materials
* ViewLayer.material_override
* Volume.materials

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionKeyframeStrip.channelbags

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingReconstructedCameras.find_frame
* MovieTrackingReconstruction.cameras

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceNodeEditor.overlay

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* FreestyleLineStyle.color_modifiers
* LineStyleColorModifiers.new
* LineStyleColorModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.region_data
* SpaceView3D.region_3d
* SpaceView3D.region_quadviews

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PointCloud.attributes
* PointCloud.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.gpencil_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_bone
* bpy.context.edit_bone
* bpy.context.editable_bones
* bpy.context.selected_bones
* bpy.context.selected_editable_bones
* bpy.context.visible_bones
* Armature.edit_bones
* ArmatureEditBones.active
* ArmatureEditBones.new
* ArmatureEditBones.remove
* EditBone.bbone_custom_handle_end
* EditBone.bbone_custom_handle_start
* EditBone.parent

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleHairKey.co_object
* ParticleHairKey.co_object_set
* ParticleSystem.mcol_on_emitter
* ParticleSystem.particles
* ParticleSystem.uv_on_emitter

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.texts

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeUserInterface.wcol_state

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.text_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FCurve.modifiers
* FCurveModifiers.active
* FCurveModifiers.new
* FCurveModifiers.remove
* NlaStrip.modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetRepresentation.metadata
* FileSelectEntry.asset_data
* ID.asset_data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.gpencil_interpolate

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.camera

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.edges

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GizmoGroup.setup_keymap
* KeyConfigurations.active
* KeyConfigurations.addon
* KeyConfigurations.default
* KeyConfigurations.new
* KeyConfigurations.remove
* KeyConfigurations.user
* WindowManager.keyconfigs

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ShaderNodeTexBrick.texture_mapping
* ShaderNodeTexChecker.texture_mapping
* ShaderNodeTexEnvironment.texture_mapping
* ShaderNodeTexGabor.texture_mapping
* ShaderNodeTexGradient.texture_mapping
* ShaderNodeTexImage.texture_mapping
* ShaderNodeTexMagic.texture_mapping
* ShaderNodeTexNoise.texture_mapping
* ShaderNodeTexSky.texture_mapping
* ShaderNodeTexVoronoi.texture_mapping
* ShaderNodeTexWave.texture_mapping

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeEvaluateClosure.output_items
* NodeEvaluateClosureOutputItems.new
* NodeEvaluateClosureOutputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Region.view2d

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewLayer.freestyle_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendImportContextItem.source_libraries

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Light.type
* Light.use_temperature
* Light.color
* Light.temperature
* Light.temperature_color
* Light.specular_factor
* Light.diffuse_factor
* Light.transmission_factor
* Light.volume_factor
* Light.use_custom_distance
* Light.cutoff_distance
* Light.use_shadow
* Light.exposure
* Light.normalize
* Light.node_tree
* Light.use_nodes
* Light.animation_data
* Light.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Light.area
* Light.inline_shader_nodes
* Light.bl_rna_get_subclass
* Light.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MeshUVLoopLayer.data

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GizmoGroup.gizmos
* GizmoGroup.invoke_prepare
* Gizmos.new
* Gizmos.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceView3D.overlay

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.world
* BlendData.worlds
* BlendDataWorlds.new
* BlendDataWorlds.remove
* Scene.world
* ViewLayer.world_override

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.material_slot
* Object.material_slots

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeTreeInterface.active
* NodeTreeInterface.copy
* NodeTreeInterface.copy
* NodeTreeInterface.items_tree
* NodeTreeInterface.move
* NodeTreeInterface.move_to_parent
* NodeTreeInterface.remove
* NodeTreeInterfacePanel.interface_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.curves_sculpt_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.spreadsheet

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.animation_visualization
* Pose.animation_visualization

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.tool_settings
* Context.tool_settings
* Scene.tool_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

The Image data-block is a shallow wrapper around image or video file(s)
(on disk, as packed data, or generated).

All actual data like the pixel buffer, size, resolution etc. is
cached in an imbuf.types.ImBuf image buffer (or several buffers
in some cases, like UDIM textures, multi-views, animations...).

Several properties and functions of the Image data-block are then actually
using/modifying its image buffer, and not the Image data-block itself.

[WARNING]
One key limitation is that image buffers are not shared between different
Image data-blocks, and they are not duplicated when copying an image.
So until a modified image buffer is saved on disk, duplicating its Image
data-block will not propagate the underlying buffer changes to the new Image.

This example script generates an Image data-block with a given size,
change its first pixel, rescale it, and duplicates the image.

The duplicated image still has the same size and colors as the original image
at its creation, all editing in the original image's buffer is 'lost' in its copy.

```../examples/bpy.types.Image.0.py```


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.edit_image
* BlendData.images
* BlendDataImages.load
* BlendDataImages.new
* BlendDataImages.remove
* CameraBackgroundImage.image
* CompositorNodeCryptomatteV2.image
* CompositorNodeImage.image
* GeometryNodeInputImage.image
* ImagePaint.canvas
* ImagePaint.clone_image
* ImagePaint.stencil_image
* ImageTexture.image
* Material.texture_paint_images
* MaterialGPencilStyle.fill_image
* MaterialGPencilStyle.stroke_image
* MovieTrackingPlaneTrack.image
* NodeSocketImage.default_value
* NodeTreeInterfaceSocketImage.default_value
* PaintModeSettings.canvas_image
* ShaderNodeTexEnvironment.image
* ShaderNodeTexImage.image
* SpaceImageEditor.image
* TextureNodeImage.image
* UILayout.template_image_layers

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskLayer.splines

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* PropertyGroup.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* PropertyGroup.bl_system_properties_get
* PropertyGroup.bl_rna_get_subclass
* PropertyGroup.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.paint_curves
* Brush.paint_curve

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationFrames.copy
* AnnotationFrames.copy
* AnnotationFrames.new
* AnnotationFrames.remove
* AnnotationLayer.active_frame
* AnnotationLayer.frames

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.loop_triangle_polygons

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CollectionChild.light_linking
* CollectionObject.light_linking

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.collection_objects

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MotionPath.points

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scopes.histogram
* SpaceImageEditor.sample_histogram

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PointCache.point_caches

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapItem.user_paths
* XrUserPaths.find
* XrUserPaths.new
* XrUserPaths.remove

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Lightgroups.add
* Lightgroups.remove
* ViewLayer.active_lightgroup
* ViewLayer.lightgroups

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.tiles

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencil.root_nodes
* GreasePencilLayerGroup.children
* GreasePencilTreeNode.next_node
* GreasePencilTreeNode.prev_node

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* PropertyGroup.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* PropertyGroup.bl_system_properties_get
* PropertyGroup.bl_rna_get_subclass
* PropertyGroup.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.curves
* BlendData.hair_curves
* BlendDataHairCurves.new
* BlendDataHairCurves.remove
* Curves.unit_test_compare

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ColorRamp.elements
* ColorRampElements.new
* ColorRampElements.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.automasking_cavity_curve
* Brush.curve_distance_falloff
* Brush.curve_jitter
* Brush.curve_random_hue
* Brush.curve_random_saturation
* Brush.curve_random_value
* Brush.curve_size
* Brush.curve_strength
* BrushCurvesSculptSettings.curve_parameter_falloff
* BrushGpencilSettings.curve_jitter
* BrushGpencilSettings.curve_random_hue
* BrushGpencilSettings.curve_random_pressure
* BrushGpencilSettings.curve_random_saturation
* BrushGpencilSettings.curve_random_strength
* BrushGpencilSettings.curve_random_uv
* BrushGpencilSettings.curve_random_value
* BrushGpencilSettings.curve_sensitivity
* BrushGpencilSettings.curve_strength
* ColorManagedViewSettings.curve_mapping
* CompositorNodeCurveRGB.mapping
* CompositorNodeHueCorrect.mapping
* CompositorNodeTime.curve
* CurvesModifier.curve_mapping
* EQCurveMappingData.curve_mapping
* GPencilInterpolateSettings.interpolation_curve
* GPencilSculptSettings.multiframe_falloff_curve
* GPencilSculptSettings.thickness_primitive_curve
* GreasePencilColorModifier.custom_curve
* GreasePencilHookModifier.custom_curve
* GreasePencilNoiseModifier.custom_curve
* GreasePencilOpacityModifier.custom_curve
* GreasePencilSmoothModifier.custom_curve
* GreasePencilThickModifierData.custom_curve
* GreasePencilTintModifier.custom_curve
* HookModifier.falloff_curve
* HueCorrectModifier.curve_mapping
* LineStyleAlphaModifier_AlongStroke.curve
* LineStyleAlphaModifier_CreaseAngle.curve
* LineStyleAlphaModifier_Curvature_3D.curve
* LineStyleAlphaModifier_DistanceFromCamera.curve
* LineStyleAlphaModifier_DistanceFromObject.curve
* LineStyleAlphaModifier_Material.curve
* LineStyleAlphaModifier_Noise.curve
* LineStyleAlphaModifier_Tangent.curve
* LineStyleThicknessModifier_AlongStroke.curve
* LineStyleThicknessModifier_CreaseAngle.curve
* LineStyleThicknessModifier_Curvature_3D.curve
* LineStyleThicknessModifier_DistanceFromCamera.curve
* LineStyleThicknessModifier_DistanceFromObject.curve
* LineStyleThicknessModifier_Material.curve
* LineStyleThicknessModifier_Tangent.curve
* Paint.cavity_curve
* ParticleBrush.curve
* ParticleSettings.clump_curve
* ParticleSettings.roughness_curve
* ParticleSettings.twist_curve
* RenderSettings.motion_blur_shutter_curve
* Sculpt.automasking_cavity_curve
* Sculpt.automasking_cavity_curve_op
* ShaderNodeFloatCurve.mapping
* ShaderNodeRGBCurve.mapping
* ShaderNodeVectorCurve.mapping
* TextureNodeCurveRGB.mapping
* TextureNodeCurveTime.curve
* UvSculpt.curve_distance_falloff
* VertexWeightEditModifier.map_curve
* VertexWeightProximityModifier.map_curve
* WarpModifier.falloff_curve

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendImportContext.import_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyingSet.paths
* KeyingSetPaths.active
* KeyingSetPaths.add
* KeyingSetPaths.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveProfile.points
* CurveProfile.segments
* CurveProfilePoints.add
* CurveProfilePoints.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* DynamicPaintCanvasSettings.canvas_surfaces
* DynamicPaintSurfaces.active

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesExtensions.repos

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.unit_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BevelModifier.custom_profile
* Curve.bevel_profile
* ToolSettings.custom_bevel_profile_preset

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Node.outputs

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.rigid_body_constraint

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ColorBalanceModifier.color_balance

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BoidSettings.active_boid_state
* BoidState.active_boid_rule
* BoidState.rules

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetShelf.get_active_asset
* Paint.brush_asset_reference
* Paint.eraser_brush_asset_reference

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSpreadsheet.viewer_path
* SpreadsheetTableIDGeometry.viewer_path

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ArmatureConstraint.targets

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceFileBrowser.params
* UILayout.template_file_select_path

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.vertex_groups

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

This example creates a simple macro operator that
moves the active object and then rotates it.
It demonstrates:

* Defining a macro operator class.
* Registering it and defining sub-operators.
* Setting property values for each step.

```../examples/bpy.types.Macro.0.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Operator.macros

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.topbar

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeOutputFile.file_output_items

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSettings.texture_slots

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curves.curve_offset_data
* GreasePencilDrawing.curve_offsets
* IntAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2

bpy.types.*

:maxdepth: 1
:glob:

Shared Enum Types <bpy_types_enum_items/index>

:hidden:
:maxdepth: 1

Types with Custom Property Support <bpy_types_custom_properties>

:hidden:
:maxdepth: 1


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.curves_sculpt

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WorkSpaceTool.gizmo_group_properties

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Lattice.points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Annotation.layers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.palettes
* BlendDataPalettes.new
* BlendDataPalettes.remove
* Paint.palette

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.pose

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveMap.points
* CurveMapPoints.new
* CurveMapPoints.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.input_items
* NodeGeometryForeachGeometryElementInputItems.new
* NodeGeometryForeachGeometryElementInputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.polygons

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.main_items
* NodeGeometryForeachGeometryElementMainItems.new
* NodeGeometryForeachGeometryElementMainItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FluidModifier.flow_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.objects

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapItem.bindings

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ActionStrip.type

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ActionStrip.bl_rna_get_subclass
* ActionStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curve.materials
* Curves.materials
* GreasePencil.materials
* Mesh.materials
* MetaBall.materials
* PointCloud.materials
* Volume.materials

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* NodeTree.color_tag
* NodeTree.default_group_node_width
* NodeTree.view_center
* NodeTree.description
* NodeTree.animation_data
* NodeTree.nodes
* NodeTree.links
* NodeTree.annotation
* NodeTree.type
* NodeTree.interface
* NodeTree.bl_idname
* NodeTree.bl_label
* NodeTree.bl_description
* NodeTree.bl_icon
* NodeTree.bl_use_group_interface

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* NodeTree.interface_update
* NodeTree.contains_tree
* NodeTree.poll
* NodeTree.update
* NodeTree.get_from_context
* NodeTree.valid_socket_type
* NodeTree.debug_lazy_function_graph
* NodeTree.bl_rna_get_subclass
* NodeTree.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.display

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py

:columns: 2


--------------------

* NodeTreeInterface.move_to_parent
* NodeTreeInterface.new_panel
* NodeTreeInterface.new_socket
* NodeTreeInterfaceItem.parent

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.layers
* ActionLayers.new
* ActionLayers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.pose_markers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSpreadsheet.tables
* SpreadsheetTables.active

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* LoopColors.active
* LoopColors.new
* LoopColors.remove
* Mesh.vertex_colors

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderEngine.render
* Scene.render

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.view_layers

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* Struct.name_property

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.vertex_paint
* ToolSettings.weight_paint

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CollisionModifier.settings
* Object.collision

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.brush_capabilities

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Depsgraph.updates

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* LightProbe.type
* LightProbe.clip_start
* LightProbe.show_clip
* LightProbe.show_influence
* LightProbe.influence_distance
* LightProbe.visibility_buffer_bias
* LightProbe.visibility_bleed_bias
* LightProbe.visibility_blur
* LightProbe.visibility_collection
* LightProbe.invert_visibility_collection
* LightProbe.show_data
* LightProbe.use_data_display
* LightProbe.data_display_size
* LightProbe.animation_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* LightProbe.bl_rna_get_subclass
* LightProbe.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ID.library_weak_reference

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.preferences

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.images

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.dopesheet_editor

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.system

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.sequencer_tool_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeBake.active_item
* GeometryNodeCaptureAttribute.active_item
* GeometryNodeFieldToGrid.active_item
* GeometryNodeRepeatOutput.active_item
* GeometryNodeRepeatOutput.repeat_items
* NodeGeometryRepeatOutputItems.new
* NodeGeometryRepeatOutputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* LightProbe.type
* LightProbe.clip_start
* LightProbe.show_clip
* LightProbe.show_influence
* LightProbe.influence_distance
* LightProbe.visibility_buffer_bias
* LightProbe.visibility_bleed_bias
* LightProbe.visibility_blur
* LightProbe.visibility_collection
* LightProbe.invert_visibility_collection
* LightProbe.show_data
* LightProbe.use_data_display
* LightProbe.data_display_size
* LightProbe.animation_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* LightProbe.bl_rna_get_subclass
* LightProbe.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.graph_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.event_timer_add
* WindowManager.event_timer_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeCombineBundle.bundle_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Float2Attribute.data
* MeshUVLoopLayer.uv

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeSimulationOutput.active_item
* GeometryNodeSimulationOutput.state_items
* NodeGeometrySimulationOutputItems.new
* NodeGeometrySimulationOutputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleLineStyle.thickness_modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.cache_files
* MeshSequenceCacheModifier.cache_file
* TransformCacheConstraint.cache_file

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MetaBall.elements
* MetaBallElements.active
* MetaBallElements.new
* MetaBallElements.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyingSetInfo.generate
* KeyingSetInfo.iterator
* KeyingSets.active
* KeyingSets.new
* KeyingSetsAll.active
* Scene.keying_sets
* Scene.keying_sets_all

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Bone.color
* EditBone.color
* PoseBone.color

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Depsgraph.object_instances

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.sounds
* BlendDataSounds.load
* BlendDataSounds.remove
* NodeSocketSound.default_value
* NodeTreeInterfaceSocketSound.default_value
* SoundStrip.sound
* Speaker.sound

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.ui_styles

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeSimulationOutput.state_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* TransformOrientationSlot.custom_orientation

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyMap.keymap_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_editable_fcurve
* bpy.context.editable_fcurves
* bpy.context.selected_editable_fcurves
* bpy.context.selected_visible_fcurves
* bpy.context.visible_fcurves
* Action.fcurve_ensure_for_datablock
* ActionChannelbag.fcurves
* ActionChannelbagFCurves.ensure
* ActionChannelbagFCurves.find
* ActionChannelbagFCurves.new
* ActionChannelbagFCurves.new_from_fcurve
* ActionChannelbagFCurves.new_from_fcurve
* ActionChannelbagFCurves.remove
* ActionGroup.channels
* AnimData.drivers
* AnimDataDrivers.find
* AnimDataDrivers.from_existing
* AnimDataDrivers.from_existing
* AnimDataDrivers.new
* AnimDataDrivers.remove
* NlaStrip.fcurves
* NlaStripFCurves.find

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* TextureSlot.texture
* TextureSlot.name
* TextureSlot.offset
* TextureSlot.scale
* TextureSlot.color
* TextureSlot.blend_type
* TextureSlot.default_value
* TextureSlot.output_node

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* TextureSlot.bl_rna_get_subclass
* TextureSlot.bl_rna_get_subclass_py

:columns: 2


--------------------

* ParticleSettings.texture_slots
* ParticleSettingsTextureSlots.add
* ParticleSettingsTextureSlots.create

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.hydra

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.keymap

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.screens

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BoolAttribute.data
* MeshUVLoopLayer.pin

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CacheFile.object_paths

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.colorspace

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.image_paint_capabilities

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.hair_curves

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifierBake.data_blocks

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.uv_layer_clone
* Mesh.uv_layer_stencil
* Mesh.uv_layers
* UVLoopLayers.active
* UVLoopLayers.new
* UVLoopLayers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.gradient
* ColorMapping.color_ramp
* DynamicPaintBrushSettings.paint_ramp
* DynamicPaintBrushSettings.velocity_ramp
* FluidDomainSettings.color_ramp
* GreasePencilTintModifier.color_ramp
* LineStyleColorModifier_AlongStroke.color_ramp
* LineStyleColorModifier_CreaseAngle.color_ramp
* LineStyleColorModifier_Curvature_3D.color_ramp
* LineStyleColorModifier_DistanceFromCamera.color_ramp
* LineStyleColorModifier_DistanceFromObject.color_ramp
* LineStyleColorModifier_Material.color_ramp
* LineStyleColorModifier_Noise.color_ramp
* LineStyleColorModifier_Tangent.color_ramp
* PreferencesView.weight_color_range
* ShaderNodeValToRGB.color_ramp
* Texture.color_ramp
* TextureNodeValToRGB.color_ramp

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeIndexSwitch.index_switch_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.xr_session_settings

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.collection_color

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.clip_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BoidSettings.states

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderLayer.passes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ImageStrip.retiming_keys
* MovieStrip.retiming_keys
* SceneStrip.retiming_keys
* SoundStrip.retiming_keys

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceImageEditor.uv_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PathCompareCollection.new
* PathCompareCollection.remove
* Preferences.autoexec_paths

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeMenuSwitch.active_item
* GeometryNodeMenuSwitch.enum_items
* NodeMenuSwitchItems.new
* NodeMenuSwitchItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.file_browser

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeRegions.asset_shelf

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.layers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.annotations
* BlendDataAnnotations.new
* BlendDataAnnotations.remove
* MovieClip.annotation
* MovieTrackingTrack.annotation
* NodeTree.annotation
* Scene.annotation
* SpaceImageEditor.annotation
* SpaceSequenceEditor.annotation

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceClipEditor.scopes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.keying_sets

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.regions

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.volumes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NlaStrip.fcurves

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.weight_paint_capabilities

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.active_action
* bpy.context.selected_editable_actions
* bpy.context.selected_visible_actions
* ActionConstraint.action
* AnimData.action
* AnimData.action_tweak_storage
* BlendData.actions
* BlendDataActions.new
* BlendDataActions.remove
* GLTF2_filter_action.action
* NlaStrip.action
* NlaStrips.new
* Pose.apply_pose_from_action
* Pose.backup_create
* Pose.blend_pose_from_action
* WindowManager.poselib_previous_action

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewLayer.eevee

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.property
* BoneCollection.assign
* BoneCollection.unassign
* FCurve.update_autoflags
* Gizmo.target_set_prop
* KeyingSetInfo.generate
* Region.data
* UILayout.context_pointer_set
* UILayout.enum_item_description
* UILayout.enum_item_icon
* UILayout.enum_item_name
* UILayout.icon
* UILayout.panel_prop
* UILayout.prop
* UILayout.prop_decorator
* UILayout.prop_enum
* UILayout.prop_menu_enum
* UILayout.prop_search
* UILayout.prop_search
* UILayout.prop_tabs_enum
* UILayout.prop_tabs_enum
* UILayout.prop_with_menu
* UILayout.prop_with_popover
* UILayout.props_enum
* UILayout.template_ID
* UILayout.template_ID_preview
* UILayout.template_ID_session_uid
* UILayout.template_ID_tabs
* UILayout.template_any_ID
* UILayout.template_cache_file
* UILayout.template_cache_file_layers
* UILayout.template_cache_file_time_settings
* UILayout.template_cache_file_velocity
* UILayout.template_color_picker
* UILayout.template_color_ramp
* UILayout.template_colormanaged_view_settings
* UILayout.template_colorspace_settings
* UILayout.template_component_menu
* UILayout.template_curve_mapping
* UILayout.template_curveprofile
* UILayout.template_greasepencil_color
* UILayout.template_histogram
* UILayout.template_icon_view
* UILayout.template_image
* UILayout.template_layers
* UILayout.template_layers
* UILayout.template_light_linking_collection
* UILayout.template_list
* UILayout.template_list
* UILayout.template_marker
* UILayout.template_matrix
* UILayout.template_movieclip
* UILayout.template_movieclip_information
* UILayout.template_palette
* UILayout.template_path_builder
* UILayout.template_search
* UILayout.template_search
* UILayout.template_search_preview
* UILayout.template_search_preview
* UILayout.template_track
* UILayout.template_vectorscope
* UILayout.template_waveform
* UIList.draw_item
* UIList.draw_item
* UIList.draw_item
* UIList.filter_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Bone.collections

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.lightprobes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.view

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetLibraryCollection.new
* AssetLibraryCollection.remove
* PreferencesFilePaths.asset_libraries

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.pointclouds

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Light.type
* Light.use_temperature
* Light.color
* Light.temperature
* Light.temperature_color
* Light.specular_factor
* Light.diffuse_factor
* Light.transmission_factor
* Light.volume_factor
* Light.use_custom_distance
* Light.cutoff_distance
* Light.use_shadow
* Light.exposure
* Light.normalize
* Light.node_tree
* Light.use_nodes
* Light.animation_data
* Light.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Light.area
* Light.inline_shader_nodes
* Light.bl_rna_get_subclass
* Light.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.children

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilLayer.mask_layers

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SceneEEVEE.ray_tracing_options

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.modifiers
* ObjectModifiers.active
* ObjectModifiers.new
* ObjectModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2

```../examples/bpy.types.AddonPreferences.1.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Addon.preferences

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceNodeEditor.path

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeClosureOutput.output_items
* NodeClosureOutputItems.new
* NodeClosureOutputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curve.splines

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* StringAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.properties

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifier.bakes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MetaStrip.channels
* SequenceEditor.channels

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.grease_pencil_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.extensions

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeCaptureAttribute.capture_items
* NodeGeometryCaptureAttributeItems.new
* NodeGeometryCaptureAttributeItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.lattices

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Material.texture_paint_slots

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewLayer.objects

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifier.panels

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* PropertyGroup.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* PropertyGroup.bl_system_properties_get
* PropertyGroup.bl_rna_get_subclass
* PropertyGroup.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MeshSkinVertexLayer.data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleSettings.linesets

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.statusbar

:columns: 2


--------------------

* bpy_struct.id_data
* FileSelectParams.title
* FileSelectParams.directory
* FileSelectParams.filename
* FileSelectParams.use_library_browsing
* FileSelectParams.display_type
* FileSelectParams.recursion_level
* FileSelectParams.show_details_size
* FileSelectParams.show_details_datetime
* FileSelectParams.use_filter
* FileSelectParams.show_hidden
* FileSelectParams.sort_method
* FileSelectParams.use_sort_invert
* FileSelectParams.use_filter_image
* FileSelectParams.use_filter_blender
* FileSelectParams.use_filter_backup
* FileSelectParams.use_filter_movie
* FileSelectParams.use_filter_script
* FileSelectParams.use_filter_font
* FileSelectParams.use_filter_sound
* FileSelectParams.use_filter_text
* FileSelectParams.use_filter_volume
* FileSelectParams.use_filter_folder
* FileSelectParams.use_filter_blendid
* FileSelectParams.use_filter_asset_only
* FileSelectParams.filter_id
* FileSelectParams.filter_glob
* FileSelectParams.filter_search
* FileSelectParams.display_size
* FileSelectParams.display_size_discrete
* FileSelectParams.list_display_size
* FileSelectParams.list_column_size

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileSelectParams.bl_rna_get_subclass
* FileSelectParams.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* World.light_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.cursor

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.node_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Armature.bones

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.armatures

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.particle_systems

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Armature.collections
* Armature.collections_all
* Bone.collections
* BoneCollection.children
* BoneCollection.parent
* BoneCollections.active
* BoneCollections.new
* BoneCollections.new
* BoneCollections.remove
* EditBone.collections

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PoseBone.constraints

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSequenceEditor.preview_overlay

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* EnumProperty.enum_items
* EnumProperty.enum_items_static
* EnumProperty.enum_items_static_ui
* KeyMap.modal_event_values
* Struct.property_tags

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.vertex_groups
* VertexGroups.active
* VertexGroups.new
* VertexGroups.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* UVProjectModifier.projectors

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifier.bakes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.info

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.stereo_3d_format
* ImageStrip.stereo_3d_format
* MovieStrip.stereo_3d_format
* ImageFormatSettings.stereo_3d_format
* UILayout.template_image_stereo_3d

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.studio_lights
* StudioLights.load
* StudioLights.new
* StudioLights.remove
* View3DShading.selected_studio_light

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* TextCurve.text_boxes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.soft_body
* SoftBodyModifier.settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceImageEditor.scopes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Palette.colors

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.grease_pencils

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilLayer.frames

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeFieldToGrid.grid_items
* GeometryNodeFieldToGridItems.new
* GeometryNodeFieldToGridItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* EffectStrip.proxy
* ImageStrip.proxy
* MetaStrip.proxy
* MovieStrip.proxy
* SceneStrip.proxy

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceFileBrowser.bookmarks
* SpaceFileBrowser.recent_folders
* SpaceFileBrowser.system_bookmarks
* SpaceFileBrowser.system_folders

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodesModifierBake.data_blocks

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.asset
* bpy.context.selected_assets
* AssetShelf.asset_poll
* AssetShelf.draw_context_menu
* Context.asset

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_bone
* bpy.context.bone
* Armature.bones
* ArmatureBones.active
* Bone.bbone_custom_handle_end
* Bone.bbone_custom_handle_start
* Bone.children
* Bone.parent
* BoneCollection.bones
* PoseBone.bone

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.gpencil_weight_paint

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

This script is the UIList subclass used to show material slots, with a bunch of additional commentaries.

Notice the name of the class, this naming convention is similar as the one for panels or menus.

[NOTE]
UIList subclasses must be registered for Blender to use them.

```../examples/bpy.types.UIList.1.py```


--------------------

This script is an extended version of the UIList

 subclass used to show vertex groups. It is not used 'as is',
because iterating over all vertices in a 'draw' function is a very bad idea for UI performance! However, it's a good
example of how to create/use filtering/reordering callbacks.

```../examples/bpy.types.UIList.2.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* DynamicPaintModifier.brush_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceClipEditor.overlay

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SoundEqualizerModifier.graphics
* SoundEqualizerModifier.new_graphic

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeBake.bake_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Operator.options

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.scene
* bpy.context.sequencer_scene
* BlendData.scenes
* BlendDataScenes.new
* BlendDataScenes.remove
* Camera.view_frame
* CompositorNodeCryptomatteV2.scene
* CompositorNodeDefocus.scene
* CompositorNodeRLayers.scene
* Context.scene
* Depsgraph.scene
* Depsgraph.scene_eval
* ID.override_hierarchy_create
* IDOverrideLibrary.resync
* Image.save_render
* NodeSocketScene.default_value
* NodeTreeInterfaceSocketScene.default_value
* Object.crazyspace_eval
* Object.is_deform_modified
* Object.is_modified
* RenderEngine.bind_display_space_shader
* RenderEngine.get_preview_pixel_size
* RenderEngine.register_pass
* RenderEngine.support_display_space_shader
* RenderEngine.update_render_passes
* Scene.background_set
* SceneStrip.scene
* StripsMeta.new_scene
* StripsTopLevel.new_scene
* Window.find_playing_scene
* Window.scene
* WorkSpace.sequencer_scene

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Gizmo.invoke
* Gizmo.modal
* KeyMapItems.match_event
* Operator.invoke
* Operator.modal
* Window.event_simulate
* WindowManager.invoke_confirm
* WindowManager.invoke_props_popup
* WindowManager.piemenu_begin__internal

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceSpreadsheet.tables

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.gpencil_vertex_paint

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieClip.tracking

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2

Base class for integrating USD Hydra based renderers.


--------------------

```../examples/bpy.types.HydraRenderEngine.0.py```


--------------------

* bpy_struct.id_data
* RenderEngine.is_animation
* RenderEngine.is_preview
* RenderEngine.camera_override
* RenderEngine.layer_override
* RenderEngine.resolution_x
* RenderEngine.resolution_y
* RenderEngine.temporary_directory
* RenderEngine.render
* RenderEngine.use_highlight_tiles
* RenderEngine.bl_idname
* RenderEngine.bl_label
* RenderEngine.bl_use_preview
* RenderEngine.bl_use_postprocess
* RenderEngine.bl_use_eevee_viewport
* RenderEngine.bl_use_custom_freestyle
* RenderEngine.bl_use_image_save
* RenderEngine.bl_use_gpu_context
* RenderEngine.bl_use_shading_nodes_custom
* RenderEngine.bl_use_spherical_stereo
* RenderEngine.bl_use_stereo_viewport
* RenderEngine.bl_use_materialx

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* RenderEngine.update
* RenderEngine.render
* RenderEngine.render_frame_finish
* RenderEngine.draw
* RenderEngine.bake
* RenderEngine.view_update
* RenderEngine.view_draw
* RenderEngine.update_script_node
* RenderEngine.update_render_passes
* RenderEngine.update_custom_camera
* RenderEngine.tag_redraw
* RenderEngine.tag_update
* RenderEngine.begin_result
* RenderEngine.update_result
* RenderEngine.end_result
* RenderEngine.add_pass
* RenderEngine.get_result
* RenderEngine.test_break
* RenderEngine.pass_by_index_get
* RenderEngine.active_view_get
* RenderEngine.active_view_set
* RenderEngine.camera_shift_x
* RenderEngine.camera_model_matrix
* RenderEngine.use_spherical_stereo
* RenderEngine.update_stats
* RenderEngine.frame_set
* RenderEngine.update_progress
* RenderEngine.update_memory_stats
* RenderEngine.report
* RenderEngine.error_set
* RenderEngine.bind_display_space_shader
* RenderEngine.unbind_display_space_shader
* RenderEngine.support_display_space_shader
* RenderEngine.get_preview_pixel_size
* RenderEngine.free_blender_memory
* RenderEngine.tile_highlight_set
* RenderEngine.tile_highlight_clear_all
* RenderEngine.register_pass
* RenderEngine.bl_rna_get_subclass
* RenderEngine.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.curve_paint_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.vertices

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.linestyles

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_annotation_layer
* Annotation.layers
* AnnotationLayers.new
* AnnotationLayers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.lattice
* BlendData.lattices
* BlendDataLattices.new
* BlendDataLattices.remove
* Lattice.unit_test_compare

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ArmatureConstraint.targets
* ArmatureConstraintTargets.new
* ArmatureConstraintTargets.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.rigidbody_world

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveMapping.curves
* CurveMapping.evaluate

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Light.type
* Light.use_temperature
* Light.color
* Light.temperature
* Light.temperature_color
* Light.specular_factor
* Light.diffuse_factor
* Light.transmission_factor
* Light.volume_factor
* Light.use_custom_distance
* Light.cutoff_distance
* Light.use_shadow
* Light.exposure
* Light.normalize
* Light.node_tree
* Light.use_nodes
* Light.animation_data
* Light.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Light.area
* Light.inline_shader_nodes
* Light.bl_rna_get_subclass
* Light.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Spline.points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* ShaderNodeTree.get_output_node

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ChannelDriverVariables.new
* ChannelDriverVariables.remove
* Driver.variables

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeView3D.space

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.objects

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curves.curves

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnimData.drivers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.fonts
* BlendDataFonts.load
* BlendDataFonts.remove
* GeometryNodeInputFont.font
* NodeSocketFont.default_value
* NodeTreeInterfaceSocketFont.default_value
* TextCurve.font
* TextCurve.font_bold
* TextCurve.font_bold_italic
* TextCurve.font_italic
* TextStrip.font

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.palettes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.image_editor

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderSettings.views

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderSettings.ffmpeg

:columns: 2


--------------------

* bpy_struct.id_data
* TextureSlot.texture
* TextureSlot.name
* TextureSlot.offset
* TextureSlot.scale
* TextureSlot.color
* TextureSlot.blend_type
* TextureSlot.default_value
* TextureSlot.output_node

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* TextureSlot.bl_rna_get_subclass
* TextureSlot.bl_rna_get_subclass_py

:columns: 2


--------------------

* Brush.mask_texture_slot
* Brush.texture_slot

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapItem.user_paths

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curve.splines
* CurveSplines.active
* CurveSplines.new
* CurveSplines.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Volume.render

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.themes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeCryptomatteV2.entries

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionGroup.colors
* BoneColor.custom
* Theme.bone_color_sets

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Node.insert_link
* Node.internal_links
* NodeLink.swap_multi_input_sort_id
* NodeLinks.new
* NodeLinks.remove
* NodeTree.links

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.objects
* MovieTrackingObjects.active
* MovieTrackingObjects.new
* MovieTrackingObjects.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.autoexec_paths

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FCurve.keyframe_points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.strip_modifier
* Strip.modifiers
* StripModifiers.active
* StripModifiers.new
* StripModifiers.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSettings.boids

:columns: 2


--------------------

This example demonstrates access to the evaluated ID (such as object, material, etc.) state from
an original ID.
This is needed every time one needs to access state with animation, constraints, and modifiers
taken into account.

```../examples/bpy.types.Depsgraph.1.py```


--------------------

This example demonstrates access to the original ID.
Such access is needed to check whether object is selected, or to compare pointers.

```../examples/bpy.types.Depsgraph.2.py```


--------------------

Sometimes it is needed to know all the instances with their matrices (for example, when writing an
exporter or a custom render engine).
This example shows how to access all objects and instances in the scene.

```../examples/bpy.types.Depsgraph.3.py```


--------------------

Function to get a mesh from any object with geometry. It is typically used by exporters, render
engines and tools that need to access the evaluated mesh as displayed in the viewport.

Object.to_mesh() is closely interacting with dependency graph: its behavior depends on whether it
is used on original or evaluated object.

When is used on original object, the result mesh is calculated from the object without taking
animation or modifiers into account:

* For meshes this is similar to duplicating the source mesh.
* For curves this disables own modifiers, and modifiers of objects used as bevel and taper.
* For meta-balls this produces an empty mesh since polygonization is done as a modifier evaluation.

When is used on evaluated object all modifiers are taken into account.

[NOTE]
The result mesh is owned by the object. It can be freed by calling ~Object.to_mesh_clear.

[NOTE]
The result mesh must be treated as temporary, and cannot be referenced from objects in the main
database. If the mesh intended to be used in a persistent manner use ~BlendDataMeshes.new_from_object
instead.

[NOTE]
If object does not have geometry (i.e. camera) the functions returns None.

```../examples/bpy.types.Depsgraph.4.py```


--------------------

Function to copy a new mesh from any object with geometry. The mesh is added to the main
database and can be referenced by objects. Typically used by tools that create new objects
or apply modifiers.

When is used on original object, the result mesh is calculated from the object without taking
animation or modifiers into account:

* For meshes this is similar to duplicating the source mesh.
* For curves this disables own modifiers, and modifiers of objects used as bevel and taper.
* For meta-balls this produces an empty mesh since polygonization is done as a modifier evaluation.

When is used on evaluated object all modifiers are taken into account.

All the references (such as materials) are re-mapped to original. This ensures validity and
consistency of the main database.

[NOTE]
If object does not have geometry (i.e. camera) the functions returns None.

```../examples/bpy.types.Depsgraph.5.py```


--------------------

This example is a combination of all previous ones, and shows how to write a simple exporter
script.

```../examples/bpy.types.Depsgraph.6.py```


--------------------

Function to get a curve from text and curve objects. It is typically used by exporters, render
engines, and tools that need to access the curve representing the object.

The function takes the evaluated dependency graph as a required parameter and optionally a boolean
apply_modifiers which defaults to false. If apply_modifiers is true and the object is a curve object,
the spline deform modifiers are applied on the control points. Note that constructive modifiers and
modifiers that are not spline-enabled will not be applied. So modifiers like Array will not be applied
and deform modifiers that have Apply On Spline disabled will not be applied.

If the object is a text object. The text will be converted into a 3D curve and returned. Modifiers are
never applied on text objects and apply_modifiers will be ignored. If the object is neither a curve nor
a text object, an error will be reported.

[NOTE]
The resulting curve is owned by the object. It can be freed by calling ~Object.to_curve_clear.

[NOTE]
The resulting curve must be treated as temporary, and cannot be referenced from objects in the main
database.

```../examples/bpy.types.Depsgraph.7.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendDataMeshes.new_from_object
* Context.evaluated_depsgraph_get
* ID.evaluated_get
* Object.calc_matrix_camera
* Object.camera_fit_coords
* Object.closest_point_on_mesh
* Object.crazyspace_eval
* Object.ray_cast
* Object.to_curve
* Object.to_mesh
* RenderEngine.bake
* RenderEngine.draw
* RenderEngine.render
* RenderEngine.update
* RenderEngine.view_draw
* RenderEngine.view_update
* Scene.ray_cast
* ViewLayer.depsgraph

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.eevee

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationFrame.strokes
* AnnotationStrokes.new
* AnnotationStrokes.remove

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* NodeTree.color_tag
* NodeTree.default_group_node_width
* NodeTree.view_center
* NodeTree.description
* NodeTree.animation_data
* NodeTree.nodes
* NodeTree.links
* NodeTree.annotation
* NodeTree.type
* NodeTree.interface
* NodeTree.bl_idname
* NodeTree.bl_label
* NodeTree.bl_description
* NodeTree.bl_icon
* NodeTree.bl_use_group_interface

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* NodeTree.interface_update
* NodeTree.contains_tree
* NodeTree.poll
* NodeTree.update
* NodeTree.get_from_context
* NodeTree.valid_socket_type
* NodeTree.debug_lazy_function_graph
* NodeTree.bl_rna_get_subclass
* NodeTree.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.apps

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeClosureOutput.input_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* MeshUVLoopLayer.pin_ensure

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* XrActionMapBinding.component_paths

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.shader_effects

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Annotation.animation_data
* Armature.animation_data
* CacheFile.animation_data
* Camera.animation_data
* Curve.animation_data
* Curves.animation_data
* FreestyleLineStyle.animation_data
* GreasePencil.animation_data
* ID.animation_data_create
* Key.animation_data
* Lattice.animation_data
* Light.animation_data
* LightProbe.animation_data
* Mask.animation_data
* Material.animation_data
* Mesh.animation_data
* MetaBall.animation_data
* MovieClip.animation_data
* NodeTree.animation_data
* Object.animation_data
* ParticleSettings.animation_data
* PointCloud.animation_data
* Scene.animation_data
* Speaker.animation_data
* Texture.animation_data
* Volume.animation_data
* World.animation_data

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* TextureSlot.texture
* TextureSlot.name
* TextureSlot.offset
* TextureSlot.scale
* TextureSlot.color
* TextureSlot.blend_type
* TextureSlot.default_value
* TextureSlot.output_node

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* TextureSlot.bl_rna_get_subclass
* TextureSlot.bl_rna_get_subclass_py

:columns: 2


--------------------

* FreestyleLineStyle.texture_slots
* LineStyleTextureSlots.add
* LineStyleTextureSlots.create

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Collection.exporters
* CollectionExports.new
* CollectionExports.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.brushes

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeCaptureAttribute.capture_items

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SceneDisplay.shading
* SpaceView3D.shading
* XrSessionSettings.shading

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CameraBackgroundImage.clip_user
* SpaceClipEditor.clip_user
* UILayout.template_marker
* UILayout.template_movieclip_information

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_node
* bpy.context.selected_nodes
* bpy.context.texture_node
* GeometryNodeForeachGeometryElementInput.paired_output
* GeometryNodeMenuSwitch.enum_definition
* GeometryNodeRepeatInput.paired_output
* GeometryNodeSimulationInput.paired_output
* Node.copy
* Node.parent
* NodeClosureInput.paired_output
* NodeLink.from_node
* NodeLink.to_node
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.node
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeTree.nodes
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocketBool.from_socket
* NodeTreeInterfaceSocketBool.init_socket
* NodeTreeInterfaceSocketBundle.from_socket
* NodeTreeInterfaceSocketBundle.init_socket
* NodeTreeInterfaceSocketClosure.from_socket
* NodeTreeInterfaceSocketClosure.init_socket
* NodeTreeInterfaceSocketCollection.from_socket
* NodeTreeInterfaceSocketCollection.init_socket
* NodeTreeInterfaceSocketColor.from_socket
* NodeTreeInterfaceSocketColor.init_socket
* NodeTreeInterfaceSocketFloat.from_socket
* NodeTreeInterfaceSocketFloat.init_socket
* NodeTreeInterfaceSocketFloatAngle.from_socket
* NodeTreeInterfaceSocketFloatAngle.init_socket
* NodeTreeInterfaceSocketFloatColorTemperature.from_socket
* NodeTreeInterfaceSocketFloatColorTemperature.init_socket
* NodeTreeInterfaceSocketFloatDistance.from_socket
* NodeTreeInterfaceSocketFloatDistance.init_socket
* NodeTreeInterfaceSocketFloatFactor.from_socket
* NodeTreeInterfaceSocketFloatFactor.init_socket
* NodeTreeInterfaceSocketFloatFrequency.from_socket
* NodeTreeInterfaceSocketFloatFrequency.init_socket
* NodeTreeInterfaceSocketFloatMass.from_socket
* NodeTreeInterfaceSocketFloatMass.init_socket
* NodeTreeInterfaceSocketFloatPercentage.from_socket
* NodeTreeInterfaceSocketFloatPercentage.init_socket
* NodeTreeInterfaceSocketFloatTime.from_socket
* NodeTreeInterfaceSocketFloatTime.init_socket
* NodeTreeInterfaceSocketFloatTimeAbsolute.from_socket
* NodeTreeInterfaceSocketFloatTimeAbsolute.init_socket
* NodeTreeInterfaceSocketFloatUnsigned.from_socket
* NodeTreeInterfaceSocketFloatUnsigned.init_socket
* NodeTreeInterfaceSocketFloatWavelength.from_socket
* NodeTreeInterfaceSocketFloatWavelength.init_socket
* NodeTreeInterfaceSocketGeometry.from_socket
* NodeTreeInterfaceSocketGeometry.init_socket
* NodeTreeInterfaceSocketImage.from_socket
* NodeTreeInterfaceSocketImage.init_socket
* NodeTreeInterfaceSocketInt.from_socket
* NodeTreeInterfaceSocketInt.init_socket
* NodeTreeInterfaceSocketIntFactor.from_socket
* NodeTreeInterfaceSocketIntFactor.init_socket
* NodeTreeInterfaceSocketIntPercentage.from_socket
* NodeTreeInterfaceSocketIntPercentage.init_socket
* NodeTreeInterfaceSocketIntUnsigned.from_socket
* NodeTreeInterfaceSocketIntUnsigned.init_socket
* NodeTreeInterfaceSocketMaterial.from_socket
* NodeTreeInterfaceSocketMaterial.init_socket
* NodeTreeInterfaceSocketMatrix.from_socket
* NodeTreeInterfaceSocketMatrix.init_socket
* NodeTreeInterfaceSocketMenu.from_socket
* NodeTreeInterfaceSocketMenu.init_socket
* NodeTreeInterfaceSocketObject.from_socket
* NodeTreeInterfaceSocketObject.init_socket
* NodeTreeInterfaceSocketRotation.from_socket
* NodeTreeInterfaceSocketRotation.init_socket
* NodeTreeInterfaceSocketShader.from_socket
* NodeTreeInterfaceSocketShader.init_socket
* NodeTreeInterfaceSocketString.from_socket
* NodeTreeInterfaceSocketString.init_socket
* NodeTreeInterfaceSocketStringFilePath.from_socket
* NodeTreeInterfaceSocketStringFilePath.init_socket
* NodeTreeInterfaceSocketTexture.from_socket
* NodeTreeInterfaceSocketTexture.init_socket
* NodeTreeInterfaceSocketVector.from_socket
* NodeTreeInterfaceSocketVector.init_socket
* NodeTreeInterfaceSocketVector2D.from_socket
* NodeTreeInterfaceSocketVector2D.init_socket
* NodeTreeInterfaceSocketVector4D.from_socket
* NodeTreeInterfaceSocketVector4D.init_socket
* NodeTreeInterfaceSocketVectorAcceleration.from_socket
* NodeTreeInterfaceSocketVectorAcceleration.init_socket
* NodeTreeInterfaceSocketVectorAcceleration2D.from_socket
* NodeTreeInterfaceSocketVectorAcceleration2D.init_socket
* NodeTreeInterfaceSocketVectorAcceleration4D.from_socket
* NodeTreeInterfaceSocketVectorAcceleration4D.init_socket
* NodeTreeInterfaceSocketVectorDirection.from_socket
* NodeTreeInterfaceSocketVectorDirection.init_socket
* NodeTreeInterfaceSocketVectorDirection2D.from_socket
* NodeTreeInterfaceSocketVectorDirection2D.init_socket
* NodeTreeInterfaceSocketVectorDirection4D.from_socket
* NodeTreeInterfaceSocketVectorDirection4D.init_socket
* NodeTreeInterfaceSocketVectorEuler.from_socket
* NodeTreeInterfaceSocketVectorEuler.init_socket
* NodeTreeInterfaceSocketVectorEuler2D.from_socket
* NodeTreeInterfaceSocketVectorEuler2D.init_socket
* NodeTreeInterfaceSocketVectorEuler4D.from_socket
* NodeTreeInterfaceSocketVectorEuler4D.init_socket
* NodeTreeInterfaceSocketVectorFactor.from_socket
* NodeTreeInterfaceSocketVectorFactor.init_socket
* NodeTreeInterfaceSocketVectorFactor2D.from_socket
* NodeTreeInterfaceSocketVectorFactor2D.init_socket
* NodeTreeInterfaceSocketVectorFactor4D.from_socket
* NodeTreeInterfaceSocketVectorFactor4D.init_socket
* NodeTreeInterfaceSocketVectorPercentage.from_socket
* NodeTreeInterfaceSocketVectorPercentage.init_socket
* NodeTreeInterfaceSocketVectorPercentage2D.from_socket
* NodeTreeInterfaceSocketVectorPercentage2D.init_socket
* NodeTreeInterfaceSocketVectorPercentage4D.from_socket
* NodeTreeInterfaceSocketVectorPercentage4D.init_socket
* NodeTreeInterfaceSocketVectorTranslation.from_socket
* NodeTreeInterfaceSocketVectorTranslation.init_socket
* NodeTreeInterfaceSocketVectorTranslation2D.from_socket
* NodeTreeInterfaceSocketVectorTranslation2D.init_socket
* NodeTreeInterfaceSocketVectorTranslation4D.from_socket
* NodeTreeInterfaceSocketVectorTranslation4D.init_socket
* NodeTreeInterfaceSocketVectorVelocity.from_socket
* NodeTreeInterfaceSocketVectorVelocity.init_socket
* NodeTreeInterfaceSocketVectorVelocity2D.from_socket
* NodeTreeInterfaceSocketVectorVelocity2D.init_socket
* NodeTreeInterfaceSocketVectorVelocity4D.from_socket
* NodeTreeInterfaceSocketVectorVelocity4D.init_socket
* NodeTreeInterfaceSocketVectorXYZ.from_socket
* NodeTreeInterfaceSocketVectorXYZ.init_socket
* NodeTreeInterfaceSocketVectorXYZ2D.from_socket
* NodeTreeInterfaceSocketVectorXYZ2D.init_socket
* NodeTreeInterfaceSocketVectorXYZ4D.from_socket
* NodeTreeInterfaceSocketVectorXYZ4D.init_socket
* Nodes.active
* Nodes.new
* Nodes.remove
* NodesModifierBake.node
* RenderEngine.update_script_node
* SpaceNodeEditorPath.append
* UILayout.template_node_inputs
* UILayout.template_node_link
* UILayout.template_node_view

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.vertices

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.skin_vertices

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnnotationStroke.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendImportContext.import_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Paint.brush
* Paint.brush_asset_reference
* Paint.eraser_brush
* Paint.eraser_brush_asset_reference
* Paint.palette
* Paint.show_brush
* Paint.show_brush_on_surface
* Paint.show_low_resolution
* Paint.use_sculpt_delay_updates
* Paint.show_bvh_nodes
* Paint.use_symmetry_x
* Paint.use_symmetry_y
* Paint.use_symmetry_z
* Paint.use_symmetry_feather
* Paint.cavity_curve
* Paint.use_cavity
* Paint.tile_offset
* Paint.tile_x
* Paint.tile_y
* Paint.tile_z
* Paint.show_strength_curve
* Paint.show_size_curve
* Paint.show_jitter_curve
* Paint.unified_paint_settings

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Paint.bl_rna_get_subclass
* Paint.bl_rna_get_subclass_py

:columns: 2


--------------------

* ToolSettings.gpencil_sculpt_paint

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewLayer.aovs

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeOutputFile.file_output_items
* NodeCompositorFileOutputItems.new
* NodeCompositorFileOutputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesFilePaths.script_directories
* ScriptDirectoryCollection.new
* ScriptDirectoryCollection.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetShelf.draw_context_menu
* AssetShelf.poll
* FileHandler.poll_drop
* Gizmo.draw
* Gizmo.draw_select
* Gizmo.exit
* Gizmo.invoke
* Gizmo.modal
* Gizmo.test_select
* GizmoGroup.draw_prepare
* GizmoGroup.invoke_prepare
* GizmoGroup.poll
* GizmoGroup.refresh
* GizmoGroup.setup
* Header.draw
* KeyingSetInfo.generate
* KeyingSetInfo.iterator
* KeyingSetInfo.poll
* Macro.draw
* Macro.poll
* Menu.draw
* Menu.poll
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.init
* Node.socket_value_update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeTree.get_from_context
* NodeTree.interface_update
* NodeTree.poll
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocketBool.draw
* NodeTreeInterfaceSocketBundle.draw
* NodeTreeInterfaceSocketClosure.draw
* NodeTreeInterfaceSocketCollection.draw
* NodeTreeInterfaceSocketColor.draw
* NodeTreeInterfaceSocketFloat.draw
* NodeTreeInterfaceSocketFloatAngle.draw
* NodeTreeInterfaceSocketFloatColorTemperature.draw
* NodeTreeInterfaceSocketFloatDistance.draw
* NodeTreeInterfaceSocketFloatFactor.draw
* NodeTreeInterfaceSocketFloatFrequency.draw
* NodeTreeInterfaceSocketFloatMass.draw
* NodeTreeInterfaceSocketFloatPercentage.draw
* NodeTreeInterfaceSocketFloatTime.draw
* NodeTreeInterfaceSocketFloatTimeAbsolute.draw
* NodeTreeInterfaceSocketFloatUnsigned.draw
* NodeTreeInterfaceSocketFloatWavelength.draw
* NodeTreeInterfaceSocketGeometry.draw
* NodeTreeInterfaceSocketImage.draw
* NodeTreeInterfaceSocketInt.draw
* NodeTreeInterfaceSocketIntFactor.draw
* NodeTreeInterfaceSocketIntPercentage.draw
* NodeTreeInterfaceSocketIntUnsigned.draw
* NodeTreeInterfaceSocketMaterial.draw
* NodeTreeInterfaceSocketMatrix.draw
* NodeTreeInterfaceSocketMenu.draw
* NodeTreeInterfaceSocketObject.draw
* NodeTreeInterfaceSocketRotation.draw
* NodeTreeInterfaceSocketShader.draw
* NodeTreeInterfaceSocketString.draw
* NodeTreeInterfaceSocketStringFilePath.draw
* NodeTreeInterfaceSocketTexture.draw
* NodeTreeInterfaceSocketVector.draw
* NodeTreeInterfaceSocketVector2D.draw
* NodeTreeInterfaceSocketVector4D.draw
* NodeTreeInterfaceSocketVectorAcceleration.draw
* NodeTreeInterfaceSocketVectorAcceleration2D.draw
* NodeTreeInterfaceSocketVectorAcceleration4D.draw
* NodeTreeInterfaceSocketVectorDirection.draw
* NodeTreeInterfaceSocketVectorDirection2D.draw
* NodeTreeInterfaceSocketVectorDirection4D.draw
* NodeTreeInterfaceSocketVectorEuler.draw
* NodeTreeInterfaceSocketVectorEuler2D.draw
* NodeTreeInterfaceSocketVectorEuler4D.draw
* NodeTreeInterfaceSocketVectorFactor.draw
* NodeTreeInterfaceSocketVectorFactor2D.draw
* NodeTreeInterfaceSocketVectorFactor4D.draw
* NodeTreeInterfaceSocketVectorPercentage.draw
* NodeTreeInterfaceSocketVectorPercentage2D.draw
* NodeTreeInterfaceSocketVectorPercentage4D.draw
* NodeTreeInterfaceSocketVectorTranslation.draw
* NodeTreeInterfaceSocketVectorTranslation2D.draw
* NodeTreeInterfaceSocketVectorTranslation4D.draw
* NodeTreeInterfaceSocketVectorVelocity.draw
* NodeTreeInterfaceSocketVectorVelocity2D.draw
* NodeTreeInterfaceSocketVectorVelocity4D.draw
* NodeTreeInterfaceSocketVectorXYZ.draw
* NodeTreeInterfaceSocketVectorXYZ2D.draw
* NodeTreeInterfaceSocketVectorXYZ4D.draw
* Operator.cancel
* Operator.check
* Operator.description
* Operator.draw
* Operator.execute
* Operator.invoke
* Operator.modal
* Operator.poll
* Panel.draw
* Panel.draw_header
* Panel.draw_header_preset
* Panel.poll
* RenderEngine.draw
* RenderEngine.view_draw
* RenderEngine.view_update
* UIList.draw_filter
* UIList.draw_item
* UIList.filter_items
* XrSessionState.action_binding_create
* XrSessionState.action_create
* XrSessionState.action_set_create
* XrSessionState.action_state_get
* XrSessionState.active_action_set_set
* XrSessionState.controller_aim_location_get
* XrSessionState.controller_aim_rotation_get
* XrSessionState.controller_grip_location_get
* XrSessionState.controller_grip_rotation_get
* XrSessionState.controller_pose_actions_set
* XrSessionState.haptic_action_apply
* XrSessionState.haptic_action_stop
* XrSessionState.is_running
* XrSessionState.reset_to_base_pose

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

This script shows simple operator which prints a message.

Since the operator only has an Operator.execute function it takes no
user input.

The function should return {'FINISHED'}

 or {'CANCELLED'}

, the latter
meaning that operator execution was aborted without making any changes, and
that no undo step will created (see next example for more info about undo).

[NOTE]
Operator subclasses must be registered before accessing them from Blender.

```../examples/bpy.types.Operator.0.py```


--------------------

Any operator modifying Blender data should enable the 'UNDO'

 option.
This will make Blender automatically create an undo step when the operator
finishes its execute

 (or invoke

, see below) functions, and returns
{'FINISHED'}

.

Otherwise, no undo step will be created, which will at best corrupt the
undo stack and confuse the user (since modifications done by the operator
may either not be undoable, or be undone together with other edits done
before). In many cases, this can even lead to data corruption and crashes.

Note that when an operator returns {'CANCELLED'}

, no undo step will be
created. This means that if an error occurs *after* modifying some data
already, it is better to return {'FINISHED'}

, unless it is possible to
fully undo the changes before returning.

[NOTE]
Most examples in this page do not do any edit to Blender data, which is
why it is safe to keep the default bl_options

 value for these operators.

[NOTE]
In some complex cases, the automatic undo step created on operator exit may
not be enough. For example, if the operator does mode switching, or calls
other operators that should create an extra undo step, etc.
Such manual undo push is possible using the bpy.ops.ed.undo_push
function. Be careful though, this is considered an advanced feature and
requires some understanding of the actual undo system in Blender code.

```../examples/bpy.types.Operator.1.py```


--------------------

Operator.invoke is used to initialize the operator from the context
at the moment the operator is called.
invoke() is typically used to assign properties which are then used by
execute().
Some operators don't have an execute() function, removing the ability to be
repeated from a script or macro.

When an operator is called via bpy.ops, the execution context depends
on the argument provided to bpy.ops. By default, it uses execute().
When an operator is activated from a button or menu item, it follows
the setting in UILayout.operator_context. In most cases, invoke() is used.
Running an operator via a key shortcut always uses invoke(),
and this behavior cannot be changed.

This example shows how to define an operator which gets mouse input to
execute a function and that this operator can be invoked or executed from
the Python API.

Also notice this operator defines its own properties, these are different
to typical class properties because Blender registers them with the
operator, to use as arguments when called, saved for operator undo/redo and
automatically added into the user interface.

```../examples/bpy.types.Operator.2.py```


--------------------

This example shows how an operator can use the file selector.

Notice the invoke function calls a window manager method and returns
{'RUNNING_MODAL'}

, this means the file selector stays open and the operator does not
exit immediately after invoke finishes.

The file selector runs the operator, calling Operator.execute when the
user confirms.

The Operator.poll function is optional, used to check if the operator
can run.

```../examples/bpy.types.Operator.3.py```


--------------------

This operator uses its Operator.invoke function to call a popup.

```../examples/bpy.types.Operator.4.py```


--------------------

By default operator properties use an automatic user interface layout.
If you need more control you can create your own layout with a
Operator.draw function.

This works like the Panel and Menu draw functions, its used
for dialogs and file selectors.

```../examples/bpy.types.Operator.5.py```


--------------------

This operator defines a Operator.modal function that will keep being
run to handle events until it returns {'FINISHED'}

 or {'CANCELLED'}

.

Modal operators run every time a new event is detected, such as a mouse click
or key press. Conversely, when no new events are detected, the modal operator
will not run. Modal operators are especially useful for interactive tools, an
operator can have its own state where keys toggle options as the operator runs.
Grab, Rotate, Scale, and Fly-Mode are examples of modal operators.

Operator.invoke is used to initialize the operator as being active
by returning {'RUNNING_MODAL'}

, initializing the modal loop.

Notice __init__()

 and __del__()

 are declared.
For other operator types they are not useful but for modal operators they will
be called before the Operator.invoke and after the operator finishes.
Also see the
class construction and destruction section <info_overview_class_construction_destruction>.

```../examples/bpy.types.Operator.6.py```


--------------------

You may want to have an operator prompt the user to select an item
from a search field, this can be done using bpy.types.Operator.invoke_search_popup.

```../examples/bpy.types.Operator.7.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_operator
* SpaceFileBrowser.active_operator
* SpaceFileBrowser.operator
* Window.modal_operators
* WindowManager.fileselect_add
* WindowManager.invoke_confirm
* WindowManager.invoke_popup
* WindowManager.invoke_props_dialog
* WindowManager.invoke_props_popup
* WindowManager.invoke_search_popup
* WindowManager.modal_handler_add
* WindowManager.operators

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.collections
* BlendDataCollections.new
* BlendDataCollections.remove
* BooleanModifier.collection
* ClothCollisionSettings.collection
* Collection.children
* CollectionChildren.link
* CollectionChildren.unlink
* Context.collection
* DopeSheet.filter_collection
* DynamicPaintSurface.brush_collection
* EffectorWeights.collection
* FluidDomainSettings.effector_group
* FluidDomainSettings.fluid_group
* FluidDomainSettings.force_collection
* FreestyleLineSet.collection
* GeometryNodeInputCollection.collection
* GreasePencilLineartModifier.source_collection
* IDOverrideLibrary.resync
* LayerCollection.collection
* LightProbe.visibility_collection
* NodeSocketCollection.default_value
* NodeTreeInterfaceSocketCollection.default_value
* ObjectLightLinking.blocker_collection
* ObjectLightLinking.receiver_collection
* Object.instance_collection
* ParticleSettings.collision_collection
* ParticleSettings.instance_collection
* RigidBodyWorld.collection
* RigidBodyWorld.constraints
* Scene.collection
* SoftBodySettings.collision_collection

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FCurve.driver

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.sequence_editor

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.meshes

:columns: 2


--------------------

PropertyGroups are the base class for dynamically defined sets of properties.

They can be used to extend existing Blender data with your own types which can
be animated, accessed from the user interface and from Python.

[NOTE]
The values assigned to Blender data are saved to disk but the class
definitions are not, this means whenever you load Blender the class needs
to be registered too.
This is best done by creating an add-on which loads on startup and registers
your properties.

[NOTE]
PropertyGroups must be registered before assigning them to Blender data.

Property types used in class declarations are all in bpy.props



```../examples/bpy.types.PropertyGroup.0.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AddonPreferences.bl_system_properties_get
* Bone.bl_system_properties_get
* BoneCollection.bl_system_properties_get
* CollectionExport.export_properties
* EditBone.bl_system_properties_get
* GizmoGroupProperties.bl_system_properties_get
* GizmoProperties.bl_system_properties_get
* ID.bl_system_properties_get
* IDPropertyWrapPtr.bl_system_properties_get
* KeyConfigPreferences.bl_system_properties_get
* Node.bl_system_properties_get
* NodeSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodesModifier.bl_system_properties_get
* OperatorProperties.bl_system_properties_get
* PoseBone.bl_system_properties_get
* PropertyGroup.bl_system_properties_get
* PropertyGroupItem.collection
* PropertyGroupItem.group
* PropertyGroupItem.idp_array
* Strip.bl_system_properties_get
* TimelineMarker.bl_system_properties_get
* UIList.bl_system_properties_get
* View3DShading.bl_system_properties_get
* ViewLayer.bl_system_properties_get

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleGeometryModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleGeometryModifier.bl_rna_get_subclass
* LineStyleGeometryModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ViewerPathElem.type
* ViewerPathElem.ui_name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ViewerPathElem.bl_rna_get_subclass
* ViewerPathElem.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetMetaData.tags
* AssetTags.new
* AssetTags.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.workspaces

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.texture_slot
* UILayout.template_preview

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.piemenu_begin__internal
* WindowManager.piemenu_end__internal

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ImageStrip.elements

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionChannelbag.groups
* ActionChannelbagGroups.new
* ActionChannelbagGroups.remove
* FCurve.group

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeStyle.panel_title
* ThemeStyle.tooltip
* ThemeStyle.widget

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeTree.interface
* UILayout.template_node_tree_interface

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskLayer.splines
* MaskSplines.active
* MaskSplines.new
* MaskSplines.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.dopesheet

:columns: 2


--------------------

```../examples/bpy.types.RenderEngine.1.py```


--------------------

```../examples/bpy.types.RenderEngine.2.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FloatColorAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.actions

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.filepaths

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.studio_lights

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Pose.ik_param

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.stabilization

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ViewerPath.path

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* KeyConfigurations.find_item_from_operator
* KeyMap.keymap_items
* KeyMap.restore_item_to_default
* KeyMapItem.compare
* KeyMapItems.find_from_operator
* KeyMapItems.find_match
* KeyMapItems.find_match
* KeyMapItems.from_id
* KeyMapItems.match_event
* KeyMapItems.new
* KeyMapItems.new_from_item
* KeyMapItems.new_from_item
* KeyMapItems.new_modal
* KeyMapItems.remove
* UILayout.template_event_from_keymap_item
* UILayout.template_keymap_item_properties

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeFieldToGrid.grid_items

:columns: 2


--------------------

* bpy_struct.id_data
* SpreadsheetTableID.type

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* SpreadsheetTableID.bl_rna_get_subclass
* SpreadsheetTableID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CacheFile.layers
* CacheFileLayers.active
* CacheFileLayers.new
* CacheFileLayers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Brush.vertex_paint_capabilities

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* EffectStrip.crop
* ImageStrip.crop
* MaskStrip.crop
* MetaStrip.crop
* MovieClipStrip.crop
* MovieStrip.crop
* SceneStrip.crop

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingObject.tracks

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.particle_settings
* BlendData.particles
* BlendDataParticles.new
* BlendDataParticles.remove
* ParticleSystem.settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.input_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GPencilSculptSettings.guide

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionLayer.strips

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.active_nla_track
* AnimData.nla_tracks
* NlaTracks.active
* NlaTracks.new
* NlaTracks.new
* NlaTracks.remove

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* RenderResult.layers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* Particle.uv_on_emitter
* ParticleHairKey.co_object
* ParticleHairKey.co_object_set
* ParticleSystem.mcol_on_emitter
* ParticleSystem.uv_on_emitter

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskSpline.points

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Curves.normals

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeTree.nodes

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ImageStrip.elements
* MovieStrip.elements
* Strip.strip_elem_from_frame
* StripElements.append

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Spline.points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.edges

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleColorModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleColorModifier.bl_rna_get_subclass
* LineStyleColorModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Volume.grids

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CompositorNodeConvertToDisplay.view_settings
* ImageFormatSettings.view_settings
* Scene.view_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.constraints
* ObjectConstraints.active
* ObjectConstraints.copy
* ObjectConstraints.copy
* ObjectConstraints.new
* ObjectConstraints.remove
* Panel.custom_data
* PoseBone.constraints
* PoseBoneConstraints.active
* PoseBoneConstraints.copy
* PoseBoneConstraints.copy
* PoseBoneConstraints.new
* PoseBoneConstraints.remove
* UILayout.template_constraint_header

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.plane_tracks

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeEvaluateClosure.input_items
* NodeEvaluateClosureInputItems.new
* NodeEvaluateClosureInputItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.window
* Window.parent
* WindowManager.event_timer_add
* WindowManager.windows
* Windows.find_playing

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.colorspace_settings
* ImageStrip.colorspace_settings
* MovieClip.colorspace_settings
* MovieStrip.colorspace_settings
* ImageFormatSettings.linear_colorspace_settings

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.light_linking

:columns: 2


--------------------

This script demonstrates basic operations on object like creating new
object, placing it into a view layer, selecting it and making it active.

```../examples/bpy.types.Object.0.py```


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.active_object
* bpy.context.edit_object
* bpy.context.editable_objects
* bpy.context.image_paint_object
* bpy.context.object
* bpy.context.objects_in_mode
* bpy.context.objects_in_mode_unique_data
* bpy.context.particle_edit_object
* bpy.context.pose_object
* bpy.context.sculpt_object
* bpy.context.selectable_objects
* bpy.context.selected_editable_objects
* bpy.context.selected_objects
* bpy.context.vertex_paint_object
* bpy.context.visible_objects
* bpy.context.weight_paint_object
* Action.flip_with_pose
* ActionConstraint.target
* ArmatureModifier.object
* ArrayModifier.curve
* ArrayModifier.end_cap
* ArrayModifier.offset_object
* ArrayModifier.start_cap
* BlendData.objects
* BlendDataMeshes.new_from_object
* BlendDataObjects.new
* BlendDataObjects.remove
* BoidRuleAvoid.object
* BoidRuleFollowLeader.object
* BoidRuleGoal.object
* BooleanModifier.object
* CameraDOFSettings.focus_object
* CastModifier.object
* ChildOfConstraint.target
* ClampToConstraint.target
* Collection.all_objects
* Collection.objects
* CollectionObjects.link
* CollectionObjects.unlink
* Constraint.space_object
* ConstraintTarget.target
* ConstraintTargetBone.target
* CopyLocationConstraint.target
* CopyRotationConstraint.target
* CopyScaleConstraint.target
* CopyTransformsConstraint.target
* Curve.bevel_object
* Curve.taper_object
* CurveModifier.object
* Curves.surface
* CyclesRenderSettings.dicing_camera
* DampedTrackConstraint.target
* DataTransferModifier.object
* Depsgraph.objects
* DepsgraphObjectInstance.instance_object
* DepsgraphObjectInstance.object
* DepsgraphObjectInstance.parent
* DisplaceModifier.texture_coords_object
* DynamicPaintSurface.output_exists
* FieldSettings.source_object
* FloorConstraint.target
* FluidDomainSettings.guide_parent
* FollowPathConstraint.target
* FollowTrackConstraint.camera
* FollowTrackConstraint.depth_object
* GPencilSculptGuide.reference_object
* GeometryAttributeConstraint.target
* GeometryNodeInputObject.object
* GreasePencilArmatureModifier.object
* GreasePencilArrayModifier.offset_object
* GreasePencilBuildModifier.object
* GreasePencilHookModifier.object
* GreasePencilLatticeModifier.object
* GreasePencilLayer.parent
* GreasePencilLineartModifier.light_contour_object
* GreasePencilLineartModifier.source_camera
* GreasePencilLineartModifier.source_object
* GreasePencilMirrorModifier.object
* GreasePencilOutlineModifier.object
* GreasePencilShrinkwrapModifier.auxiliary_target
* GreasePencilShrinkwrapModifier.target
* GreasePencilTintModifier.object
* GreasePencilWeightProximityModifier.object
* HookModifier.object
* KinematicConstraint.pole_target
* KinematicConstraint.target
* LatticeModifier.object
* LayerObjects.active
* LayerObjects.selected
* LimitDistanceConstraint.target
* LineStyleAlphaModifier_DistanceFromObject.target
* LineStyleColorModifier_DistanceFromObject.target
* LineStyleThicknessModifier_DistanceFromObject.target
* LockedTrackConstraint.target
* MaskModifier.armature
* MeshDeformModifier.object
* MeshToVolumeModifier.object
* MirrorModifier.mirror_object
* NodeSocketObject.default_value
* NodeTreeInterfaceSocketObject.default_value
* NormalEditModifier.target
* Object.find_armature
* Object.parent
* ObjectBase.object
* ObjectSolverConstraint.camera
* ParticleEdit.object
* ParticleEdit.shape_object
* ParticleHairKey.co_object
* ParticleHairKey.co_object_set
* ParticleInstanceModifier.object
* ParticleSettings.instance_object
* ParticleSettingsTextureSlot.object
* ParticleSystem.co_hair
* ParticleSystem.parent
* ParticleSystem.reactor_target_object
* ParticleTarget.object
* PivotConstraint.target
* PoseBone.custom_shape
* RenderEngine.bake
* RenderEngine.camera_model_matrix
* RenderEngine.camera_override
* RenderEngine.camera_shift_x
* RenderEngine.use_spherical_stereo
* RigidBodyConstraint.object1
* RigidBodyConstraint.object2
* RigidBodyWorld.convex_sweep_test
* BakeSettings.cage_object
* Scene.camera
* Scene.objects
* Scene.ray_cast
* Scene.uvedit_aspect
* SceneStrip.scene_camera
* ScrewModifier.object
* Sculpt.gravity_object
* ShaderFxShadow.object
* ShaderFxSwirl.object
* ShaderNodeTexCoord.object
* ShrinkwrapConstraint.target
* ShrinkwrapModifier.auxiliary_target
* ShrinkwrapModifier.target
* SimpleDeformModifier.origin
* SpaceView3D.camera
* SpaceView3D.lock_object
* SplineIKConstraint.target
* StretchToConstraint.target
* SurfaceDeformModifier.target
* TextCurve.follow_curve
* TimelineMarker.camera
* ToolSettings.anim_mirror_object
* ToolSettings.anim_relative_object
* TrackToConstraint.target
* TransformConstraint.target
* UVProjector.object
* UVWarpModifier.object_from
* UVWarpModifier.object_to
* VertexWeightEditModifier.mask_tex_map_object
* VertexWeightMixModifier.mask_tex_map_object
* VertexWeightProximityModifier.mask_tex_map_object
* VertexWeightProximityModifier.target
* ViewLayer.objects
* VolumeDisplaceModifier.texture_map_object
* VolumeToMeshModifier.object
* WarpModifier.object_from
* WarpModifier.object_to
* WarpModifier.texture_coords_object
* WaveModifier.start_position_object
* WaveModifier.texture_coords_object
* XrSessionSettings.base_pose_object

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GizmoGroup.setup_keymap
* KeyConfig.keymaps
* KeyConfigurations.find_item_from_operator
* KeyMap.active
* KeyMapItems.find_match
* KeyMaps.find
* KeyMaps.find_match
* KeyMaps.find_match
* KeyMaps.find_modal
* KeyMaps.new
* KeyMaps.remove
* WindowManager.popover_end__internal

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Event.ndof_motion

:columns: 2


--------------------

* bpy_struct.id_data
* ShaderFx.name
* ShaderFx.type
* ShaderFx.show_viewport
* ShaderFx.show_render
* ShaderFx.show_in_editmode
* ShaderFx.show_expanded

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ShaderFx.bl_rna_get_subclass
* ShaderFx.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.cloth
* ParticleSystem.cloth

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* World.mist_settings

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingMarkers.find_frame
* MovieTrackingMarkers.insert_frame
* MovieTrackingTrack.markers

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesFilePaths.asset_libraries

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ActionLayer.strips
* ActionStrips.new
* ActionStrips.remove

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Area.regions
* Context.region
* Context.region_popup

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* BoidRule.name
* BoidRule.type
* BoidRule.use_in_air
* BoidRule.use_on_land

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* BoidRule.bl_rna_get_subclass
* BoidRule.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Context.area
* Screen.areas

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FunctionNodeFormatString.format_items

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* TextCurve.body_format
* TextCurve.edit_format

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.materials

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeClosureInputItems.new
* NodeClosureInputItems.remove
* NodeClosureOutput.input_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* FileHandler.bl_idname
* FileHandler.bl_import_operator
* FileHandler.bl_export_operator
* FileHandler.bl_label
* FileHandler.bl_file_extensions

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FileHandler.poll_drop
* FileHandler.bl_rna_get_subclass
* FileHandler.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.packed_file
* ImagePackedFile.packed_file
* Library.packed_file
* Sound.packed_file
* VectorFont.packed_file
* Volume.packed_file

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GizmoGroup.gizmos

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SequenceEditor.strips

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.user_interface

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.nla_editor

:columns: 2


--------------------

* bpy_struct.id_data
* AssetShelf.bl_idname
* AssetShelf.bl_space_type
* AssetShelf.bl_options
* AssetShelf.bl_activate_operator
* AssetShelf.bl_drag_operator
* AssetShelf.bl_default_preview_size
* AssetShelf.filter_action
* AssetShelf.filter_armature
* AssetShelf.filter_brush
* AssetShelf.filter_camera
* AssetShelf.filter_cachefile
* AssetShelf.filter_curve
* AssetShelf.filter_annotations
* AssetShelf.filter_grease_pencil
* AssetShelf.filter_group
* AssetShelf.filter_curves
* AssetShelf.filter_image
* AssetShelf.filter_light
* AssetShelf.filter_light_probe
* AssetShelf.filter_linestyle
* AssetShelf.filter_lattice
* AssetShelf.filter_material
* AssetShelf.filter_metaball
* AssetShelf.filter_movie_clip
* AssetShelf.filter_mesh
* AssetShelf.filter_mask
* AssetShelf.filter_node_tree
* AssetShelf.filter_object
* AssetShelf.filter_particle_settings
* AssetShelf.filter_palette
* AssetShelf.filter_paint_curve
* AssetShelf.filter_pointcloud
* AssetShelf.filter_scene
* AssetShelf.filter_speaker
* AssetShelf.filter_sound
* AssetShelf.filter_texture
* AssetShelf.filter_text
* AssetShelf.filter_font
* AssetShelf.filter_volume
* AssetShelf.filter_world
* AssetShelf.filter_work_space
* AssetShelf.asset_library_reference
* AssetShelf.show_names
* AssetShelf.preview_size
* AssetShelf.search_filter

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* AssetShelf.poll
* AssetShelf.asset_poll
* AssetShelf.get_active_asset
* AssetShelf.draw_context_menu
* AssetShelf.bl_rna_get_subclass
* AssetShelf.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleAlphaModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleAlphaModifier.bl_rna_get_subclass
* LineStyleAlphaModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FModifierEnvelope.control_points

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.edit_movieclip
* BlendData.movieclips
* BlendDataMovieClips.load
* BlendDataMovieClips.remove
* CameraBackgroundImage.clip
* CameraSolverConstraint.clip
* CompositorNodeKeyingScreen.clip
* CompositorNodeMovieClip.clip
* CompositorNodeMovieDistortion.clip
* CompositorNodePlaneTrackDeform.clip
* CompositorNodeStabilize.clip
* CompositorNodeTrackPos.clip
* FollowTrackConstraint.clip
* MovieClipStrip.clip
* ObjectSolverConstraint.clip
* Scene.active_clip
* SpaceClipEditor.clip
* StripsMeta.new_clip
* StripsTopLevel.new_clip

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WorkSpace.owner_ids
* wmOwnerIDs.new
* wmOwnerIDs.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Armature.collections

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FunctionNodeFormatString.format_items
* NodeFunctionFormatStringItems.new
* NodeFunctionFormatStringItems.remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.generation_items
* NodeGeometryForeachGeometryElementGenerationItems.new
* NodeGeometryForeachGeometryElementGenerationItems.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.particle_system
* bpy.context.particle_system_editable
* DepsgraphObjectInstance.particle_system
* DynamicPaintBrushSettings.particle_system
* FluidFlowSettings.particle_system
* Object.particle_systems
* ParticleInstanceModifier.particle_system
* ParticleSystemModifier.particle_system
* ParticleSystems.active

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

A file handler allows custom drag-and-drop behavior to be associated with a given Operator


(FileHandler.bl_import_operator) and set of file extensions
(FileHandler.bl_file_extensions). Control over which area of the UI accepts the
drag-in-drop action is specified using the FileHandler.poll_drop method.

Similar to operators that use a file select window, operators participating in drag-and-drop, and
only accepting a single file, must define the following property:

```
filepath: bpy.props.StringProperty(subtype='FILE_PATH', options={'SKIP_SAVE'})
```

This filepath

 property will be set to the full path of the file dropped by the user.

```../examples/bpy.types.FileHandler.1.py```


--------------------

Operators which support being executed with multiple files from drag-and-drop require the
following properties be defined:

```
directory: StringProperty(subtype='DIR_PATH', options={'SKIP_SAVE', 'HIDDEN'})
files: CollectionProperty(type=OperatorFileListElement, options={'SKIP_SAVE', 'HIDDEN'})
```

These directory

 and files

 properties will be set with the necessary data from the
drag-and-drop operation.

Additionally, if the operator provides operator properties that need to be accessible to the user,
the ImportHelper.invoke_popup method can be used to show a dialog leveraging the standard
Operator.draw method for layout and display.

```../examples/bpy.types.FileHandler.2.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NlaTrack.strips

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.safe_areas

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.paint_curves

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ByteIntAttribute.data

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MetaBall.elements

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.volume
* BlendData.volumes
* BlendDataVolumes.new
* BlendDataVolumes.remove

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Texture.type
* Texture.use_clamp
* Texture.use_color_ramp
* Texture.color_ramp
* Texture.intensity
* Texture.contrast
* Texture.saturation
* Texture.factor_red
* Texture.factor_green
* Texture.factor_blue
* Texture.use_preview_alpha
* Texture.use_nodes
* Texture.node_tree
* Texture.animation_data
* Texture.users_material
* Texture.users_object_modifier

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Texture.evaluate
* Texture.bl_rna_get_subclass
* Texture.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AnimData.nla_tracks

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.textures

:columns: 2


--------------------

* bpy_struct.id_data
* LineStyleThicknessModifier.name

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* LineStyleModifier.bl_rna_get_subclass
* LineStyleModifier.bl_rna_get_subclass_py
* LineStyleThicknessModifier.bl_rna_get_subclass
* LineStyleThicknessModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.polygons

:columns: 2


--------------------

* bpy_struct.id_data
* FModifier.name
* FModifier.type
* FModifier.show_expanded
* FModifier.mute
* FModifier.is_valid
* FModifier.active
* FModifier.use_restricted_range
* FModifier.frame_start
* FModifier.frame_end
* FModifier.blend_in
* FModifier.blend_out
* FModifier.use_influence
* FModifier.influence

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* FModifier.bl_rna_get_subclass
* FModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PointCache.point_caches

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.selected_editable_keyframes
* FCurve.keyframe_points
* FCurveKeyframePoints.insert
* FCurveKeyframePoints.remove

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.display

:columns: 2

Action Slots organize animation data within an action. Each action has slots with specific animation
data. An animated data-block specifies an action and a slot, determining the animation data it uses.
See the Blender Manual
for how Action Slots are used, or the
technical documentation
for details on the animation system's architecture.


--------------------

To get started with Action Slots, you can easily create them by inserting a keyframe on an object. When you do this,
Blender automatically creates an Action & Slot for that data-block.

```../examples/bpy.types.ActionSlot.1.py```


--------------------

If required you can also manually create Action Slots on an Action. Note the target_id_type


that matches the data-block type. Identifiers start with a prefix based on the ID type,
e.g. "OB" for objects, followed by the name. There can be identifiers like OBSuzanne


and MESuzanne

 and the name (Suzanne

) can be shared between them. This is intentional,
so that the slots and the datablocks can have the same name.

```../examples/bpy.types.ActionSlot.2.py```


--------------------

An action slot is compatible with a data-block if the slot's target_id_type

 matches the data-block's type.
If there are multiple slots on the Action, and you want to just pick the first one that's
compatible, use the following code. anim_data.action_suitable_slots

 can be used after the
Action has been assigned; it is a list of action slots of that Action, but only the ones that
are actually compatible with the owner of anim_data (in this case, Suzanne).

```../examples/bpy.types.ActionSlot.3.py```


--------------------

To return a list of the data-blocks that are animated by a specific slot of an Action,
use the users()

 method of the ActionSlot.

```../examples/bpy.types.ActionSlot.4.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.slots
* ActionChannelbag.slot
* ActionChannelbags.new
* ActionConstraint.action_slot
* ActionConstraint.action_suitable_slots
* ActionKeyframeStrip.channelbag
* ActionKeyframeStrip.key_insert
* ActionSlot.duplicate
* ActionSlots.active
* ActionSlots.new
* ActionSlots.remove
* AnimData.action_slot
* AnimData.action_suitable_slots
* NlaStrip.action_slot
* NlaStrip.action_suitable_slots

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py

:columns: 2


--------------------

* NodeTreeInterface.new_socket

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.light
* BlendData.lights
* BlendDataLights.new
* BlendDataLights.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Strip.name
* Strip.type
* Strip.select
* Strip.select_left_handle
* Strip.select_right_handle
* Strip.mute
* Strip.lock
* Strip.frame_final_duration
* Strip.duration
* Strip.frame_duration
* Strip.content_duration
* Strip.frame_start
* Strip.content_start
* Strip.content_end
* Strip.frame_final_start
* Strip.left_handle
* Strip.frame_final_end
* Strip.right_handle
* Strip.frame_offset_start
* Strip.left_handle_offset
* Strip.frame_offset_end
* Strip.right_handle_offset
* Strip.channel
* Strip.use_linear_modifiers
* Strip.blend_type
* Strip.blend_alpha
* Strip.effect_fader
* Strip.use_default_fade
* Strip.color_tag
* Strip.modifiers
* Strip.show_retiming_keys
* Strip.connections
* EffectStrip.use_deinterlace
* EffectStrip.alpha_mode
* EffectStrip.use_flip_x
* EffectStrip.use_flip_y
* EffectStrip.use_float
* EffectStrip.use_reverse_frames
* EffectStrip.color_multiply
* EffectStrip.multiply_alpha
* EffectStrip.color_saturation
* EffectStrip.strobe
* EffectStrip.transform
* EffectStrip.crop
* EffectStrip.use_proxy
* EffectStrip.proxy

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Strip.bl_system_properties_get
* Strip.strip_elem_from_frame
* Strip.swap
* Strip.move_to_meta
* Strip.parent_meta
* Strip.invalidate_cache
* Strip.split
* Strip.bl_rna_get_subclass
* Strip.bl_rna_get_subclass_py
* EffectStrip.bl_rna_get_subclass
* EffectStrip.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesInput.xr_navigation

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.timeline_markers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilDrawing.attributes
* GreasePencilDrawing.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothModifier.solver_result

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CameraBackgroundImage.image_user
* Image.filepath_from_user
* ImageTexture.image_user
* Object.image_user
* RenderSlot.clear
* ShaderNodeTexEnvironment.image_user
* ShaderNodeTexImage.image_user
* SpaceImageEditor.image_user
* TextureNodeImage.image_user
* UILayout.template_image
* UILayout.template_image_layers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveMap.points

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleLineStyle.geometry_modifiers

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.workspaces
* Context.workspace
* Window.workspace

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FModifierEnvelope.control_points
* FModifierEnvelopeControlPoints.add
* FModifierEnvelopeControlPoints.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* BlendData.libraries
* BlendDataLibraries.remove
* BlendImportContextItem.source_library
* ID.library
* Library.archive_libraries
* Library.archive_parent_library
* Library.parent

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.attributes
* Mesh.color_attributes

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FluidModifier.domain_settings

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingReconstruction.cameras

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FreestyleModules.new
* FreestyleModules.remove
* FreestyleSettings.modules

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.speakers

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.annotation_data_owner
* bpy.context.id
* bpy.context.selected_ids
* bpy.context.texture_user
* Action.fcurve_ensure_for_datablock
* ActionSlot.users
* AssetRepresentation.local_id
* BlendData.pack_linked_ids_hierarchy
* BlendData.pack_linked_ids_hierarchy
* BlendDataObjects.new
* BlendImportContextItem.id
* BlendImportContextItem.library_override_id
* BlendImportContextItem.reusable_local_id
* Depsgraph.id_eval_get
* Depsgraph.id_eval_get
* Depsgraph.ids
* DepsgraphUpdate.id
* DopeSheet.source
* DriverTarget.id
* ID.copy
* ID.evaluated_get
* ID.make_local
* ID.original
* ID.override_create
* ID.override_hierarchy_create
* ID.override_hierarchy_create
* ID.user_of_id
* ID.user_remap
* IDOverrideLibrary.hierarchy_root
* IDOverrideLibrary.reference
* IDOverrideLibraryPropertyOperation.subitem_local_id
* IDOverrideLibraryPropertyOperation.subitem_reference_id
* IDOverrideLibraryPropertyOperations.add
* IDOverrideLibraryPropertyOperations.add
* IDViewerPathElem.id
* Key.user
* KeyingSetPath.id
* KeyingSetPaths.add
* MaskParent.id
* NodeTree.get_from_context
* NodeTree.get_from_context
* NodesModifierDataBlock.id
* Object.data
* PropertyGroupItem.id
* SpaceFileBrowser.activate_asset_by_id
* SpaceNodeEditor.id
* SpaceNodeEditor.id_from
* SpaceProperties.pin_id
* UILayout.template_action
* UILayout.template_path_builder
* UILayout.template_preview
* UILayout.template_preview

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Material.lineart

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* AssetShelf.draw_context_menu
* Header.layout
* Menu.layout
* Node.draw_buttons
* Node.draw_buttons_ext
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeSocket.draw
* NodeSocketStandard.draw
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocketBool.draw
* NodeTreeInterfaceSocketBundle.draw
* NodeTreeInterfaceSocketClosure.draw
* NodeTreeInterfaceSocketCollection.draw
* NodeTreeInterfaceSocketColor.draw
* NodeTreeInterfaceSocketFloat.draw
* NodeTreeInterfaceSocketFloatAngle.draw
* NodeTreeInterfaceSocketFloatColorTemperature.draw
* NodeTreeInterfaceSocketFloatDistance.draw
* NodeTreeInterfaceSocketFloatFactor.draw
* NodeTreeInterfaceSocketFloatFrequency.draw
* NodeTreeInterfaceSocketFloatMass.draw
* NodeTreeInterfaceSocketFloatPercentage.draw
* NodeTreeInterfaceSocketFloatTime.draw
* NodeTreeInterfaceSocketFloatTimeAbsolute.draw
* NodeTreeInterfaceSocketFloatUnsigned.draw
* NodeTreeInterfaceSocketFloatWavelength.draw
* NodeTreeInterfaceSocketGeometry.draw
* NodeTreeInterfaceSocketImage.draw
* NodeTreeInterfaceSocketInt.draw
* NodeTreeInterfaceSocketIntFactor.draw
* NodeTreeInterfaceSocketIntPercentage.draw
* NodeTreeInterfaceSocketIntUnsigned.draw
* NodeTreeInterfaceSocketMaterial.draw
* NodeTreeInterfaceSocketMatrix.draw
* NodeTreeInterfaceSocketMenu.draw
* NodeTreeInterfaceSocketObject.draw
* NodeTreeInterfaceSocketRotation.draw
* NodeTreeInterfaceSocketShader.draw
* NodeTreeInterfaceSocketString.draw
* NodeTreeInterfaceSocketStringFilePath.draw
* NodeTreeInterfaceSocketTexture.draw
* NodeTreeInterfaceSocketVector.draw
* NodeTreeInterfaceSocketVector2D.draw
* NodeTreeInterfaceSocketVector4D.draw
* NodeTreeInterfaceSocketVectorAcceleration.draw
* NodeTreeInterfaceSocketVectorAcceleration2D.draw
* NodeTreeInterfaceSocketVectorAcceleration4D.draw
* NodeTreeInterfaceSocketVectorDirection.draw
* NodeTreeInterfaceSocketVectorDirection2D.draw
* NodeTreeInterfaceSocketVectorDirection4D.draw
* NodeTreeInterfaceSocketVectorEuler.draw
* NodeTreeInterfaceSocketVectorEuler2D.draw
* NodeTreeInterfaceSocketVectorEuler4D.draw
* NodeTreeInterfaceSocketVectorFactor.draw
* NodeTreeInterfaceSocketVectorFactor2D.draw
* NodeTreeInterfaceSocketVectorFactor4D.draw
* NodeTreeInterfaceSocketVectorPercentage.draw
* NodeTreeInterfaceSocketVectorPercentage2D.draw
* NodeTreeInterfaceSocketVectorPercentage4D.draw
* NodeTreeInterfaceSocketVectorTranslation.draw
* NodeTreeInterfaceSocketVectorTranslation2D.draw
* NodeTreeInterfaceSocketVectorTranslation4D.draw
* NodeTreeInterfaceSocketVectorVelocity.draw
* NodeTreeInterfaceSocketVectorVelocity2D.draw
* NodeTreeInterfaceSocketVectorVelocity4D.draw
* NodeTreeInterfaceSocketVectorXYZ.draw
* NodeTreeInterfaceSocketVectorXYZ2D.draw
* NodeTreeInterfaceSocketVectorXYZ4D.draw
* Operator.layout
* Panel.layout
* UILayout.box
* UILayout.column
* UILayout.column_flow
* UILayout.grid_flow
* UILayout.menu_pie
* UILayout.panel
* UILayout.panel
* UILayout.panel_prop
* UILayout.panel_prop
* UILayout.row
* UILayout.split
* UILayout.template_light_linking_collection
* UIList.draw_filter
* UIList.draw_item
* UIPieMenu.layout
* UIPopover.layout
* UIPopupMenu.layout

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.metaballs

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WindowManager.xr_session_state
* XrActionMaps.find
* XrActionMaps.new
* XrActionMaps.new_from_actionmap
* XrActionMaps.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTracking.reconstruction
* MovieTrackingObject.reconstruction

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilTimeModifier.segments

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

This script is a simple panel which will draw into the object properties
section.

Notice the 'CATEGORY_PT_name' Panel.bl_idname, this is a naming
convention for panels.

[NOTE]
Panel subclasses must be registered for Blender to use them.

```../examples/bpy.types.Panel.0.py```


--------------------

This panel has a Panel.poll and Panel.draw_header function,
even though the contents is basic this closely resembles blenders panels.

```../examples/bpy.types.Panel.1.py```


--------------------

A mix-in parent class can be used to share common properties and
Menu.poll function.

```../examples/bpy.types.Panel.2.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpreadsheetColumn.id

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingTrack.markers

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpreadsheetTable.id

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.cameras

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Scene.transform_orientation_slots

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

Here is an example of a simple menu. Menus differ from panels in that they must
reference from a header, panel or another menu.

Notice the 'CATEGORY_MT_name' in  Menu.bl_idname, this is a naming
convention for menus.

[NOTE]
Menu subclasses must be registered before referencing them from Blender.

[NOTE]
Menus have their UILayout.operator_context initialized as
'EXEC_REGION_WIN' rather than 'INVOKE_REGION_WIN' (see Execution Context <rna_enum_operator_context_items>).
If the operator context needs to initialize inputs from the
Operator.invoke function, then this needs to be explicitly set.
When a menu is added to UI elements such as a panel or header,
the operator execution context will be inherited from them.

```../examples/bpy.types.Menu.0.py```


--------------------

This menu demonstrates some different functions.

```../examples/bpy.types.Menu.1.py```


--------------------

When creating menus for add-ons you can't reference menus
in Blender's default scripts.
Instead, the add-on can add menu items to existing menus.

The function menu_draw acts like Menu.draw.

```../examples/bpy.types.Menu.2.py```


--------------------

Preset menus are simply a convention that uses a menu sub-class
to perform the common task of managing presets.

This example shows how you can add a preset menu.

This example uses the object display options,
however you can use properties defined by your own scripts too.

```../examples/bpy.types.Menu.3.py```


--------------------

This example enables you to insert your own menu entry into the common
right click menu that you get while hovering over a UI button (e.g. operator,
value field, color, string, etc.)

To make the example work, you have to first select an object
then right click on an user interface element (maybe a color in the
material properties) and choose *Execute Custom Action*.

Executing the operator will then print all values.

```../examples/bpy.types.Menu.4.py```


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeEvaluateClosure.input_items

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* CurveSlice.points
* Curves.points

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Preferences.addons

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilDashModifierData.segments

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* FluidModifier.effector_settings

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MeshLoopColorLayer.data

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeRegions.scrubbing

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Modifier.name
* Modifier.type
* Modifier.show_viewport
* Modifier.show_render
* Modifier.show_in_editmode
* Modifier.show_on_cage
* Modifier.show_expanded
* Modifier.is_active
* Modifier.use_pin_to_last
* Modifier.is_override_data
* Modifier.use_apply_on_spline
* Modifier.execution_time
* Modifier.persistent_uid

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Modifier.bl_rna_get_subclass
* Modifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.render_slots

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ID.override_library

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Particle.hair_keys

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* PreferencesSystem.solid_lights
* StudioLight.solid_lights

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GeometryNodeForeachGeometryElementOutput.main_items

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview
* Curve.shape_keys
* Curve.splines
* Curve.path_duration
* Curve.use_path
* Curve.use_path_follow
* Curve.use_path_clamp
* Curve.use_stretch
* Curve.use_deform_bounds
* Curve.use_radius
* Curve.bevel_mode
* Curve.bevel_profile
* Curve.bevel_resolution
* Curve.offset
* Curve.extrude
* Curve.bevel_depth
* Curve.resolution_u
* Curve.resolution_v
* Curve.render_resolution_u
* Curve.render_resolution_v
* Curve.eval_time
* Curve.bevel_object
* Curve.taper_object
* Curve.dimensions
* Curve.fill_mode
* Curve.fill_solver
* Curve.fill_rule
* Curve.twist_mode
* Curve.taper_radius_mode
* Curve.bevel_factor_mapping_start
* Curve.bevel_factor_mapping_end
* Curve.twist_smooth
* Curve.use_fill_caps
* Curve.use_map_taper
* Curve.use_auto_texspace
* Curve.texspace_location
* Curve.texspace_size
* Curve.materials
* Curve.bevel_factor_start
* Curve.bevel_factor_end
* Curve.is_editmode
* Curve.animation_data
* Curve.cycles

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py
* Curve.transform
* Curve.validate_material_indices
* Curve.update_gpu_tag
* Curve.bl_rna_get_subclass
* Curve.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencilFrame.drawing

:columns: 2


--------------------

* bpy_struct.id_data
* Attribute.name
* Attribute.data_type
* Attribute.storage_type
* Attribute.domain
* Attribute.is_internal
* Attribute.is_required

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Attribute.bl_rna_get_subclass
* Attribute.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.slots

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.loops

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ParticleSystem.child_particles

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* DynamicPaintCanvasSettings.canvas_surfaces

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Theme.strip_color

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.camera
* BlendData.cameras
* BlendDataCameras.new
* BlendDataCameras.remove
* RenderEngine.update_custom_camera

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.view_layer
* Context.view_layer
* Depsgraph.view_layer
* Depsgraph.view_layer_eval
* ID.override_hierarchy_create
* IDOverrideLibrary.resync
* LayerCollection.has_selected_objects
* Object.hide_get
* Object.hide_set
* Object.holdout_get
* Object.indirect_only_get
* Object.select_get
* Object.select_set
* Object.visible_get
* RenderEngine.register_pass
* RenderEngine.update_render_passes
* Scene.statistics
* Scene.view_layers
* ViewLayers.new
* ViewLayers.remove
* Window.view_layer

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ThemeCommon.curves

:columns: 2


--------------------

* bpy_struct.id_data
* Constraint.name
* Constraint.type
* Constraint.is_override_data
* Constraint.owner_space
* Constraint.target_space
* Constraint.space_object
* Constraint.space_subtarget
* Constraint.mute
* Constraint.enabled
* Constraint.show_expanded
* Constraint.is_valid
* Constraint.active
* Constraint.influence
* Constraint.error_location
* Constraint.error_rotation

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Constraint.bl_rna_get_subclass
* Constraint.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ToolSettings.gpencil_sculpt

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MovieTrackingPlaneMarkers.find_frame
* MovieTrackingPlaneMarkers.insert_frame
* MovieTrackingPlaneTrack.markers

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* bpy.context.texture_user_property
* Function.parameters
* Struct.properties

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.corner_normals
* Mesh.polygon_normals
* Mesh.vertex_normals

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* BlendData.fonts

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* GreasePencil.layers

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeTreeInterfaceItem.item_type
* NodeTreeInterfaceItem.parent
* NodeTreeInterfaceItem.position
* NodeTreeInterfaceItem.index
* NodeTreeInterfaceSocket.name
* NodeTreeInterfaceSocket.identifier
* NodeTreeInterfaceSocket.description
* NodeTreeInterfaceSocket.socket_type
* NodeTreeInterfaceSocket.in_out
* NodeTreeInterfaceSocket.hide_value
* NodeTreeInterfaceSocket.hide_in_modifier
* NodeTreeInterfaceSocket.force_non_field
* NodeTreeInterfaceSocket.is_inspect_output
* NodeTreeInterfaceSocket.is_panel_toggle
* NodeTreeInterfaceSocket.layer_selection_field
* NodeTreeInterfaceSocket.menu_expanded
* NodeTreeInterfaceSocket.optional_label
* NodeTreeInterfaceSocket.select
* NodeTreeInterfaceSocket.attribute_domain
* NodeTreeInterfaceSocket.default_attribute_name
* NodeTreeInterfaceSocket.structure_type
* NodeTreeInterfaceSocket.default_input
* NodeTreeInterfaceSocket.bl_socket_idname

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeTreeInterfaceItem.bl_rna_get_subclass
* NodeTreeInterfaceItem.bl_rna_get_subclass_py
* NodeTreeInterfaceSocket.bl_system_properties_get
* NodeTreeInterfaceSocket.draw
* NodeTreeInterfaceSocket.init_socket
* NodeTreeInterfaceSocket.from_socket
* NodeTreeInterfaceSocket.bl_rna_get_subclass
* NodeTreeInterfaceSocket.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* StripModifier.name
* StripModifier.type
* StripModifier.mute
* StripModifier.enable
* StripModifier.show_expanded
* StripModifier.input_mask_type
* StripModifier.mask_time
* StripModifier.input_mask_strip
* StripModifier.input_mask_id
* StripModifier.is_active

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* StripModifier.bl_rna_get_subclass
* StripModifier.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* NodeSeparateBundle.bundle_items

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Property.name
* Property.identifier
* Property.description
* Property.translation_context
* Property.type
* Property.subtype
* Property.srna
* Property.unit
* Property.icon
* Property.is_readonly
* Property.is_animatable
* Property.is_overridable
* Property.is_required
* Property.is_argument_optional
* Property.is_never_none
* Property.is_hidden
* Property.is_skip_save
* Property.is_skip_preset
* Property.is_output
* Property.is_registered
* Property.is_registered_optional
* Property.is_runtime
* Property.is_enum_flag
* Property.is_library_editable
* Property.is_path_output
* Property.is_path_supports_blend_relative
* Property.is_path_supports_templates
* Property.is_deprecated
* Property.deprecated_note
* Property.deprecated_version
* Property.deprecated_removal_version
* Property.tags

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Property.bl_rna_get_subclass
* Property.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Mesh.loop_triangles

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Image.render_slots
* RenderSlots.active
* RenderSlots.new

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* WorkSpace.owner_ids

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Action.pose_markers
* ActionPoseMarkers.active
* ActionPoseMarkers.new
* ActionPoseMarkers.remove
* Scene.timeline_markers
* TimelineMarkers.new
* TimelineMarkers.remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* ClothSettings.effector_weights
* DynamicPaintSurface.effector_weights
* FluidDomainSettings.effector_weights
* ParticleSettings.effector_weights
* RigidBodyWorld.effector_weights
* SoftBodySettings.effector_weights

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* ShaderNode.poll
* ShaderNode.bl_rna_get_subclass
* ShaderNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Addons.new
* Addons.remove
* Preferences.addons

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Space.type
* Space.show_locked_time
* Space.show_region_header

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Space.bl_rna_get_subclass
* Space.bl_rna_get_subclass_py
* Space.draw_handler_add
* Space.draw_handler_remove

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* ID.name
* ID.name_full
* ID.id_type
* ID.session_uid
* ID.is_evaluated
* ID.original
* ID.users
* ID.use_fake_user
* ID.use_extra_user
* ID.is_embedded_data
* ID.is_linked_packed
* ID.is_missing
* ID.is_runtime_data
* ID.is_editable
* ID.tag
* ID.is_library_indirect
* ID.library
* ID.library_weak_reference
* ID.asset_data
* ID.override_library
* ID.preview

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* ID.bl_system_properties_get
* ID.rename
* ID.evaluated_get
* ID.copy
* ID.asset_mark
* ID.asset_clear
* ID.asset_generate_preview
* ID.override_create
* ID.override_hierarchy_create
* ID.user_clear
* ID.user_remap
* ID.make_local
* ID.user_of_id
* ID.animation_data_create
* ID.animation_data_clear
* ID.update_tag
* ID.preview_ensure
* ID.bl_rna_get_subclass
* ID.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy.context.curve
* BlendData.curves
* BlendDataCurves.new
* BlendDataCurves.remove
* Object.to_curve

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* MaskSpline.points
* MaskSplinePoints.remove
* MaskSplines.active_point

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* Object.motion_path
* PoseBone.motion_path

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* NodeSocket.name
* NodeSocket.label
* NodeSocket.identifier
* NodeSocket.description
* NodeSocket.is_output
* NodeSocket.select
* NodeSocket.hide
* NodeSocket.enabled
* NodeSocket.link_limit
* NodeSocket.is_linked
* NodeSocket.is_unavailable
* NodeSocket.is_multi_input
* NodeSocket.show_expanded
* NodeSocket.is_inactive
* NodeSocket.is_icon_visible
* NodeSocket.hide_value
* NodeSocket.pin_gizmo
* NodeSocket.node
* NodeSocket.type
* NodeSocket.display_shape
* NodeSocket.inferred_structure_type
* NodeSocket.bl_idname
* NodeSocket.bl_label
* NodeSocket.bl_subtype_label
* NodeSocket.links
* NodeSocketStandard.links

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* NodeSocket.bl_system_properties_get
* NodeSocket.draw
* NodeSocket.draw_color
* NodeSocket.draw_color_simple
* NodeSocket.bl_rna_get_subclass
* NodeSocket.bl_rna_get_subclass_py
* NodeSocketStandard.draw
* NodeSocketStandard.draw_color
* NodeSocketStandard.draw_color_simple
* NodeSocketStandard.bl_rna_get_subclass
* NodeSocketStandard.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* TextureNode.poll
* TextureNode.bl_rna_get_subclass
* TextureNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* GeometryNode.poll
* GeometryNode.bl_rna_get_subclass
* GeometryNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* UIList.bl_idname
* UIList.list_id
* UIList.layout_type
* UIList.use_filter_show
* UIList.filter_name
* UIList.use_filter_invert
* UIList.use_filter_sort_alpha
* UIList.use_filter_sort_reverse
* UIList.use_filter_sort_lock
* UIList.bitflag_filter_item
* UIList.bitflag_item_never_show

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* UIList.bl_system_properties_get
* UIList.draw_item
* UIList.draw_filter
* UIList.filter_items
* UIList.append
* UIList.is_extended
* UIList.prepend
* UIList.remove
* UIList.bl_rna_get_subclass
* UIList.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* CompositorNode.poll
* CompositorNode.bl_rna_get_subclass
* CompositorNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data
* Node.type
* Node.location
* Node.location_absolute
* Node.width
* Node.height
* Node.dimensions
* Node.name
* Node.label
* Node.inputs
* Node.outputs
* Node.internal_links
* Node.parent
* Node.warning_propagation
* Node.use_custom_color
* Node.color
* Node.color_tag
* Node.select
* Node.show_options
* Node.show_preview
* Node.hide
* Node.mute
* Node.show_texture
* Node.bl_idname
* Node.bl_label
* Node.bl_description
* Node.bl_icon
* Node.bl_static_type
* Node.bl_width_default
* Node.bl_width_min
* Node.bl_width_max
* Node.bl_height_default
* Node.bl_height_min
* Node.bl_height_max

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values
* Node.bl_system_properties_get
* Node.socket_value_update
* Node.is_registered_node_type
* Node.poll
* Node.poll_instance
* Node.update
* Node.insert_link
* Node.init
* Node.copy
* Node.free
* Node.draw_buttons
* Node.draw_buttons_ext
* Node.draw_label
* Node.debug_zone_body_lazy_function_graph
* Node.debug_zone_lazy_function_graph
* Node.poll
* Node.bl_rna_get_subclass
* Node.bl_rna_get_subclass_py
* NodeInternal.poll
* NodeInternal.poll_instance
* NodeInternal.update
* NodeInternal.draw_buttons
* NodeInternal.draw_buttons_ext
* NodeInternal.bl_rna_get_subclass
* NodeInternal.bl_rna_get_subclass_py
* FunctionNode.bl_rna_get_subclass
* FunctionNode.bl_rna_get_subclass_py

:columns: 2


--------------------

* bpy_struct.id_data

:columns: 2


--------------------

* bpy_struct.as_pointer
* bpy_struct.driver_add
* bpy_struct.driver_remove
* bpy_struct.get
* bpy_struct.id_properties_clear
* bpy_struct.id_properties_ensure
* bpy_struct.id_properties_ui
* bpy_struct.is_property_hidden
* bpy_struct.is_property_overridable_library
* bpy_struct.is_property_readonly
* bpy_struct.is_property_set
* bpy_struct.items
* bpy_struct.keyframe_delete
* bpy_struct.keyframe_insert
* bpy_struct.keys
* bpy_struct.path_from_id
* bpy_struct.path_from_module
* bpy_struct.path_resolve
* bpy_struct.pop
* bpy_struct.property_overridable_library_set
* bpy_struct.property_unset
* bpy_struct.rna_ancestors
* bpy_struct.type_recast
* bpy_struct.values

:columns: 2


--------------------

* SpaceConsole.history
* SpaceConsole.scrollback

:columns: 2

"""

import typing
import collections.abc
import typing_extensions
import numpy.typing as npt
import bl_operators.anim
import bl_operators.assets
import bl_operators.bone_selection_sets
import bl_operators.clip
import bl_operators.connect_to_output
import bl_operators.constraint
import bl_operators.copy_global_transform
import bl_operators.file
import bl_operators.freestyle
import bl_operators.grease_pencil
import bl_operators.image
import bl_operators.image_as_planes
import bl_operators.node
import bl_operators.object
import bl_operators.presets
import bl_operators.render
import bl_operators.sequencer
import bl_operators.spreadsheet
import bl_operators.userpref
import bl_operators.view3d
import bl_operators.wm
import bl_operators.world
import bl_ui
import bl_ui.anim
import bl_ui.asset_shelf
import bl_ui.generic_ui_list
import bl_ui.properties_collection
import bl_ui.properties_constraint
import bl_ui.properties_data_armature
import bl_ui.properties_data_bone
import bl_ui.properties_data_camera
import bl_ui.properties_data_curve
import bl_ui.properties_data_curves
import bl_ui.properties_data_empty
import bl_ui.properties_data_grease_pencil
import bl_ui.properties_data_lattice
import bl_ui.properties_data_light
import bl_ui.properties_data_lightprobe
import bl_ui.properties_data_mesh
import bl_ui.properties_data_metaball
import bl_ui.properties_data_modifier
import bl_ui.properties_data_pointcloud
import bl_ui.properties_data_shaderfx
import bl_ui.properties_data_speaker
import bl_ui.properties_data_volume
import bl_ui.properties_freestyle
import bl_ui.properties_grease_pencil_common
import bl_ui.properties_mask_common
import bl_ui.properties_material
import bl_ui.properties_material_gpencil
import bl_ui.properties_object
import bl_ui.properties_output
import bl_ui.properties_paint_common
import bl_ui.properties_particle
import bl_ui.properties_physics_cloth
import bl_ui.properties_physics_common
import bl_ui.properties_physics_dynamicpaint
import bl_ui.properties_physics_field
import bl_ui.properties_physics_fluid
import bl_ui.properties_physics_geometry_nodes
import bl_ui.properties_physics_rigidbody
import bl_ui.properties_physics_rigidbody_constraint
import bl_ui.properties_physics_softbody
import bl_ui.properties_render
import bl_ui.properties_scene
import bl_ui.properties_strip
import bl_ui.properties_strip_modifier
import bl_ui.properties_texture
import bl_ui.properties_view_layer
import bl_ui.properties_workspace
import bl_ui.properties_world
import bl_ui.space_clip
import bl_ui.space_console
import bl_ui.space_dopesheet
import bl_ui.space_filebrowser
import bl_ui.space_graph
import bl_ui.space_image
import bl_ui.space_info
import bl_ui.space_nla
import bl_ui.space_node
import bl_ui.space_outliner
import bl_ui.space_properties
import bl_ui.space_sequencer
import bl_ui.space_spreadsheet
import bl_ui.space_statusbar
import bl_ui.space_text
import bl_ui.space_time
import bl_ui.space_toolsystem_common
import bl_ui.space_toolsystem_toolbar
import bl_ui.space_topbar
import bl_ui.space_userpref
import bl_ui.space_view3d
import bl_ui.space_view3d_sidebar
import bl_ui.space_view3d_toolbar
import bpy.stub_internal.rna_enums
import idprop.types
import mathutils

class bpy_prop:
    """built-in base class for all property classes."""

    data: typing.Any
    """ The data this property is using, type `bpy.types.bpy_struct`"""

    id_data: ID | None
    """ The `bpy.types.ID` object this data-block is from or None, (not available for all data types) (readonly)"""

    rna_type: typing.Any
    """ The property type for introspection."""

    def as_bytes(self) -> bytes:
        """Returns this string property as a byte rather than a Python string.

        :return: The string as bytes.
        """

    def path_from_id(self) -> str:
        """Returns the data path from the ID to this property (string).

        :return: The path from `bpy.types.bpy_struct.id_data` to this property.
        """

    def path_from_module(self) -> str:
        """Returns the full data path to this struct (as a string) from the bpy module.

        :return: The full path to the data.
        """

    def update(self) -> None:
        """Execute the properties update callback."""

class bpy_struct[_GenericType1]:
    """built-in base class for all classes in bpy.types."""

    id_data: ID | None
    """ The `bpy.types.ID` object this data-block is from or None, (not available for all data types) (readonly)"""

    bl_rna: BlenderRNA

    def as_pointer(self) -> int:
        """Returns the memory address which holds a pointer to Blenders internal data

        :return: int (memory address).
        """

    def driver_add(
        self,
        path: str | None,
        index: int | None = -1,
        /,
    ) -> FCurve | list[FCurve]:
        """Adds driver(s) to the given property

        :param path: path to the property to drive, analogous to the fcurves data path.
        :param index: array index of the property drive. Defaults to -1 for all indices or a single channel if the property is not an array.
        :return: The driver added or a list of drivers when index is -1.
        """

    def driver_remove(
        self,
        path: str | None,
        index: int | None = -1,
        /,
    ) -> bool:
        """Remove driver(s) from the given property

        :param path: path to the property to drive, analogous to the fcurves data path.
        :param index: array index of the property drive. Defaults to -1 for all indices or a single channel if the property is not an array.
        :return: Success of driver removal.
        """

    def get(
        self,
        key: str | None,
        default: typing.Any | None = None,
        /,
    ) -> typing.Any:
        """Returns the value of the custom property assigned to key or default
        when not found (matches Pythons dictionary function of the same name).

                :param key: The key associated with the custom property.
                :param default: Optional argument for the value to return if
        key is not found.
                :return: Custom property value or default.
        """

    def id_properties_clear(self) -> None:
        """Remove the parent group for an RNA structs custom IDProperties."""

    def id_properties_ensure(self) -> idprop.types.IDPropertyGroup:
        """

        :return: the parent group for an RNA structs custom IDProperties.
        """

    def id_properties_ui(
        self,
        key: str | None,
        /,
    ) -> None:
        """

        :param key: String name of the property.
        :return: An object used to manage an IDPropertys UI data.
        """

    def is_property_hidden(
        self,
        property: str | None,
        /,
    ) -> bool:
        """Check if a property is hidden.

        :param property: Property name.
        :return: True when the property is hidden.
        """

    def is_property_overridable_library(
        self,
        property: str | None,
        /,
    ) -> bool:
        """Check if a property is overridable.

        :param property: Property name.
        :return: True when the property is overridable.
        """

    def is_property_readonly(
        self,
        property: str | None,
        /,
    ) -> bool:
        """Check if a property is readonly.

        :param property: Property name.
        :return: True when the property is readonly (not writable).
        """

    def is_property_set(
        self, property: str | None, /, *, ghost: bool | None = True
    ) -> bool:
        """Check if a property is set, use for testing operator properties.

                :param property: Property name.
                :param ghost: Used for operators that re-run with previous settings.
        In this case the property is not marked as set,
        yet the value from the previous execution is used.

        In rare cases you may want to set this option to false.
                :return: True when the property has been set.
        """

    def items(self) -> idprop.types.IDPropertyGroupViewItems:
        """Returns the items of this objects custom properties (matches Pythons
        dictionary function of the same name).

                :return: custom property key, value pairs.
        """

    def keyframe_delete(
        self,
        data_path: str | None,
        *,
        index: int | None = -1,
        frame: float | None = bpy.context.scene.frame_current,
        group: str | None = "",
    ) -> bool:
        """Remove a keyframe from this properties fcurve.

        :param data_path: path to the property to remove a key, analogous to the fcurves data path.
        :param index: array index of the property to remove a key. Defaults to -1 removing all indices or a single channel if the property is not an array.
        :param frame: The frame on which the keyframe is deleted, defaulting to the current frame.
        :param group: The name of the group the F-Curve should be added to if it doesnt exist yet.
        :return: Success of keyframe deletion.
        """

    def keyframe_insert(
        self,
        data_path: str | None,
        *,
        index: int | None = -1,
        frame: float | None = bpy.context.scene.frame_current,
        group: str | None = "",
        options: set[
            typing.Literal[
                "INSERTKEY_NEEDED",
                "INSERTKEY_VISUAL",
                "INSERTKEY_REPLACE",
                "INSERTKEY_AVAILABLE",
                "INSERTKEY_CYCLE_AWARE",
            ]
        ]
        | None = set(),
        keytype: typing.Literal[
            "KEYFRAME", "BREAKDOWN", "MOVING_HOLD", "EXTREME", "JITTER", "GENERATED"
        ]
        | None = "KEYFRAME",
    ) -> bool:
        """Insert a keyframe on the property given, adding fcurves and animation data when necessary.This is the most simple example of inserting a keyframe from Python.Note that when keying data paths which contain nested properties this must be
        done from the `ID` subclass, in this case the `Armature` rather
        than the bone.

                :param data_path: path to the property to key, analogous to the fcurves data path.
                :param index: array index of the property to key.
        Defaults to -1 which will key all indices or a single channel if the property is not an array.
                :param frame: The frame on which the keyframe is inserted, defaulting to the current frame.
                :param group: The name of the group the F-Curve should be added to if it doesnt exist yet.
                :param options: Optional set of flags:

        INSERTKEY_NEEDED Only insert keyframes where theyre needed in the relevant F-Curves.

        INSERTKEY_VISUAL Insert keyframes based on visual transforms.

        INSERTKEY_REPLACE Only replace already existing keyframes.

        INSERTKEY_AVAILABLE Only insert into already existing F-Curves.

        INSERTKEY_CYCLE_AWARE Take cyclic extrapolation into account (Cycle-Aware Keying option).
                :param keytype: Type of the key.
                :return: Success of keyframe insertion.
        """

    def keys(self) -> idprop.types.IDPropertyGroupViewKeys:
        """Returns the keys of this objects custom properties (matches Pythons
        dictionary function of the same name).

                :return: custom property keys.
        """

    def path_from_id(
        self,
        property: str | None = "",
        /,
    ) -> str:
        """Returns the data path from the ID to this object (string).

                :param property: Optional property name which can be used if the path is
        to a property of this object.
                :return: The path from `bpy.types.bpy_struct.id_data`
        to this struct and property (when given).
        """

    def path_from_module(
        self,
        property: str | None = "",
        index: int | None = -1,
        /,
    ) -> str:
        """Returns the full data path to this struct (as a string) from the bpy module.

                :param property: Optional property name to get the full path from
                :param index: Optional index of the property.
        "-1" means that the property has no indices.
                :return: The full path to the data.
        """

    def path_resolve(
        self,
        path: str | None,
        coerce: bool | None = True,
        /,
    ) -> bpy_prop | typing.Any:
        """Returns the property from the path, raise an exception when not found.

                :param path: path which this property resolves.
                :param coerce: optional argument, when True, the property will be converted
        into its Python representation.
                :return: Property value or property object.
        """

    def pop(
        self,
        key: str | None,
        default: typing.Any | None = None,
        /,
    ) -> typing.Any:
        """Remove and return the value of the custom property assigned to key or default
        when not found (matches Pythons dictionary function of the same name).

                :param key: The key associated with the custom property.
                :param default: Optional argument for the value to return if
        key is not found.
                :return: Custom property value or default.
        """

    def property_overridable_library_set(
        self,
        property: str | None,
        overridable: bool | None,
        /,
    ) -> bool:
        """Define a property as overridable or not (only for custom properties!).

        :param property: Property name.
        :param overridable: Overridable status to set.
        :return: True when the overridable status of the property was successfully set.
        """

    def property_unset(
        self,
        property: str | None,
        /,
    ) -> None:
        """Unset a property, will use default value afterward.

        :param property: Property name.
        """

    def rna_ancestors(self) -> list[bpy_struct]:
        """Return the chain of data containing this struct, if known.
        The first item is the root (typically an ID), the last one is the immediate parent.
        May be empty.

                :return: a list of this objects ancestors.
        """

    def type_recast(self) -> typing_extensions.Self:
        """Return a new instance, this is needed because types
        such as textures can be changed at runtime.

                :return: a new instance of this object with the type initialized again.
        """

    def values(self) -> idprop.types.IDPropertyGroupViewValues:
        """Returns the values of this objects custom properties (matches Pythons
        dictionary function of the same name).

                :return: custom property values.
        """

    def __getitem__(self, key: int | str) -> typing.Any:
        """

        :param key:
        :return:
        """

    def __setitem__(self, key: int | str, value: typing.Any) -> None:
        """

        :param key:
        :param value:
        """

    def __delitem__(self, key: int | str) -> None:
        """

        :param key:
        """

class ContextTempOverride:
    def __enter__(self) -> typing_extensions.Self:
        """

        :return:
        """

    def __exit__(
        self,
        exc_type: type[BaseException] | None,
        exc_val: BaseException | None,
        exc_tb,
    ) -> None:
        """

        :param exc_type:
        :param exc_val:
        :param exc_tb:
        """

class bpy_prop_collection[_GenericType1](bpy_prop):
    """built-in class used for all collections."""

    def find(self, key: str) -> int:
        """Returns the index of a key in a collection or -1 when not found
        (matches Pythons string find function of the same name).

                :param key: The identifier for the collection member.
                :return: index of the key.
        """

    def foreach_get(
        self,
        attr: str,
        seq: collections.abc.MutableSequence[bool]
        | collections.abc.MutableSequence[int]
        | collections.abc.MutableSequence[float]
        | typing_extensions.Buffer
        | npt.NDArray,
    ) -> None:
        """This is a function to give fast access to attributes within a collection.Only works for basic type properties (bool, int and float)!
        Multi-dimensional arrays (like array of vectors) will be flattened into seq.

                :param attr:
                :param seq:
        """

    def foreach_set(
        self,
        attr: str,
        seq: collections.abc.Sequence[bool]
        | collections.abc.Sequence[int]
        | collections.abc.Sequence[float]
        | typing_extensions.Buffer
        | npt.NDArray,
    ) -> None:
        """This is a function to give fast access to attributes within a collection.Only works for basic type properties (bool, int and float)!
        seq must be uni-dimensional, multi-dimensional arrays (like array of vectors) will be re-created from it.

                :param attr:
                :param seq:
        """

    def get[_GenericType2](
        self, key: str | tuple[str, str | None], default: _GenericType2 = None
    ) -> bpy_struct:
        """Returns the value of the item assigned to key or default when not found
        (matches Pythons dictionary function of the same name).

                :param key: The identifier for the collection member.
                :param default: Optional argument for the value to return if
        key is not found.
                :return: The collection member or default.
        """

    def items(self) -> list[tuple[str, _GenericType1]]:
        """Return the identifiers of collection members
        (matching Pythons dict.items() functionality).

                :return: (key, value) pairs for each member of this collection.
        """

    def keys(self) -> list[str]:
        """Return the identifiers of collection members
        (matching Pythons dict.keys() functionality).

                :return: the identifiers for each member of this collection.
        """

    def values(self) -> list[_GenericType1 | None]:
        """Return the values of collection
        (matching Pythons dict.values() functionality).

                :return: The members of this collection.
        """

    @typing.overload
    def __getitem__(self, key: int | str | tuple[str, str | None]) -> _GenericType1:
        """

        :param key:
        :return:
        """

    @typing.overload
    def __getitem__(self, key: slice) -> list[_GenericType1]:
        """

        :param key:
        :return:
        """

    def __setitem__(self, key: int | str, value: _GenericType1 | None) -> None:
        """

        :param key:
        :param value:
        """

    @typing.overload
    def __setitem__(self, key: int, value: _GenericType1 | None) -> None:
        """

        :param key:
        :param value:
        """

    @typing.overload
    def __setitem__(self, key: str, value: _GenericType1) -> None:
        """

        :param key:
        :param value:
        """

    def __iter__(self) -> collections.abc.Iterator[_GenericType1]:
        """

        :return:
        """

    def __next__(self) -> _GenericType1:
        """

        :return:
        """

    def __len__(self) -> int:
        """

        :return:
        """

    def __contains__(self, key: str | tuple[str, str | None] | _GenericType1) -> bool:
        """

        :param key:
        :return:
        """

class bpy_prop_array(bpy_prop):
    """built-in class used for array properties."""

    def foreach_get(self, seq) -> None:
        """This is a function to give fast access to array data.

        :param seq:
        """

    def foreach_set(self, seq) -> None:
        """This is a function to give fast access to array data.

        :param seq:
        """

class AOVs(bpy_prop_collection, bpy_prop):
    """Collection of AOVs"""

    def add(self) -> AOV:
        """add

        :return: Newly created AOV
        """

    def remove(self, aov: AOV | None) -> None:
        """Remove an AOV

        :param aov: AOV to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionChannelbagFCurves(bpy_prop_collection, bpy_prop):
    """Collection of F-Curves for a specific action slot, on a specific strip"""

    def new(
        self,
        data_path: str | None,
        *,
        index: int | None = 0,
        group_name: str | None = "",
    ) -> FCurve:
        """Add an F-Curve to the channelbag

        :param data_path: Data Path, F-Curve data path to use (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :param group_name: Group Name, Name of the Group for this F-Curve, will be created if it does not exist yet (optional, never None)
        :return: Newly created F-Curve
        """

    def new_from_fcurve(
        self, source: FCurve | None, *, data_path: str | None = ""
    ) -> FCurve:
        """Copy an F-Curve into the channelbag. The original F-Curve is unchanged

        :param source: Source F-Curve, The F-Curve to copy
        :param data_path: Data Path, F-Curve data path to use. If not provided, this will use the same data path as the given F-Curve (optional, never None)
        :return: Newly created F-Curve
        """

    def ensure(
        self,
        data_path: str | None,
        *,
        index: int | None = 0,
        group_name: str | None = "",
    ) -> FCurve:
        """Returns the F-Curve if it already exists, and creates it if necessary

        :param data_path: Data Path, F-Curve data path to use (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :param group_name: Group Name, Name of the Group for this F-Curve, will be created if it does not exist yet. This parameter is ignored if the F-Curve already exists (optional, never None)
        :return: Found or newly created F-Curve
        """

    def find(self, data_path: str | None, *, index: int | None = 0) -> FCurve:
        """Find an F-Curve. Note that this function performs a linear scan of all F-Curves in the channelbag.

        :param data_path: Data Path, F-Curve data path (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :return: The found F-Curve, or None if it does not exist
        """

    def remove(self, fcurve: FCurve | None) -> None:
        """Remove F-Curve

        :param fcurve: F-Curve to remove (never None)
        """

    def clear(self) -> None:
        """Remove all F-Curves from this channelbag"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionChannelbagGroups(bpy_prop_collection, bpy_prop):
    """Collection of f-curve groups"""

    def new(self, name: str | None) -> ActionGroup:
        """Create a new action group and add it to the action

        :param name: New name for the action group (never None)
        :return: Newly created action group
        """

    def remove(self, action_group: ActionGroup | None) -> None:
        """Remove action group

        :param action_group: Action group to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionChannelbags(bpy_prop_collection, bpy_prop):
    """For each action slot, a list of animation channels that are meant for that slot"""

    def new(self, slot: ActionSlot | None) -> ActionChannelbag:
        """Add a new channelbag to the strip, to contain animation channels for a specific slot

        :param slot: Action Slot, The slot that should be animated by this channelbag
        :return: Newly created channelbag
        """

    def remove(self, channelbag: ActionChannelbag | None) -> None:
        """Remove the channelbag from the strip

        :param channelbag: The channelbag to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionLayers(bpy_prop_collection, bpy_prop):
    """Collection of animation layers"""

    def new(self, name: str | None) -> ActionLayer:
        """Add a layer to the Animation. Currently an Animation can only have at most one layer.

        :param name: Name, Name of the layer, will be made unique within the Action (never None)
        :return: Newly created animation layer
        """

    def remove(self, anim_layer: ActionLayer | None) -> None:
        """Remove the layer from the animation

        :param anim_layer: Animation Layer, The layer to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionPoseMarkers(bpy_prop_collection, bpy_prop):
    """Collection of timeline markers"""

    active: TimelineMarker | None
    """ Active pose marker for this action"""

    active_index: int | None
    """ Index of active pose marker (in [0, inf], default 0)"""

    def new(self, name: str | None) -> TimelineMarker:
        """Add a pose marker to the action

        :param name: New name for the marker (not unique) (never None)
        :return: Newly created marker
        """

    def remove(self, marker: TimelineMarker | None) -> None:
        """Remove a timeline marker

        :param marker: Timeline marker to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionSlots(bpy_prop_collection, bpy_prop):
    """Collection of action slots"""

    active: ActionSlot | None
    """ Active slot for this action"""

    def new(
        self,
        id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems] | None,
        name: str | None,
    ) -> ActionSlot:
        """Add a slot to the Action

        :param id_type: Data-block Type, The data-block type that the slot is intended for. This is combined with the slot name to create the slots unique identifier, and is also used to limit (on a best-effort basis) which data-blocks the slot can be assigned to.
        :param name: Name, Name of the slot. This will be made unique within the Action among slots of the same type (never None)
        :return: Newly created action slot
        """

    def remove(self, action_slot: ActionSlot | None) -> None:
        """Remove the slot from the Action, including all animation that is associated with that slot

        :param action_slot: Action Slot, The slot to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionStrips(bpy_prop_collection, bpy_prop):
    """Collection of animation strips"""

    def new(
        self, *, type: typing.Literal["KEYFRAME"] | None = "KEYFRAME"
    ) -> ActionStrip:
        """Add a new strip to the layer. Currently a layer can only have one strip, with infinite boundaries.

                :param type: Type, The type of strip to create (optional)

        KEYFRAME
        Keyframe -- Strip containing keyframes on F-Curves.
                :return: Newly created animation strip
        """

    def remove(self, anim_strip: ActionStrip | None) -> None:
        """Remove the strip from the animation layer

        :param anim_strip: Animation Strip, The strip to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Addons(bpy_prop_collection, bpy_prop):
    """Collection of add-ons"""

    @classmethod
    def new(cls) -> Addon:
        """Add a new add-on

        :return: Add-on data
        """

    @classmethod
    def remove(cls, addon: Addon | None) -> None:
        """Remove add-on

        :param addon: Add-on to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnimDataDrivers(bpy_prop_collection, bpy_prop):
    """Collection of Driver F-Curves"""

    def new(self, data_path: str | None, *, index: int | None = 0) -> FCurve:
        """new

        :param data_path: Data Path, F-Curve data path to use (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :return: Newly Driver F-Curve
        """

    def remove(self, driver: FCurve | None) -> None:
        """remove

        :param driver: (never None)
        """

    def from_existing(self, *, src_driver: FCurve | None = None) -> FCurve:
        """Add a new driver given an existing one

        :param src_driver: Existing Driver F-Curve to use as template for a new one (optional)
        :return: New Driver F-Curve
        """

    def find(self, data_path: str | None, *, index: int | None = 0) -> FCurve:
        """Find a driver F-Curve. Note that this function performs a linear scan of all driver F-Curves.

        :param data_path: Data Path, F-Curve data path (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :return: The found F-Curve, or None if it doesnt exist
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationFrames(bpy_prop_collection, bpy_prop):
    """Collection of annotation frames"""

    def new(
        self, frame_number: int | None, *, active: bool | None = False
    ) -> AnnotationFrame:
        """Add a new annotation frame

        :param frame_number: Frame Number, The frame on which this sketch appears (in [-1048574, 1048574])
        :param active: Active, (optional)
        :return: The newly created frame
        """

    def remove(self, frame: AnnotationFrame | None) -> None:
        """Remove an annotation frame

        :param frame: Frame, The frame to remove (never None)
        """

    def copy(self, source: AnnotationFrame | None) -> AnnotationFrame:
        """Copy an annotation frame

        :param source: Source, The source frame (never None)
        :return: The newly copied frame
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationLayers(bpy_prop_collection, bpy_prop):
    """Collection of annotation layers"""

    active_index: int | None
    """ Index of active annotation layer (in [0, inf], default 0)"""

    active_note: typing.Literal["DEFAULT"] | None
    """ Note/Layer to add annotation strokes to (default 'DEFAULT')"""

    def new(
        self, name: str | None, *, set_active: bool | None = True
    ) -> AnnotationLayer:
        """Add a new annotation layer

        :param name: Name, Name of the layer (never None)
        :param set_active: Set Active, Set the newly created layer to the active layer (optional)
        :return: The newly created layer
        """

    def remove(self, layer: AnnotationLayer | None) -> None:
        """Remove a annotation layer

        :param layer: The layer to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationStrokePoints(bpy_prop_collection, bpy_prop):
    """Collection of annotation stroke points"""

    def add(
        self,
        count: int | None,
        *,
        pressure: float | None = 1.0,
        strength: float | None = 1.0,
    ) -> None:
        """Add point(s) to the stroke

        :param count: Count, Number of points to add (in [1, inf])
        :param pressure: Pressure, Pressure/radius for new points (in [0, inf], optional)
        :param strength: Strength, Color strength/opacity for new points (in [0, 1], optional)
        """

    def remove(self, index: int | None) -> None:
        """Remove a point from the stroke

        :param index: Index, Index of point to remove (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationStrokes(bpy_prop_collection, bpy_prop):
    """Collection of annotation strokes"""

    def new(self) -> AnnotationStroke:
        """Add a new annotation stroke

        :return: The newly created stroke
        """

    def remove(self, stroke: AnnotationStroke | None) -> None:
        """Remove an annotation stroke

        :param stroke: The stroke to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AreaSpaces(bpy_prop_collection, bpy_prop):
    """Collection of spaces"""

    active: Space | None
    """ Space currently being displayed in this area (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArmatureBones(bpy_prop_collection, bpy_prop):
    """Collection of armature bones"""

    active: Bone | None
    """ Armature's active bone"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArmatureConstraintTargets(bpy_prop_collection, bpy_prop):
    """Collection of target bones and weights"""

    def new(self) -> ConstraintTargetBone:
        """Add a new target to the constraint

        :return: New target bone
        """

    def remove(self, target: ConstraintTargetBone | None) -> None:
        """Delete target from the constraint

        :param target: Target to remove (never None)
        """

    def clear(self) -> None:
        """Delete all targets from object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArmatureEditBones(bpy_prop_collection, bpy_prop):
    """Collection of armature edit bones"""

    active: EditBone | None
    """ Armatures active edit bone"""

    def new(self, name: str | None) -> EditBone:
        """Add a new bone

        :param name: New name for the bone (never None)
        :return: Newly created edit bone
        """

    def remove(self, bone: EditBone | None) -> None:
        """Remove an existing bone from the armature

        :param bone: EditBone to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetLibraryCollection(bpy_prop_collection, bpy_prop):
    """Collection of user asset libraries"""

    @classmethod
    def new(
        cls, *, name: str | None = "", directory: str | None = ""
    ) -> UserAssetLibrary:
        """Add a new Asset Library

        :param name: Name, (optional, never None)
        :param directory: Directory, (optional, never None)
        :return: Newly added asset library
        """

    @classmethod
    def remove(cls, library: UserAssetLibrary | None) -> None:
        """Remove an Asset Library

        :param library: (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetTags(bpy_prop_collection, bpy_prop):
    """Collection of custom asset tags"""

    def new(self, name: str | None, *, skip_if_exists: bool | None = False) -> AssetTag:
        """Add a new tag to this asset

        :param name: Name, (never None)
        :param skip_if_exists: Skip if Exists, Do not add a new tag if one of the same type already exists (optional)
        :return: New tag
        """

    def remove(self, tag: AssetTag | None) -> None:
        """Remove an existing tag from this asset

        :param tag: Removed tag (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AttributeGroupCurves(bpy_prop_collection, bpy_prop):
    """Group of geometry attributes"""

    active: Attribute | None
    """ Active attribute"""

    active_index: int | None
    """ Active attribute index or -1 when none are active (in [-1, inf], default 0)"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems] | None,
        domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None,
    ) -> Attribute:
        """Add attribute to geometry

        :param name: Name, Name of geometry attribute (never None)
        :param type: Type, Attribute type
        :param domain: Domain, Type of element that attribute is stored on
        :return: New geometry attribute
        """

    def remove(self, attribute: Attribute | None) -> None:
        """Remove attribute from geometry

        :param attribute: Geometry Attribute (never None)
        """

    def domain_size(
        self, domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None
    ) -> int:
        """Get the size of a given domain

        :param domain: Domain, Type of element that attribute is stored on
        :return: Size, Size of the domain (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AttributeGroupGreasePencil(bpy_prop_collection, bpy_prop):
    """Group of geometry attributes"""

    active: Attribute | None
    """ Active attribute"""

    active_index: int | None
    """ Active attribute index or -1 when none are active (in [-1, inf], default 0)"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems] | None,
        domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None,
    ) -> Attribute:
        """Add attribute to geometry

        :param name: Name, Name of geometry attribute (never None)
        :param type: Type, Attribute type
        :param domain: Domain, Type of element that attribute is stored on
        :return: New geometry attribute
        """

    def remove(self, attribute: Attribute | None) -> None:
        """Remove attribute from geometry

        :param attribute: Geometry Attribute (never None)
        """

    def domain_size(
        self, domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None
    ) -> int:
        """Get the size of a given domain

        :param domain: Domain, Type of element that attribute is stored on
        :return: Size, Size of the domain (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AttributeGroupGreasePencilDrawing(bpy_prop_collection, bpy_prop):
    """Group of geometry attributes"""

    active: Attribute | None
    """ Active attribute"""

    active_index: int | None
    """ Active attribute index or -1 when none are active (in [-1, inf], default 0)"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems] | None,
        domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None,
    ) -> Attribute:
        """Add attribute to geometry

        :param name: Name, Name of geometry attribute (never None)
        :param type: Type, Attribute type
        :param domain: Domain, Type of element that attribute is stored on
        :return: New geometry attribute
        """

    def remove(self, attribute: Attribute | None) -> None:
        """Remove attribute from geometry

        :param attribute: Geometry Attribute (never None)
        """

    def domain_size(
        self, domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None
    ) -> int:
        """Get the size of a given domain

        :param domain: Domain, Type of element that attribute is stored on
        :return: Size, Size of the domain (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AttributeGroupMesh(bpy_prop_collection, bpy_prop):
    """Group of geometry attributes"""

    active: Attribute | None
    """ Active attribute"""

    active_color: Attribute | None
    """ Active color attribute for display and editing"""

    active_color_index: int | None
    """ Active color attribute index (in [-inf, inf], default 0)"""

    active_color_name: str | None
    """ The name of the active color attribute for display and editing (default "", never None)"""

    active_index: int | None
    """ Active attribute index or -1 when none are active (in [-1, inf], default 0)"""

    default_color_name: str
    """ The name of the default color attribute used as a fallback for rendering (default "", never None)"""

    render_color_index: int
    """ The index of the color attribute used as a fallback for rendering (in [-inf, inf], default 0)"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems] | None,
        domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None,
    ) -> Attribute:
        """Add attribute to geometry

        :param name: Name, Name of geometry attribute (never None)
        :param type: Type, Attribute type
        :param domain: Domain, Type of element that attribute is stored on
        :return: New geometry attribute
        """

    def remove(self, attribute: Attribute | None) -> None:
        """Remove attribute from geometry

        :param attribute: Geometry Attribute (never None)
        """

    def domain_size(
        self, domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None
    ) -> int:
        """Get the size of a given domain

        :param domain: Domain, Type of element that attribute is stored on
        :return: Size, Size of the domain (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AttributeGroupPointCloud(bpy_prop_collection, bpy_prop):
    """Group of geometry attributes"""

    active: Attribute | None
    """ Active attribute"""

    active_index: int | None
    """ Active attribute index or -1 when none are active (in [-1, inf], default 0)"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems] | None,
        domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None,
    ) -> Attribute:
        """Add attribute to geometry

        :param name: Name, Name of geometry attribute (never None)
        :param type: Type, Attribute type
        :param domain: Domain, Type of element that attribute is stored on
        :return: New geometry attribute
        """

    def remove(self, attribute: Attribute | None) -> None:
        """Remove attribute from geometry

        :param attribute: Geometry Attribute (never None)
        """

    def domain_size(
        self, domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems] | None
    ) -> int:
        """Get the size of a given domain

        :param domain: Domain, Type of element that attribute is stored on
        :return: Size, Size of the domain (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataActions(bpy_prop_collection, bpy_prop):
    """Collection of actions"""

    def new(self, name: str | None) -> Action:
        """Add a new action to the main database

        :param name: New name for the data-block (never None)
        :return: New action data-block
        """

    def remove(
        self,
        action: Action | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove an action from the current blendfile

        :param action: Action to remove (never None)
        :param do_unlink: Unlink all usages of this action before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this action (optional)
        :param do_ui_user: Make sure interface does not reference this action (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataAnnotations(bpy_prop_collection, bpy_prop):
    """Collection of annotations"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def new(self, name: str | None) -> Annotation:
        """Add a new annotation data-block to the main database

        :param name: New name for the data-block (never None)
        :return: New annotation data-block
        """

    def remove(
        self,
        annotation: Annotation | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove annotation instance from the current blendfile

        :param annotation: Grease Pencil to remove (never None)
        :param do_unlink: Unlink all usages of this annotation before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this annotation (optional)
        :param do_ui_user: Make sure interface does not reference this annotation (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataArmatures(bpy_prop_collection, bpy_prop):
    """Collection of armatures"""

    def new(self, name: str | None) -> Armature:
        """Add a new armature to the main database

        :param name: New name for the data-block (never None)
        :return: New armature data-block
        """

    def remove(
        self,
        armature: Armature | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove an armature from the current blendfile

        :param armature: Armature to remove (never None)
        :param do_unlink: Unlink all usages of this armature before deleting it (WARNING: will also delete objects instancing that armature data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this armature data (optional)
        :param do_ui_user: Make sure interface does not reference this armature data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataBrushes(bpy_prop_collection, bpy_prop):
    """Collection of brushes"""

    def new(
        self,
        name: str | None,
        *,
        mode: Literal[bpy.stub_internal.rna_enums.ObjectModeItems]
        | None = "TEXTURE_PAINT",
    ) -> Brush:
        """Add a new brush to the main database

        :param name: New name for the data-block (never None)
        :param mode: Paint Mode for the new brush (optional)
        :return: New brush data-block
        """

    def remove(
        self,
        brush: Brush | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a brush from the current blendfile

        :param brush: Brush to remove (never None)
        :param do_unlink: Unlink all usages of this brush before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this brush (optional)
        :param do_ui_user: Make sure interface does not reference this brush (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def create_gpencil_data(self, brush: Brush | None) -> None:
        """Add Grease Pencil brush settings

        :param brush: Brush (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataCacheFiles(bpy_prop_collection, bpy_prop):
    """Collection of cache files"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataCameras(bpy_prop_collection, bpy_prop):
    """Collection of cameras"""

    def new(self, name: str | None) -> Camera:
        """Add a new camera to the main database

        :param name: New name for the data-block (never None)
        :return: New camera data-block
        """

    def remove(
        self,
        camera: Camera | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a camera from the current blendfile

        :param camera: Camera to remove (never None)
        :param do_unlink: Unlink all usages of this camera before deleting it (WARNING: will also delete objects instancing that camera data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this camera (optional)
        :param do_ui_user: Make sure interface does not reference this camera (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataCollections(bpy_prop_collection, bpy_prop):
    """Collection of collections"""

    def new(self, name: str | None) -> Collection:
        """Add a new collection to the main database

        :param name: New name for the data-block (never None)
        :return: New collection data-block
        """

    def remove(
        self,
        collection: Collection | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a collection from the current blendfile

        :param collection: Collection to remove (never None)
        :param do_unlink: Unlink all usages of this collection before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this collection (optional)
        :param do_ui_user: Make sure interface does not reference this collection (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataCurves(bpy_prop_collection, bpy_prop):
    """Collection of curves"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.ObjectTypeCurveItems] | None,
    ) -> Curve:
        """Add a new curve to the main database

        :param name: New name for the data-block (never None)
        :param type: Type, The type of curve to add
        :return: New curve data-block
        """

    def remove(
        self,
        curve: Curve | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a curve from the current blendfile

        :param curve: Curve to remove (never None)
        :param do_unlink: Unlink all usages of this curve before deleting it (WARNING: will also delete objects instancing that curve data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this curve data (optional)
        :param do_ui_user: Make sure interface does not reference this curve data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataFonts(bpy_prop_collection, bpy_prop):
    """Collection of fonts"""

    def load(
        self, filepath: str | None, *, check_existing: bool | None = False
    ) -> VectorFont:
        """Load a new font into the main database

        :param filepath: path of the font to load (never None, blend relative // prefix supported)
        :param check_existing: Using existing data-block if this file is already loaded (optional)
        :return: New font data-block
        """

    def remove(
        self,
        vfont: VectorFont | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a font from the current blendfile

        :param vfont: Font to remove (never None)
        :param do_unlink: Unlink all usages of this font before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this font (optional)
        :param do_ui_user: Make sure interface does not reference this font (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataGreasePencilsV3(bpy_prop_collection, bpy_prop):
    """Collection of Grease Pencils"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def new(self, name: str | None) -> GreasePencil:
        """Add a new Grease Pencil data-block to the main database

        :param name: New name for the data-block (never None)
        :return: New Grease Pencil data-block
        """

    def remove(
        self,
        grease_pencil: GreasePencil | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a Grease Pencil instance from the current blendfile

        :param grease_pencil: Grease Pencil to remove (never None)
        :param do_unlink: Unlink all usages of this Grease Pencil before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this Grease Pencil (optional)
        :param do_ui_user: Make sure interface does not reference this Grease Pencil (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataHairCurves(bpy_prop_collection, bpy_prop):
    """Collection of hair curves"""

    def new(self, name: str | None) -> Curves:
        """Add a new hair to the main database

        :param name: New name for the data-block (never None)
        :return: New curves data-block
        """

    def remove(
        self,
        curves: Curves | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a curves data-block from the current blendfile

        :param curves: Curves data-block to remove (never None)
        :param do_unlink: Unlink all usages of this curves before deleting it (WARNING: will also delete objects instancing that curves data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this curves data (optional)
        :param do_ui_user: Make sure interface does not reference this curves data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataImages(bpy_prop_collection, bpy_prop):
    """Collection of images"""

    def new(
        self,
        name: str | None,
        width: int | None,
        height: int | None,
        *,
        alpha: bool | None = False,
        float_buffer: bool | None = False,
        stereo3d: bool | None = False,
        is_data: bool | None = False,
        tiled: bool | None = False,
    ) -> Image:
        """Add a new image to the main database

        :param name: New name for the data-block (never None)
        :param width: Width of the image (in [1, inf])
        :param height: Height of the image (in [1, inf])
        :param alpha: Alpha, Use alpha channel (optional)
        :param float_buffer: Float Buffer, Create an image with floating-point color (optional)
        :param stereo3d: Stereo 3D, Create left and right views (optional)
        :param is_data: Is Data, Create image with non-color data color space (optional)
        :param tiled: Tiled, Create a tiled image (optional)
        :return: New image data-block
        """

    def load(
        self, filepath: str | None, *, check_existing: bool | None = False
    ) -> Image:
        """Load a new image into the main database

        :param filepath: Path of the file to load (never None, blend relative // prefix supported)
        :param check_existing: Using existing data-block if this file is already loaded (optional)
        :return: New image data-block
        """

    def remove(
        self,
        image: Image | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove an image from the current blendfile

        :param image: Image to remove (never None)
        :param do_unlink: Unlink all usages of this image before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this image (optional)
        :param do_ui_user: Make sure interface does not reference this image (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataLattices(bpy_prop_collection, bpy_prop):
    """Collection of lattices"""

    def new(self, name: str | None) -> Lattice:
        """Add a new lattice to the main database

        :param name: New name for the data-block (never None)
        :return: New lattice data-block
        """

    def remove(
        self,
        lattice: Lattice | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a lattice from the current blendfile

        :param lattice: Lattice to remove (never None)
        :param do_unlink: Unlink all usages of this lattice before deleting it (WARNING: will also delete objects instancing that lattice data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this lattice data (optional)
        :param do_ui_user: Make sure interface does not reference this lattice data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataLibraries(bpy_prop_collection, bpy_prop):
    """Collection of libraries"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def remove(
        self,
        library: Library | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a library from the current blendfile

        :param library: Library to remove (never None)
        :param do_unlink: Unlink all usages of this library before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this library (optional)
        :param do_ui_user: Make sure interface does not reference this library (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def load(
        self,
        filepath: bytes | str | None,
        *,
        link: bool | None = False,
        pack: bool | None = False,
        relative: bool | None = False,
        set_fake: bool | None = False,
        recursive: bool | None = False,
        reuse_local_id: bool | None = False,
        assets_only: bool | None = False,
        clear_asset_data: bool | None = False,
        create_liboverrides: bool | None = False,
        reuse_liboverrides: bool | None = False,
        create_liboverrides_runtime: bool | None = False,
    ) -> None:
        """Returns a context manager which exposes 2 library objects on entering.
        Each object has attributes matching bpy.data which are lists of strings to be linked.

                :param filepath: The path to a blend file.
                :param link: When False reference to the original file is lost.
                :param pack: If True, and link is also True, pack linked data-blocks into the current blend-file.
                :param relative: When True the path is stored relative to the open blend file.
                :param set_fake: If True, set fake user on appended IDs.
                :param recursive: If True, also make indirect dependencies of appended libraries local.
                :param reuse_local_id: If True,try to re-use previously appended matching ID on new append.
                :param assets_only: If True, only list data-blocks marked as assets.
                :param clear_asset_data: If True, clear the asset data on append (it is always kept for linked data).
                :param create_liboverrides: If True and link is True, liboverrides will
        be created for linked data.
                :param reuse_liboverrides: If True and create_liboverride is True,
        search for existing liboverride first.
                :param create_liboverrides_runtime: If True and create_liboverride is True,
        create (or search for existing) runtime liboverride.
        """

    def write(
        self,
        filepath: bytes | str | None,
        datablocks: set[ID] | None,
        *,
        path_remap: str | None = "NONE",
        fake_user: bool | None = False,
        compress: bool | None = False,
    ) -> None:
        """Write data-blocks into a blend file.

                :param filepath: The path to write the blend-file.
                :param datablocks: set of data-blocks.
                :param path_remap: Optionally remap paths when writing the file:

        NONE No path manipulation (default).

        RELATIVE Remap paths that are already relative to the new location.

        RELATIVE_ALL Remap all paths to be relative to the new location.

        ABSOLUTE Make all paths absolute on writing.
                :param fake_user: When True, data-blocks will be written with fake-user flag enabled.
                :param compress: When True, write a compressed blend file.
        """

class BlendDataLights(bpy_prop_collection, bpy_prop):
    """Collection of lights"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LightTypeItems] | None,
    ) -> Light:
        """Add a new light to the main database

        :param name: New name for the data-block (never None)
        :param type: Type, The type of light to add
        :return: New light data-block
        """

    def remove(
        self,
        light: Light | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a light from the current blendfile

        :param light: Light to remove (never None)
        :param do_unlink: Unlink all usages of this light before deleting it (WARNING: will also delete objects instancing that light data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this light data (optional)
        :param do_ui_user: Make sure interface does not reference this light data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataLineStyles(bpy_prop_collection, bpy_prop):
    """Collection of line styles"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def new(self, name: str | None) -> FreestyleLineStyle:
        """Add a new line style instance to the main database

        :param name: New name for the data-block (never None)
        :return: New line style data-block
        """

    def remove(
        self,
        linestyle: FreestyleLineStyle | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a line style instance from the current blendfile

        :param linestyle: Line style to remove (never None)
        :param do_unlink: Unlink all usages of this line style before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this line style (optional)
        :param do_ui_user: Make sure interface does not reference this line style (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataMasks(bpy_prop_collection, bpy_prop):
    """Collection of masks"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def new(self, name: str | None) -> Mask:
        """Add a new mask with a given name to the main database

        :param name: Mask, Name of new mask data-block (never None)
        :return: New mask data-block
        """

    def remove(
        self,
        mask: Mask | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a mask from the current blendfile

        :param mask: Mask to remove (never None)
        :param do_unlink: Unlink all usages of this mask before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this mask (optional)
        :param do_ui_user: Make sure interface does not reference this mask (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataMaterials(bpy_prop_collection, bpy_prop):
    """Collection of materials"""

    def new(self, name: str | None) -> Material:
        """Add a new material to the main database

        :param name: New name for the data-block (never None)
        :return: New material data-block
        """

    def create_gpencil_data(self, material: Material | None) -> None:
        """Add Grease Pencil material settings

        :param material: Material (never None)
        """

    def remove_gpencil_data(self, material: Material | None) -> None:
        """Remove Grease Pencil material settings

        :param material: Material (never None)
        """

    def remove(
        self,
        material: Material | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a material from the current blendfile

        :param material: Material to remove (never None)
        :param do_unlink: Unlink all usages of this material before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this material (optional)
        :param do_ui_user: Make sure interface does not reference this material (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataMeshes(bpy_prop_collection, bpy_prop):
    """Collection of meshes"""

    def new(self, name: str | None) -> Mesh:
        """Add a new mesh to the main database

        :param name: New name for the data-block (never None)
        :return: New mesh data-block
        """

    def new_from_object(
        self,
        object: Object | None,
        *,
        preserve_all_data_layers: bool | None = False,
        depsgraph: Depsgraph | None = None,
    ) -> Mesh:
        """Add a new mesh created from given object (undeformed geometry if object is original, and final evaluated geometry, with all modifiers etc., if object is evaluated)

        :param object: Object to create mesh from (never None)
        :param preserve_all_data_layers: Preserve all data layers in the mesh, like UV maps and vertex groups. By default Blender only computes the subset of data layers needed for viewport display and rendering, for better performance. (optional)
        :param depsgraph: Dependency Graph, Evaluated dependency graph which is required when preserve_all_data_layers is true (optional)
        :return: Mesh created from object, remove it if it is only used for export
        """

    def remove(
        self,
        mesh: Mesh | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a mesh from the current blendfile

        :param mesh: Mesh to remove (never None)
        :param do_unlink: Unlink all usages of this mesh before deleting it (WARNING: will also delete objects instancing that mesh data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this mesh data (optional)
        :param do_ui_user: Make sure interface does not reference this mesh data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataMetaBalls(bpy_prop_collection, bpy_prop):
    """Collection of metaballs"""

    def new(self, name: str | None) -> MetaBall:
        """Add a new metaball to the main database

        :param name: New name for the data-block (never None)
        :return: New metaball data-block
        """

    def remove(
        self,
        metaball: MetaBall | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a metaball from the current blendfile

        :param metaball: Metaball to remove (never None)
        :param do_unlink: Unlink all usages of this metaball before deleting it (WARNING: will also delete objects instancing that metaball data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this metaball data (optional)
        :param do_ui_user: Make sure interface does not reference this metaball data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataMovieClips(bpy_prop_collection, bpy_prop):
    """Collection of movie clips"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    def remove(
        self,
        clip: MovieClip | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a movie clip from the current blendfile.

        :param clip: Movie clip to remove (never None)
        :param do_unlink: Unlink all usages of this movie clip before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this movie clip (optional)
        :param do_ui_user: Make sure interface does not reference this movie clip (optional)
        """

    def load(
        self, filepath: str | None, *, check_existing: bool | None = False
    ) -> MovieClip:
        """Add a new movie clip to the main database from a file (while check_existing is disabled for consistency with other load functions, behavior with multiple movie-clips using the same file may incorrectly generate proxies)

        :param filepath: path for the data-block (never None, blend relative // prefix supported)
        :param check_existing: Using existing data-block if this file is already loaded (optional)
        :return: New movie clip data-block
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataNodeTrees(bpy_prop_collection, bpy_prop):
    """Collection of node trees"""

    def new(
        self,
        name: str | None,
        type: typing.Literal[
            "GeometryNodeTree",
            "CompositorNodeTree",
            "ShaderNodeTree",
            "TextureNodeTree",
        ]
        | None,
    ) -> NodeTree:
        """Add a new node tree to the main database

                :param name: New name for the data-block (never None)
                :param type: Type, The type of node_group to add

        GeometryNodeTree
        Geometry Node Editor -- Advanced geometry editing and tools creation using nodes.

        CompositorNodeTree
        Compositor -- Create effects and post-process renders, images, and the 3D Viewport.

        ShaderNodeTree
        Shader Editor -- Edit materials, lights, and world shading using nodes.

        TextureNodeTree
        Texture Node Editor -- Edit textures using nodes.
                :return: New node tree data-block
        """

    def remove(
        self,
        tree: NodeTree | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a node tree from the current blendfile

        :param tree: Node tree to remove (never None)
        :param do_unlink: Unlink all usages of this node tree before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this node tree (optional)
        :param do_ui_user: Make sure interface does not reference this node tree (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataObjects(bpy_prop_collection, bpy_prop):
    """Collection of objects"""

    def new(self, name: str | None, object_data: ID | None) -> Object:
        """Add a new object to the main database

        :param name: New name for the data-block (never None)
        :param object_data: Object data or None for an empty object
        :return: New object data-block
        """

    def remove(
        self,
        object: Object | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove an object from the current blendfile

        :param object: Object to remove (never None)
        :param do_unlink: Unlink all usages of this object before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this object (optional)
        :param do_ui_user: Make sure interface does not reference this object (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataPaintCurves(bpy_prop_collection, bpy_prop):
    """Collection of paint curves"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataPalettes(bpy_prop_collection, bpy_prop):
    """Collection of palettes"""

    def new(self, name: str | None) -> Palette:
        """Add a new palette to the main database

        :param name: New name for the data-block (never None)
        :return: New palette data-block
        """

    def remove(
        self,
        palette: Palette | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a palette from the current blendfile

        :param palette: Palette to remove (never None)
        :param do_unlink: Unlink all usages of this palette before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this palette (optional)
        :param do_ui_user: Make sure interface does not reference this palette (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataParticles(bpy_prop_collection, bpy_prop):
    """Collection of particle settings"""

    def new(self, name: str | None) -> ParticleSettings:
        """Add a new particle settings instance to the main database

        :param name: New name for the data-block (never None)
        :return: New particle settings data-block
        """

    def remove(
        self,
        particle: ParticleSettings | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a particle settings instance from the current blendfile

        :param particle: Particle Settings to remove (never None)
        :param do_unlink: Unlink all usages of those particle settings before deleting them (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this particle settings (optional)
        :param do_ui_user: Make sure interface does not reference this particle settings (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataPointClouds(bpy_prop_collection, bpy_prop):
    """Collection of point clouds"""

    def new(self, name: str | None) -> PointCloud:
        """Add a new point cloud to the main database

        :param name: New name for the data-block (never None)
        :return: New point cloud data-block
        """

    def remove(
        self,
        pointcloud: PointCloud | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a point cloud from the current blendfile

        :param pointcloud: Point cloud to remove (never None)
        :param do_unlink: Unlink all usages of this point cloud before deleting it (WARNING: will also delete objects instancing that point cloud data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this point cloud data (optional)
        :param do_ui_user: Make sure interface does not reference this point cloud data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataProbes(bpy_prop_collection, bpy_prop):
    """Collection of light probes"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LightprobesTypeItems] | None,
    ) -> LightProbe:
        """Add a new light probe to the main database

        :param name: New name for the data-block (never None)
        :param type: Type, The type of light probe to add
        :return: New light probe data-block
        """

    def remove(
        self,
        lightprobe: LightProbe | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a light probe from the current blendfile

        :param lightprobe: Light probe to remove (never None)
        :param do_unlink: Unlink all usages of this light probe before deleting it (WARNING: will also delete objects instancing that light probe data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this light probe (optional)
        :param do_ui_user: Make sure interface does not reference this light probe (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataScenes(bpy_prop_collection, bpy_prop):
    """Collection of scenes"""

    def new(self, name: str | None) -> Scene:
        """Add a new scene to the main database

        :param name: New name for the data-block (never None)
        :return: New scene data-block
        """

    def remove(self, scene: Scene | None, *, do_unlink: bool | None = True) -> None:
        """Remove a scene from the current blendfile

        :param scene: Scene to remove (never None)
        :param do_unlink: Unlink all usages of this scene before deleting it (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataScreens(bpy_prop_collection, bpy_prop):
    """Collection of screens"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataSounds(bpy_prop_collection, bpy_prop):
    """Collection of sounds"""

    def load(
        self, filepath: str | None, *, check_existing: bool | None = False
    ) -> Sound:
        """Add a new sound to the main database from a file

        :param filepath: path for the data-block (never None, blend relative // prefix supported)
        :param check_existing: Using existing data-block if this file is already loaded (optional)
        :return: New text data-block
        """

    def remove(
        self,
        sound: Sound | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a sound from the current blendfile

        :param sound: Sound to remove (never None)
        :param do_unlink: Unlink all usages of this sound before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this sound (optional)
        :param do_ui_user: Make sure interface does not reference this sound (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataSpeakers(bpy_prop_collection, bpy_prop):
    """Collection of speakers"""

    def new(self, name: str | None) -> Speaker:
        """Add a new speaker to the main database

        :param name: New name for the data-block (never None)
        :return: New speaker data-block
        """

    def remove(
        self,
        speaker: Speaker | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a speaker from the current blendfile

        :param speaker: Speaker to remove (never None)
        :param do_unlink: Unlink all usages of this speaker before deleting it (WARNING: will also delete objects instancing that speaker data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this speaker data (optional)
        :param do_ui_user: Make sure interface does not reference this speaker data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataTexts(bpy_prop_collection, bpy_prop):
    """Collection of texts"""

    def new(self, name: str | None) -> Text:
        """Add a new text to the main database

        :param name: New name for the data-block (never None)
        :return: New text data-block
        """

    def remove(
        self,
        text: Text | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a text from the current blendfile

        :param text: Text to remove (never None)
        :param do_unlink: Unlink all usages of this text before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this text (optional)
        :param do_ui_user: Make sure interface does not reference this text (optional)
        """

    def load(self, filepath: str | None, *, internal: bool | None = False) -> Text:
        """Add a new text to the main database from a file

        :param filepath: path for the data-block (never None, blend relative // prefix supported)
        :param internal: Make internal, Make text file internal after loading (optional)
        :return: New text data-block
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataTextures(bpy_prop_collection, bpy_prop):
    """Collection of textures"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.TextureTypeItems] | None,
    ) -> Texture:
        """Add a new texture to the main database

        :param name: New name for the data-block (never None)
        :param type: Type, The type of texture to add
        :return: New texture data-block
        """

    def remove(
        self,
        texture: Texture | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a texture from the current blendfile

        :param texture: Texture to remove (never None)
        :param do_unlink: Unlink all usages of this texture before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this texture (optional)
        :param do_ui_user: Make sure interface does not reference this texture (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataVolumes(bpy_prop_collection, bpy_prop):
    """Collection of volumes"""

    def new(self, name: str | None) -> Volume:
        """Add a new volume to the main database

        :param name: New name for the data-block (never None)
        :return: New volume data-block
        """

    def remove(
        self,
        volume: Volume | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a volume from the current blendfile

        :param volume: Volume to remove (never None)
        :param do_unlink: Unlink all usages of this volume before deleting it (WARNING: will also delete objects instancing that volume data) (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this volume data (optional)
        :param do_ui_user: Make sure interface does not reference this volume data (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataWindowManagers(bpy_prop_collection, bpy_prop):
    """Collection of window managers"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataWorkSpaces(bpy_prop_collection, bpy_prop):
    """Collection of workspaces"""

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendDataWorlds(bpy_prop_collection, bpy_prop):
    """Collection of worlds"""

    def new(self, name: str | None) -> World:
        """Add a new world to the main database

        :param name: New name for the data-block (never None)
        :return: New world data-block
        """

    def remove(
        self,
        world: World | None,
        *,
        do_unlink: bool | None = True,
        do_id_user: bool | None = True,
        do_ui_user: bool | None = True,
    ) -> None:
        """Remove a world from the current blendfile

        :param world: World to remove (never None)
        :param do_unlink: Unlink all usages of this world before deleting it (optional)
        :param do_id_user: Decrement user counter of all data-blocks used by this world (optional)
        :param do_ui_user: Make sure interface does not reference this world (optional)
        """

    def tag(self, value: bool | None) -> None:
        """tag

        :param value: Value
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendImportContextItems(bpy_prop_collection, bpy_prop):
    """Collection of blendfile import context items"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendImportContextLibraries(bpy_prop_collection, bpy_prop):
    """Collection of source libraries, i.e. blendfile paths"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoneCollectionMemberships(bpy_prop_collection, bpy_prop):
    """The Bone Collections that contain this Bone"""

    def clear(self) -> None:
        """Remove this bone from all bone collections"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoneCollections(bpy_prop_collection, bpy_prop):
    """The Bone Collections of this Armature"""

    active: BoneCollection | None
    """ Armature's active bone collection"""

    active_index: int | None
    """ The index of the Armature's active bone collection; -1 when there is no active collection. Note that this is indexing the underlying array of bone collections, which may not be in the order you expect. Root collections are listed first, and siblings are always sequential. Apart from that, bone collections can be in any order, and thus incrementing or decrementing this index can make the active bone collection jump around in unexpected ways. For a more predictable interface, use active or active_name. (in [-inf, inf], default 0)"""

    active_name: str | None
    """ The name of the Armature's active bone collection; empty when there is no active collection (default "", never None)"""

    is_solo_active: bool
    """ Read-only flag that indicates there is at least one bone collection marked as 'solo' (default False, readonly)"""

    def new(
        self, name: str | None, *, parent: BoneCollection | None = None
    ) -> BoneCollection:
        """Add a new empty bone collection to the armature

        :param name: Name, Name of the new collection. Blender will ensure it is unique within the collections of the Armature. (never None)
        :param parent: Parent Collection, If not None, the new bone collection becomes a child of this collection (optional)
        :return: Newly created bone collection
        """

    def remove(self, bone_collection: BoneCollection | None) -> None:
        """Remove the bone collection from the armature. If this bone collection has any children, they will be reassigned to their grandparent; in other words, the children will take the place of the removed bone collection.

        :param bone_collection: Bone Collection, The bone collection to remove
        """

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a bone collection to a different position in the collection list. This can only be used to reorder siblings, and not to change parent-child relationships.

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CacheFileLayers(bpy_prop_collection, bpy_prop):
    """Collection of cache layers"""

    active: CacheFileLayer | None
    """ Active layer of the CacheFile"""

    def new(self, filepath: str | None) -> CacheFileLayer:
        """Add a new layer

        :param filepath: File path to the archive used as a layer (never None)
        :return: Newly created layer
        """

    def remove(self, layer: CacheFileLayer | None) -> None:
        """Remove an existing layer from the cache file

        :param layer: Layer to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CacheObjectPaths(bpy_prop_collection, bpy_prop):
    """Collection of object paths"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CameraBackgroundImages(bpy_prop_collection, bpy_prop):
    """Collection of background images"""

    def new(self) -> CameraBackgroundImage:
        """Add new background image

        :return: Image displayed as viewport background
        """

    def remove(self, image: CameraBackgroundImage | None) -> None:
        """Remove background image

        :param image: Image displayed as viewport background (never None)
        """

    def clear(self) -> None:
        """Remove all background images"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ChannelDriverVariables(bpy_prop_collection, bpy_prop):
    """Collection of channel driver Variables"""

    def new(self) -> DriverVariable:
        """Add a new variable for the driver

        :return: Newly created Driver Variable
        """

    def remove(self, variable: DriverVariable | None) -> None:
        """Remove an existing variable from the driver

        :param variable: Variable to remove from the driver (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionChildren(bpy_prop_collection, bpy_prop):
    """Collection of child collections"""

    def link(self, child: Collection | None) -> None:
        """Add this collection as child of this collection

        :param child: Collection to add (never None)
        """

    def unlink(self, child: Collection | None) -> None:
        """Remove this child collection from a collection

        :param child: Collection to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionExports(bpy_prop_collection, bpy_prop):
    """Collection of export handlers"""

    def new(
        self,
        type: typing.Literal[
            "IO_FH_alembic",
            "IO_FH_usd",
            "IO_FH_obj",
            "IO_FH_ply",
            "IO_FH_stl",
            "IO_FH_fbx",
            "IO_FH_gltf2",
        ]
        | None,
        *,
        name: str | None = "",
    ) -> CollectionExport:
        """Add an export handler to the collection

        :param type: Type, The type of export handler to add
        :param name: Name, Name of the new export handler (optional, never None)
        :return: Newly created export handler
        """

    def remove(self, exporter: CollectionExport | None) -> None:
        """Remove an export handler from the collection

        :param exporter: Export Handler to remove
        """

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an export handler

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionObjects(bpy_prop_collection, bpy_prop):
    """Collection of collection objects"""

    def link(self, object: Object | None) -> None:
        """Add this object to a collection

        :param object: Object to add (never None)
        """

    def unlink(self, object: Object | None) -> None:
        """Remove this object from a collection

        :param object: Object to remove
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorRampElements(bpy_prop_collection, bpy_prop):
    """Collection of Color Ramp Elements"""

    def new(self, position: float | None) -> ColorRampElement:
        """Add element to Color Ramp

        :param position: Position, Position to add element (in [0, 1])
        :return: New element
        """

    def remove(self, element: ColorRampElement | None) -> None:
        """Delete element from Color Ramp

        :param element: Element to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveMapPoints(bpy_prop_collection, bpy_prop):
    """Collection of Curve Map Points"""

    def new(self, position: float | None, value: float | None) -> CurveMapPoint:
        """Add point to CurveMap

        :param position: Position, Position to add point (in [-inf, inf])
        :param value: Value, Value of point (in [-inf, inf])
        :return: New point
        """

    def remove(self, point: CurveMapPoint | None) -> None:
        """Delete point from CurveMap

        :param point: PointElement to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveProfilePoints(bpy_prop_collection, bpy_prop):
    """Collection of Profile Points"""

    def add(self, x: float | None, y: float | None) -> CurveProfilePoint:
        """Add point to the profile

        :param x: X Position, X Position for new point (in [-inf, inf])
        :param y: Y Position, Y Position for new point (in [-inf, inf])
        :return: New point
        """

    def remove(self, point: CurveProfilePoint | None) -> None:
        """Delete point from the profile

        :param point: Point to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveSplines(bpy_prop_collection, bpy_prop):
    """Collection of curve splines"""

    active: Spline | None
    """ Active curve spline"""

    def new(self, type: typing.Literal["POLY", "BEZIER", "NURBS"] | None) -> Spline:
        """Add a new spline to the curve

        :param type: type for the new spline
        :return: The newly created spline
        """

    def remove(self, spline: Spline | None) -> None:
        """Remove a spline from a curve

        :param spline: The spline to remove (never None)
        """

    def clear(self) -> None:
        """Remove all splines from a curve"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DynamicPaintSurfaces(bpy_prop_collection, bpy_prop):
    """Collection of Dynamic Paint Canvas surfaces"""

    active: DynamicPaintSurface | None
    """ Active Dynamic Paint surface being displayed (readonly)"""

    active_index: int | None
    """ (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FCurveKeyframePoints(bpy_prop_collection, bpy_prop):
    """Collection of keyframe points"""

    def insert(
        self,
        frame: float | None,
        value: float | None,
        *,
        options: set[typing.Literal["REPLACE", "NEEDED", "FAST"]] | None = set(),
        keyframe_type: Literal[bpy.stub_internal.rna_enums.BeztripleKeyframeTypeItems]
        | None = "KEYFRAME",
    ) -> Keyframe:
        """Add a keyframe point to a F-Curve

                :param frame: X Value of this keyframe point (in [-inf, inf])
                :param value: Y Value of this keyframe point (in [-inf, inf])
                :param options: Keyframe options (optional)

        REPLACE
        Replace -- Dont add any new keyframes, but just replace existing ones.

        NEEDED
        Needed -- Only adds keyframes that are needed.

        FAST
        Fast -- Fast keyframe insertion to avoid recalculating the curve each time.
                :param keyframe_type: Type of keyframe to insert (optional)
                :return: Newly created keyframe
        """

    def add(self, count: int | None) -> None:
        """Add a keyframe point to a F-Curve

        :param count: Number, Number of points to add to the spline (in [0, inf])
        """

    def remove(self, keyframe: Keyframe | None, *, fast: bool | None = False) -> None:
        """Remove keyframe from an F-Curve

        :param keyframe: Keyframe to remove (never None)
        :param fast: Fast, Fast keyframe removal to avoid recalculating the curve each time (optional)
        """

    def clear(self) -> None:
        """Remove all keyframes from an F-Curve"""

    def sort(self) -> None:
        """Ensure all keyframe points are chronologically sorted"""

    def deduplicate(self) -> None:
        """Ensure there are no duplicate keys. Assumes that the points have already been sorted"""

    def handles_recalc(self) -> None:
        """Update handles after modifications to the keyframe points, to update things like auto-clamping"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FCurveModifiers(bpy_prop_collection, bpy_prop):
    """Collection of F-Curve Modifiers"""

    active: FModifier | None
    """ Active F-Curve Modifier"""

    def new(
        self, type: Literal[bpy.stub_internal.rna_enums.FmodifierTypeItems] | None
    ) -> FModifier:
        """Add a constraint to this object

        :param type: Constraint type to add
        :return: New fmodifier
        """

    def remove(self, modifier: FModifier | None) -> None:
        """Remove a modifier from this F-Curve

        :param modifier: Removed modifier (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierEnvelopeControlPoints(bpy_prop_collection, bpy_prop):
    """Control points defining the shape of the envelope"""

    def add(self, frame: float | None) -> FModifierEnvelopeControlPoint:
        """Add a control point to a FModifierEnvelope

        :param frame: Frame to add this control-point (in [-inf, inf])
        :return: Newly created control-point
        """

    def remove(self, point: FModifierEnvelopeControlPoint | None) -> None:
        """Remove a control-point from an FModifierEnvelope

        :param point: Control-point to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FreestyleModules(bpy_prop_collection, bpy_prop):
    """A list of style modules (to be applied from top to bottom)"""

    def new(self) -> FreestyleModuleSettings:
        """Add a style module to scene render layer Freestyle settings

        :return: Newly created style module
        """

    def remove(self, module: FreestyleModuleSettings | None) -> None:
        """Remove a style module from scene render layer Freestyle settings

        :param module: Style module to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToGridItems(bpy_prop_collection, bpy_prop):
    """Collection of field to grid items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> GeometryNodeFieldToGridItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: GeometryNodeFieldToGridItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToListItems(bpy_prop_collection, bpy_prop):
    """Collection of field to list items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> GeometryNodeFieldToListItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: GeometryNodeFieldToListItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Gizmos(bpy_prop_collection, bpy_prop):
    """Collection of gizmos"""

    def new(self, type: str | None) -> Gizmo:
        """Add gizmo

        :param type: Gizmo identifier (never None)
        :return: New gizmo
        """

    def remove(self, gizmo: Gizmo | None) -> None:
        """Delete gizmo

        :param gizmo: New gizmo (never None)
        """

    def clear(self) -> None:
        """Delete all gizmos"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilFrames(bpy_prop_collection, bpy_prop):
    """Collection of Grease Pencil frames"""

    def new(self, frame_number: int | None) -> GreasePencilFrame:
        """Add a new Grease Pencil frame

        :param frame_number: Frame Number, The frame on which the drawing appears (in [-1048574, 1048574])
        :return: The newly created frame
        """

    def remove(self, frame_number: int | None) -> None:
        """Remove a Grease Pencil frame

        :param frame_number: Frame Number, The frame number of the frame to remove (in [-1048574, 1048574])
        """

    def copy(
        self,
        from_frame_number: int | None,
        to_frame_number: int | None,
        *,
        instance_drawing: bool | None = False,
    ) -> GreasePencilFrame:
        """Copy a Grease Pencil frame

        :param from_frame_number: Source Frame Number, The frame number of the source frame (in [-1048574, 1048574])
        :param to_frame_number: Frame Number of Copy, The frame number to copy the frame to (in [-1048574, 1048574])
        :param instance_drawing: Instance Drawing, Let the copied frame use the same drawing as the source (optional)
        :return: The newly copied frame
        """

    def move(
        self, from_frame_number: int | None, to_frame_number: int | None
    ) -> GreasePencilFrame:
        """Move a Grease Pencil frame

        :param from_frame_number: Source Frame Number, The frame number of the source frame (in [-1048574, 1048574])
        :param to_frame_number: Target Frame Number, The frame number to move the frame to (in [-1048574, 1048574])
        :return: The moved frame
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLayerMasks(bpy_prop_collection, bpy_prop):
    """Collection of Grease Pencil masking layers"""

    active_mask_index: int | None
    """ Active index in layer mask array (in [0, inf], default 0)"""

    def add(self, layer: GreasePencilLayer | None) -> GreasePencilLayerMask:
        """Add an existing layer as a mask to this layer

        :param layer: Layer to add as a mask (never None)
        :return: The mask entry referencing the layer
        """

    def remove(self, mask: GreasePencilLayerMask | None) -> None:
        """Remove a mask from the layer

        :param mask: Mask to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilv3LayerGroup(bpy_prop_collection, bpy_prop):
    """Collection of Grease Pencil layers"""

    active: GreasePencilLayerGroup | None
    """ Active Grease Pencil layer group"""

    def new(
        self, name: str | None, *, parent_group: GreasePencilLayerGroup | None = None
    ) -> GreasePencilLayerGroup:
        """Add a new Grease Pencil layer group

        :param name: Name, Name of the layer group (never None)
        :param parent_group: The parent layer group the new group will be created in (use None for the main stack) (optional)
        :return: The newly created layer group
        """

    def remove(
        self,
        layer_group: GreasePencilLayerGroup | None,
        *,
        keep_children: bool | None = False,
    ) -> None:
        """Remove a new Grease Pencil layer group

        :param layer_group: The layer group to remove (never None)
        :param keep_children: Keep the children nodes of the group and only delete the group itself (optional)
        """

    def move(
        self,
        layer_group: GreasePencilLayerGroup | None,
        type: typing.Literal["DOWN", "UP"] | None,
    ) -> None:
        """Move a layer group in the parent layer group or main stack

        :param layer_group: The layer group to move (never None)
        :param type: Direction of movement
        """

    def move_top(self, layer_group: GreasePencilLayerGroup | None) -> None:
        """Move a layer group to the top of the parent layer group or main stack

        :param layer_group: The layer group to move (never None)
        """

    def move_bottom(self, layer_group: GreasePencilLayerGroup | None) -> None:
        """Move a layer group to the bottom of the parent layer group or main stack

        :param layer_group: The layer group to move (never None)
        """

    def move_to_layer_group(
        self,
        layer_group: GreasePencilLayerGroup | None,
        parent_group: GreasePencilLayerGroup | None,
    ) -> None:
        """Move a layer group into a parent layer group

        :param layer_group: The layer group to move (never None)
        :param parent_group: The parent layer group the layer group will be moved into (use None for the main stack)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilv3Layers(bpy_prop_collection, bpy_prop):
    """Collection of Grease Pencil layers"""

    active: GreasePencilLayer | None
    """ Active Grease Pencil layer"""

    def new(
        self,
        name: str | None,
        *,
        set_active: bool | None = True,
        layer_group: GreasePencilLayerGroup | None = None,
    ) -> GreasePencilLayer:
        """Add a new Grease Pencil layer

        :param name: Name, Name of the layer (never None)
        :param set_active: Set Active, Set the newly created layer as the active layer (optional)
        :param layer_group: The layer group the new layer will be created in (use None for the main stack) (optional)
        :return: The newly created layer
        """

    def remove(self, layer: GreasePencilLayer | None) -> None:
        """Remove a Grease Pencil layer

        :param layer: The layer to remove (never None)
        """

    def move(
        self, layer: GreasePencilLayer | None, type: typing.Literal["DOWN", "UP"] | None
    ) -> None:
        """Move a Grease Pencil layer in the layer group or main stack

        :param layer: The layer to move (never None)
        :param type: Direction of movement
        """

    def move_top(self, layer: GreasePencilLayer | None) -> None:
        """Move a Grease Pencil layer to the top of the layer group or main stack

        :param layer: The layer to move (never None)
        """

    def move_bottom(self, layer: GreasePencilLayer | None) -> None:
        """Move a Grease Pencil layer to the bottom of the layer group or main stack

        :param layer: The layer to move (never None)
        """

    def move_to_layer_group(
        self,
        layer: GreasePencilLayer | None,
        layer_group: GreasePencilLayerGroup | None,
    ) -> None:
        """Move a Grease Pencil layer into a layer group

        :param layer: The layer to move (never None)
        :param layer_group: The layer group the layer will be moved into (use None for the main stack)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDMaterials(bpy_prop_collection, bpy_prop):
    """Collection of materials"""

    def append(self, material: Material | None) -> None:
        """Add a new material to the data-block

        :param material: Material to add
        """

    def pop(self, *, index: int = -1) -> Material:
        """Remove a material from the data-block

        :param index: Index of material to remove (in [-32766, 32766], optional)
        :return: Material to remove
        """

    def clear(self) -> None:
        """Remove all materials from the data-block"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @typing.overload
    def __getitem__(self, key: int | str) -> Material | None:
        """

        :param key:
        :return:
        """

    @typing.overload
    def __getitem__(self, key: slice) -> list[Material | None]:
        """

        :param key:
        :return:
        """

    @typing.overload
    def __iter__(self) -> collections.abc.Iterator[Material | None]:
        """

        :return:
        """

class IDOverrideLibraryProperties(bpy_prop_collection, bpy_prop):
    """Collection of override properties"""

    def add(self, rna_path: str | None) -> IDOverrideLibraryProperty:
        """Add a property to the override library when it doesnt exist yet

        :param rna_path: RNA Path, RNA-Path of the property to add (never None)
        :return: New Property, Newly created override property or existing one
        """

    def remove(self, property: IDOverrideLibraryProperty | None) -> None:
        """Remove and delete a property

        :param property: Property, Override property to be deleted
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDOverrideLibraryPropertyOperations(bpy_prop_collection, bpy_prop):
    """Collection of override operations"""

    def add(
        self,
        operation: typing.Literal[
            "NOOP",
            "REPLACE",
            "DIFF_ADD",
            "DIFF_SUB",
            "FACT_MULTIPLY",
            "INSERT_AFTER",
            "INSERT_BEFORE",
        ]
        | None,
        *,
        use_id: bool | None = False,
        subitem_reference_name: str | None = "",
        subitem_local_name: str | None = "",
        subitem_reference_id: ID | None = None,
        subitem_local_id: ID | None = None,
        subitem_reference_index: int | None = -1,
        subitem_local_index: int | None = -1,
    ) -> IDOverrideLibraryPropertyOperation:
        """Add a new operation

                :param operation: Operation, What override operation is performed

        NOOP
        No-Op -- Does nothing, prevents adding actual overrides (NOT USED).

        REPLACE
        Replace -- Replace value of reference by overriding one.

        DIFF_ADD
        Differential -- Stores and apply difference between reference and local value (NOT USED).

        DIFF_SUB
        Differential -- Stores and apply difference between reference and local value (NOT USED).

        FACT_MULTIPLY
        Factor -- Stores and apply multiplication factor between reference and local value (NOT USED).

        INSERT_AFTER
        Insert After -- Insert a new item into collection after the one referenced in subitem_reference_name/_id or _index.

        INSERT_BEFORE
        Insert Before -- Insert a new item into collection before the one referenced in subitem_reference_name/_id or _index (NOT USED).
                :param use_id: Use ID Pointer Subitem, Whether the found or created liboverride operation should use ID pointers or not (optional)
                :param subitem_reference_name: Subitem Reference Name, Used to handle insertions or ID replacements into collection (optional, never None)
                :param subitem_local_name: Subitem Local Name, Used to handle insertions or ID replacements into collection (optional, never None)
                :param subitem_reference_id: Subitem Reference ID, Used to handle ID replacements into collection (optional)
                :param subitem_local_id: Subitem Local ID, Used to handle ID replacements into collection (optional)
                :param subitem_reference_index: Subitem Reference Index, Used to handle insertions or ID replacements into collection (in [-1, inf], optional)
                :param subitem_local_index: Subitem Local Index, Used to handle insertions or ID replacements into collection (in [-1, inf], optional)
                :return: New Operation, Created operation
        """

    def remove(self, operation: IDOverrideLibraryPropertyOperation | None) -> None:
        """Remove and delete an operation

        :param operation: Operation, Override operation to be deleted
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyConfigurations(bpy_prop_collection, bpy_prop):
    """Collection of KeyConfigs"""

    active: KeyConfig | None
    """ Active key configuration (preset)"""

    addon: KeyConfig | None
    """ Key configuration that can be extended by add-ons, and is added to the active configuration when handling events (readonly)"""

    default: KeyConfig | None
    """ Default builtin key configuration (readonly)"""

    user: KeyConfig | None
    """ Final key configuration that combines keymaps from the active and add-on configurations, and can be edited by the user (readonly)"""

    def new(self, name: str | None) -> KeyConfig:
        """new

        :param name: Name, (never None)
        :return: Key Configuration, Added key configuration
        """

    def remove(self, keyconfig: KeyConfig | None) -> None:
        """remove

        :param keyconfig: Key Configuration, Removed key configuration (never None)
        """

    def find_item_from_operator(
        self,
        idname: str | None,
        *,
        context: Literal[bpy.stub_internal.rna_enums.OperatorContextItems]
        | None = "INVOKE_DEFAULT",
        properties: OperatorProperties | None = None,
        include: set[Literal[bpy.stub_internal.rna_enums.EventTypeMaskItems]] | None = {
            "ACTIONZONE",
            "KEYBOARD",
            "MOUSE",
            "NDOF",
        },
        exclude: set[Literal[bpy.stub_internal.rna_enums.EventTypeMaskItems]]
        | None = set(),
    ) -> tuple[KeyMap, KeyMapItem]:
        """find_item_from_operator

                :param idname: Operator Identifier, (never None)
                :param context: context, (optional)
                :param properties: (optional)
                :param include: Include, (optional)
                :param exclude: Exclude, (optional)
                :return: keymap, `KeyMap`

        item, `KeyMapItem`
        """

    def update(self, *, keep_properties: bool | None = False) -> None:
        """update

        :param keep_properties: Keep Properties, Operator properties are kept to allow the operators to be registered again in the future (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyMapItems(bpy_prop_collection, bpy_prop):
    """Collection of keymap items"""

    def new(
        self,
        idname: str | None,
        type: Literal[bpy.stub_internal.rna_enums.EventTypeItems] | None,
        value: Literal[bpy.stub_internal.rna_enums.EventValueItems] | None,
        *,
        any: bool | None = False,
        shift: int | None = 0,
        ctrl: int | None = 0,
        alt: int | None = 0,
        oskey: int | None = 0,
        hyper: int | None = 0,
        key_modifier: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
        | None = "NONE",
        direction: Literal[bpy.stub_internal.rna_enums.EventDirectionItems]
        | None = "ANY",
        repeat: bool | None = False,
        head: bool | None = False,
    ) -> KeyMapItem:
        """new

        :param idname: Operator Identifier, (never None)
        :param type: Type
        :param value: Value
        :param any: Any, (optional)
        :param shift: Shift, (in [-1, 1], optional)
        :param ctrl: Ctrl, (in [-1, 1], optional)
        :param alt: Alt, (in [-1, 1], optional)
        :param oskey: OS Key, (in [-1, 1], optional)
        :param hyper: Hyper, (in [-1, 1], optional)
        :param key_modifier: Key Modifier, (optional)
        :param direction: Direction, (optional)
        :param repeat: Repeat, When set, accept key-repeat events (optional)
        :param head: At Head, Force item to be added at start (not end) of key map so that it doesnt get blocked by an existing key map item (optional)
        :return: Item, Added key map item
        """

    def new_modal(
        self,
        propvalue: str | None,
        type: Literal[bpy.stub_internal.rna_enums.EventTypeItems] | None,
        value: Literal[bpy.stub_internal.rna_enums.EventValueItems] | None,
        *,
        any: bool | None = False,
        shift: int | None = 0,
        ctrl: int | None = 0,
        alt: int | None = 0,
        oskey: int | None = 0,
        hyper: int | None = 0,
        key_modifier: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
        | None = "NONE",
        direction: Literal[bpy.stub_internal.rna_enums.EventDirectionItems]
        | None = "ANY",
        repeat: bool | None = False,
    ) -> KeyMapItem:
        """new_modal

        :param propvalue: Property Value, (never None)
        :param type: Type
        :param value: Value
        :param any: Any, (optional)
        :param shift: Shift, (in [-1, 1], optional)
        :param ctrl: Ctrl, (in [-1, 1], optional)
        :param alt: Alt, (in [-1, 1], optional)
        :param oskey: OS Key, (in [-1, 1], optional)
        :param hyper: Hyper, (in [-1, 1], optional)
        :param key_modifier: Key Modifier, (optional)
        :param direction: Direction, (optional)
        :param repeat: Repeat, When set, accept key-repeat events (optional)
        :return: Item, Added key map item
        """

    def new_from_item(
        self, item: KeyMapItem | None, *, head: bool | None = False
    ) -> KeyMapItem:
        """new_from_item

        :param item: Item, Item to use as a reference (never None)
        :param head: At Head, (optional)
        :return: Item, Added key map item
        """

    def remove(self, item: KeyMapItem | None) -> None:
        """remove

        :param item: Item, (never None)
        """

    def from_id(self, id: int | None) -> KeyMapItem:
        """from_id

        :param id: id, ID of the item (in [-inf, inf])
        :return: Item
        """

    def find_from_operator(
        self,
        idname: str | None,
        *,
        properties: OperatorProperties | None = None,
        include: set[Literal[bpy.stub_internal.rna_enums.EventTypeMaskItems]] | None = {
            "ACTIONZONE",
            "KEYBOARD",
            "MOUSE",
            "NDOF",
        },
        exclude: set[Literal[bpy.stub_internal.rna_enums.EventTypeMaskItems]]
        | None = set(),
    ) -> KeyMapItem:
        """find_from_operator

        :param idname: Operator Identifier, (never None)
        :param properties: (optional)
        :param include: Include, (optional)
        :param exclude: Exclude, (optional)
        :return:
        """

    def find_match(self, keymap: KeyMap | None, item: KeyMapItem | None) -> KeyMapItem:
        """find_match

        :param keymap: The matching keymap
        :param item: The matching keymap item
        :return: The keymap item from this keymap which matches the keymap item from the arguments passed in
        """

    def match_event(self, event: Event | None) -> KeyMapItem:
        """match_event

        :param event:
        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyMaps(bpy_prop_collection, bpy_prop):
    """Collection of keymaps"""

    def new(
        self,
        name: str | None,
        *,
        space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
        | None = "EMPTY",
        region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
        | None = "WINDOW",
        modal: bool | None = False,
        tool: bool | None = False,
    ) -> KeyMap:
        """Ensure the keymap exists. This will return the one with the given name/space type/region type, or create a new one if it does not exist yet.

        :param name: Name, (never None)
        :param space_type: Space Type, (optional)
        :param region_type: Region Type, (optional)
        :param modal: Modal, Keymap for modal operators. Modal keymaps are not supported for `KeyConfigs.addons`. (optional)
        :param tool: Tool, Keymap for active tools (optional)
        :return: Key Map, Added key map
        """

    def remove(self, keymap: KeyMap | None) -> None:
        """remove

        :param keymap: Key Map, Removed key map (never None)
        """

    def clear(self) -> None:
        """Remove all keymaps."""

    def find(
        self,
        name: str | None,
        *,
        space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
        | None = "EMPTY",
        region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
        | None = "WINDOW",
    ) -> KeyMap:
        """find

        :param name: Name, (never None)
        :param space_type: Space Type, (optional)
        :param region_type: Region Type, (optional)
        :return: Key Map, Corresponding key map
        """

    def find_match(self, keymap: KeyMap | None) -> KeyMap:
        """find_match

        :param keymap: Key Map, The key map for comparison
        :return: Key Map, Corresponding key map
        """

    def find_modal(self, name: str | None) -> KeyMap:
        """find_modal

        :param name: Operator Name, (never None)
        :return: Key Map, Corresponding key map
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSetPaths(bpy_prop_collection, bpy_prop):
    """Collection of keying set paths"""

    active: KeyingSetPath | None
    """ Active Keying Set used to insert/delete keyframes"""

    active_index: int | None
    """ Current Keying Set index (in [-inf, inf], default 0)"""

    def add(
        self,
        target_id: ID | None,
        data_path: str | None,
        *,
        index: int | None = -1,
        group_method: Literal[bpy.stub_internal.rna_enums.KeyingsetPathGroupingItems]
        | None = "KEYINGSET",
        group_name: str | None = "",
    ) -> KeyingSetPath:
        """Add a new path for the Keying Set

        :param target_id: Target ID, ID data-block for the destination
        :param data_path: Data-Path, RNA-Path to destination property (never None)
        :param index: Index, The index of the destination property (i.e. axis of Location/Rotation/etc.), or -1 for the entire array (in [-1, inf], optional)
        :param group_method: Grouping Method, Method used to define which Group-name to use (optional)
        :param group_name: Group Name, Name of Action Group to assign destination to (only if grouping mode is to use this name) (optional, never None)
        :return: New Path, Path created and added to the Keying Set
        """

    def remove(self, path: KeyingSetPath | None) -> None:
        """Remove the given path from the Keying Set

        :param path: Path, (never None)
        """

    def clear(self) -> None:
        """Remove all the paths from the Keying Set"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSets(bpy_prop_collection, bpy_prop):
    """Scene keying sets"""

    active: KeyingSet | None
    """ Active Keying Set used to insert/delete keyframes"""

    active_index: int | None
    """ Current Keying Set index (negative for 'builtin' and positive for 'absolute') (in [-inf, inf], default 0)"""

    def new(
        self, *, idname: str | None = "KeyingSet", name: str | None = "KeyingSet"
    ) -> KeyingSet:
        """Add a new Keying Set to Scene

        :param idname: IDName, Internal identifier of Keying Set (optional, never None)
        :param name: Name, User visible name of Keying Set (optional, never None)
        :return: Newly created Keying Set
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSetsAll(bpy_prop_collection, bpy_prop):
    """All available keying sets"""

    active: KeyingSet | None
    """ Active Keying Set used to insert/delete keyframes"""

    active_index: int | None
    """ Current Keying Set index (negative for 'builtin' and positive for 'absolute') (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LayerObjects(bpy_prop_collection, bpy_prop):
    """Collections of objects"""

    active: Object | None
    """ Active object for this layer"""

    selected: typing.Any
    """ All the selected objects of this layer (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Lightgroups(bpy_prop_collection, bpy_prop):
    """Collection of Lightgroups"""

    def add(self, *, name: str | None = "") -> Lightgroup:
        """add

        :param name: Name, Name of newly created lightgroup (optional, never None)
        :return: Newly created Lightgroup
        """

    def remove(self, lightgroup: Lightgroup | None) -> None:
        """Remove given light group

        :param lightgroup: Lightgroup to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifiers(bpy_prop_collection, bpy_prop):
    """Alpha modifiers for changing line alphas"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
        | None,
    ) -> LineStyleAlphaModifier:
        """Add a alpha modifier to line style

        :param name: New name for the alpha modifier (not unique) (never None)
        :param type: Alpha modifier type to add
        :return: Newly added alpha modifier
        """

    def remove(self, modifier: LineStyleAlphaModifier | None) -> None:
        """Remove a alpha modifier from line style

        :param modifier: Alpha modifier to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifiers(bpy_prop_collection, bpy_prop):
    """Color modifiers for changing line colors"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
        | None,
    ) -> LineStyleColorModifier:
        """Add a color modifier to line style

        :param name: New name for the color modifier (not unique) (never None)
        :param type: Color modifier type to add
        :return: Newly added color modifier
        """

    def remove(self, modifier: LineStyleColorModifier | None) -> None:
        """Remove a color modifier from line style

        :param modifier: Color modifier to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifiers(bpy_prop_collection, bpy_prop):
    """Geometry modifiers for changing line geometries"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
        | None,
    ) -> LineStyleGeometryModifier:
        """Add a geometry modifier to line style

        :param name: New name for the geometry modifier (not unique) (never None)
        :param type: Geometry modifier type to add
        :return: Newly added geometry modifier
        """

    def remove(self, modifier: LineStyleGeometryModifier | None) -> None:
        """Remove a geometry modifier from line style

        :param modifier: Geometry modifier to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleTextureSlots(bpy_prop_collection, bpy_prop):
    """Collection of texture slots"""

    @classmethod
    def add(cls) -> LineStyleTextureSlot:
        """add

        :return: The newly initialized mtex
        """

    @classmethod
    def create(cls, index: int | None) -> LineStyleTextureSlot:
        """create

        :param index: Index, Slot index to initialize (in [0, inf])
        :return: The newly initialized mtex
        """

    @classmethod
    def clear(cls, index: int | None) -> None:
        """clear

        :param index: Index, Slot index to clear (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifiers(bpy_prop_collection, bpy_prop):
    """Thickness modifiers for changing line thickness"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
        | None,
    ) -> LineStyleThicknessModifier:
        """Add a thickness modifier to line style

        :param name: New name for the thickness modifier (not unique) (never None)
        :param type: Thickness modifier type to add
        :return: Newly added thickness modifier
        """

    def remove(self, modifier: LineStyleThicknessModifier | None) -> None:
        """Remove a thickness modifier from line style

        :param modifier: Thickness modifier to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Linesets(bpy_prop_collection, bpy_prop):
    """Line sets for associating lines and style parameters"""

    active: FreestyleLineSet | None
    """ Active line set being displayed (readonly)"""

    active_index: int | None
    """ Index of active line set slot (in [0, inf], default 0)"""

    def new(self, name: str | None) -> FreestyleLineSet:
        """Add a line set to scene render layer Freestyle settings

        :param name: New name for the line set (not unique) (never None)
        :return: Newly created line set
        """

    def remove(self, lineset: FreestyleLineSet | None) -> None:
        """Remove a line set from scene render layer Freestyle settings

        :param lineset: Line set to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LoopColors(bpy_prop_collection, bpy_prop):
    """Collection of vertex colors"""

    active: MeshLoopColorLayer | None
    """ Active vertex color layer"""

    active_index: int | None
    """ Active vertex color index (in [0, inf], default 0)"""

    def new(
        self, *, name: str | None = "Col", do_init: bool | None = True
    ) -> MeshLoopColorLayer:
        """Add a vertex color layer to Mesh

        :param name: Vertex color name (optional, never None)
        :param do_init: Whether new layers data should be initialized by copying current active one (optional)
        :return: The newly created layer
        """

    def remove(self, layer: MeshLoopColorLayer | None) -> None:
        """Remove a vertex color layer

        :param layer: The layer to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskLayers(bpy_prop_collection, bpy_prop):
    """Collection of layers used by mask"""

    active: MaskLayer | None
    """ Active layer in this mask"""

    def new(self, *, name: str | None = "") -> MaskLayer:
        """Add layer to this mask

        :param name: Name, Name of new layer (optional, never None)
        :return: New mask layer
        """

    def remove(self, layer: MaskLayer | None) -> None:
        """Remove layer from this mask

        :param layer: Shape to be removed (never None)
        """

    def clear(self) -> None:
        """Remove all mask layers"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskSplinePoints(bpy_prop_collection, bpy_prop):
    """Collection of masking spline points"""

    def add(self, count: int | None) -> None:
        """Add a number of point to this spline

        :param count: Number, Number of points to add to the spline (in [0, inf])
        """

    def remove(self, point: MaskSplinePoint | None) -> None:
        """Remove a point from a spline

        :param point: The point to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskSplines(bpy_prop_collection, bpy_prop):
    """Collection of masking splines"""

    active: MaskSpline | None
    """ Active spline of masking layer"""

    active_point: MaskSplinePoint | None
    """ Active point of masking layer"""

    def new(self) -> MaskSpline:
        """Add a new spline to the layer

        :return: The newly created spline
        """

    def remove(self, spline: MaskSpline | None) -> None:
        """Remove a spline from a layer

        :param spline: The spline to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshEdges(bpy_prop_collection, bpy_prop):
    """Collection of mesh edges"""

    def add(self, count: int | None) -> None:
        """add

        :param count: Count, Number of edges to add (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoopTriangles(bpy_prop_collection, bpy_prop):
    """Tessellation of mesh polygons into triangles"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoops(bpy_prop_collection, bpy_prop):
    """Collection of mesh loops"""

    def add(self, count: int | None) -> None:
        """add

        :param count: Count, Number of loops to add (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshPolygons(bpy_prop_collection, bpy_prop):
    """Collection of mesh polygons"""

    active: int | None
    """ The active face for this mesh (in [-inf, inf], default 0)"""

    def add(self, count: int | None) -> None:
        """add

        :param count: Count, Number of polygons to add (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshVertices(bpy_prop_collection, bpy_prop):
    """Collection of mesh vertices"""

    def add(self, count: int | None) -> None:
        """add

        :param count: Count, Number of vertices to add (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MetaBallElements(bpy_prop_collection, bpy_prop):
    """Collection of metaball elements"""

    active: MetaElement | None
    """ Last selected element (readonly)"""

    def new(
        self,
        *,
        type: Literal[bpy.stub_internal.rna_enums.MetaelemTypeItems] | None = "BALL",
    ) -> MetaElement:
        """Add a new element to the metaball

        :param type: Type for the new metaball element (optional)
        :return: The newly created metaball element
        """

    def remove(self, element: MetaElement | None) -> None:
        """Remove an element from the metaball

        :param element: The element to remove (never None)
        """

    def clear(self) -> None:
        """Remove all elements from the metaball"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingMarkers(bpy_prop_collection, bpy_prop):
    """Collection of markers for movie tracking track"""

    def find_frame(
        self, frame: int | None, *, exact: bool | None = True
    ) -> MovieTrackingMarker:
        """Get marker for specified frame

        :param frame: Frame, Frame number to find marker for (in [0, 1048574])
        :param exact: Exact, Get marker at exact frame number rather than get estimated marker (optional)
        :return: Marker for specified frame
        """

    def insert_frame(
        self,
        frame: int | None,
        *,
        co: collections.abc.Sequence[float] | mathutils.Vector | None = (0.0, 0.0),
    ) -> MovieTrackingMarker:
        """Insert a new marker at the specified frame

        :param frame: Frame, Frame number to insert marker to (in [0, 1048574])
        :param co: Coordinate, Place new marker at the given frame using specified in normalized space coordinates (array of 2 items, in [-1, 1], optional)
        :return: Newly created marker
        """

    def delete_frame(self, frame: int | None) -> None:
        """Delete marker at specified frame

        :param frame: Frame, Frame number to delete marker from (in [0, 1048574])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingObjectPlaneTracks(bpy_prop_collection, bpy_prop):
    """Collection of tracking plane tracks"""

    active: MovieTrackingTrack | None
    """ Active track in this tracking data object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingObjectTracks(bpy_prop_collection, bpy_prop):
    """Collection of movie tracking tracks"""

    active: MovieTrackingTrack | None
    """ Active track in this tracking data object"""

    def new(
        self, *, name: str | None = "", frame: int | None = 1
    ) -> MovieTrackingTrack:
        """create new motion track in this movie clip

        :param name: Name of new track (optional, never None)
        :param frame: Frame, Frame number to add tracks on (in [0, 1048574], optional)
        :return: Newly created track
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingObjects(bpy_prop_collection, bpy_prop):
    """Collection of movie tracking objects"""

    active: MovieTrackingObject | None
    """ Active object in this tracking data object"""

    def new(self, name: str | None) -> MovieTrackingObject:
        """Add tracking object to this movie clip

        :param name: Name of new object (never None)
        :return: New motion tracking object
        """

    def remove(self, object: MovieTrackingObject | None) -> None:
        """Remove tracking object from this movie clip

        :param object: Motion tracking object to be removed (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingPlaneMarkers(bpy_prop_collection, bpy_prop):
    """Collection of markers for movie tracking plane track"""

    def find_frame(
        self, frame: int | None, *, exact: bool | None = True
    ) -> MovieTrackingPlaneMarker:
        """Get plane marker for specified frame

        :param frame: Frame, Frame number to find marker for (in [0, 1048574])
        :param exact: Exact, Get plane marker at exact frame number rather than get estimated marker (optional)
        :return: Plane marker for specified frame
        """

    def insert_frame(self, frame: int | None) -> MovieTrackingPlaneMarker:
        """Insert a new plane marker at the specified frame

        :param frame: Frame, Frame number to insert marker to (in [0, 1048574])
        :return: Newly created plane marker
        """

    def delete_frame(self, frame: int | None) -> None:
        """Delete plane marker at specified frame

        :param frame: Frame, Frame number to delete plane marker from (in [0, 1048574])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingPlaneTracks(bpy_prop_collection, bpy_prop):
    """Collection of movie tracking plane tracks"""

    active: MovieTrackingPlaneTrack | None
    """ Active plane track in this tracking data object. Deprecated, use objects[name].plane_tracks.active"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingReconstructedCameras(bpy_prop_collection, bpy_prop):
    """Collection of solved cameras"""

    def find_frame(self, *, frame: int | None = 1) -> MovieReconstructedCamera:
        """Find a reconstructed camera for a give frame number

        :param frame: Frame, Frame number to find camera for (in [0, 1048574], optional)
        :return: Camera for a given frame
        """

    def matrix_from_frame(self, *, frame: int | None = 1) -> mathutils.Matrix:
        """Return interpolated camera matrix for a given frame

        :param frame: Frame, Frame number to find camera for (in [0, 1048574], optional)
        :return: Matrix, Interpolated camera matrix for a given frame (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingTracks(bpy_prop_collection, bpy_prop):
    """Collection of movie tracking tracks"""

    active: MovieTrackingTrack | None
    """ Active track in this tracking data object. Deprecated, use objects[name].tracks.active"""

    def new(
        self, *, name: str | None = "", frame: int | None = 1
    ) -> MovieTrackingTrack:
        """Create new motion track in this movie clip

        :param name: Name of new track (optional, never None)
        :param frame: Frame, Frame number to add track on (in [0, 1048574], optional)
        :return: Newly created track
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NlaStripFCurves(bpy_prop_collection, bpy_prop):
    """Collection of NLA strip F-Curves"""

    def find(self, data_path: str | None, *, index: int | None = 0) -> FCurve:
        """Find an F-Curve. Note that this function performs a linear scan of all F-Curves in the NLA strip.

        :param data_path: Data Path, F-Curve data path (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :return: The found F-Curve, or None if it doesnt exist
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NlaStrips(bpy_prop_collection, bpy_prop):
    """Collection of NLA Strips"""

    def new(
        self, name: str | None, start: int | None, action: Action | None
    ) -> NlaStrip:
        """Add a new Action-Clip strip to the track

        :param name: Name for the NLA Strip (never None)
        :param start: Start Frame, Start frame for this strip (in [-inf, inf])
        :param action: Action to assign to this strip (never None)
        :return: New NLA Strip
        """

    def remove(self, strip: NlaStrip | None) -> None:
        """Remove a NLA Strip

        :param strip: NLA Strip to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NlaTracks(bpy_prop_collection, bpy_prop):
    """Collection of NLA Tracks"""

    active: NlaTrack | None
    """ Active NLA Track"""

    def new(self, *, prev: NlaTrack | None = None) -> NlaTrack:
        """Add a new NLA Track

        :param prev: NLA Track to add the new one after (optional)
        :return: New NLA Track
        """

    def remove(self, track: NlaTrack | None) -> None:
        """Remove a NLA Track

        :param track: NLA Track to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureInputItems(bpy_prop_collection, bpy_prop):
    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeClosureInputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeClosureInputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureOutputItems(bpy_prop_collection, bpy_prop):
    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeClosureOutputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeClosureOutputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCombineBundleItems(bpy_prop_collection, bpy_prop):
    """Collection of combine bundle items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeCombineBundleItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeCombineBundleItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCompositorFileOutputItems(bpy_prop_collection, bpy_prop):
    """Collection of file output items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeCompositorFileOutputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeCompositorFileOutputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEvaluateClosureInputItems(bpy_prop_collection, bpy_prop):
    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeEvaluateClosureInputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeEvaluateClosureInputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEvaluateClosureOutputItems(bpy_prop_collection, bpy_prop):
    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeEvaluateClosureOutputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeEvaluateClosureOutputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeFunctionFormatStringItems(bpy_prop_collection, bpy_prop):
    """Collection of format string items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeFunctionFormatStringItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeFunctionFormatStringItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryBakeItems(bpy_prop_collection, bpy_prop):
    """Collection of bake items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeGeometryBakeItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeGeometryBakeItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryCaptureAttributeItems(bpy_prop_collection, bpy_prop):
    """Collection of capture attribute items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeGeometryCaptureAttributeItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeGeometryCaptureAttributeItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryForeachGeometryElementGenerationItems(bpy_prop_collection, bpy_prop):
    """Collection of generation items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> ForeachGeometryElementGenerationItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: ForeachGeometryElementGenerationItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryForeachGeometryElementInputItems(bpy_prop_collection, bpy_prop):
    """Collection of input items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> ForeachGeometryElementInputItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: ForeachGeometryElementInputItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryForeachGeometryElementMainItems(bpy_prop_collection, bpy_prop):
    """Collection of main items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> ForeachGeometryElementMainItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: ForeachGeometryElementMainItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryRepeatOutputItems(bpy_prop_collection, bpy_prop):
    """Collection of repeat items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> RepeatItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: RepeatItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometrySimulationOutputItems(bpy_prop_collection, bpy_prop):
    """Collection of simulation items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> SimulationStateItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: SimulationStateItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryViewerItems(bpy_prop_collection, bpy_prop):
    """Collection of viewer items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeGeometryViewerItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeGeometryViewerItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeIndexSwitchItems(bpy_prop_collection, bpy_prop):
    """Collection of index_switch items"""

    def new(self) -> IndexSwitchItem:
        """Add an item at the end

        :return: Item, New item
        """

    def remove(self, item: IndexSwitchItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeInputs(bpy_prop_collection, bpy_prop):
    """Collection of Node Sockets"""

    def new(
        self,
        type: str | None,
        name: str | None,
        *,
        identifier: str | None = "",
        use_multi_input: bool | None = False,
    ) -> NodeSocket:
        """Add a socket to this node

        :param type: Type, Data type (never None)
        :param name: Name, (never None)
        :param identifier: Identifier, Unique socket identifier (optional, never None)
        :param use_multi_input: Make the socket multi-input (valid for inputs only) (optional)
        :return: New socket
        """

    def remove(self, socket: NodeSocket | None) -> None:
        """Remove a socket from this node

        :param socket: The socket to remove
        """

    def clear(self) -> None:
        """Remove all sockets from this node"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a socket to another position

        :param from_index: From Index, Index of the socket to move (in [0, inf])
        :param to_index: To Index, Target index for the socket (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeLinks(bpy_prop_collection, bpy_prop):
    """Collection of Node Links"""

    def new(
        self,
        input: NodeSocket | None,
        output: NodeSocket | None,
        *,
        verify_limits: bool | None = True,
        handle_dynamic_sockets: bool | None = False,
    ) -> NodeLink:
        """Add a node link to this node tree

        :param input: The input socket (never None)
        :param output: The output socket (never None)
        :param verify_limits: Verify Limits, Remove existing links if connection limit is exceeded (optional)
        :param handle_dynamic_sockets: Handle Dynamic Sockets, Handle node specific features like virtual sockets (optional)
        :return: New node link
        """

    def remove(self, link: NodeLink | None) -> None:
        """remove a node link from the node tree

        :param link: The node link to remove (never None)
        """

    def clear(self) -> None:
        """remove all node links from the node tree"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeMenuSwitchItems(bpy_prop_collection, bpy_prop):
    """Collection of items that make up an enum"""

    def new(self, name: str | None) -> NodeEnumItem:
        """Add an a new enum item

        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeEnumItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeOutputs(bpy_prop_collection, bpy_prop):
    """Collection of Node Sockets"""

    def new(
        self,
        type: str | None,
        name: str | None,
        *,
        identifier: str | None = "",
        use_multi_input: bool | None = False,
    ) -> NodeSocket:
        """Add a socket to this node

        :param type: Type, Data type (never None)
        :param name: Name, (never None)
        :param identifier: Identifier, Unique socket identifier (optional, never None)
        :param use_multi_input: Make the socket multi-input (valid for inputs only) (optional)
        :return: New socket
        """

    def remove(self, socket: NodeSocket | None) -> None:
        """Remove a socket from this node

        :param socket: The socket to remove
        """

    def clear(self) -> None:
        """Remove all sockets from this node"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a socket to another position

        :param from_index: From Index, Index of the socket to move (in [0, inf])
        :param to_index: To Index, Target index for the socket (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSeparateBundleItems(bpy_prop_collection, bpy_prop):
    """Collection of separate bundle items"""

    def new(
        self,
        socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
        | None,
        name: str | None,
    ) -> NodeSeparateBundleItem:
        """Add an item at the end

        :param socket_type: Socket Type, Socket type of the item
        :param name: Name, (never None)
        :return: Item, New item
        """

    def remove(self, item: NodeSeparateBundleItem | None) -> None:
        """Remove an item

        :param item: Item, The item to remove (never None)
        """

    def clear(self) -> None:
        """Remove all items"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move an item to another position

        :param from_index: From Index, Index of the item to move (in [0, inf])
        :param to_index: To Index, Target index for the item (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Nodes(bpy_prop_collection, bpy_prop):
    """Collection of Nodes"""

    active: Node | None
    """ Active node in this tree"""

    def new(self, type: str | None) -> Node:
        """Add a node to this node tree

        :param type: Type, Type of node to add (Warning: should be same as node.bl_idname, not node.type!) (never None)
        :return: New node
        """

    def remove(self, node: Node | None) -> None:
        """Remove a node from this node tree

        :param node: The node to remove (never None)
        """

    def clear(self) -> None:
        """Remove all nodes from this node tree"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierBakeDataBlocks(bpy_prop_collection, bpy_prop):
    """Collection of data-blocks that can be referenced by baked data"""

    active_index: int | None
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierBakes(bpy_prop_collection, bpy_prop):
    """Bake data for every bake node"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierPanels(bpy_prop_collection, bpy_prop):
    """State of all panels defined by the node group"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectConstraints(bpy_prop_collection, bpy_prop):
    """Collection of object constraints"""

    active: Constraint | None
    """ Active Object constraint"""

    def new(
        self, type: Literal[bpy.stub_internal.rna_enums.ConstraintTypeItems] | None
    ) -> Constraint:
        """Add a new constraint to this object

        :param type: Constraint type to add
        :return: New constraint
        """

    def remove(self, constraint: Constraint | None) -> None:
        """Remove a constraint from this object

        :param constraint: Removed constraint (never None)
        """

    def clear(self) -> None:
        """Remove all constraint from this object"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a constraint to a different position

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    def copy(self, constraint: Constraint | None) -> Constraint:
        """Add a new constraint that is a copy of the given one

        :param constraint: Constraint to copy - may belong to a different object (never None)
        :return: New constraint
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectModifiers(bpy_prop_collection, bpy_prop):
    """Collection of object modifiers"""

    active: Modifier | None
    """ The active modifier in the list"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.ObjectModifierTypeItems] | None,
    ) -> Modifier:
        """Add a new modifier

        :param name: New name for the modifier (never None)
        :param type: Modifier type to add
        :return: Newly created modifier
        """

    def remove(self, modifier: Modifier | None) -> None:
        """Remove an existing modifier from the object

        :param modifier: Modifier to remove (never None)
        """

    def clear(self) -> None:
        """Remove all modifiers from the object"""

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a modifier to a different position

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectShaderFx(bpy_prop_collection, bpy_prop):
    """Collection of object effects"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.ObjectShaderfxTypeItems] | None,
    ) -> ShaderFx:
        """Add a new shader fx

        :param name: New name for the effect (never None)
        :param type: Effect type to add
        :return: Newly created effect
        """

    def remove(self, shader_fx: ShaderFx | None) -> None:
        """Remove an existing effect from the object

        :param shader_fx: Effect to remove (never None)
        """

    def clear(self) -> None:
        """Remove all effects from the object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PaletteColors(bpy_prop_collection, bpy_prop):
    """Collection of palette colors"""

    active: PaletteColor | None

    def new(self) -> PaletteColor:
        """Add a new color to the palette

        :return: The newly created color
        """

    def remove(self, color: PaletteColor | None) -> None:
        """Remove a color from the palette

        :param color: The color to remove (never None)
        """

    def clear(self) -> None:
        """Remove all colors from the palette"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSettingsTextureSlots(bpy_prop_collection, bpy_prop):
    """Collection of texture slots"""

    @classmethod
    def add(cls) -> ParticleSettingsTextureSlot:
        """add

        :return: The newly initialized mtex
        """

    @classmethod
    def create(cls, index: int | None) -> ParticleSettingsTextureSlot:
        """create

        :param index: Index, Slot index to initialize (in [0, inf])
        :return: The newly initialized mtex
        """

    @classmethod
    def clear(cls, index: int | None) -> None:
        """clear

        :param index: Index, Slot index to clear (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSystems(bpy_prop_collection, bpy_prop):
    """Collection of particle systems"""

    active: ParticleSystem | None
    """ Active particle system being displayed (readonly)"""

    active_index: int | None
    """ Index of active particle system slot (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PathCompareCollection(bpy_prop_collection, bpy_prop):
    """Collection of paths"""

    @classmethod
    def new(cls) -> PathCompare:
        """Add a new path

        :return:
        """

    @classmethod
    def remove(cls, pathcmp: PathCompare | None) -> None:
        """Remove path

        :param pathcmp: (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointCaches(bpy_prop_collection, bpy_prop):
    """Collection of point caches"""

    active_index: int | None
    """ (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PoseBoneConstraints(bpy_prop_collection, bpy_prop):
    """Collection of pose bone constraints"""

    active: Constraint | None
    """ Active PoseChannel constraint"""

    def new(
        self, type: Literal[bpy.stub_internal.rna_enums.ConstraintTypeItems] | None
    ) -> Constraint:
        """Add a constraint to this object

        :param type: Constraint type to add
        :return: New constraint
        """

    def remove(self, constraint: Constraint | None) -> None:
        """Remove a constraint from this object

        :param constraint: Removed constraint (never None)
        """

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a constraint to a different position

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    def copy(self, constraint: Constraint | None) -> Constraint:
        """Add a new constraint that is a copy of the given one

        :param constraint: Constraint to copy - may belong to a different object (never None)
        :return: New constraint
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderPasses(bpy_prop_collection, bpy_prop):
    """Collection of render passes"""

    def find_by_name(self, name: str | None, view: str | None) -> RenderPass:
        """Get the render pass for a given name and view

        :param name: Pass, (never None)
        :param view: View, Render view to get pass from (never None)
        :return: The matching render pass
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderSlots(bpy_prop_collection, bpy_prop):
    """Collection of render layers"""

    active: RenderSlot | None
    """ Active render slot of the image"""

    active_index: int | None
    """ Active render slot of the image (in [0, 32767], default 0)"""

    def new(self, *, name: str | None = "") -> RenderSlot:
        """Add a render slot to the image

        :param name: Name, New name for the render slot (optional, never None)
        :return: Newly created render layer
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderViews(bpy_prop_collection, bpy_prop):
    """Collection of render views"""

    active: SceneRenderView | None
    """ Active Render View (never None)"""

    active_index: int | None
    """ Active index in render view array (in [0, 32767], default 0)"""

    def new(self, name: str | None) -> SceneRenderView:
        """Add a render view to scene

        :param name: New name for the marker (not unique) (never None)
        :return: Newly created render view
        """

    def remove(self, view: SceneRenderView | None) -> None:
        """Remove a render view

        :param view: Render view to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RetimingKeys(bpy_prop_collection, bpy_prop):
    """Collection of RetimingKey"""

    def add(self, *, timeline_frame: int | None = 0) -> RetimingKey:
        """Add retiming key

        :param timeline_frame: Timeline Frame, (in [-1048574, 1048574], optional)
        :return: New RetimingKey
        """

    def reset(self) -> None:
        """Remove all retiming keys"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneObjects(bpy_prop_collection, bpy_prop):
    """All of the scene objects"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ScriptDirectoryCollection(bpy_prop_collection, bpy_prop):
    @classmethod
    def new(cls) -> ScriptDirectory:
        """Add a new Python script directory

        :return:
        """

    @classmethod
    def remove(cls, script_directory: ScriptDirectory | None) -> None:
        """Remove a Python script directory

        :param script_directory: (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceNodeEditorPath(bpy_prop_collection, bpy_prop):
    """Get the node tree path as a string"""

    to_string: str
    """ (default "", readonly, never None)"""

    def clear(self) -> None:
        """Reset the node tree path"""

    def start(self, node_tree: NodeTree | None) -> None:
        """Set the root node tree

        :param node_tree: Node Tree
        """

    def append(self, node_tree: NodeTree | None, *, node: Node | None = None) -> None:
        """Append a node group tree to the path

        :param node_tree: Node Tree, Node tree to append to the node editor path
        :param node: Node, Group node linking to this node tree (optional)
        """

    def pop(self) -> None:
        """Remove the last node tree from the path"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SplineBezierPoints(bpy_prop_collection, bpy_prop):
    """Collection of spline Bézier points"""

    def add(self, count: int | None) -> None:
        """Add a number of points to this spline

        :param count: Number, Number of points to add to the spline (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SplinePoints(bpy_prop_collection, bpy_prop):
    """Collection of spline points"""

    def add(self, count: int | None) -> None:
        """Add a number of points to this spline

        :param count: Number, Number of points to add to the spline (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetTables(bpy_prop_collection, bpy_prop):
    """Active table and persisted state of previously displayed tables"""

    active: SpreadsheetTable | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripElements(bpy_prop_collection, bpy_prop):
    """Collection of StripElement"""

    def append(self, filename: str | None) -> StripElement:
        """Push an image from ImageStrip.directory

        :param filename: Filepath to image (never None)
        :return: New StripElement
        """

    def pop(self, index: int | None) -> None:
        """Pop an image off the collection

        :param index: Index of image to remove (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripModifiers(bpy_prop_collection, bpy_prop):
    """Collection of strip modifiers"""

    active: StripModifier | None
    """ The active strip modifier in the list"""

    def new(
        self,
        name: str | None,
        type: Literal[bpy.stub_internal.rna_enums.StripModifierTypeItems] | None,
    ) -> StripModifier:
        """Add a new modifier

        :param name: New name for the modifier (never None)
        :param type: Modifier type to add
        :return: Newly created modifier
        """

    def remove(self, modifier: StripModifier | None) -> None:
        """Remove an existing modifier from the strip

        :param modifier: Modifier to remove (never None)
        """

    def clear(self) -> None:
        """Remove all modifiers from the strip"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripsMeta(bpy_prop_collection, bpy_prop):
    """Collection of Strips"""

    def new_clip(
        self,
        name: str | None,
        clip: MovieClip | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new movie clip strip

        :param name: Name for the new strip (never None)
        :param clip: Movie clip to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_mask(
        self,
        name: str | None,
        mask: Mask | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new mask strip

        :param name: Name for the new strip (never None)
        :param mask: Mask to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_scene(
        self,
        name: str | None,
        scene: Scene | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new scene strip

        :param name: Name for the new strip (never None)
        :param scene: Scene to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_image(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
        *,
        fit_method: Literal[bpy.stub_internal.rna_enums.StripScaleMethodItems]
        | None = "ORIGINAL",
    ) -> Strip:
        """Add a new image strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to image (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :param fit_method: Image Fit Method, (optional)
        :return: New Strip
        """

    def new_movie(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
        *,
        fit_method: Literal[bpy.stub_internal.rna_enums.StripScaleMethodItems]
        | None = "ORIGINAL",
    ) -> Strip:
        """Add a new movie strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to movie (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :param fit_method: Image Fit Method, (optional)
        :return: New Strip
        """

    def new_sound(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new sound strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to movie (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_meta(
        self, name: str | None, channel: int | None, frame_start: int | None
    ) -> Strip:
        """Add a new meta strip

        :param name: Name for the new strip (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_effect(
        self,
        name: str | None,
        type: typing.Literal[
            "CROSS",
            "ADD",
            "SUBTRACT",
            "ALPHA_OVER",
            "ALPHA_UNDER",
            "GAMMA_CROSS",
            "COMPOSITOR",
            "MULTIPLY",
            "WIPE",
            "GLOW",
            "COLOR",
            "SPEED",
            "MULTICAM",
            "ADJUSTMENT",
            "GAUSSIAN_BLUR",
            "TEXT",
            "COLORMIX",
        ]
        | None,
        channel: int | None,
        frame_start: int | None,
        *,
        length: int | None = 0,
        input1: Strip | None = None,
        input2: Strip | None = None,
    ) -> Strip:
        """Add a new effect strip

                :param name: Name for the new strip (never None)
                :param type: Type, type for the new strip

        CROSS
        Crossfade -- Fade out of one video, fading into another.

        ADD
        Add -- Add together color channels from two videos.

        SUBTRACT
        Subtract -- Subtract one strips color from another.

        ALPHA_OVER
        Alpha Over -- Blend alpha on top of another video.

        ALPHA_UNDER
        Alpha Under -- Blend alpha below another video.

        GAMMA_CROSS
        Gamma Crossfade -- Crossfade with color correction.

        COMPOSITOR
        Compositor -- Compositor based effect.

        MULTIPLY
        Multiply -- Multiply color channels from two videos.

        WIPE
        Wipe -- Sweep a transition line across the frame.

        GLOW
        Glow -- Add blur and brightness to light areas.

        COLOR
        Color -- Add a simple color strip.

        SPEED
        Speed -- Timewarp video strips, modifying playback speed.

        MULTICAM
        Multicam Selector -- Control active camera angles.

        ADJUSTMENT
        Adjustment Layer -- Apply nondestructive effects.

        GAUSSIAN_BLUR
        Gaussian Blur -- Soften details along axes.

        TEXT
        Text -- Add a simple text strip.

        COLORMIX
        Color Mix -- Combine two strips using blend modes.
                :param channel: Channel, The channel for the new strip (in [1, 128])
                :param frame_start: The start frame for the new strip (in [-inf, inf])
                :param length: Length of the strip in frames, or the length of each strip if multiple are added (in [-inf, inf], optional)
                :param input1: First input strip for effect (optional)
                :param input2: Second input strip for effect (optional)
                :return: New Strip
        """

    def remove(self, sequence: Strip | None) -> None:
        """Remove a Strip

        :param sequence: Strip to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripsTopLevel(bpy_prop_collection, bpy_prop):
    """Collection of Strips"""

    def new_clip(
        self,
        name: str | None,
        clip: MovieClip | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new movie clip strip

        :param name: Name for the new strip (never None)
        :param clip: Movie clip to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_mask(
        self,
        name: str | None,
        mask: Mask | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new mask strip

        :param name: Name for the new strip (never None)
        :param mask: Mask to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_scene(
        self,
        name: str | None,
        scene: Scene | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new scene strip

        :param name: Name for the new strip (never None)
        :param scene: Scene to add (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_image(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
        *,
        fit_method: Literal[bpy.stub_internal.rna_enums.StripScaleMethodItems]
        | None = "ORIGINAL",
    ) -> Strip:
        """Add a new image strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to image (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :param fit_method: Image Fit Method, (optional)
        :return: New Strip
        """

    def new_movie(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
        *,
        fit_method: Literal[bpy.stub_internal.rna_enums.StripScaleMethodItems]
        | None = "ORIGINAL",
    ) -> Strip:
        """Add a new movie strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to movie (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :param fit_method: Image Fit Method, (optional)
        :return: New Strip
        """

    def new_sound(
        self,
        name: str | None,
        filepath: str | None,
        channel: int | None,
        frame_start: int | None,
    ) -> Strip:
        """Add a new sound strip

        :param name: Name for the new strip (never None)
        :param filepath: Filepath to movie (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_meta(
        self, name: str | None, channel: int | None, frame_start: int | None
    ) -> Strip:
        """Add a new meta strip

        :param name: Name for the new strip (never None)
        :param channel: Channel, The channel for the new strip (in [1, 128])
        :param frame_start: The start frame for the new strip (in [-1048574, 1048574])
        :return: New Strip
        """

    def new_effect(
        self,
        name: str | None,
        type: typing.Literal[
            "CROSS",
            "ADD",
            "SUBTRACT",
            "ALPHA_OVER",
            "ALPHA_UNDER",
            "GAMMA_CROSS",
            "COMPOSITOR",
            "MULTIPLY",
            "WIPE",
            "GLOW",
            "COLOR",
            "SPEED",
            "MULTICAM",
            "ADJUSTMENT",
            "GAUSSIAN_BLUR",
            "TEXT",
            "COLORMIX",
        ]
        | None,
        channel: int | None,
        frame_start: int | None,
        *,
        length: int | None = 0,
        input1: Strip | None = None,
        input2: Strip | None = None,
    ) -> Strip:
        """Add a new effect strip

                :param name: Name for the new strip (never None)
                :param type: Type, type for the new strip

        CROSS
        Crossfade -- Fade out of one video, fading into another.

        ADD
        Add -- Add together color channels from two videos.

        SUBTRACT
        Subtract -- Subtract one strips color from another.

        ALPHA_OVER
        Alpha Over -- Blend alpha on top of another video.

        ALPHA_UNDER
        Alpha Under -- Blend alpha below another video.

        GAMMA_CROSS
        Gamma Crossfade -- Crossfade with color correction.

        COMPOSITOR
        Compositor -- Compositor based effect.

        MULTIPLY
        Multiply -- Multiply color channels from two videos.

        WIPE
        Wipe -- Sweep a transition line across the frame.

        GLOW
        Glow -- Add blur and brightness to light areas.

        COLOR
        Color -- Add a simple color strip.

        SPEED
        Speed -- Timewarp video strips, modifying playback speed.

        MULTICAM
        Multicam Selector -- Control active camera angles.

        ADJUSTMENT
        Adjustment Layer -- Apply nondestructive effects.

        GAUSSIAN_BLUR
        Gaussian Blur -- Soften details along axes.

        TEXT
        Text -- Add a simple text strip.

        COLORMIX
        Color Mix -- Combine two strips using blend modes.
                :param channel: Channel, The channel for the new strip (in [1, 128])
                :param frame_start: The start frame for the new strip (in [-inf, inf])
                :param length: Length of the strip in frames, or the length of each strip if multiple are added (in [-inf, inf], optional)
                :param input1: First input strip for effect (optional)
                :param input2: Second input strip for effect (optional)
                :return: New Strip
        """

    def remove(self, sequence: Strip | None) -> None:
        """Remove a Strip

        :param sequence: Strip to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StudioLights(bpy_prop_collection, bpy_prop):
    """Collection of studio lights"""

    def load(
        self, path: str | None, type: typing.Literal["STUDIO", "WORLD", "MATCAP"] | None
    ) -> StudioLight:
        """Load studiolight from file

        :param path: File Path, File path where the studio light file can be found (never None)
        :param type: Type, The type for the new studio light
        :return: Newly created StudioLight
        """

    def new(self, path: str | None) -> StudioLight:
        """Create studiolight from default lighting

        :param path: Path, Path to the file that will contain the lighting info (without extension) (never None)
        :return: Newly created StudioLight
        """

    def remove(self, studio_light: StudioLight | None) -> None:
        """Remove a studio light

        :param studio_light: The studio light to remove (never None)
        """

    def refresh(self) -> None:
        """Refresh Studio Lights from disk"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TimelineMarkers(bpy_prop_collection, bpy_prop):
    """Collection of timeline markers"""

    def new(self, name: str | None, *, frame: int | None = 1) -> TimelineMarker:
        """Add a timeline marker

        :param name: New name for the marker (not unique) (never None)
        :param frame: The frame for the new marker (in [-1048574, 1048574], optional)
        :return: Newly created timeline marker
        """

    def remove(self, marker: TimelineMarker | None) -> None:
        """Remove a timeline marker

        :param marker: Timeline marker to remove (never None)
        """

    def clear(self) -> None:
        """Remove all timeline markers"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UDIMTiles(bpy_prop_collection, bpy_prop):
    """Collection of UDIM tiles"""

    active: UDIMTile | None
    """ Active Image Tile (never None)"""

    active_index: int | None
    """ Active index in tiles array (in [0, inf], default 0)"""

    def new(self, tile_number: int | None, *, label: str | None = "") -> UDIMTile:
        """Add a tile to the image

        :param tile_number: Number of the newly created tile (in [1, inf])
        :param label: Optional label for the tile (optional, never None)
        :return: Newly created image tile
        """

    def get(self, tile_number: int | None) -> UDIMTile:
        """Get a tile based on its tile number

        :param tile_number: Number of the tile (in [0, inf])
        :return: The tile
        """

    def remove(self, tile: UDIMTile | None) -> None:
        """Remove an image tile

        :param tile: Image tile to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UVLoopLayers(bpy_prop_collection, bpy_prop):
    """Collection of UV map layers"""

    active: MeshUVLoopLayer | None
    """ Active UV Map layer"""

    active_index: int | None
    """ Active UV map index (in [0, inf], default 0)"""

    def new(
        self, *, name: str | None = "UVMap", do_init: bool | None = True
    ) -> MeshUVLoopLayer:
        """Add a UV map layer to Mesh

        :param name: UV map name (optional, never None)
        :param do_init: Whether new layers data should be initialized by copying current active one, or if none is active, with a default UVmap (optional)
        :return: The newly created layer
        """

    def remove(self, layer: MeshUVLoopLayer | None) -> None:
        """Remove a UV map layer

        :param layer: The layer to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UserExtensionRepoCollection(bpy_prop_collection, bpy_prop):
    """Collection of user extension repositories"""

    @classmethod
    def new(
        cls,
        *,
        name: str | None = "",
        module: str | None = "",
        custom_directory: str | None = "",
        remote_url: str | None = "",
        source: typing.Literal["USER", "SYSTEM"] | None = "USER",
    ) -> UserExtensionRepo:
        """Add a new repository

                :param name: Name, (optional, never None)
                :param module: Module, (optional, never None)
                :param custom_directory: Custom Directory, (optional, never None)
                :param remote_url: Remote URL, (optional, never None)
                :param source: Source, How the repository is managed (optional)

        USER
        User -- Repository managed by the user, stored in user directories.

        SYSTEM
        System -- Read-only repository provided by the system.
                :return: Newly added repository
        """

    @classmethod
    def remove(cls, repo: UserExtensionRepo | None) -> None:
        """Remove repos

        :param repo: Repository to remove (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexGroups(bpy_prop_collection, bpy_prop):
    """Collection of vertex groups"""

    active: VertexGroup | None
    """ Vertex groups of the object"""

    active_index: int | None
    """ Active index in vertex group array (in [0, inf], default 0)"""

    def new(self, *, name: str | None = "Group") -> VertexGroup:
        """Add vertex group to object

        :param name: Vertex group name (optional, never None)
        :return: New vertex group
        """

    def remove(self, group: VertexGroup | None) -> None:
        """Delete vertex group from object

        :param group: Vertex group to remove (never None)
        """

    def clear(self) -> None:
        """Delete all vertex groups from object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewLayers(bpy_prop_collection, bpy_prop):
    """Collection of render layers"""

    def new(self, name: str | None) -> ViewLayer:
        """Add a view layer to scene

        :param name: New name for the view layer (not unique) (never None)
        :return: Newly created view layer
        """

    def remove(self, layer: ViewLayer | None) -> None:
        """Remove a view layer

        :param layer: View layer to remove (never None)
        """

    def move(self, from_index: int | None, to_index: int | None) -> None:
        """Move a view layer

        :param from_index: From Index, Index to move (in [-inf, inf])
        :param to_index: To Index, Target index (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeGrids(bpy_prop_collection, bpy_prop):
    """3D volume grids"""

    active_index: int | None
    """ Index of active volume grid (in [0, inf], default 0)"""

    error_message: str
    """ If loading grids failed, error message with details (default "", readonly, never None)"""

    frame: int
    """ Frame number that volume grids will be loaded at, based on scene time and volume parameters (in [-inf, inf], default 0, readonly)"""

    frame_filepath: str
    """ Volume file used for loading the volume at the current frame. Empty if the volume has not be loaded or the frame only exists in memory. (default "", readonly, never None, blend relative // prefix supported)"""

    is_loaded: bool
    """ List of grids and metadata are loaded in memory (default False, readonly)"""

    def load(self) -> bool:
        """Load list of grids and metadata from file

        :return: True if grid list was successfully loaded
        """

    def unload(self) -> None:
        """Unload all grid and voxel data from memory"""

    def save(self, filepath: str | None) -> bool:
        """Save grids and metadata to file

        :param filepath: File path to save to (never None)
        :return: True if grid list was successfully loaded
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Windows(bpy_prop_collection, bpy_prop):
    """Collection of windows"""

    def find_playing(self, *, scrub: bool | None = False) -> Window:
        """find_playing

        :param scrub: Scrubbing, Check if time in the window is being scrubbed (optional)
        :return: Window, Window that is currently playing
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMapBindings(bpy_prop_collection, bpy_prop):
    """Collection of XR action map bindings"""

    def new(
        self, name: str | None, replace_existing: bool | None
    ) -> XrActionMapBinding:
        """new

        :param name: Name of the action map binding, (never None)
        :param replace_existing: Replace Existing, Replace any existing binding with the same name
        :return: Binding, Added action map binding
        """

    def new_from_binding(
        self, binding: XrActionMapBinding | None
    ) -> XrActionMapBinding:
        """new_from_binding

        :param binding: Binding, Binding to use as a reference (never None)
        :return: Binding, Added action map binding
        """

    def remove(self, binding: XrActionMapBinding | None) -> None:
        """remove

        :param binding: Binding, (never None)
        """

    def find(self, name: str | None) -> XrActionMapBinding:
        """find

        :param name: Name, (never None)
        :return: Binding, The action map binding with the given name
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMapItems(bpy_prop_collection, bpy_prop):
    """Collection of XR action map items"""

    def new(self, name: str | None, replace_existing: bool | None) -> XrActionMapItem:
        """new

        :param name: Name of the action map item, (never None)
        :param replace_existing: Replace Existing, Replace any existing item with the same name
        :return: Item, Added action map item
        """

    def new_from_item(self, item: XrActionMapItem | None) -> XrActionMapItem:
        """new_from_item

        :param item: Item, Item to use as a reference (never None)
        :return: Item, Added action map item
        """

    def remove(self, item: XrActionMapItem | None) -> None:
        """remove

        :param item: Item, (never None)
        """

    def find(self, name: str | None) -> XrActionMapItem:
        """find

        :param name: Name, (never None)
        :return: Item, The action map item with the given name
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMaps(bpy_prop_collection, bpy_prop):
    """Collection of XR action maps"""

    @classmethod
    def new(
        cls,
        xr_session_state: XrSessionState | None,
        name: str | None,
        replace_existing: bool | None,
    ) -> XrActionMap:
        """new

        :param xr_session_state: XR Session State, (never None)
        :param name: Name, (never None)
        :param replace_existing: Replace Existing, Replace any existing actionmap with the same name
        :return: Action Map, Added action map
        """

    @classmethod
    def new_from_actionmap(
        cls, xr_session_state: XrSessionState | None, actionmap: XrActionMap | None
    ) -> XrActionMap:
        """new_from_actionmap

        :param xr_session_state: XR Session State, (never None)
        :param actionmap: Action Map, Action map to use as a reference (never None)
        :return: Action Map, Added action map
        """

    @classmethod
    def remove(
        cls, xr_session_state: XrSessionState | None, actionmap: XrActionMap | None
    ) -> None:
        """remove

        :param xr_session_state: XR Session State, (never None)
        :param actionmap: Action Map, Removed action map (never None)
        """

    @classmethod
    def find(
        cls, xr_session_state: XrSessionState | None, name: str | None
    ) -> XrActionMap:
        """find

        :param xr_session_state: XR Session State, (never None)
        :param name: Name, (never None)
        :return: Action Map, The action map with the given name
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrComponentPaths(bpy_prop_collection, bpy_prop):
    """Collection of OpenXR component paths"""

    def new(self, path: str | None) -> XrComponentPath:
        """new

        :param path: Path, OpenXR component path (never None)
        :return: Component Path, Added component path
        """

    def remove(self, component_path: XrComponentPath | None) -> None:
        """remove

        :param component_path: Component Path, (never None)
        """

    def find(self, path: str | None) -> XrComponentPath:
        """find

        :param path: Path, OpenXR component path (never None)
        :return: Component Path, The component path with the given path
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrUserPaths(bpy_prop_collection, bpy_prop):
    """Collection of OpenXR user paths"""

    def new(self, path: str | None) -> XrUserPath:
        """new

        :param path: Path, OpenXR user path (never None)
        :return: User Path, Added user path
        """

    def remove(self, user_path: XrUserPath | None) -> None:
        """remove

        :param user_path: User Path, (never None)
        """

    def find(self, path: str | None) -> XrUserPath:
        """find

        :param path: Path, OpenXR user path (never None)
        :return: User Path, The user path with the given path
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class wmOwnerIDs(bpy_prop_collection, bpy_prop):
    def new(self, name: str | None) -> wmOwnerID:
        """Add ui tag

        :param name: New name for the tag (never None)
        :return:
        """

    def remove(self, owner_id: wmOwnerID | None) -> None:
        """Remove ui tag

        :param owner_id: Tag to remove (never None)
        """

    def clear(self) -> None:
        """Remove all tags"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class wmTools(bpy_prop_collection, bpy_prop):
    def from_space_view3d_mode(
        self,
        mode: Literal[bpy.stub_internal.rna_enums.ContextModeItems] | None,
        *,
        create: bool | None = False,
    ) -> WorkSpaceTool:
        """

        :param mode:
        :param create: Create, (optional)
        :return:
        """

    def from_space_image_mode(
        self,
        mode: Literal[bpy.stub_internal.rna_enums.SpaceImageModeAllItems] | None,
        *,
        create: bool | None = False,
    ) -> WorkSpaceTool:
        """

        :param mode:
        :param create: Create, (optional)
        :return:
        """

    def from_space_node(self, *, create: bool | None = False) -> WorkSpaceTool:
        """

        :param create: Create, (optional)
        :return:
        """

    def from_space_sequencer(
        self,
        mode: Literal[bpy.stub_internal.rna_enums.SpaceSequencerViewTypeItems] | None,
        *,
        create: bool | None = False,
    ) -> WorkSpaceTool:
        """

        :param mode:
        :param create: Create, (optional)
        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AOV(bpy_struct):
    is_valid: bool
    """ Is the name of the AOV conflicting (default True)"""

    name: str
    """ Name of the AOV (default "", never None)"""

    type: typing.Literal["COLOR", "VALUE"]
    """ Data type of the AOV (default 'COLOR')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ASSETBROWSER_UL_metadata_tags(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Action(ID, bpy_struct):
    """A collection of F-Curves for animation"""

    curve_frame_range: mathutils.Vector
    """ The combined frame range of all F-Curves within this action (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    frame_end: float
    """ The end frame of the manually set intended playback range (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    frame_range: mathutils.Vector
    """ The intended playback frame range of this action, using the manually set range if available, or the combined frame range of all F-Curves within this action if not (assigning sets the manual frame range) (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    frame_start: float
    """ The start frame of the manually set intended playback range (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    is_action_layered: bool
    """ Return whether this is a layered Action. At this point all actions are layered through versioning and this function will always return true (default False, readonly)"""

    is_action_legacy: bool
    """ Return whether this is a legacy Action. Legacy Actions have no layers or slots. Since Blender 4.4 actions are automatically updated to layered actions. This will only return true on empty actions (default False, readonly)"""

    is_empty: bool
    """ False when there is any Layer, Slot, or legacy F-Curve (default False, readonly)"""

    layers: typing.Any
    """ The list of layers that make up this Action (default None, readonly)"""

    pose_markers: typing.Any
    """ Markers specific to this action, for labeling poses (default None, readonly)"""

    slots: typing.Any
    """ The list of slots in this Action (default None, readonly)"""

    use_cyclic: bool
    """ The action is intended to be used as a cycle looping over its manually set playback frame range (enabling this does not automatically make it loop) (default False)"""

    use_frame_range: bool
    """ Manually specify the intended playback frame range for the action (this range is used by some tools, but does not affect animation evaluation) (default False)"""

    def deselect_keys(self) -> None:
        """Deselects all keys of the Action. The selection status of F-Curves is unchanged."""

    def fcurve_ensure_for_datablock(
        self,
        datablock: ID | None,
        data_path: str | None,
        *,
        index: int | None = 0,
        group_name: str | None = "",
    ) -> FCurve:
        """Ensure that an F-Curve exists, with the given data path and array index, for the given data-block. This action must already be assigned to the data-block. This function will also create the layer, keyframe strip, and action slot if necessary, and take care of assigning the action slot too

        :param datablock: The data-block animated by this action, for which to ensure the F-Curve exists. This action must already be assigned to the data-block (never None)
        :param data_path: Data Path, F-Curve data path (never None)
        :param index: Index, Array index (in [0, inf], optional)
        :param group_name: Group Name, Name of the group for this F-Curve, if any. If the F-Curve already exists, this parameter is ignored (optional, never None)
        :return: The found or created F-Curve
        """

    def flip_with_pose(self, object: Object | None) -> None:
        """Flip the action around the X axis using a pose

        :param object: The reference armature object to use when flipping (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionChannelbag(bpy_struct):
    """Collection of animation channels, typically associated with an action slot"""

    fcurves: typing.Any
    """ The individual F-Curves that animate the slot (default None, readonly)"""

    groups: typing.Any
    """ Groupings of F-Curves for display purposes, in e.g. the dopesheet and graph editor (default None, readonly)"""

    slot: ActionSlot | None
    """ The Slot that the Channelbag's animation data is for (readonly)"""

    slot_handle: int
    """ (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionConstraint(Constraint, bpy_struct):
    """Map an action to the transform axes of a bone"""

    action: Action | None
    """ The constraining action"""

    action_slot: ActionSlot | None
    """ The slot identifies which sub-set of the Action is considered to be for this strip, and its name is used to find the right slot when assigning another Action"""

    action_slot_handle: int
    """ A number that identifies which sub-set of the Action is considered to be for this Action Constraint (in [-inf, inf], default 0)"""

    action_suitable_slots: typing.Any
    """ The list of action slots suitable for this NLA strip (default None, readonly)"""

    eval_time: float
    """ Interpolates between Action Start and End frames (in [0, 1], default 0.0)"""

    frame_end: int
    """ Last frame of the Action to use (in [-1048574, 1048574], default 0)"""

    frame_start: int
    """ First frame of the Action to use (in [-1048574, 1048574], default 0)"""

    last_slot_identifier: str
    """ The identifier of the most recently assigned action slot. The slot identifies which sub-set of the Action is considered to be for this constraint, and its identifier is used to find the right slot when assigning an Action. (default "", never None)"""

    max: float
    """ Maximum value for target channel range (in [-1000, 1000], default 0.0)"""

    min: float
    """ Minimum value for target channel range (in [-1000, 1000], default 0.0)"""

    mix_mode: typing.Literal[
        "REPLACE",
        "BEFORE_FULL",
        "BEFORE",
        "BEFORE_SPLIT",
        "AFTER_FULL",
        "AFTER",
        "AFTER_SPLIT",
    ]
    """ Specify how existing transformations and the action channels are combined (default 'AFTER_FULL')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    transform_channel: typing.Literal[
        "LOCATION_X",
        "LOCATION_Y",
        "LOCATION_Z",
        "ROTATION_X",
        "ROTATION_Y",
        "ROTATION_Z",
        "SCALE_X",
        "SCALE_Y",
        "SCALE_Z",
    ]
    """ Transformation channel from the target that is used to key the Action (default 'ROTATION_X')"""

    use_bone_object_action: bool
    """ Bones only: apply the object's transformation channels of the action to the constrained bone, instead of bone's channels (default False)"""

    use_eval_time: bool
    """ Interpolate between Action Start and End frames, with the Evaluation Time slider instead of the Target object/bone (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionGroup(bpy_struct):
    """Groups of F-Curves"""

    channels: typing.Any
    """ F-Curves in this group (default None, readonly)"""

    color_set: Literal[bpy.stub_internal.rna_enums.ColorSetsItems]
    """ Custom color set to use (default 'DEFAULT')"""

    colors: ThemeBoneColorSet | None
    """ Copy of the colors associated with the group's color set (readonly, never None)"""

    is_custom_color_set: bool
    """ Color set is user-defined instead of a fixed theme color set (default False, readonly)"""

    lock: bool
    """ Action group is locked (default False)"""

    mute: bool
    """ Action group is muted (default False)"""

    name: str
    """ (default "", never None)"""

    select: bool
    """ Action group is selected (default False)"""

    show_expanded: bool
    """ Action group is expanded except in graph editor (default False)"""

    show_expanded_graph: bool
    """ Action group is expanded in graph editor (default False)"""

    use_pin: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionKeyframeStrip(ActionStrip, bpy_struct):
    """Strip with a set of F-Curves for each action slot"""

    channelbags: typing.Any
    """ (default None, readonly)"""

    def channelbag(
        self, slot: ActionSlot | None, *, ensure: bool | None = False
    ) -> ActionChannelbag:
        """Find the ActionChannelbag for a specific Slot

        :param slot: Slot, The slot for which to find the channelbag
        :param ensure: Create if necessary, Ensure the channelbag exists for this slot, creating it if necessary (optional)
        :return: Channels
        """

    def key_insert(
        self,
        slot: ActionSlot | None,
        data_path: str | None,
        array_index: int | None,
        value: float | None,
        time: float | None,
    ) -> bool:
        """key_insert

        :param slot: Slot, The slot that identifies which thing should be keyed
        :param data_path: Data Path, F-Curve data path (never None)
        :param array_index: Array Index, Index of the animated array element, or -1 if the property is not an array (in [-inf, inf])
        :param value: Value to key, Value of the animated property (in [-inf, inf])
        :param time: Time of the key, Time, in frames, of the key (in [-inf, inf])
        :return: Success, Whether the key was successfully inserted
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionLayer(bpy_struct):
    name: str
    """ (default "", never None)"""

    strips: typing.Any
    """ The list of strips that are on this animation layer (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionSlot(bpy_struct):
    """Identifier for a set of channels in this Action, that can be used by a data-block to specify what it gets animated by"""

    active: bool | None
    """ Whether this is the active slot, can be set by assigning to action.slots.active (default False, readonly)"""

    handle: int
    """ Number specific to this Slot, unique within the Action.
This is used, for example, on a ActionKeyframeStrip to look up the ActionChannelbag for this Slot(in [-inf, inf], default 0, readonly)"""

    identifier: str
    """ Used when connecting an Action to a data-block, to find the correct slot handle. This is the display name, prefixed by two characters determined by the slot's ID type (default "", never None)"""

    name_display: str
    """ Name of the slot, for display in the user interface. This name combined with the slot's data-block type is unique within its Action (default "", never None)"""

    select: bool
    """ Selection state of the slot (default False)"""

    show_expanded: bool
    """ Expanded state of the slot (default False)"""

    target_id_type: typing.Literal[
        "ACTION",
        "ARMATURE",
        "BRUSH",
        "CACHEFILE",
        "CAMERA",
        "COLLECTION",
        "CURVE",
        "CURVES",
        "FONT",
        "GREASEPENCIL",
        "GREASEPENCIL_V3",
        "IMAGE",
        "KEY",
        "LATTICE",
        "LIBRARY",
        "LIGHT",
        "LIGHT_PROBE",
        "LINESTYLE",
        "MASK",
        "MATERIAL",
        "MESH",
        "META",
        "MOVIECLIP",
        "NODETREE",
        "OBJECT",
        "PAINTCURVE",
        "PALETTE",
        "PARTICLE",
        "POINTCLOUD",
        "SCENE",
        "SCREEN",
        "SOUND",
        "SPEAKER",
        "TEXT",
        "TEXTURE",
        "VOLUME",
        "WINDOWMANAGER",
        "WORKSPACE",
        "WORLD",
        "UNSPECIFIED",
    ]
    """ Type of data-block that this slot is intended to animate; can be set when 'UNSPECIFIED' but is otherwise read-only (default 'UNSPECIFIED')"""

    target_id_type_icon: int
    """ (in [-inf, inf], default 0, readonly)"""

    def users(self) -> None:
        """Return the data-blocks that are animated by this slot of this action

        :return: users
        """

    def duplicate(self) -> typing_extensions.Self:
        """Duplicate this slot, including all the animation data associated with it

        :return: Duplicated Slot, The slot created by duplicating this one
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ActionStrip(bpy_struct):
    type: typing.Literal["KEYFRAME"]
    """ (default 'KEYFRAME', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AddStrip(EffectStrip, Strip, bpy_struct):
    """Add Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Addon(bpy_struct):
    """Python add-ons to be loaded automatically"""

    module: str
    """ Module name (default "", never None)"""

    preferences: AddonPreferences | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AddonPreferences(bpy_struct):
    bl_idname: str
    """ (default "", never None)"""

    layout: UILayout

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AdjustmentStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip to perform filter adjustments to layers below"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AlphaOverStrip(EffectStrip, Strip, bpy_struct):
    """Alpha Over Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AlphaUnderStrip(EffectStrip, Strip, bpy_struct):
    """Alpha Under Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnimData(bpy_struct):
    """Animation data for data-block"""

    action: Action | None
    """ Active Action for this data-block"""

    action_blend_type: typing.Literal[
        "REPLACE", "COMBINE", "ADD", "SUBTRACT", "MULTIPLY"
    ]
    """ Method used for combining Active Action's result with result of NLA stack (default 'REPLACE')"""

    action_extrapolation: typing.Literal["NOTHING", "HOLD", "HOLD_FORWARD"]
    """ Action to take for gaps past the Active Action's range (when evaluating with NLA) (default 'HOLD')"""

    action_influence: float
    """ Amount the Active Action contributes to the result of the NLA stack (in [0, 1], default 1.0)"""

    action_slot: ActionSlot | None
    """ The slot identifies which sub-set of the Action is considered to be for this data-block, and its name is used to find the right slot when assigning an Action"""

    action_slot_handle: int
    """ A number that identifies which sub-set of the Action is considered to be for this data-block (in [-inf, inf], default 0)"""

    action_slot_handle_tweak_storage: int
    """ Storage to temporarily hold the main action slot while in tweak mode (in [-inf, inf], default 0)"""

    action_suitable_slots: typing.Any
    """ The list of slots in this animation data-block (default None, readonly)"""

    action_tweak_storage: Action | None
    """ Storage to temporarily hold the main action while in tweak mode"""

    drivers: typing.Any
    """ The Drivers/Expressions for this data-block (default None, readonly)"""

    last_slot_identifier: str
    """ The identifier of the most recently assigned action slot. The slot identifies which sub-set of the Action is considered to be for this data-block, and its identifier is used to find the right slot when assigning an Action. (default "", never None)"""

    nla_tracks: typing.Any
    """ NLA Tracks (i.e. Animation Layers) (default None, readonly)"""

    use_nla: bool
    """ NLA stack is evaluated when evaluating this block (default True)"""

    use_pin: bool
    """ (default False)"""

    use_tweak_mode: bool
    """ Whether to enable or disable tweak mode in NLA (default False)"""

    def nla_tweak_strip_time_to_scene(
        self, frame: float | None, *, invert: bool | None = False
    ) -> float:
        """Convert a time value from the local time of the tweaked strip to scene time, exactly as done by built-in key editing tools. Returns the input time unchanged if not tweaking.

        :param frame: Input time (in [-1.04857e+06, 1.04857e+06])
        :param invert: Invert, Convert scene time to action time (optional)
        :return: Converted time (in [-1.04857e+06, 1.04857e+06])
        """

    def fix_paths_rename_all(
        self,
        *,
        prefix: str | None = "",
        old_name: str | None = "",
        new_name: str | None = "",
    ) -> None:
        """Rename the property paths in the animation system, since properties are animated via string paths, its needed to keep them valid after properties has been renamed

        :param prefix: Prefix, Name prefix (optional, never None)
        :param old_name: Old Name, Old name (optional, never None)
        :param new_name: New Name, New name (optional, never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnimViz(bpy_struct):
    """Settings for the visualization of motion"""

    motion_path: AnimVizMotionPaths | None
    """ Motion Path settings for visualization (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnimVizMotionPaths(bpy_struct):
    """Motion Path settings for animation visualization"""

    bake_location: Literal[bpy.stub_internal.rna_enums.MotionpathBakeLocationItems]
    """ When calculating Bone Paths, use Head or Tips (default 'TAILS')"""

    frame_after: int
    """ Number of frames to show after the current frame (only for 'Around Frame' Onion-skinning method) (in [1, 524287], default 0)"""

    frame_before: int
    """ Number of frames to show before the current frame (only for 'Around Frame' Onion-skinning method) (in [1, 524287], default 0)"""

    frame_end: int
    """ End frame of range of paths to display/calculate (not for 'Around Frame' Onion-skinning method) (in [-inf, inf], default 0)"""

    frame_start: int
    """ Starting frame of range of paths to display/calculate (not for 'Around Frame' Onion-skinning method) (in [-inf, inf], default 0)"""

    frame_step: int
    """ Number of frames between paths shown (not for 'On Keyframes' Onion-skinning method) (in [1, 100], default 0)"""

    has_motion_paths: bool
    """ Are there any bone paths that will need updating (read-only) (default False, readonly)"""

    range: Literal[bpy.stub_internal.rna_enums.MotionpathRangeItems]
    """ Type of range to calculate for Motion Paths (default 'SCENE')"""

    show_frame_numbers: bool
    """ Show frame numbers on Motion Paths (default False)"""

    show_keyframe_action_all: bool
    """ For bone motion paths, search whole Action for keyframes instead of in group with matching name only (is slower) (default False)"""

    show_keyframe_highlight: bool
    """ Emphasize position of keyframes on Motion Paths (default False)"""

    show_keyframe_numbers: bool
    """ Show frame numbers of Keyframes on Motion Paths (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.MotionpathDisplayTypeItems]
    """ Type of range to show for Motion Paths (default 'RANGE')"""

    use_camera_space_bake: bool
    """ Motion path points will be baked into the camera space of the active camera. This means they will only look right when looking through that camera. Switching cameras using markers is not supported. (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Annotation(ID, bpy_struct):
    """Freehand annotation sketchbook"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    layers: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationFrame(bpy_struct):
    """Collection of related sketches on a particular frame"""

    frame_number: int
    """ The frame on which this sketch appears (in [-1048574, 1048574], default 0)"""

    select: bool
    """ Frame is selected for editing in the Dope Sheet (default False)"""

    strokes: typing.Any
    """ Freehand curves defining the sketch on this frame (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationLayer(bpy_struct):
    """Collection of related sketches"""

    active_frame: AnnotationFrame | None
    """ Frame currently being displayed for this layer (readonly)"""

    annotation_hide: bool
    """ Set annotation Visibility (default False)"""

    annotation_onion_after_color: mathutils.Color
    """ Base color for ghosts after the active frame (array of 3 items, in [0, 1], default (0.25, 0.1, 1.0))"""

    annotation_onion_after_range: int
    """ Maximum number of frames to show after current frame (in [-1, 120], default 0)"""

    annotation_onion_before_color: mathutils.Color
    """ Base color for ghosts before the active frame (array of 3 items, in [0, 1], default (0.302, 0.851, 0.302))"""

    annotation_onion_before_range: int
    """ Maximum number of frames to show before current frame (in [-1, 120], default 0)"""

    annotation_onion_use_custom_color: bool
    """ Use custom colors for onion skinning instead of the theme (default False)"""

    annotation_opacity: float
    """ Annotation Layer Opacity (in [0, 1], default 0.0)"""

    color: mathutils.Color
    """ Color for all strokes in this layer (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    frames: typing.Any
    """ Sketches for this layer on different frames (default None, readonly)"""

    info: str
    """ Layer name (default "", never None)"""

    is_ruler: bool
    """ This is a special ruler layer (default False, readonly)"""

    lock: bool
    """ Protect layer from further editing and/or frame changes (default False)"""

    lock_frame: bool
    """ Lock current frame displayed by layer (default False)"""

    select: bool
    """ Layer is selected for editing in the Dope Sheet (default False)"""

    show_in_front: bool
    """ Make the layer display in front of objects (default True)"""

    thickness: int
    """ Thickness of annotation strokes (in [1, 10], default 0)"""

    use_annotation_onion_skinning: bool
    """ Display annotation onion skins before and after the current frame (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationStroke(bpy_struct):
    """Freehand curve defining part of a sketch"""

    display_mode: typing.Literal["3DSPACE", "2DSPACE", "2DIMAGE"]
    """ Coordinate space that stroke is in (default '3DSPACE')"""

    points: typing.Any
    """ Stroke data points (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnnotationStrokePoint(bpy_struct):
    """Data point for freehand stroke curve"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AnyType(bpy_struct):
    """RNA type used for pointers to any possible data"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Area(bpy_struct):
    """Area in a subdivided screen, containing an editor"""

    height: int
    """ Area height (in [0, 32767], default 0, readonly)"""

    regions: typing.Any
    """ Regions this area is subdivided in (default None, readonly)"""

    show_menus: bool
    """ Show menus in the header (default True)"""

    spaces: typing.Any
    """ Spaces contained in this area, the first being the active space (NOTE: Useful for example to restore a previously used 3D view space in a certain area to get the old view orientation) (default None, readonly)"""

    type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ Current editor type for this area (default 'VIEW_3D')"""

    ui_type: str
    """ Current editor type for this area"""

    width: int
    """ Area width (in [0, 32767], default 0, readonly)"""

    x: int
    """ The window relative vertical location of the area (in [-inf, inf], default 0, readonly)"""

    y: int
    """ The window relative horizontal location of the area (in [-inf, inf], default 0, readonly)"""

    def tag_redraw(self) -> None:
        """tag_redraw"""

    def header_text_set(self, text: str | None) -> None:
        """Set the header status text

        :param text: Text, New string for the header, None clears the text
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AreaLight(Light, ID, bpy_struct):
    """Directional area Light"""

    energy: float
    """ Light energy emitted over the entire area of the light in all directions, in units of radiant power (W) (in [-inf, inf], default 10.0)"""

    shadow_buffer_clip_start: float
    """ Shadow map clip start, below which objects will not generate shadows (in [1e-06, inf], default 0.05)"""

    shadow_filter_radius: float
    """ Blur shadow aliasing using Percentage Closer Filtering (in [0, inf], default 1.0)"""

    shadow_jitter_overblur: float
    """ Apply shadow tracing to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 10.0)"""

    shadow_maximum_resolution: float
    """ Minimum size of a shadow map pixel. Higher values use less memory at the cost of shadow quality. (in [0, inf], default 0.001)"""

    shadow_soft_size: float
    """ Light size for ray shadow sampling (Raytraced shadows) (in [0, inf], default 0.0)"""

    shape: typing.Literal["SQUARE", "RECTANGLE", "DISK", "ELLIPSE"]
    """ Shape of the area Light (default 'SQUARE')"""

    size: float
    """ Size of the area of the area light, X direction size for rectangle shapes (in [0, inf], default 0.25)"""

    size_y: float
    """ Size of the area of the area light in the Y direction for rectangle shapes (in [0, inf], default 0.25)"""

    spread: float
    """ How widely the emitted light fans out, as in the case of a gridded softbox (in [0, 3.14159], default 3.14159)"""

    use_absolute_resolution: bool
    """ Limit the resolution at 1 unit from the light origin instead of relative to the shadowed pixel (default False)"""

    use_shadow_jitter: bool
    """ Enable jittered soft shadows to increase shadow precision (disabled in viewport unless enabled in the render settings). Has a high performance impact. (default False)"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this light. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Armature(ID, bpy_struct):
    """Armature data-block containing a hierarchy of bones, usually used for rigging characters"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    axes_position: float
    """ The position for the axes on the bone. Increasing the value moves it closer to the tip; decreasing moves it closer to the root. (in [0, 1], default 0.0)"""

    bones: typing.Any
    """ (default None, readonly)"""

    collections: typing.Any
    """ (default None)"""

    collections_all: typing.Any
    """ List of all bone collections of the armature (default None, readonly)"""

    display_type: typing.Literal["OCTAHEDRAL", "STICK", "BBONE", "ENVELOPE", "WIRE"]
    """ (default 'OCTAHEDRAL')"""

    edit_bones: typing.Any
    """ (default None, readonly)"""

    is_editmode: bool
    """ True when used in editmode (default False, readonly)"""

    pose_position: typing.Literal["POSE", "REST"]
    """ Show armature in binding pose or final posed state (default 'POSE')"""

    relation_line_position: typing.Literal["TAIL", "HEAD"]
    """ The start position of the relation lines from parent to child bones (default 'TAIL')"""

    show_axes: bool
    """ Display bone axes (default False)"""

    show_bone_colors: bool
    """ Display bone colors (default True)"""

    show_bone_custom_shapes: bool
    """ Display bones with their custom shapes (default True)"""

    show_names: bool
    """ Display bone names (default False)"""

    use_mirror_x: bool
    """ Apply changes to matching bone on opposite side of X-Axis (default False)"""

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
    ) -> None:
        """Transform armature bones by a matrix

        :param matrix: Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArmatureConstraint(Constraint, bpy_struct):
    """Applies transformations done by the Armature modifier"""

    targets: typing.Any
    """ Target Bones (default None, readonly)"""

    use_bone_envelopes: bool
    """ Multiply weights by envelope for all bones, instead of acting like Vertex Group based blending. The specified weights are still used, and only the listed bones are considered. (default False)"""

    use_current_location: bool
    """ Use the current bone location for envelopes and choosing B-Bone segments instead of rest position (default False)"""

    use_deform_preserve_volume: bool
    """ Deform rotation interpolation with quaternions (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArmatureModifier(Modifier, bpy_struct):
    """Armature deformation modifier"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object: Object | None
    """ Armature object to deform with"""

    use_bone_envelopes: bool
    """ Bind Bone envelopes to armature modifier (default False)"""

    use_deform_preserve_volume: bool
    """ Deform rotation interpolation with quaternions (default False)"""

    use_multi_modifier: bool
    """ Use same input as previous modifier, and mix results using overall vgroup (default False)"""

    use_vertex_groups: bool
    """ Bind vertex groups to armature modifier (default True)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ArrayModifier(Modifier, bpy_struct):
    """Array duplication modifier"""

    constant_offset_displace: mathutils.Vector
    """ Value for the distance between arrayed items (array of 3 items, in [-inf, inf], default (1.0, 0.0, 0.0))"""

    count: int
    """ Number of duplicates to make (in [1, inf], default 2)"""

    curve: Object | None
    """ Curve object to fit array length to"""

    end_cap: Object | None
    """ Mesh object to use as an end cap"""

    fit_length: float
    """ Length to fit array within (in [0, inf], default 0.0)"""

    fit_type: typing.Literal["FIXED_COUNT", "FIT_LENGTH", "FIT_CURVE"]
    """ Array length calculation method (default 'FIXED_COUNT')"""

    merge_threshold: float
    """ Limit below which to merge vertices (in [0, inf], default 0.01)"""

    offset_object: Object | None
    """ Use the location and rotation of another object to determine the distance and rotational change between arrayed items"""

    offset_u: float
    """ Amount to offset array UVs on the U axis (in [-1, 1], default 0.0)"""

    offset_v: float
    """ Amount to offset array UVs on the V axis (in [-1, 1], default 0.0)"""

    relative_offset_displace: mathutils.Vector
    """ The size of the geometry will determine the distance between arrayed items (array of 3 items, in [-inf, inf], default (1.0, 0.0, 0.0))"""

    start_cap: Object | None
    """ Mesh object to use as a start cap"""

    use_constant_offset: bool
    """ Add a constant offset (default False)"""

    use_merge_vertices: bool
    """ Merge vertices in adjacent duplicates (default False)"""

    use_merge_vertices_cap: bool
    """ Merge vertices in first and last duplicates (default False)"""

    use_object_offset: bool
    """ Add another object's transformation to the total offset (default False)"""

    use_relative_offset: bool
    """ Add an offset relative to the object's bounding box (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetLibraryReference(bpy_struct):
    """Identifier to refer to the asset library"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetMetaData(bpy_struct):
    """Additional data stored for an asset data-block"""

    active_tag: int | None
    """ Index of the tag set for editing (in [-32768, 32767], default 0)"""

    author: str
    """ Name of the creator of the asset (default "", never None)"""

    catalog_id: str
    """ Identifier for the asset's catalog, used by Blender to look up the asset's catalog path. Must be a UUID according to RFC4122. (default "", never None)"""

    catalog_simple_name: str
    """ Simple name of the asset's catalog, for debugging and data recovery purposes (default "", readonly, never None)"""

    copyright: str
    """ Copyright notice for this asset. An empty copyright notice does not necessarily indicate that this is copyright-free. Contact the author if any clarification is needed. (default "", never None)"""

    description: str
    """ A description of the asset to be displayed for the user (default "", never None)"""

    license: str
    """ The type of license this asset is distributed under. An empty license name does not necessarily indicate that this is free of licensing terms. Contact the author if any clarification is needed. (default "", never None)"""

    tags: typing.Any
    """ Custom tags (name tokens) for the asset, used for filtering and general asset management (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetRepresentation(bpy_struct):
    """Information about an entity that makes it possible for the asset system to deal with the entity as asset"""

    full_library_path: str
    """ Absolute path to the .blend file containing this asset (default "", readonly, never None)"""

    full_path: str
    """ Absolute path to the .blend file containing this asset extended with the path of the asset inside the file (default "", readonly, never None)"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ The type of the data-block, if the asset represents one ('NONE' otherwise) (default 'ACTION', readonly)"""

    is_online: bool
    """ True if this asset is accessed via internet, not stored on disk (default False, readonly)"""

    local_id: ID | None
    """ The local data-block this asset represents; only valid if that is a data-block in this file (readonly)"""

    metadata: AssetMetaData | None
    """ Additional information about the asset (readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetShelf(bpy_struct):
    """Regions for quick access to assets"""

    asset_library_reference: typing.Literal["ALL", "LOCAL", "ESSENTIALS", "CUSTOM"]
    """ Choose the asset library to display assets from (default 'ALL')"""

    bl_activate_operator: str
    """ Operator to call when activating an item with asset reference properties (default "", never None)"""

    bl_default_preview_size: int
    """ Default size of the asset preview thumbnails in pixels (in [32, 256], default 0)"""

    bl_drag_operator: str
    """ Operator to call when dragging an item with asset reference properties (default "", never None)"""

    bl_idname: str
    """ If this is set, the asset gets a custom ID, otherwise it takes the name of the class used to define the asset (for example, if the class name is "OBJECT_AST_hello", and bl_idname is not set by the script, then bl_idname = "OBJECT_AST_hello") (default "", never None)"""

    bl_options: set[
        typing.Literal[
            "NO_ASSET_DRAG",
            "DEFAULT_VISIBLE",
            "STORE_ENABLED_CATALOGS_IN_PREFERENCES",
            "ACTIVATE_FOR_CONTEXT_MENU",
        ]
    ]
    """ Options for this asset shelf type (default set())"""

    bl_space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ The space where the asset shelf will show up in. Ignored for popup asset shelves which can be displayed in any space. (default 'EMPTY')"""

    filter_action: bool
    """ Show Action data-blocks (default False)"""

    filter_annotations: bool
    """ Show Annotation data-blocks (default False)"""

    filter_armature: bool
    """ Show Armature data-blocks (default False)"""

    filter_brush: bool
    """ Show Brushes data-blocks (default False)"""

    filter_cachefile: bool
    """ Show Cache File data-blocks (default False)"""

    filter_camera: bool
    """ Show Camera data-blocks (default False)"""

    filter_curve: bool
    """ Show Curve data-blocks (default False)"""

    filter_curves: bool
    """ Show/hide Curves data-blocks (default False)"""

    filter_font: bool
    """ Show Font data-blocks (default False)"""

    filter_grease_pencil: bool
    """ Show Grease Pencil data-blocks (default False)"""

    filter_group: bool
    """ Show Collection data-blocks (default False)"""

    filter_image: bool
    """ Show Image data-blocks (default False)"""

    filter_lattice: bool
    """ Show Lattice data-blocks (default False)"""

    filter_light: bool
    """ Show Light data-blocks (default False)"""

    filter_light_probe: bool
    """ Show Light Probe data-blocks (default False)"""

    filter_linestyle: bool
    """ Show Freestyle's Line Style data-blocks (default False)"""

    filter_mask: bool
    """ Show Mask data-blocks (default False)"""

    filter_material: bool
    """ Show Material data-blocks (default False)"""

    filter_mesh: bool
    """ Show Mesh data-blocks (default False)"""

    filter_metaball: bool
    """ Show Metaball data-blocks (default False)"""

    filter_movie_clip: bool
    """ Show Movie Clip data-blocks (default False)"""

    filter_node_tree: bool
    """ Show Node Tree data-blocks (default False)"""

    filter_object: bool
    """ Show Object data-blocks (default False)"""

    filter_paint_curve: bool
    """ Show Paint Curve data-blocks (default False)"""

    filter_palette: bool
    """ Show Palette data-blocks (default False)"""

    filter_particle_settings: bool
    """ Show Particle Settings data-blocks (default False)"""

    filter_pointcloud: bool
    """ Show/hide Point Cloud data-blocks (default False)"""

    filter_scene: bool
    """ Show Scene data-blocks (default False)"""

    filter_sound: bool
    """ Show Sound data-blocks (default False)"""

    filter_speaker: bool
    """ Show Speaker data-blocks (default False)"""

    filter_text: bool
    """ Show Text data-blocks (default False)"""

    filter_texture: bool
    """ Show Texture data-blocks (default False)"""

    filter_volume: bool
    """ Show/hide Volume data-blocks (default False)"""

    filter_work_space: bool
    """ Show workspace data-blocks (default False)"""

    filter_world: bool
    """ Show World data-blocks (default False)"""

    preview_size: int
    """ Size of the asset preview thumbnails in pixels (in [24, 256], default 0)"""

    search_filter: str
    """ Filter assets by name (default "", never None)"""

    show_names: bool
    """ Show the asset name together with the preview. Otherwise only the preview will be visible. (default False)"""

    @classmethod
    def poll(cls, context: Context) -> bool:
        """If this method returns a non-null output, the asset shelf will be visible

        :param context:
        :return:
        """

    @classmethod
    def asset_poll(cls, asset: AssetRepresentation | None) -> bool:
        """Determine if an asset should be visible in the asset shelf. If this method returns a non-null output, the asset will be visible.

        :param asset:
        :return:
        """

    @classmethod
    def get_active_asset(cls) -> AssetWeakReference:
        """Return a reference to the asset that should be highlighted as active in the asset shelf

        :return: The weak reference to the asset to be highlighted as active, or None
        """

    @classmethod
    def draw_context_menu(
        cls,
        context: Context,
        asset: AssetRepresentation | None,
        layout: UILayout | None,
    ) -> None:
        """Draw UI elements into the context menu UI layout displayed on right click

        :param context:
        :param asset:
        :param layout:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetTag(bpy_struct):
    """User defined tag (name token)"""

    name: str
    """ The identifier that makes up this tag (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class AssetWeakReference(bpy_struct):
    """Weak reference to some asset"""

    asset_library_identifier: str
    """ (default "", readonly, never None)"""

    asset_library_type: typing.Literal["ALL", "LOCAL", "ESSENTIALS", "CUSTOM"]
    """ (default 'ALL', readonly)"""

    relative_asset_identifier: str
    """ (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Attribute(bpy_struct):
    """Geometry attribute"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ Type of data stored in attribute (default 'FLOAT', readonly)"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Domain of the Attribute (default 'POINT', readonly)"""

    is_internal: bool
    """ The attribute is meant for internal use by Blender (default False, readonly)"""

    is_required: bool
    """ Whether the attribute can be removed or renamed (default False, readonly)"""

    name: str
    """ Name of the Attribute (default "", never None)"""

    storage_type: Literal[bpy.stub_internal.rna_enums.AttrStorageTypeItems]
    """ Method used to store the data (default 'ARRAY', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BakeSettings(bpy_struct):
    """Bake data for a Scene data-block"""

    cage_extrusion: float
    """ Inflate the active object by the specified distance for baking. This helps matching to points nearer to the outside of the selected object meshes. (in [0, inf], default 0.0)"""

    cage_object: Object | None
    """ Object to use as cage instead of calculating the cage from the active object with cage extrusion"""

    displacement_space: typing.Literal["OBJECT", "TANGENT"]
    """ Choose displacement space for baking (default 'OBJECT')"""

    filepath: str
    """ Image filepath to use when saving externally (default "", never None, blend relative // prefix supported)"""

    height: int
    """ Vertical dimension of the baking map (in [4, 10000], default 512)"""

    image_settings: ImageFormatSettings | None
    """ (readonly, never None)"""

    margin: int
    """ Extends the baked result as a post process filter (in [0, 32767], default 16)"""

    margin_type: Literal[bpy.stub_internal.rna_enums.BakeMarginTypeItems]
    """ Algorithm to extend the baked result (default 'ADJACENT_FACES')"""

    max_ray_distance: float
    """ The maximum ray distance for matching points between the active and selected objects. If zero, there is no limit. (in [0, inf], default 0.0)"""

    normal_b: Literal[bpy.stub_internal.rna_enums.NormalSwizzleItems]
    """ Axis to bake in blue channel (default 'POS_X')"""

    normal_g: Literal[bpy.stub_internal.rna_enums.NormalSwizzleItems]
    """ Axis to bake in green channel (default 'POS_X')"""

    normal_r: Literal[bpy.stub_internal.rna_enums.NormalSwizzleItems]
    """ Axis to bake in red channel (default 'POS_X')"""

    normal_space: Literal[bpy.stub_internal.rna_enums.NormalSpaceItems]
    """ Choose normal space for baking (default 'TANGENT')"""

    pass_filter: set[Literal[bpy.stub_internal.rna_enums.BakePassFilterTypeItems]]
    """ Passes to include in the active baking pass (default {'COLOR', 'DIFFUSE', 'DIRECT', 'EMIT', 'GLOSSY', 'INDIRECT', 'TRANSMISSION'}, readonly)"""

    save_mode: Literal[bpy.stub_internal.rna_enums.BakeSaveModeItems]
    """ Where to save baked image textures (default 'INTERNAL')"""

    target: Literal[bpy.stub_internal.rna_enums.BakeTargetItems]
    """ Where to output the baked map (default 'IMAGE_TEXTURES')"""

    type: typing.Literal["NORMALS", "DISPLACEMENT", "VECTOR_DISPLACEMENT"]
    """ Choose shading information to bake into the image (default 'NORMALS')"""

    use_automatic_name: bool
    """ Automatically name the output file with the pass type (external only) (default False)"""

    use_cage: bool
    """ Cast rays to active object from a cage (default False)"""

    use_clear: bool
    """ Clear Images before baking (internal only) (default True)"""

    use_lores_mesh: bool
    """ Calculate heights against unsubdivided low resolution mesh (default False)"""

    use_multires: bool
    """ Bake directly from multires object (default False)"""

    use_pass_color: bool
    """ Color the pass (default True)"""

    use_pass_diffuse: bool
    """ Add diffuse contribution (default True)"""

    use_pass_direct: bool
    """ Add direct lighting contribution (default True)"""

    use_pass_emit: bool
    """ Add emission contribution (default True)"""

    use_pass_glossy: bool
    """ Add glossy contribution (default True)"""

    use_pass_indirect: bool
    """ Add indirect lighting contribution (default True)"""

    use_pass_transmission: bool
    """ Add transmission contribution (default True)"""

    use_selected_to_active: bool
    """ Bake shading on the surface of selected objects to the active object (default False)"""

    use_split_materials: bool
    """ Split external images per material (external only) (default False)"""

    view_from: typing.Literal["ABOVE_SURFACE", "ACTIVE_CAMERA"]
    """ Source of reflection ray directions (default 'ABOVE_SURFACE')"""

    width: int
    """ Horizontal dimension of the baking map (in [4, 10000], default 512)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BevelModifier(Modifier, bpy_struct):
    """Bevel modifier to make edges and vertices more rounded"""

    affect: typing.Literal["VERTICES", "EDGES"]
    """ Affect edges or vertices (default 'EDGES')"""

    angle_limit: float
    """ Angle above which to bevel edges (in [0, 3.14159], default 0.523599)"""

    custom_profile: CurveProfile | None
    """ The path for the custom profile (readonly)"""

    edge_weight: str
    """ Attribute name for edge weight (default "", never None)"""

    face_strength_mode: typing.Literal[
        "FSTR_NONE", "FSTR_NEW", "FSTR_AFFECTED", "FSTR_ALL"
    ]
    """ Whether to set face strength, and which faces to set it on (default 'FSTR_NONE')"""

    harden_normals: bool
    """ Match normals of new faces to adjacent faces (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    limit_method: typing.Literal["NONE", "ANGLE", "WEIGHT", "VGROUP"]
    """ (default 'ANGLE')"""

    loop_slide: bool
    """ Prefer sliding along edges to having even widths (default True)"""

    mark_seam: bool
    """ Mark Seams along beveled edges (default False)"""

    mark_sharp: bool
    """ Mark beveled edges as sharp (default False)"""

    material: int
    """ Material index of generated faces, -1 for automatic (in [-1, 32767], default -1)"""

    miter_inner: typing.Literal["MITER_SHARP", "MITER_ARC"]
    """ Pattern to use for inside of miters (default 'MITER_SHARP')"""

    miter_outer: typing.Literal["MITER_SHARP", "MITER_PATCH", "MITER_ARC"]
    """ Pattern to use for outside of miters (default 'MITER_SHARP')"""

    offset_type: typing.Literal["OFFSET", "WIDTH", "DEPTH", "PERCENT", "ABSOLUTE"]
    """ What distance Width measures (default 'OFFSET')"""

    profile: float
    """ The profile shape (0.5 = round) (in [0, 1], default 0.5)"""

    profile_type: typing.Literal["SUPERELLIPSE", "CUSTOM"]
    """ The type of shape used to rebuild a beveled section (default 'SUPERELLIPSE')"""

    segments: int
    """ Number of segments for round edges/verts (in [1, 1000], default 1)"""

    spread: float
    """ Spread distance for inner miter arcs (in [0, inf], default 0.1)"""

    use_clamp_overlap: bool
    """ Clamp the width to avoid overlap (default True)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    vertex_weight: str
    """ Attribute name for vertex weight (default "", never None)"""

    vmesh_method: typing.Literal["ADJ", "CUTOFF"]
    """ The method to use to create the mesh at intersections (default 'ADJ')"""

    width: float
    """ Bevel amount (in [0, inf], default 0.1)"""

    width_pct: float
    """ Bevel amount for percentage method (in [0, inf], default 0.1)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BezierSplinePoint(bpy_struct):
    """Bézier curve point with two handles"""

    co: mathutils.Vector
    """ Coordinates of the control point (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    handle_left: mathutils.Vector
    """ Coordinates of the first handle (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    handle_left_type: typing.Literal["FREE", "VECTOR", "ALIGNED", "AUTO"]
    """ Handle types (default 'FREE')"""

    handle_right: mathutils.Vector
    """ Coordinates of the second handle (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    handle_right_type: typing.Literal["FREE", "VECTOR", "ALIGNED", "AUTO"]
    """ Handle types (default 'FREE')"""

    hide: bool
    """ Visibility status (default False)"""

    radius: float
    """ Radius for beveling (in [0, inf], default 0.0)"""

    select_control_point: bool
    """ Control point selection status (default False)"""

    select_left_handle: bool
    """ Handle 1 selection status (default False)"""

    select_right_handle: bool
    """ Handle 2 selection status (default False)"""

    tilt: float
    """ Tilt in 3D View (in [-376.991, 376.991], default 0.0)"""

    weight_softbody: float
    """ Softbody goal weight (in [0.01, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendData(bpy_struct):
    """Main data structure representing a .blend file and all its data-blocks"""

    actions: typing.Any
    """ Action data-blocks (default None, readonly)"""

    annotations: typing.Any
    """ Annotation data-blocks (legacy Grease Pencil) (default None, readonly)"""

    armatures: typing.Any
    """ Armature data-blocks (default None, readonly)"""

    brushes: typing.Any
    """ Brush data-blocks (default None, readonly)"""

    cache_files: typing.Any
    """ Cache Files data-blocks (default None, readonly)"""

    cameras: typing.Any
    """ Camera data-blocks (default None, readonly)"""

    collections: typing.Any
    """ Collection data-blocks (default None, readonly)"""

    colorspace: BlendFileColorspace | None
    """ Information about the color space used for data-blocks in a blend file (readonly, never None)"""

    curves: typing.Any
    """ Curve data-blocks (default None, readonly)"""

    filepath: str
    """ Path to the .blend file (default "", readonly, never None)"""

    fonts: typing.Any
    """ Vector font data-blocks (default None, readonly)"""

    grease_pencils: typing.Any
    """ Grease Pencil data-blocks (default None, readonly)"""

    hair_curves: typing.Any
    """ Hair curve data-blocks (default None, readonly)"""

    images: typing.Any
    """ Image data-blocks (default None, readonly)"""

    is_dirty: bool
    """ Have recent edits been saved to disk (default False, readonly)"""

    is_saved: bool
    """ Has the current session been saved to disk as a .blend file (default False, readonly)"""

    lattices: typing.Any
    """ Lattice data-blocks (default None, readonly)"""

    libraries: typing.Any
    """ Library data-blocks (default None, readonly)"""

    lightprobes: typing.Any
    """ Light Probe data-blocks (default None, readonly)"""

    lights: typing.Any
    """ Light data-blocks (default None, readonly)"""

    linestyles: typing.Any
    """ Line Style data-blocks (default None, readonly)"""

    masks: typing.Any
    """ Masks data-blocks (default None, readonly)"""

    materials: typing.Any
    """ Material data-blocks (default None, readonly)"""

    meshes: typing.Any
    """ Mesh data-blocks (default None, readonly)"""

    metaballs: typing.Any
    """ Metaball data-blocks (default None, readonly)"""

    movieclips: typing.Any
    """ Movie Clip data-blocks (default None, readonly)"""

    node_groups: typing.Any
    """ Node group data-blocks (default None, readonly)"""

    objects: typing.Any
    """ Object data-blocks (default None, readonly)"""

    paint_curves: typing.Any
    """ Paint Curves data-blocks (default None, readonly)"""

    palettes: typing.Any
    """ Palette data-blocks (default None, readonly)"""

    particles: typing.Any
    """ Particle data-blocks (default None, readonly)"""

    pointclouds: typing.Any
    """ Point cloud data-blocks (default None, readonly)"""

    scenes: typing.Any
    """ Scene data-blocks (default None, readonly)"""

    screens: typing.Any
    """ Screen data-blocks (default None, readonly)"""

    shape_keys: typing.Any
    """ Shape Key data-blocks (default None, readonly)"""

    sounds: typing.Any
    """ Sound data-blocks (default None, readonly)"""

    speakers: typing.Any
    """ Speaker data-blocks (default None, readonly)"""

    texts: typing.Any
    """ Text data-blocks (default None, readonly)"""

    textures: typing.Any
    """ Texture data-blocks (default None, readonly)"""

    use_autopack: bool
    """ Automatically pack all external data into .blend file (default False)"""

    version: typing.Any
    """ File format version the .blend file was saved with (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    volumes: typing.Any
    """ Volume data-blocks (default None, readonly)"""

    window_managers: typing.Any
    """ Window manager data-blocks (default None, readonly)"""

    workspaces: typing.Any
    """ Workspace data-blocks (default None, readonly)"""

    worlds: typing.Any
    """ World data-blocks (default None, readonly)"""

    def pack_linked_ids_hierarchy(self, root_id: ID | None) -> ID:
        """Pack the given linked ID and its dependencies into current blendfile

        :param root_id: Root linked ID to pack
        :return: The packed ID matching the given root ID
        """

    def batch_remove(self, ids: collections.abc.Sequence[ID] | None) -> None:
        """Remove (delete) several IDs at once.Note that this function is quicker than individual calls to `remove()` (from `bpy.types.BlendData`
        ID collections), but less safe/versatile (it can break Blender, e.g. by removing all scenes...).

                :param ids: Sequence of IDs (types can be mixed).
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def file_path_foreach(
        self,
        visit_path_fn: collections.abc.Callable[[ID, str, typing.Any], str | None]
        | None,
        *,
        subset: None | set[str] | None = None,
        visit_types: None | set[str] | None = None,
        flags: set[str] | None = {"SKIP_PACKED", "SKIP_WEAK_REFERENCES"},
    ) -> None:
        """Call visit_path_fn for the file paths used by all ID data-blocks in current bpy.data.For list of valid set members for visit_types, see: `bpy.types.KeyingSetPath.id_type`.

        :param visit_path_fn: function that takes three parameters: the data-block, a file path, and a placeholder for future use. The function should return either None or a str. In the latter case, the visited file path will be replaced with the returned string.
        :param subset: When given, only these data-blocks and their used file paths will be visited.
        :param visit_types: When given, only visit data-blocks of these types. Ignored if subset is also given.
        :param flags: Set of flags that influence which data-blocks are visited. See `rna_enum_file_path_foreach_flag_items`.
        """

    def file_path_map(
        self,
        *,
        subset: None | collections.abc.Sequence[ID] | None = None,
        key_types: None | set[str] | None = None,
        include_libraries: bool | None = False,
    ) -> dict[ID, set[str]]:
        """Returns a mapping of all ID data-blocks in current bpy.data to a set of all file paths used by them.For list of valid set members for key_types, see: `bpy.types.KeyingSetPath.id_type`.

        :param subset: When given, only these data-blocks and their used file paths will be included as keys/values in the map.
        :param key_types: When given, filter the keys mapped by ID types. Ignored if subset is also given.
        :param include_libraries: Include library file paths of linked data. False by default.
        :return: dictionary of `bpy.types.ID` instances, with sets of file path strings as their values.
        """

    def orphans_purge(self) -> int:
        """Remove (delete) all IDs with no user.

        :return: The number of deleted IDs.
        """

    @staticmethod
    def temp_data(
        *, filepath: None | bytes | str | None = None
    ) -> typing_extensions.Self:
        """A context manager that temporarily creates blender file data.

        :param filepath: The file path for the newly temporary data. When None, the path of the currently open file is used.
        :return: Blend file data which is freed once the context exits.
        """

    def user_map(
        self,
        *,
        subset: None | collections.abc.Sequence[ID] | None = None,
        key_types: None | set[str] | None = None,
        value_types: None | set[str] | None = None,
    ) -> dict[ID, set[ID]]:
        """Returns a mapping of all ID data-blocks in current bpy.data to a set of all data-blocks using them.For list of valid set members for key_types & value_types, see: `bpy.types.KeyingSetPath.id_type`.

        :param subset: When passed, only these data-blocks and their users will be included as keys/values in the map.
        :param key_types: Filter the keys mapped by ID types.
        :param value_types: Filter the values in the set by ID types.
        :return: dictionary that maps data-blocks IDs to their users.
        """

class BlendFileColorspace(bpy_struct):
    """Information about the color space used for data-blocks in a blend file"""

    is_missing_opencolorio_config: bool
    """ A color space, view or display was not found, which likely means the OpenColorIO config used to create this blend file is missing (default False, readonly)"""

    working_space: typing.Literal["Linear Rec.709", "Linear Rec.2020", "ACEScg"]
    """ Color space used for all scene linear colors in this file, and for compositing, shader and geometry nodes processing (readonly)"""

    working_space_interop_id: str
    """ Unique identifier for common color spaces, as defined by the Color Interop Forum. May be empty if there is no interop ID for the working space. Common values are lin_rec709_scene, lin_rec2020_scene and lin_ap1_scene (for ACEScg) (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendImportContext(bpy_struct):
    """Contextual data for a blendfile library/linked-data related operation. Currently only exposed as read-only data for the pre/post blendimport handlers"""

    import_items: typing.Any
    """ (default None, readonly)"""

    options: set[
        typing.Literal[
            "LINK",
            "MAKE_PATHS_RELATIVE",
            "USE_PLACEHOLDERS",
            "FORCE_INDIRECT",
            "APPEND_SET_FAKEUSER",
            "APPEND_RECURSIVE",
            "APPEND_LOCAL_ID_REUSE",
            "APPEND_ASSET_DATA_CLEAR",
            "SELECT_OBJECTS",
            "USE_ACTIVE_COLLECTION",
            "OBDATA_INSTANCE",
            "COLLECTION_INSTANCE",
        ]
    ]
    """ Options for this blendfile import operation (default set(), readonly)"""

    process_stage: typing.Literal["INIT", "DONE"]
    """ Current stage of the import process (default 'INIT', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendImportContextItem(bpy_struct):
    """An item (representing a data-block) in a BlendImportContext data. Currently only exposed as read-only data for the pre/post linking handlers"""

    append_action: typing.Literal[
        "UNSET", "KEEP_LINKED", "REUSE_LOCAL", "MAKE_LOCAL", "COPY_LOCAL"
    ]
    """ How this item has been handled by the append operation. Only set if the data has been appended (default 'UNSET', readonly)"""

    id: ID | None
    """ The imported ID. None until it has been linked or appended. May be the same as reusable_local_id when appended (readonly)"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ ID type of the item (default 'ACTION', readonly)"""

    import_info: set[
        typing.Literal[
            "INDIRECT_USAGE", "LIBOVERRIDE_DEPENDENCY", "LIBOVERRIDE_DEPENDENCY_ONLY"
        ]
    ]
    """ Various status info about an item after it has been imported (default set(), readonly)"""

    library_override_id: ID | None
    """ The library override of the linked ID. None until it has been created (readonly)"""

    name: str
    """ ID name of the item (default "", readonly, never None)"""

    reusable_local_id: ID | None
    """ The already existing local ID that may be reused in append & reuse case. None until it has been found (readonly)"""

    source_libraries: typing.Any
    """ List of libraries to search and import that ID from. The ID will be imported from the first file in that list that contains it (default None, readonly)"""

    source_library: Library | None
    """ Library ID representing the blendfile from which the ID was imported. None until the ID has been linked or appended (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendImportContextLibrary(bpy_struct):
    """Library (blendfile) reference in a BlendImportContext data. Currently only exposed as read-only data for the pre/post blendimport handlers"""

    filepath: str
    """ (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlendTexture(Texture, ID, bpy_struct):
    """Procedural color blending texture"""

    progression: typing.Literal[
        "LINEAR",
        "QUADRATIC",
        "EASING",
        "DIAGONAL",
        "SPHERICAL",
        "QUADRATIC_SPHERE",
        "RADIAL",
    ]
    """ Style of the color blending (default 'LINEAR')"""

    use_flip_axis: typing.Literal["HORIZONTAL", "VERTICAL"]
    """ Flip the texture's X and Y axis (default 'HORIZONTAL')"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BlenderRNA(bpy_struct):
    """Blender RNA structure definitions"""

    structs: typing.Any
    """ (default None, readonly)"""

    properties: bpy_prop_collection[Property]

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRule(bpy_struct):
    name: str
    """ Boid rule name (default "", never None)"""

    type: Literal[bpy.stub_internal.rna_enums.BoidruleTypeItems]
    """ (default 'GOAL', readonly)"""

    use_in_air: bool
    """ Use rule when boid is flying (default False)"""

    use_on_land: bool
    """ Use rule when boid is on land (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleAverageSpeed(BoidRule, bpy_struct):
    level: float
    """ How much velocity's z-component is kept constant (in [0, 1], default 0.0)"""

    speed: float
    """ Percentage of maximum speed (in [0, 1], default 0.0)"""

    wander: float
    """ How fast velocity's direction is randomized (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleAvoid(BoidRule, bpy_struct):
    fear_factor: float
    """ Avoid object if danger from it is above this threshold (in [0, 100], default 0.0)"""

    object: Object | None
    """ Object to avoid"""

    use_predict: bool
    """ Predict target movement (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleAvoidCollision(BoidRule, bpy_struct):
    look_ahead: float
    """ Time to look ahead in seconds (in [0, 100], default 0.0)"""

    use_avoid: bool
    """ Avoid collision with other boids (default False)"""

    use_avoid_collision: bool
    """ Avoid collision with deflector objects (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleFight(BoidRule, bpy_struct):
    distance: float
    """ Attack boids at max this distance (in [0, 100], default 0.0)"""

    flee_distance: float
    """ Flee to this distance (in [0, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleFollowLeader(BoidRule, bpy_struct):
    distance: float
    """ Distance behind leader to follow (in [0, 100], default 0.0)"""

    object: Object | None
    """ Follow this object instead of a boid"""

    queue_count: int
    """ How many boids in a line (in [0, 100], default 0)"""

    use_line: bool
    """ Follow leader in a line (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidRuleGoal(BoidRule, bpy_struct):
    object: Object | None
    """ Goal object"""

    use_predict: bool
    """ Predict target movement (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidSettings(bpy_struct):
    """Settings for boid physics"""

    accuracy: float
    """ Accuracy of attack (in [0, 1], default 0.0)"""

    active_boid_state: BoidRule | None
    """ (readonly)"""

    active_boid_state_index: int | None
    """ (in [0, inf], default 0)"""

    aggression: float
    """ Boid will fight this times stronger enemy (in [0, 100], default 0.0)"""

    air_acc_max: float
    """ Maximum acceleration in air (relative to maximum speed) (in [0, 1], default 0.0)"""

    air_ave_max: float
    """ Maximum angular velocity in air (relative to 180 degrees) (in [0, 1], default 0.0)"""

    air_personal_space: float
    """ Radius of boids personal space in air (% of particle size) (in [0, 10], default 0.0)"""

    air_speed_max: float
    """ Maximum speed in air (in [0, 100], default 0.0)"""

    air_speed_min: float
    """ Minimum speed in air (relative to maximum speed) (in [0, 1], default 0.0)"""

    bank: float
    """ Amount of rotation around velocity vector on turns (in [0, 2], default 0.0)"""

    health: float
    """ Initial boid health when born (in [0, 100], default 0.0)"""

    height: float
    """ Boid height relative to particle size (in [0, 2], default 0.0)"""

    land_acc_max: float
    """ Maximum acceleration on land (relative to maximum speed) (in [0, 1], default 0.0)"""

    land_ave_max: float
    """ Maximum angular velocity on land (relative to 180 degrees) (in [0, 1], default 0.0)"""

    land_jump_speed: float
    """ Maximum speed for jumping (in [0, 100], default 0.0)"""

    land_personal_space: float
    """ Radius of boids personal space on land (% of particle size) (in [0, 10], default 0.0)"""

    land_smooth: float
    """ How smoothly the boids land (in [0, 10], default 0.0)"""

    land_speed_max: float
    """ Maximum speed on land (in [0, 100], default 0.0)"""

    land_stick_force: float
    """ How strong a force must be to start effecting a boid on land (in [0, 1000], default 0.0)"""

    pitch: float
    """ Amount of rotation around side vector (in [0, 2], default 0.0)"""

    range: float
    """ Maximum distance from which a boid can attack (in [0, 100], default 0.0)"""

    states: typing.Any
    """ (default None, readonly)"""

    strength: float
    """ Maximum caused damage on attack per second (in [0, 100], default 0.0)"""

    use_climb: bool
    """ Allow boids to climb goal objects (default False)"""

    use_flight: bool
    """ Allow boids to move in air (default False)"""

    use_land: bool
    """ Allow boids to move on land (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoidState(bpy_struct):
    """Boid state for boid physics"""

    active_boid_rule: BoidRule | None
    """ (readonly)"""

    active_boid_rule_index: int | None
    """ (in [0, inf], default 0)"""

    falloff: float
    """ (in [0, 10], default 0.0)"""

    name: str
    """ Boid state name (default "", never None)"""

    rule_fuzzy: float
    """ (in [0, 1], default 0.0)"""

    rules: typing.Any
    """ (default None, readonly)"""

    ruleset_type: typing.Literal["FUZZY", "RANDOM", "AVERAGE"]
    """ How the rules in the list are evaluated (default 'FUZZY')"""

    volume: float
    """ (in [0, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Bone(bpy_struct):
    """Bone in an Armature data-block"""

    bbone_curveinx: float
    """ X-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveinz: float
    """ Z-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutx: float
    """ X-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutz: float
    """ Z-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_custom_handle_end: typing_extensions.Self | None
    """ Bone that serves as the end handle for the B-Bone curve"""

    bbone_custom_handle_start: typing_extensions.Self | None
    """ Bone that serves as the start handle for the B-Bone curve"""

    bbone_easein: float
    """ Length of first Bézier Handle (for B-Bones only) (in [-inf, inf], default 1.0)"""

    bbone_easeout: float
    """ Length of second Bézier Handle (for B-Bones only) (in [-inf, inf], default 1.0)"""

    bbone_handle_type_end: typing.Literal["AUTO", "ABSOLUTE", "RELATIVE", "TANGENT"]
    """ Selects how the end handle of the B-Bone is computed (default 'AUTO')"""

    bbone_handle_type_start: typing.Literal["AUTO", "ABSOLUTE", "RELATIVE", "TANGENT"]
    """ Selects how the start handle of the B-Bone is computed (default 'AUTO')"""

    bbone_handle_use_ease_end: bool
    """ Multiply the B-Bone Ease Out channel by the local Y scale value of the end handle. This is done after the Scale Easing option and isn't affected by it. (default False)"""

    bbone_handle_use_ease_start: bool
    """ Multiply the B-Bone Ease In channel by the local Y scale value of the start handle. This is done after the Scale Easing option and isn't affected by it. (default False)"""

    bbone_handle_use_scale_end: typing.Any
    """ Multiply B-Bone Scale Out channels by the local scale values of the end handle. This is done after the Scale Easing option and isn't affected by it. (array of 3 items, default (False, False, False))"""

    bbone_handle_use_scale_start: typing.Any
    """ Multiply B-Bone Scale In channels by the local scale values of the start handle. This is done after the Scale Easing option and isn't affected by it. (array of 3 items, default (False, False, False))"""

    bbone_mapping_mode: typing.Literal["STRAIGHT", "CURVED"]
    """ Selects how the vertices are mapped to B-Bone segments based on their position (default 'STRAIGHT')"""

    bbone_rollin: float
    """ Roll offset for the start of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_rollout: float
    """ Roll offset for the end of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_scalein: mathutils.Vector
    """ Scale factors for the start of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    bbone_scaleout: mathutils.Vector
    """ Scale factors for the end of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    bbone_segments: int
    """ Number of subdivisions of bone (for B-Bones only) (in [1, 32], default 0)"""

    bbone_x: float
    """ B-Bone X size (in [-inf, inf], default 0.0)"""

    bbone_z: float
    """ B-Bone Z size (in [-inf, inf], default 0.0)"""

    children: typing.Any
    """ Bones which are children of this bone (default None, readonly)"""

    collections: typing.Any
    """ Bone Collections that contain this bone (default None, readonly)"""

    color: BoneColor | None
    """ (readonly)"""

    display_type: typing.Literal[
        "ARMATURE_DEFINED", "OCTAHEDRAL", "STICK", "BBONE", "ENVELOPE", "WIRE"
    ]
    """ (default 'OCTAHEDRAL')"""

    envelope_distance: float
    """ Bone deformation distance (for Envelope deform only) (in [0, 1000], default 0.0)"""

    envelope_weight: float
    """ Bone deformation weight (for Envelope deform only) (in [0, 1000], default 0.0)"""

    head: mathutils.Vector
    """ Location of head end of the bone relative to its parent (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    head_local: mathutils.Vector
    """ Location of head end of the bone relative to armature (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    head_radius: float
    """ Radius of head of bone (for Envelope deform only) (in [-inf, inf], default 0.0)"""

    hide: bool
    """ Bone is not visible when it is in Edit Mode (default False)"""

    hide_select: bool
    """ Bone is able to be selected (default False)"""

    inherit_scale: typing.Literal[
        "FULL", "FIX_SHEAR", "ALIGNED", "AVERAGE", "NONE", "NONE_LEGACY"
    ]
    """ Specifies how the bone inherits scaling from the parent bone (default 'FULL')"""

    length: float
    """ Length of the bone (in [-inf, inf], default 0.0, readonly)"""

    matrix: mathutils.Matrix
    """ 3×3 bone matrix (multi-dimensional array of 3 * 3 items, in [-inf, inf], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), readonly)"""

    matrix_local: mathutils.Matrix
    """ 4×4 bone matrix relative to armature (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    name: str
    """ (default "", never None)"""

    parent: Bone | None
    """ Parent bone (in same Armature) (readonly)"""

    show_wire: bool
    """ Bone is always displayed in wireframe regardless of viewport shading mode (useful for non-obstructive custom bone shapes) (default False)"""

    tail: mathutils.Vector
    """ Location of tail end of the bone relative to its parent (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    tail_local: mathutils.Vector
    """ Location of tail end of the bone relative to armature (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    tail_radius: float
    """ Radius of tail of bone (for Envelope deform only) (in [-inf, inf], default 0.0)"""

    use_connect: bool
    """ When bone has a parent, bone's head is stuck to the parent's tail (default False, readonly)"""

    use_cyclic_offset: bool
    """ When bone does not have a parent, it receives cyclic offset effects (Deprecated) (default True)"""

    use_deform: bool
    """ Enable Bone to deform geometry (default True)"""

    use_endroll_as_inroll: bool
    """ Add Roll Out of the Start Handle bone to the Roll In value (default False)"""

    use_envelope_multiply: bool
    """ When deforming bone, multiply effects of Vertex Group weights with Envelope influence (default False)"""

    use_inherit_rotation: bool
    """ Bone inherits rotation or scale from parent bone (default True)"""

    use_local_location: bool
    """ Bone location is set in local space (default True)"""

    use_relative_parent: bool
    """ Object children will use relative transform, like deform (default False)"""

    use_scale_easing: bool
    """ Multiply the final easing values by the Scale In/Out Y factors (default False)"""

    basename: typing.Any
    """ The name of this bone before any . character.(readonly)"""

    center: typing.Any
    """ The midpoint between the head and the tail.(readonly)"""

    children_recursive: typing.Any
    """ A list of all children from this bone.(readonly)"""

    children_recursive_basename: typing.Any
    """ Returns a chain of children with the same base name as this bone.
Only direct chains are supported, forks caused by multiple children
with matching base names will terminate the function
and not be returned.(readonly)"""

    parent_recursive: typing.Any
    """ A list of parents, starting with the immediate parent.(readonly)"""

    vector: typing.Any
    """ The direction this bone is pointing.
Utility function for (tail - head)(readonly)"""

    x_axis: typing.Any
    """ Vector pointing down the x-axis of the bone.(readonly)"""

    y_axis: typing.Any
    """ Vector pointing down the y-axis of the bone.(readonly)"""

    z_axis: typing.Any
    """ Vector pointing down the z-axis of the bone.(readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def evaluate_envelope(
        self, point: collections.abc.Sequence[float] | mathutils.Vector | None
    ) -> float:
        """Calculate bone envelope at given point

        :param point: Point, Position in 3d space to evaluate (array of 3 items, in [-inf, inf])
        :return: Factor, Envelope factor (in [-inf, inf])
        """

    def convert_local_to_pose(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        matrix_local: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        parent_matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None = (
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
        ),
        parent_matrix_local: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None = (
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
        ),
        invert: bool | None = False,
    ) -> mathutils.Matrix:
        """Transform a matrix from Local to Pose space (or back), taking into account options like Inherit Scale and Local Location. Unlike Object.convert_space, this uses custom rest and pose matrices provided by the caller. If the parent matrices are omitted, the bone is assumed to have no parent.This method enables conversions between Local and Pose space for bones in
        the middle of updating the armature without having to update dependencies
        after each change, by manually carrying updated matrices in a recursive walk.

                :param matrix: The matrix to transform (multi-dimensional array of 4 * 4 items, in [-inf, inf])
                :param matrix_local: The custom rest matrix of this bone (Bone.matrix_local) (multi-dimensional array of 4 * 4 items, in [-inf, inf])
                :param parent_matrix: The custom pose matrix of the parent bone (PoseBone.matrix) (multi-dimensional array of 4 * 4 items, in [-inf, inf], optional)
                :param parent_matrix_local: The custom rest matrix of the parent bone (Bone.matrix_local) (multi-dimensional array of 4 * 4 items, in [-inf, inf], optional)
                :param invert: Convert from Pose to Local space (optional)
                :return: The transformed matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    @classmethod
    def MatrixFromAxisRoll(
        cls,
        axis: collections.abc.Sequence[float] | mathutils.Vector | None,
        roll: float | None,
    ) -> mathutils.Matrix:
        """Convert the axis + roll representation to a matrix

        :param axis: The main axis of the bone (tail - head) (array of 3 items, in [-inf, inf], never None)
        :param roll: The roll of the bone (in [-inf, inf])
        :return: The resulting orientation matrix (multi-dimensional array of 3 * 3 items, in [-inf, inf])
        """

    @classmethod
    def AxisRollFromMatrix(
        cls,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        axis: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0),
    ) -> tuple[mathutils.Vector, float]:
        """Convert a rotational matrix to the axis + roll representation. Note that the resulting value of the roll may not be as expected if the matrix has shear or negative determinant.

                :param matrix: The orientation matrix of the bone (multi-dimensional array of 3 * 3 items, in [-inf, inf], never None)
                :param axis: The optional override for the axis (finds closest approximation for the matrix) (array of 3 items, in [-inf, inf], optional)
                :return: result_axis, The main axis of the bone, `mathutils.Vector`

        result_roll, The roll of the bone, float
        """

    def parent_index(self, parent_test) -> None:
        """The same as bone in other_bone.parent_recursive
        but saved generating a list.

                :param parent_test:
        """

    def translate(self, vec) -> None:
        """Utility function to add vec to the head and tail of this bone.

        :param vec:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoneCollection(bpy_struct):
    """Bone collection in an Armature data-block"""

    bones: typing.Any
    """ Bones assigned to this bone collection. In armature edit mode this will always return an empty list of bones, as the bone collection memberships are only synchronized when exiting edit mode. (default None, readonly)"""

    child_number: int
    """ Index of this collection into its parent's list of children. Note that finding this index requires a scan of all the bone collections, so do access this with care. (in [-inf, inf], default 0)"""

    children: typing.Any
    """ (default None, readonly)"""

    index: int
    """ Index of this bone collection in the armature.collections_all array. Note that finding this index requires a scan of all the bone collections, so do access this with care. (in [-inf, inf], default 0, readonly)"""

    is_editable: bool
    """ This collection is owned by a local Armature, or was added via a library override in the current blend file (default False, readonly)"""

    is_expanded: bool
    """ This bone collection is expanded in the bone collections tree view (default False)"""

    is_local_override: bool
    """ This collection was added via a library override in the current blend file (default False, readonly)"""

    is_solo: bool
    """ Show only this bone collection, and others also marked as 'solo' (default False)"""

    is_visible: bool
    """ Bones in this collection will be visible in pose/object mode (default False)"""

    is_visible_ancestors: bool
    """ True when all of the ancestors of this bone collection are marked as visible; always True for root bone collections (default False, readonly)"""

    is_visible_effectively: bool
    """ Whether this bone collection is effectively visible in the viewport. This is True when this bone collection and all of its ancestors are visible, or when it is marked as 'solo'. (default False, readonly)"""

    name: str
    """ Unique within the Armature (default "", never None)"""

    parent: BoneCollection | None
    """ Parent bone collection. Note that accessing this requires a scan of all the bone collections to find the parent."""

    bones_recursive: typing.Any
    """ A set of all bones assigned to this bone collection and its child collections.(readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def assign(self, bone: typing.Any | None) -> bool:
        """Assign the given bone to this collection

        :param bone: Bone, PoseBone, or EditBone to assign to this collection
        :return: Assigned, Whether the bone was actually assigned; will be false if the bone was already member of the collection
        """

    def unassign(self, bone: typing.Any | None) -> bool:
        """Remove the given bone from this collection

        :param bone: Bone, PoseBone, or EditBone to remove from this collection
        :return: Unassigned, Whether the bone was actually removed; will be false if the bone was not a member of the collection to begin with
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoneColor(bpy_struct):
    """Theme color or custom color of a bone"""

    custom: ThemeBoneColorSet | None
    """ The custom bone colors, used when palette is 'CUSTOM' (readonly, never None)"""

    is_custom: bool
    """ A color palette is user-defined, instead of using a theme-defined one (default False, readonly)"""

    palette: typing.Literal[
        "DEFAULT",
        "THEME01",
        "THEME02",
        "THEME03",
        "THEME04",
        "THEME05",
        "THEME06",
        "THEME07",
        "THEME08",
        "THEME09",
        "THEME10",
        "THEME11",
        "THEME12",
        "THEME13",
        "THEME14",
        "THEME15",
        "THEME16",
        "THEME17",
        "THEME18",
        "THEME19",
        "THEME20",
        "CUSTOM",
    ]
    """ Color palette to use (default 'DEFAULT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoolAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores booleans"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoolAttributeValue(bpy_struct):
    """Bool value in geometry attribute"""

    value: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BoolProperty(Property, bpy_struct):
    """RNA boolean property definition"""

    array_dimensions: typing.Any
    """ Length of each dimension of the array (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    array_length: int
    """ Maximum length of the array, 0 means unlimited (in [0, inf], default 0, readonly)"""

    default: bool
    """ Default value for this number (default False, readonly)"""

    default_array: typing.Any
    """ Default value for this array (array of 3 items, default (False, False, False), readonly)"""

    is_array: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BooleanModifier(Modifier, bpy_struct):
    """Boolean operations modifier"""

    collection: Collection | None
    """ Use mesh objects in this collection for Boolean operation"""

    debug_options: set[typing.Literal["SEPARATE", "NO_DISSOLVE", "NO_CONNECT_REGIONS"]]
    """ Debugging options, only when started with '-d' (default set())"""

    double_threshold: float
    """ Threshold for checking overlapping geometry (in [0, 1], default 1e-06)"""

    material_mode: typing.Literal["INDEX", "TRANSFER"]
    """ Method for setting materials on the new faces (default 'INDEX')"""

    object: Object | None
    """ Mesh object to use for Boolean operation"""

    operand_type: typing.Literal["OBJECT", "COLLECTION"]
    """ (default 'OBJECT')"""

    operation: typing.Literal["INTERSECT", "UNION", "DIFFERENCE"]
    """ (default 'DIFFERENCE')"""

    solver: typing.Literal["FLOAT", "EXACT", "MANIFOLD"]
    """ Method for calculating booleans (default 'EXACT')"""

    use_hole_tolerant: bool
    """ Better results when there are holes (slower) (default False)"""

    use_self: bool
    """ Allow self-intersection in operands (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrightContrastModifier(StripModifier, bpy_struct):
    """Bright/contrast modifier data for sequence strip"""

    bright: float
    """ Adjust the luminosity of the colors (in [-inf, inf], default 0.0)"""

    contrast: float
    """ Adjust the difference in luminosity between pixels (in [-100, 100], default 0.0)"""

    open_mask_input_panel: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Brush(ID, bpy_struct):
    """Brush data-block for storing brush settings for painting and sculpting"""

    area_radius_factor: float
    """ Ratio between the brush radius and the radius that is going to be used to sample the area center (in [0, 2], default 0.5)"""

    auto_smooth_factor: float
    """ Amount of smoothing to automatically apply to each stroke (in [0, 1], default 0.0)"""

    automasking_boundary_edges_propagation_steps: int
    """ Distance where boundary edge automasking is going to protect vertices from the fully masked edge (in [1, 20], default 1)"""

    automasking_cavity_blur_steps: int
    """ The number of times the cavity mask is blurred (in [0, 25], default 0)"""

    automasking_cavity_curve: CurveMapping | None
    """ Curve used for the sensitivity (readonly)"""

    automasking_cavity_factor: float
    """ The contrast of the cavity mask (in [0, 5], default 1.0)"""

    automasking_start_normal_falloff: float
    """ Extend the angular range with a falloff gradient (in [0.0001, 1], default 0.25)"""

    automasking_start_normal_limit: float
    """ The range of angles that will be affected (in [0.0001, 3.14159], default 0.349066)"""

    automasking_view_normal_falloff: float
    """ Extend the angular range with a falloff gradient (in [0.0001, 1], default 0.25)"""

    automasking_view_normal_limit: float
    """ The range of angles that will be affected (in [0.0001, 3.14159], default 1.5708)"""

    blend: typing.Literal[
        "MIX",
        "DARKEN",
        "MUL",
        "COLORBURN",
        "LINEARBURN",
        "LIGHTEN",
        "SCREEN",
        "COLORDODGE",
        "ADD",
        "OVERLAY",
        "SOFTLIGHT",
        "HARDLIGHT",
        "VIVIDLIGHT",
        "LINEARLIGHT",
        "PINLIGHT",
        "DIFFERENCE",
        "EXCLUSION",
        "SUB",
        "HUE",
        "SATURATION",
        "COLOR",
        "LUMINOSITY",
        "ERASE_ALPHA",
        "ADD_ALPHA",
    ]
    """ Brush blending mode (default 'MIX')"""

    blur_kernel_radius: int
    """ Radius of kernel used for soften and sharpen in pixels (in [1, 10000], default 2)"""

    blur_mode: typing.Literal["BOX", "GAUSSIAN"]
    """ (default 'GAUSSIAN')"""

    boundary_deform_type: typing.Literal[
        "BEND", "EXPAND", "INFLATE", "GRAB", "TWIST", "SMOOTH"
    ]
    """ Deformation type that is used in the brush (default 'BEND')"""

    boundary_falloff_type: typing.Literal["CONSTANT", "RADIUS", "LOOP", "LOOP_INVERT"]
    """ How the brush falloff is applied across the boundary (default 'CONSTANT')"""

    boundary_offset: float
    """ Offset of the boundary origin in relation to the brush radius (in [0, 30], default 0.0)"""

    brush_capabilities: BrushCapabilities | None
    """ Brush's capabilities (readonly, never None)"""

    cloth_constraint_softbody_strength: float
    """ How much the cloth preserves the original shape, acting as a soft body (in [0, 1], default 0.0)"""

    cloth_damping: float
    """ How much the applied forces are propagated through the cloth (in [0.01, 1], default 0.01)"""

    cloth_deform_type: typing.Literal[
        "DRAG",
        "PUSH",
        "PINCH_POINT",
        "PINCH_PERPENDICULAR",
        "INFLATE",
        "GRAB",
        "EXPAND",
        "SNAKE_HOOK",
    ]
    """ Deformation type that is used in the brush (default 'DRAG')"""

    cloth_force_falloff_type: typing.Literal["RADIAL", "PLANE"]
    """ Shape used in the brush to apply force to the cloth (default 'RADIAL')"""

    cloth_mass: float
    """ Mass of each simulation particle (in [0.01, 2], default 1.0)"""

    cloth_sim_falloff: float
    """ Area to apply deformation falloff to the effects of the simulation (in [0, 1], default 0.75)"""

    cloth_sim_limit: float
    """ Factor added relative to the size of the radius to limit the cloth simulation effects (in [0.1, 10], default 2.5)"""

    cloth_simulation_area_type: typing.Literal["LOCAL", "GLOBAL", "DYNAMIC"]
    """ Part of the mesh that is going to be simulated when the stroke is active (default 'LOCAL')"""

    color: mathutils.Color
    """ (array of 3 items, in [0, inf], default (1.0, 1.0, 1.0))"""

    color_type: typing.Literal["COLOR", "GRADIENT"]
    """ Use single color or gradient when painting (default 'COLOR')"""

    crease_pinch_factor: float
    """ How much the crease brush pinches (in [0, 1], default 0.5)"""

    cursor_color_add: typing.Any
    """ Color of cursor when adding (array of 4 items, in [0, inf], default (1.0, 0.39, 0.39, 0.9))"""

    cursor_color_subtract: typing.Any
    """ Color of cursor when subtracting (array of 4 items, in [0, inf], default (0.39, 0.39, 1.0, 0.9))"""

    cursor_overlay_alpha: int
    """ (in [0, 100], default 33)"""

    curve_distance_falloff: CurveMapping | None
    """ Editable falloff curve (readonly, never None)"""

    curve_distance_falloff_preset: Literal[
        bpy.stub_internal.rna_enums.BrushCurvePresetItems
    ]
    """ (default 'CUSTOM')"""

    curve_jitter: CurveMapping | None
    """ Curve used to map pressure to brush jitter (readonly)"""

    curve_random_hue: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_saturation: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_value: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_size: CurveMapping | None
    """ Curve used to map pressure to brush size (readonly)"""

    curve_strength: CurveMapping | None
    """ Curve used to map pressure to brush strength (readonly)"""

    curves_sculpt_brush_type: Literal[
        bpy.stub_internal.rna_enums.BrushCurvesSculptBrushTypeItems
    ]
    """ (default 'COMB')"""

    curves_sculpt_settings: BrushCurvesSculptSettings | None
    """ (readonly)"""

    dash_ratio: float
    """ Ratio of samples in a cycle that the brush is enabled (in [0, 1], default 1.0)"""

    dash_samples: int
    """ Length of a dash cycle measured in stroke samples (in [1, 10000], default 20)"""

    deform_target: typing.Literal["GEOMETRY", "CLOTH_SIM"]
    """ How the deformation of the brush will affect the object (default 'GEOMETRY')"""

    density: float
    """ Amount of random elements that are going to be affected by the brush (in [0, 1], default 0.0)"""

    direction: typing.Literal["ADD", "SUBTRACT"]
    """ (default 'ADD')"""

    disconnected_distance_max: float
    """ Maximum distance to search for disconnected loose parts in the mesh (in [0, 10], default 0.1)"""

    elastic_deform_type: typing.Literal[
        "GRAB", "GRAB_BISCALE", "GRAB_TRISCALE", "SCALE", "TWIST"
    ]
    """ Deformation type that is used in the brush (default 'GRAB')"""

    elastic_deform_volume_preservation: float
    """ Poisson ratio for elastic deformation. Higher values preserve volume more, but also lead to more bulging. (in [0, 0.9], default 0.0)"""

    falloff_angle: float
    """ Paint most on faces pointing towards the view according to this angle (in [0, 1.5708], default 0.0)"""

    falloff_shape: typing.Literal["SPHERE", "PROJECTED"]
    """ Use projected or spherical falloff (default 'SPHERE')"""

    fill_threshold: float
    """ Threshold above which filling is not propagated (in [0, 100], default 0.2)"""

    flow: float
    """ Amount of paint that is applied per stroke sample (in [0, 1], default 0.0)"""

    gpencil_brush_type: Literal[bpy.stub_internal.rna_enums.BrushGpencilTypesItems]
    """ (default 'DRAW')"""

    gpencil_sculpt_brush_type: Literal[
        bpy.stub_internal.rna_enums.BrushGpencilSculptTypesItems
    ]
    """ (default 'SMOOTH')"""

    gpencil_settings: BrushGpencilSettings | None
    """ (readonly)"""

    gpencil_vertex_brush_type: Literal[
        bpy.stub_internal.rna_enums.BrushGpencilVertexTypesItems
    ]
    """ (default 'DRAW')"""

    gpencil_weight_brush_type: Literal[
        bpy.stub_internal.rna_enums.BrushGpencilWeightTypesItems
    ]
    """ (default 'WEIGHT')"""

    grad_spacing: int
    """ Spacing before brush gradient goes full circle (in [1, 10000], default 0)"""

    gradient: ColorRamp | None
    """ (readonly)"""

    gradient_fill_mode: typing.Literal["LINEAR", "RADIAL"]
    """ (default 'LINEAR')"""

    gradient_stroke_mode: typing.Literal["PRESSURE", "SPACING_REPEAT", "SPACING_CLAMP"]
    """ (default 'PRESSURE')"""

    hardness: float
    """ How close the brush falloff starts from the edge of the brush (in [0, 1], default 0.0)"""

    has_unsaved_changes: bool
    """ Indicates that there are any user visible changes since the brush has been imported or read from the file (default False, readonly)"""

    height: float
    """ Affectable height of brush (i.e. the layer height for the layer tool) (in [0, 1], default 0.5)"""

    hue_jitter: float
    """ Color jitter effect on hue (in [0, 1], default 0.0)"""

    image_brush_type: Literal[bpy.stub_internal.rna_enums.BrushImageBrushTypeItems]
    """ (default 'DRAW')"""

    image_paint_capabilities: BrushCapabilitiesImagePaint | None
    """ (readonly, never None)"""

    input_samples: int
    """ Number of input samples to average together to smooth the brush stroke (in [1, 64], default 1)"""

    invert_density_pressure: bool
    """ Invert the modulation of pressure in density (default False)"""

    invert_flow_pressure: bool
    """ Invert the modulation of pressure in flow (default False)"""

    invert_hardness_pressure: bool
    """ Invert the modulation of pressure in hardness (default False)"""

    invert_to_scrape_fill: bool
    """ Use Scrape or Fill brush when inverting this brush instead of inverting its displacement direction (default False)"""

    invert_wet_mix_pressure: bool
    """ Invert the modulation of pressure in wet mix (default False)"""

    invert_wet_persistence_pressure: bool
    """ Invert the modulation of pressure in wet persistence (default False)"""

    jitter: float
    """ Jitter the position of the brush while painting (in [0, 1000], default 0.0)"""

    jitter_absolute: int
    """ Jitter the position of the brush in pixels while painting (in [0, 1000000], default 0)"""

    jitter_unit: typing.Literal["VIEW", "BRUSH"]
    """ Jitter in screen space or relative to brush size (default 'VIEW')"""

    mask_overlay_alpha: int
    """ (in [0, 100], default 33)"""

    mask_stencil_dimension: mathutils.Vector
    """ Dimensions of mask stencil in viewport (array of 2 items, in [-inf, inf], default (256.0, 256.0))"""

    mask_stencil_pos: mathutils.Vector
    """ Position of mask stencil in viewport (array of 2 items, in [-inf, inf], default (256.0, 256.0))"""

    mask_texture: Texture | None
    mask_texture_slot: BrushTextureSlot | None
    """ (readonly)"""

    mask_tool: typing.Literal["DRAW", "SMOOTH"]
    """ (default 'DRAW')"""

    multiplane_scrape_angle: float
    """ Angle between the planes of the crease (in [0, 160], default 0.0)"""

    normal_radius_factor: float
    """ Ratio between the brush radius and the radius that is going to be used to sample the normal (in [0, 2], default 0.5)"""

    normal_weight: float
    """ How much grab will pull vertices out of surface during a grab (in [0, 1], default 0.0)"""

    paint_curve: PaintCurve | None
    """ Active paint curve"""

    plane_depth: float
    """ The maximum distance below the plane for affected vertices. Increasing the depth affects vertices farther below the plane. (in [0, 1], default 0.0)"""

    plane_height: float
    """ The maximum distance above the plane for affected vertices. Increasing the height affects vertices farther above the plane. (in [0, 1], default 1.0)"""

    plane_inversion_mode: typing.Literal["INVERT_DISPLACEMENT", "SWAP_DEPTH_AND_HEIGHT"]
    """ Inversion Mode (default 'INVERT_DISPLACEMENT')"""

    plane_offset: float
    """ Adjust plane on which the brush acts towards or away from the object surface (in [-2, 2], default 0.0)"""

    plane_trim: float
    """ If a vertex is further away from offset plane than this, then it is not affected (in [0, 1], default 0.5)"""

    pose_deform_type: typing.Literal[
        "ROTATE_TWIST", "SCALE_TRANSLATE", "SQUASH_STRETCH"
    ]
    """ Deformation type that is used in the brush (default 'ROTATE_TWIST')"""

    pose_ik_segments: int
    """ Number of segments of the inverse kinematics chain that will deform the mesh (in [1, 20], default 1)"""

    pose_offset: float
    """ Offset of the pose origin in relation to the brush radius (in [0, 2], default 0.0)"""

    pose_origin_type: typing.Literal["TOPOLOGY", "FACE_SETS", "FACE_SETS_FK"]
    """ Method to set the rotation origins for the segments of the brush (default 'TOPOLOGY')"""

    pose_smooth_iterations: int
    """ Smooth iterations applied after calculating the pose factor of each vertex (in [0, 100], default 4)"""

    rake_factor: float
    """ How much grab will follow cursor rotation (in [0, 10], default 0.0)"""

    rate: float
    """ Interval between paints for Airbrush (in [0.0001, 10000], default 0.1)"""

    saturation_jitter: float
    """ Color jitter effect on saturation (in [0, 1], default 0.0)"""

    sculpt_brush_type: Literal[bpy.stub_internal.rna_enums.BrushSculptBrushTypeItems]
    """ (default 'DRAW')"""

    sculpt_capabilities: BrushCapabilitiesSculpt | None
    """ (readonly, never None)"""

    sculpt_plane: typing.Literal["AREA", "VIEW", "X", "Y", "Z"]
    """ (default 'AREA')"""

    secondary_color: mathutils.Color
    """ (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    sharp_threshold: float
    """ Threshold below which, no sharpening is done (in [0, 100], default 0.0)"""

    show_multiplane_scrape_planes_preview: bool
    """ Preview the scrape planes in the cursor during the stroke (default False)"""

    size: int
    """ Diameter of the brush in pixels (in [1, 10000], default 70)"""

    slide_deform_type: typing.Literal["DRAG", "PINCH", "EXPAND"]
    """ Deformation type that is used in the brush (default 'DRAG')"""

    smear_deform_type: typing.Literal["DRAG", "PINCH", "EXPAND"]
    """ Deformation type that is used in the brush (default 'DRAG')"""

    smooth_deform_type: typing.Literal["LAPLACIAN", "SURFACE"]
    """ Deformation type that is used in the brush (default 'LAPLACIAN')"""

    smooth_stroke_factor: float
    """ Higher values give a smoother stroke (in [0.5, 0.99], default 0.9)"""

    smooth_stroke_radius: int
    """ Minimum distance from last point before stroke continues (in [10, 200], default 75)"""

    snake_hook_deform_type: typing.Literal["FALLOFF", "ELASTIC"]
    """ Deformation type that is used in the brush (default 'FALLOFF')"""

    spacing: int
    """ Spacing between brush daubs as a percentage of brush diameter (in [1, 1000], default 10)"""

    stabilize_normal: float
    """ How stable the plane normal is over the course of the stroke. A value of 0 corresponds to using the current normal, and a value of 1 corresponds to using the initial normal. (in [0, 1], default 0.0)"""

    stabilize_plane: float
    """ How stable the plane center is over the course of the stroke. A value of 0 corresponds to using the current center, and a value of 1 corresponds to using the initial center. (in [0, 1], default 0.0)"""

    stencil_dimension: mathutils.Vector
    """ Dimensions of stencil in viewport (array of 2 items, in [-inf, inf], default (256.0, 256.0))"""

    stencil_pos: mathutils.Vector
    """ Position of stencil in viewport (array of 2 items, in [-inf, inf], default (256.0, 256.0))"""

    strength: float
    """ How powerful the effect of the brush is when applied (in [0, 10], default 1.0)"""

    stroke_method: typing.Literal[
        "DOTS", "DRAG_DOT", "SPACE", "AIRBRUSH", "ANCHORED", "LINE", "CURVE"
    ]
    """ (default 'DOTS')"""

    surface_smooth_current_vertex: float
    """ How much the position of each individual vertex influences the final result (in [0, 1], default 0.0)"""

    surface_smooth_iterations: int
    """ Number of smoothing iterations per brush step (in [1, 10], default 0)"""

    surface_smooth_shape_preservation: float
    """ How much of the original shape is preserved when smoothing (in [0, 1], default 0.0)"""

    texture: Texture | None
    texture_overlay_alpha: int
    """ (in [0, 100], default 33)"""

    texture_sample_bias: float
    """ Value added to texture samples (in [-1, 1], default 0.0)"""

    texture_slot: BrushTextureSlot | None
    """ (readonly)"""

    tilt_strength_factor: float
    """ How much the tilt of the pen will affect the brush. Negative values indicate inverting the tilt directions. (in [-1, 1], default 0.0)"""

    tip_roundness: float
    """ Roundness of the brush tip (in [0, 1], default 1.0)"""

    tip_scale_x: float
    """ Scale of the brush tip in the X axis (in [0.0001, 1], default 1.0)"""

    topology_rake_factor: float
    """ Automatically align edges to the brush direction to generate cleaner topology and define sharp features. Best used on low-poly meshes as it has a performance impact. (in [0, 1], default 0.0)"""

    unprojected_size: float
    """ Diameter of brush in Blender units (in [0.001, inf], default 0.1)"""

    use_accumulate: bool
    """ Accumulate stroke daubs on top of each other (default False)"""

    use_adaptive_space: bool
    """ Space daubs according to surface orientation instead of screen space (default False)"""

    use_alpha: bool
    """ When this is disabled, lock alpha while painting (default True)"""

    use_automasking_boundary_edges: bool
    """ Do not affect non manifold boundary edges (default False)"""

    use_automasking_boundary_face_sets: bool
    """ Do not affect vertices that belong to a face set boundary (default False)"""

    use_automasking_cavity: bool
    """ Do not affect vertices on peaks, based on the surface curvature (default False)"""

    use_automasking_cavity_inverted: bool
    """ Do not affect vertices within crevices, based on the surface curvature (default False)"""

    use_automasking_custom_cavity_curve: bool
    """ Use custom curve (default False)"""

    use_automasking_face_sets: bool
    """ Affect only vertices that share face sets with the active vertex (default False)"""

    use_automasking_start_normal: bool
    """ Affect only vertices with a similar normal to where the stroke starts (default False)"""

    use_automasking_topology: bool
    """ Affect only vertices connected to the active vertex under the brush (default False)"""

    use_automasking_view_normal: bool
    """ Affect only vertices with a normal that faces the viewer (default False)"""

    use_automasking_view_occlusion: bool
    """ Only affect vertices that are not occluded by other faces (slower performance) (default False)"""

    use_cloth_collision: bool
    """ Collide with objects during the simulation (default False)"""

    use_cloth_pin_simulation_boundary: bool
    """ Lock the position of the vertices in the simulation falloff area to avoid artifacts and create a softer transition with unaffected areas (default False)"""

    use_color_as_displacement: bool
    """ Handle each pixel color as individual vector for displacement (area plane mapping only) (default False)"""

    use_color_jitter: bool
    """ Jitter brush color (default False)"""

    use_connected_only: bool
    """ Affect only topologically connected elements (default False)"""

    use_cursor_overlay: bool
    """ Show cursor in viewport (default False)"""

    use_cursor_overlay_override: bool
    """ Don't show overlay during a stroke (default False)"""

    use_density_pressure: bool
    """ Use pressure to modulate density (default False)"""

    use_edge_to_edge: bool
    """ Drag anchor brush from edge-to-edge (default False)"""

    use_flow_pressure: bool
    """ Use pressure to modulate flow (default False)"""

    use_frontface: bool
    """ Brush only affects vertices that face the viewer (default False)"""

    use_frontface_falloff: bool
    """ Blend brush influence by how much they face the front (default False)"""

    use_grab_active_vertex: bool
    """ Apply the maximum grab strength to the active vertex instead of the cursor location (default False)"""

    use_grab_silhouette: bool
    """ Grabs trying to automask the silhouette of the object (default False)"""

    use_hardness_pressure: bool
    """ Use pressure to modulate hardness (default False)"""

    use_inverse_smooth_pressure: bool
    """ Lighter pressure causes more smoothing to be applied (default False)"""

    use_locked_size: typing.Literal["VIEW", "SCENE"]
    """ Measure brush size relative to the view or the scene (default 'VIEW')"""

    use_multiplane_scrape_dynamic: bool
    """ The angle between the planes changes during the stroke to fit the surface under the cursor (default False)"""

    use_offset_pressure: bool
    """ Enable tablet pressure sensitivity for offset (default False)"""

    use_original_normal: bool
    """ When locked keep using normal of surface where stroke was initiated (default False)"""

    use_original_plane: bool
    """ When locked keep using the plane origin of surface where stroke was initiated (default False)"""

    use_paint_antialiasing: bool
    """ Smooths the edges of the strokes (default True)"""

    use_paint_grease_pencil: bool
    """ Use this brush in Grease Pencil drawing mode (default False)"""

    use_paint_image: bool
    """ Use this brush in texture paint mode (default True)"""

    use_paint_sculpt: bool
    """ Use this brush in sculpt mode (default True)"""

    use_paint_sculpt_curves: bool
    """ Use this brush in sculpt curves mode (default False)"""

    use_paint_uv_sculpt: bool
    """ Use this brush in UV sculpt mode (default False)"""

    use_paint_vertex: bool
    """ Use this brush in vertex paint mode (default True)"""

    use_paint_weight: bool
    """ Use this brush in weight paint mode (default True)"""

    use_persistent: bool
    """ Sculpt on a persistent layer of the mesh (default False)"""

    use_plane_trim: bool
    """ Limit the distance from the offset plane that a vertex can be affected (default False)"""

    use_pose_ik_anchored: bool
    """ Keep the position of the last segment in the IK chain fixed (default False)"""

    use_pose_lock_rotation: bool
    """ Do not rotate the segment when using the scale deform mode (default False)"""

    use_pressure_area_radius: bool
    """ Enable tablet pressure sensitivity for area radius (default False)"""

    use_pressure_jitter: bool
    """ Enable tablet pressure sensitivity for jitter (default False)"""

    use_pressure_masking: typing.Literal["NONE", "RAMP", "CUTOFF"]
    """ Pen pressure makes texture influence smaller (default 'NONE')"""

    use_pressure_size: bool
    """ Enable tablet pressure sensitivity for size (default False)"""

    use_pressure_spacing: bool
    """ Enable tablet pressure sensitivity for spacing (default False)"""

    use_pressure_strength: bool
    """ Enable tablet pressure sensitivity for strength (default True)"""

    use_primary_overlay: bool
    """ Show texture in viewport (default False)"""

    use_primary_overlay_override: bool
    """ Don't show overlay during a stroke (default False)"""

    use_random_press_hue: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_sat: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_val: bool
    """ Use pressure to modulate randomness (default False)"""

    use_scene_spacing: typing.Literal["VIEW", "SCENE"]
    """ Calculate the brush spacing using view or scene distance (default 'VIEW')"""

    use_secondary_overlay: bool
    """ Show texture in viewport (default False)"""

    use_secondary_overlay_override: bool
    """ Don't show overlay during a stroke (default False)"""

    use_smooth_stroke: bool
    """ Brush lags behind mouse and follows a smoother path (default False)"""

    use_space_attenuation: bool
    """ Automatically adjust strength to give consistent results for different spacings (default True)"""

    use_stroke_random_hue: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_sat: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_val: bool
    """ Use randomness at stroke level (default False)"""

    use_vertex_grease_pencil: bool
    """ Use this brush in Grease Pencil vertex color mode (default False)"""

    use_wet_mix_pressure: bool
    """ Use pressure to modulate wet mix (default False)"""

    use_wet_persistence_pressure: bool
    """ Use pressure to modulate wet persistence (default False)"""

    value_jitter: float
    """ Color jitter effect on value (in [0, 1], default 0.0)"""

    vertex_brush_type: Literal[bpy.stub_internal.rna_enums.BrushVertexBrushTypeItems]
    """ (default 'DRAW')"""

    vertex_paint_capabilities: BrushCapabilitiesVertexPaint | None
    """ (readonly, never None)"""

    weight: float
    """ Vertex weight when brush is applied (in [0, 1], default 1.0)"""

    weight_brush_type: Literal[bpy.stub_internal.rna_enums.BrushWeightBrushTypeItems]
    """ (default 'DRAW')"""

    weight_paint_capabilities: BrushCapabilitiesWeightPaint | None
    """ (readonly, never None)"""

    wet_mix: float
    """ Amount of paint that is picked from the surface into the brush color (in [0, 1], default 0.0)"""

    wet_paint_radius_factor: float
    """ Ratio between the brush radius and the radius that is going to be used to sample the color to blend in wet paint (in [0, 2], default 0.5)"""

    wet_persistence: float
    """ Amount of wet paint that stays in the brush after applying paint to the surface (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCapabilities(bpy_struct):
    """Read-only indications of supported operations"""

    has_overlay: bool
    """ (default False, readonly)"""

    has_random_texture_angle: bool
    """ (default False, readonly)"""

    has_smooth_stroke: bool
    """ (default False, readonly)"""

    has_spacing: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCapabilitiesImagePaint(bpy_struct):
    """Read-only indications of supported operations"""

    has_accumulate: bool
    """ (default False, readonly)"""

    has_color: bool
    """ (default False, readonly)"""

    has_radius: bool
    """ (default False, readonly)"""

    has_space_attenuation: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCapabilitiesSculpt(bpy_struct):
    """Read-only indications of which brush operations are supported by the current sculpt tool"""

    has_accumulate: bool
    """ (default False, readonly)"""

    has_auto_smooth: bool
    """ (default False, readonly)"""

    has_auto_smooth_pressure: bool
    """ (default False, readonly)"""

    has_color: bool
    """ (default False, readonly)"""

    has_direction: bool
    """ (default False, readonly)"""

    has_dyntopo: bool
    """ (default False, readonly)"""

    has_gravity: bool
    """ (default False, readonly)"""

    has_hardness: bool
    """ (default False, readonly)"""

    has_hardness_pressure: bool
    """ (default False, readonly)"""

    has_height: bool
    """ (default False, readonly)"""

    has_jitter: bool
    """ (default False, readonly)"""

    has_normal_radius: bool
    """ (default False, readonly)"""

    has_normal_weight: bool
    """ (default False, readonly)"""

    has_persistence: bool
    """ (default False, readonly)"""

    has_pinch_factor: bool
    """ (default False, readonly)"""

    has_plane_depth: bool
    """ (default False, readonly)"""

    has_plane_height: bool
    """ (default False, readonly)"""

    has_plane_offset: bool
    """ (default False, readonly)"""

    has_rake_factor: bool
    """ (default False, readonly)"""

    has_random_texture_angle: bool
    """ (default False, readonly)"""

    has_sculpt_plane: bool
    """ (default False, readonly)"""

    has_secondary_color: bool
    """ (default False, readonly)"""

    has_size_pressure: bool
    """ (default False, readonly)"""

    has_smooth_stroke: bool
    """ (default False, readonly)"""

    has_space_attenuation: bool
    """ (default False, readonly)"""

    has_strength_pressure: bool
    """ (default False, readonly)"""

    has_tilt: bool
    """ (default False, readonly)"""

    has_topology_rake: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCapabilitiesVertexPaint(bpy_struct):
    """Read-only indications of supported operations"""

    has_color: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCapabilitiesWeightPaint(bpy_struct):
    """Read-only indications of supported operations"""

    has_weight: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushCurvesSculptSettings(bpy_struct):
    add_amount: int
    """ Number of curves added by the Add brush (in [1, inf], default 0)"""

    curve_length: float
    """ Length of newly added curves when it is not interpolated from other curves (in [0, inf], default 0.0)"""

    curve_parameter_falloff: CurveMapping | None
    """ Falloff that is applied from the tip to the root of each curve (readonly)"""

    curve_radius: float
    """ Radius of newly added curves when it is not interpolated from other curves (in [0, inf], default 0.01)"""

    density_add_attempts: int
    """ How many times the Density brush tries to add a new curve (in [0, inf], default 0)"""

    density_mode: typing.Literal["AUTO", "ADD", "REMOVE"]
    """ Determines whether the brush adds or removes curves (default 'AUTO')"""

    minimum_distance: float
    """ Goal distance between curve roots for the Density brush (in [0, inf], default 0.0)"""

    minimum_length: float
    """ Avoid shrinking curves shorter than this length (in [0, inf], default 0.0)"""

    points_per_curve: int
    """ Number of control points in a newly added curve (in [2, inf], default 0)"""

    use_length_interpolate: bool
    """ Use length of the curves in close proximity (default False)"""

    use_point_count_interpolate: bool
    """ Use the number of points from the curves in close proximity (default False)"""

    use_radius_interpolate: bool
    """ Use radius of the curves in close proximity (default True)"""

    use_shape_interpolate: bool
    """ Use shape of the curves in close proximity (default False)"""

    use_uniform_scale: bool
    """ Grow or shrink curves by changing their size uniformly instead of using trimming or extrapolation (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushGpencilSettings(bpy_struct):
    """Settings for Grease Pencil brush"""

    active_smooth_factor: float | None
    """ Amount of smoothing while drawing (in [0, 1], default 0.0)"""

    angle: float
    """ Direction of the stroke at which brush gives maximal thickness (0° for horizontal) (in [-1.5708, 1.5708], default 0.0)"""

    angle_factor: float
    """ Reduce brush thickness by this factor when stroke is perpendicular to 'Angle' direction (in [0, 1], default 0.0)"""

    aspect: mathutils.Vector
    """ (array of 2 items, in [0.01, 1], default (0.0, 0.0))"""

    brush_draw_mode: typing.Literal["ACTIVE", "MATERIAL", "VERTEXCOLOR"]
    """ Preselected mode when using this brush (default 'ACTIVE')"""

    caps_type: typing.Literal["ROUND", "FLAT"]
    """ The shape of the start and end of the stroke (default 'ROUND')"""

    curve_jitter: CurveMapping | None
    """ Curve used for the jitter effect (readonly)"""

    curve_random_hue: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_pressure: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_saturation: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_strength: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_uv: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_random_value: CurveMapping | None
    """ Curve used for modulating effect (readonly)"""

    curve_sensitivity: CurveMapping | None
    """ Curve used for the sensitivity (readonly)"""

    curve_strength: CurveMapping | None
    """ Curve used for the strength (readonly)"""

    dilate: int
    """ Number of pixels to expand or contract fill area (in [-40, 40], default 1)"""

    eraser_mode: typing.Literal["SOFT", "HARD", "STROKE"]
    """ Eraser Mode (default 'SOFT')"""

    eraser_strength_factor: float
    """ Amount of erasing for strength (in [0, 100], default 0.0)"""

    eraser_thickness_factor: float
    """ Amount of erasing for thickness (in [0, 100], default 0.0)"""

    extend_stroke_factor: float
    """ Strokes end extension for closing gaps, use zero to disable (in [0, 10], default 0.0)"""

    fill_direction: typing.Literal["NORMAL", "INVERT"]
    """ Direction of the fill (default 'NORMAL')"""

    fill_draw_mode: typing.Literal["BOTH", "STROKE", "CONTROL"]
    """ Mode to draw boundary limits (default 'BOTH')"""

    fill_extend_mode: typing.Literal["EXTEND", "RADIUS"]
    """ Types of stroke extensions used for closing gaps (default 'EXTEND')"""

    fill_factor: float
    """ Factor for fill boundary accuracy, higher values are more accurate but slower (in [0.05, 8], default 0.0)"""

    fill_layer_mode: typing.Literal[
        "VISIBLE", "ACTIVE", "ABOVE", "BELOW", "ALL_ABOVE", "ALL_BELOW"
    ]
    """ Layers used as boundaries (default 'VISIBLE')"""

    fill_simplify_level: int
    """ Number of simplify steps (large values reduce fill accuracy) (in [0, 10], default 0)"""

    fill_threshold: float
    """ Threshold to consider color transparent for filling (in [0, 1], default 0.0)"""

    hardness: float
    """ Gradient from the center of Dot and Box strokes (set to 1 for a solid stroke) (in [0.001, 1], default 1.0)"""

    input_samples: int
    """ Generated intermediate points for very fast mouse movements (Set to 0 to disable) (in [0, 10], default 0)"""

    material: Material | None
    """ Material used for strokes drawn using this brush"""

    material_alt: Material | None
    """ Material used for secondary uses for this brush"""

    outline_thickness_factor: float
    """ Thickness of the outline stroke relative to current brush thickness (in [0, 1], default 0.0)"""

    pen_jitter: float
    """ Jitter factor of brush radius for new strokes (in [0, 100], default 0.0)"""

    pen_smooth_factor: float
    """ Amount of smoothing to apply after finish newly created strokes, to reduce jitter/noise (in [0, 2], default 0.0)"""

    pen_smooth_steps: int
    """ Number of times to smooth newly created strokes (in [0, 100], default 0)"""

    pen_strength: float
    """ Color strength for new strokes (affect alpha factor of color) (in [0, 1], default 0.0)"""

    pen_subdivision_steps: int
    """ Number of times to subdivide newly created strokes, for less jagged strokes (in [0, 3], default 0)"""

    pin_draw_mode: bool
    """ Pin the mode to the brush (default False)"""

    random_hue_factor: float
    """ Random factor to modify original hue (in [0, 1], default 0.0)"""

    random_pressure: float
    """ Randomness factor for pressure in new strokes (in [0, 1], default 0.0)"""

    random_saturation_factor: float
    """ Random factor to modify original saturation (in [0, 1], default 0.0)"""

    random_strength: float
    """ Randomness factor strength in new strokes (in [0, 1], default 0.0)"""

    random_value_factor: float
    """ Random factor to modify original value (in [0, 1], default 0.0)"""

    show_fill: bool
    """ Show transparent lines to use as boundary for filling (default True)"""

    show_fill_boundary: bool
    """ Show help lines for filling to see boundaries (default True)"""

    show_fill_extend: bool
    """ Show help lines for stroke extension (default True)"""

    show_lasso: bool
    """ Do not display fill color while drawing the stroke (default True)"""

    simplify_factor: float
    """ Factor of Simplify using adaptive algorithm (in [0, 100], default 0.0)"""

    simplify_pixel_threshold: float
    """ Threshold in screen space used for the simplify algorithm. Points within this threshold are treated as if they were in a straight line. (in [0, 10], default 0.0)"""

    stroke_type: typing.Literal["STROKE", "FILL", "BOTH"]
    """ Mode to use when creating strokes (default 'STROKE')"""

    use_active_layer_only: bool
    """ Only edit the active layer of the object (default False)"""

    use_auto_remove_fill_guides: bool
    """ Automatically remove fill guide strokes after fill operation (default True)"""

    use_collide_strokes: bool
    """ Check if extend lines collide with strokes (default False)"""

    use_edit_position: bool
    """ The brush affects the position of the point (default False)"""

    use_edit_strength: bool
    """ The brush affects the color strength of the point (default False)"""

    use_edit_thickness: bool
    """ The brush affects the thickness of the point (default False)"""

    use_edit_uv: bool
    """ The brush affects the UV rotation of the point (default False)"""

    use_fill_limit: bool
    """ Fill only visible areas in viewport (default True)"""

    use_jitter_pressure: bool
    """ Use tablet pressure for jitter (default False)"""

    use_keep_caps_eraser: bool
    """ Keep the caps as they are and don't flatten them when erasing (default False)"""

    use_material_pin: bool
    """ Keep material assigned to brush (default False)"""

    use_occlude_eraser: bool
    """ Erase only strokes visible and not occluded (default False)"""

    use_pressure: bool
    """ Use tablet pressure (default False)"""

    use_random_press_hue: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_radius: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_sat: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_strength: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_uv: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_val: bool
    """ Use pressure to modulate randomness (default False)"""

    use_settings_outline: bool
    """ Convert stroke to outline (default False)"""

    use_settings_postprocess: bool
    """ Additional post processing options for new strokes (default False)"""

    use_settings_random: bool
    """ Random brush settings (default False)"""

    use_settings_stabilizer: bool
    """ Draw lines with a delay to allow smooth strokes (press Shift key to override while drawing) (default True)"""

    use_strength_pressure: bool
    """ Use tablet pressure for color strength (default False)"""

    use_stroke_random_hue: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_radius: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_sat: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_strength: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_uv: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_val: bool
    """ Use randomness at stroke level (default False)"""

    use_trim: bool
    """ Trim intersecting stroke ends (default False)"""

    uv_random: float
    """ Random factor for auto-generated UV rotation (in [0, 1], default 0.0)"""

    vertex_color_factor: float
    """ Factor used to mix vertex color to get final color (in [0, 1], default 0.0)"""

    vertex_mode: typing.Literal["STROKE", "FILL", "BOTH"]
    """ Defines how vertex color affect to the strokes (default 'STROKE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BrushTextureSlot(TextureSlot, bpy_struct):
    """Texture slot for textures in a Brush data-block"""

    angle: float
    """ Brush texture rotation (in [0, 6.28319], default 0.0)"""

    has_random_texture_angle: bool
    """ (default False, readonly)"""

    has_texture_angle: bool
    """ (default False, readonly)"""

    has_texture_angle_source: bool
    """ (default False, readonly)"""

    map_mode: typing.Literal[
        "VIEW_PLANE", "AREA_PLANE", "TILED", "3D", "RANDOM", "STENCIL"
    ]
    """ (default 'VIEW_PLANE')"""

    mask_map_mode: typing.Literal["VIEW_PLANE", "TILED", "RANDOM", "STENCIL"]
    """ (default 'VIEW_PLANE')"""

    random_angle: float
    """ Brush texture random angle (in [0, 6.28319], default 6.28319)"""

    use_rake: bool
    """ (default False)"""

    use_random: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class BuildModifier(Modifier, bpy_struct):
    """Build effect modifier"""

    frame_duration: float
    """ Total time the build effect requires (in [1, 1.04857e+06], default 100.0)"""

    frame_start: float
    """ Start frame of the effect (in [-1.04857e+06, 1.04857e+06], default 1.0)"""

    seed: int
    """ Seed for random if used (in [1, 1048574], default 0)"""

    use_random_order: bool
    """ Randomize the faces or edges during build (default False)"""

    use_reverse: bool
    """ Deconstruct the mesh instead of building it (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ByteColorAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores RGBA colors as positive integer values using 8-bits per channel"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ByteColorAttributeValue(bpy_struct):
    """Color value in geometry attribute"""

    color: typing.Any
    """ RGBA color in scene linear color space (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    color_srgb: typing.Any
    """ RGBA color in sRGB color space (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ByteIntAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores 8-bit integers"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ByteIntAttributeValue(bpy_struct):
    """8-bit value in geometry attribute"""

    value: int
    """ (in [-128, 127], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CLIP_UL_tracking_objects(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CURVES_UL_attributes(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CacheFile(ID, bpy_struct):
    active_index: int | None
    """ (in [0, inf], default 0)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    filepath: str
    """ Path to external displacements file (default "", never None, blend relative // prefix supported)"""

    forward_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ (default 'POS_X')"""

    frame: float
    """ The time to use for looking up the data in the cache file, or to determine which file to use in a file sequence (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    frame_offset: float
    """ Subtracted from the current frame to use for looking up the data in the cache file, or to determine which file to use in a file sequence (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    is_sequence: bool
    """ Whether the cache is separated in a series of files (default False)"""

    layers: typing.Any
    """ Layers of the cache (default None, readonly)"""

    object_paths: typing.Any
    """ Paths of the objects inside the Alembic archive (default None, readonly)"""

    override_frame: bool
    """ Whether to use a custom frame for looking up data in the cache file, instead of using the current scene frame (default False)"""

    scale: float
    """ Value by which to enlarge or shrink the object with respect to the world's origin (only applicable through a Transform Cache constraint) (in [0.0001, 1000], default 1.0)"""

    up_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ (default 'POS_X')"""

    velocity_name: str
    """ Name of the Alembic attribute used for generating motion blur data (default "", never None)"""

    velocity_unit: Literal[bpy.stub_internal.rna_enums.VelocityUnitItems]
    """ Define how the velocity vectors are interpreted with regard to time, 'frame' means the delta time is 1 frame, 'second' means the delta time is 1 / FPS (default 'FRAME')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CacheFileLayer(bpy_struct):
    """Layer of the cache, used to load or override data from the first the first layer"""

    filepath: str
    """ Path to the archive (default "", never None, blend relative // prefix supported)"""

    hide_layer: bool
    """ Do not load data from this layer (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CacheObjectPath(bpy_struct):
    """Path of an object inside of an Alembic archive"""

    path: str
    """ Object path (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Camera(ID, bpy_struct):
    """Camera data-block for storing camera settings"""

    angle: float
    """ Camera lens field of view (in [0.00640536, 3.01675], default 0.69115)"""

    angle_x: float
    """ Camera lens horizontal field of view (in [0.00640536, 3.01675], default 0.0)"""

    angle_y: float
    """ Camera lens vertical field of view (in [0.00640536, 3.01675], default 0.0)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    background_images: typing.Any
    """ List of background images (default None, readonly)"""

    central_cylindrical_radius: float
    """ Radius of the virtual cylinder (in [1e-05, inf], default 1.0)"""

    central_cylindrical_range_u_max: float
    """ Maximum Longitude value for the central cylindrical lens (in [-inf, inf], default 3.14159)"""

    central_cylindrical_range_u_min: float
    """ Minimum Longitude value for the central cylindrical lens (in [-inf, inf], default -3.14159)"""

    central_cylindrical_range_v_max: float
    """ Maximum Height value for the central cylindrical lens (in [-inf, inf], default 1.0)"""

    central_cylindrical_range_v_min: float
    """ Minimum Height value for the central cylindrical lens (in [-inf, inf], default -1.0)"""

    clip_end: float
    """ Camera far clipping distance (in [1e-06, inf], default 1000.0)"""

    clip_start: float
    """ Camera near clipping distance (in [1e-06, inf], default 0.1)"""

    composition_guide_color: typing.Any
    """ Color and alpha for compositional guide overlays (array of 4 items, in [0, inf], default (0.5, 0.5, 0.5, 1.0))"""

    custom_bytecode: str
    """ Compiled bytecode of the custom shader (default "", never None)"""

    custom_bytecode_hash: str
    """ Hash of the compiled bytecode of the custom shader, for quick equality checking (default "", never None)"""

    custom_filepath: str
    """ Path to the shader defining the custom camera (default "", never None)"""

    custom_mode: typing.Literal["INTERNAL", "EXTERNAL"]
    """ (default 'INTERNAL')"""

    custom_shader: Text | None
    """ Shader defining the custom camera"""

    cycles_custom: typing.Any
    """ Parameters for custom (OSL-based) cameras (readonly)"""

    display_size: float
    """ Apparent size of the Camera object in the 3D View (in [0.01, 1000], default 1.0)"""

    dof: CameraDOFSettings | None
    """ (readonly)"""

    fisheye_fov: float
    """ Field of view for the fisheye lens (in [0.1745, 31.4159], default 3.14159)"""

    fisheye_lens: float
    """ Lens focal length (mm) (in [0.01, 100], default 10.5)"""

    fisheye_polynomial_k0: float
    """ Coefficient K0 of the lens polynomial (in [-inf, inf], default -1.17351e-05)"""

    fisheye_polynomial_k1: float
    """ Coefficient K1 of the lens polynomial (in [-inf, inf], default -0.0199887)"""

    fisheye_polynomial_k2: float
    """ Coefficient K2 of the lens polynomial (in [-inf, inf], default -3.3525e-06)"""

    fisheye_polynomial_k3: float
    """ Coefficient K3 of the lens polynomial (in [-inf, inf], default 3.0993e-06)"""

    fisheye_polynomial_k4: float
    """ Coefficient K4 of the lens polynomial (in [-inf, inf], default -2.61e-08)"""

    latitude_max: float
    """ Maximum latitude (vertical angle) for the equirectangular lens (in [-1.5708, 1.5708], default 1.5708)"""

    latitude_min: float
    """ Minimum latitude (vertical angle) for the equirectangular lens (in [-1.5708, 1.5708], default -1.5708)"""

    lens: float
    """ Perspective Camera focal length value in millimeters (in [1, inf], default 50.0)"""

    lens_unit: typing.Literal["MILLIMETERS", "FOV"]
    """ Unit to edit lens in for the user interface (default 'MILLIMETERS')"""

    longitude_max: float
    """ Maximum longitude (horizontal angle) for the equirectangular lens (in [-inf, inf], default 3.14159)"""

    longitude_min: float
    """ Minimum longitude (horizontal angle) for the equirectangular lens (in [-inf, inf], default -3.14159)"""

    ortho_scale: float
    """ Orthographic Camera scale (similar to zoom) (in [0, inf], default 6.0)"""

    panorama_type: typing.Literal[
        "EQUIRECTANGULAR",
        "EQUIANGULAR_CUBEMAP_FACE",
        "MIRRORBALL",
        "FISHEYE_EQUIDISTANT",
        "FISHEYE_EQUISOLID",
        "FISHEYE_LENS_POLYNOMIAL",
        "CENTRAL_CYLINDRICAL",
    ]
    """ Distortion to use for the calculation (default 'FISHEYE_EQUISOLID')"""

    passepartout_alpha: float
    """ Opacity (alpha) of the darkened overlay in Camera view (in [0, 1], default 0.5)"""

    sensor_fit: typing.Literal["AUTO", "HORIZONTAL", "VERTICAL"]
    """ Method to fit image and field of view angle inside the sensor (default 'AUTO')"""

    sensor_height: float
    """ Vertical size of the image sensor area in millimeters (in [1, inf], default 24.0)"""

    sensor_width: float
    """ Horizontal size of the image sensor area in millimeters (in [1, inf], default 36.0)"""

    shift_x: float
    """ Camera horizontal shift (in [-inf, inf], default 0.0)"""

    shift_y: float
    """ Camera vertical shift (in [-inf, inf], default 0.0)"""

    show_background_images: bool
    """ Display reference images behind objects in the 3D View (default False)"""

    show_composition_center: bool
    """ Display center composition guide inside the camera view (default False)"""

    show_composition_center_diagonal: bool
    """ Display diagonal center composition guide inside the camera view (default False)"""

    show_composition_golden: bool
    """ Display golden ratio composition guide inside the camera view (default False)"""

    show_composition_golden_tria_a: bool
    """ Display golden triangle A composition guide inside the camera view (default False)"""

    show_composition_golden_tria_b: bool
    """ Display golden triangle B composition guide inside the camera view (default False)"""

    show_composition_harmony_tri_a: bool
    """ Display harmony A composition guide inside the camera view (default False)"""

    show_composition_harmony_tri_b: bool
    """ Display harmony B composition guide inside the camera view (default False)"""

    show_composition_thirds: bool
    """ Display rule of thirds composition guide inside the camera view (default False)"""

    show_limits: bool
    """ Display the clipping range and focus point on the camera (default False)"""

    show_mist: bool
    """ Display a line from the Camera to indicate the mist area (default False)"""

    show_name: bool
    """ Show the active Camera's name in Camera view (default False)"""

    show_passepartout: bool
    """ Show a darkened overlay outside the image area in Camera view (default True)"""

    show_safe_areas: bool
    """ Show TV title safe and action safe areas in Camera view (default False)"""

    show_safe_center: bool
    """ Show safe areas to fit content in a different aspect ratio (default False)"""

    show_sensor: bool
    """ Show sensor size (film gate) in Camera view (default False)"""

    stereo: CameraStereoData | None
    """ (readonly, never None)"""

    type: typing.Literal["PERSP", "ORTHO", "PANO", "CUSTOM"]
    """ Camera types (default 'PERSP')"""

    def view_frame(
        self, *, scene: Scene | None = None
    ) -> tuple[mathutils.Vector, mathutils.Vector, mathutils.Vector, mathutils.Vector]:
        """Return 4 points for the cameras frame (before object transformation)

                :param scene: Scene to use for aspect calculation, when omitted 1:1 aspect is used (optional)
                :return: result_1, Result, `mathutils.Vector`

        result_2, Result, `mathutils.Vector`

        result_3, Result, `mathutils.Vector`

        result_4, Result, `mathutils.Vector`
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CameraBackgroundImage(bpy_struct):
    """Image and settings for display in the 3D View background"""

    alpha: float
    """ Image opacity to blend the image against the background color (in [0, 1], default 0.0)"""

    clip: MovieClip | None
    """ Movie clip displayed and edited in this space"""

    clip_user: MovieClipUser | None
    """ Parameters defining which frame of the movie clip is displayed (readonly, never None)"""

    display_depth: typing.Literal["BACK", "FRONT"]
    """ Display under or over everything (default 'BACK')"""

    frame_method: typing.Literal["STRETCH", "FIT", "CROP"]
    """ How the image fits in the camera frame (default 'FIT')"""

    image: Image | None
    """ Image displayed and edited in this space"""

    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly, never None)"""

    is_override_data: bool
    """ In a local override camera, whether this background image comes from the linked reference camera, or is local to the override (default True, readonly)"""

    offset: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    rotation: float
    """ Rotation for the background image (ortho view only) (in [-inf, inf], default 0.0)"""

    scale: float
    """ Scale the background image (in [0, inf], default 0.0)"""

    show_background_image: bool
    """ Show this image as background (default True)"""

    show_expanded: bool
    """ Show the details in the user interface (default False)"""

    show_on_foreground: bool
    """ Show this image in front of objects in viewport (default False)"""

    source: typing.Literal["IMAGE", "MOVIE_CLIP"]
    """ Data source used for background (default 'IMAGE')"""

    use_camera_clip: bool
    """ Use movie clip from active scene camera (default False)"""

    use_flip_x: bool
    """ Flip the background image horizontally (default False)"""

    use_flip_y: bool
    """ Flip the background image vertically (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CameraDOFSettings(bpy_struct):
    """Depth of Field settings"""

    aperture_blades: int
    """ Number of blades in aperture for polygonal bokeh (at least 3) (in [0, 16], default 0)"""

    aperture_fstop: float
    """ F-Stop ratio (lower numbers give more defocus, higher numbers give a sharper image) (in [0, inf], default 2.8)"""

    aperture_ratio: float
    """ Distortion to simulate anamorphic lens bokeh (in [0.01, inf], default 1.0)"""

    aperture_rotation: float
    """ Rotation of blades in aperture (in [-3.14159, 3.14159], default 0.0)"""

    focus_distance: float
    """ Distance to the focus point for depth of field (in [0, inf], default 10.0)"""

    focus_object: Object | None
    """ Use this object to define the depth of field focal point"""

    focus_subtarget: str
    """ Use this armature bone to define the depth of field focal point (default "", never None)"""

    use_dof: bool
    """ Use Depth of Field (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CameraSolverConstraint(Constraint, bpy_struct):
    """Lock motion to the reconstructed camera movement"""

    clip: MovieClip | None
    """ Movie Clip to get tracking data from"""

    use_active_clip: bool
    """ Use active clip defined in scene (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CameraStereoData(bpy_struct):
    """Stereoscopy settings for a Camera data-block"""

    convergence_distance: float
    """ The converge point for the stereo cameras (often the distance between a projector and the projection screen) (in [1e-05, inf], default 1.95)"""

    convergence_mode: typing.Literal["OFFAXIS", "PARALLEL", "TOE"]
    """ (default 'OFFAXIS')"""

    interocular_distance: float
    """ Set the distance between the eyes - the stereo plane distance / 30 should be fine (in [0, inf], default 0.065)"""

    pivot: typing.Literal["LEFT", "RIGHT", "CENTER"]
    """ (default 'LEFT')"""

    pole_merge_angle_from: float
    """ Angle at which interocular distance starts to fade to 0 (in [0, 1.5708], default 1.0472)"""

    pole_merge_angle_to: float
    """ Angle at which interocular distance is 0 (in [0, 1.5708], default 1.309)"""

    use_pole_merge: bool
    """ Fade interocular distance to 0 after the given cutoff angle (default False)"""

    use_spherical_stereo: bool
    """ Render every pixel rotating the camera around the middle of the interocular distance (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CastModifier(Modifier, bpy_struct):
    """Modifier to cast to other shapes"""

    cast_type: typing.Literal["SPHERE", "CYLINDER", "CUBOID"]
    """ Target object shape (default 'SPHERE')"""

    factor: float
    """ (in [-inf, inf], default 0.5)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object: Object | None
    """ Control object: if available, its location determines the center of the effect"""

    radius: float
    """ Only deform vertices within this distance from the center of the effect (leave as 0 for infinite.) (in [0, inf], default 0.0)"""

    size: float
    """ Size of projection shape (leave as 0 for auto) (in [0, inf], default 0.0)"""

    use_radius_as_size: bool
    """ Use radius as size of projection shape (0 = auto) (default True)"""

    use_transform: bool
    """ Use object transform to control projection shape (default False)"""

    use_x: bool
    """ (default True)"""

    use_y: bool
    """ (default True)"""

    use_z: bool
    """ (default True)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ChildOfConstraint(Constraint, bpy_struct):
    """Create constraint-based parent-child relationship"""

    inverse_matrix: mathutils.Matrix
    """ Transformation matrix to apply before (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    set_inverse_pending: bool
    """ Set to true to request recalculation of the inverse matrix (default False)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_location_x: bool
    """ Use X Location of Parent (default False)"""

    use_location_y: bool
    """ Use Y Location of Parent (default False)"""

    use_location_z: bool
    """ Use Z Location of Parent (default False)"""

    use_rotation_x: bool
    """ Use X Rotation of Parent (default False)"""

    use_rotation_y: bool
    """ Use Y Rotation of Parent (default False)"""

    use_rotation_z: bool
    """ Use Z Rotation of Parent (default False)"""

    use_scale_x: bool
    """ Use X Scale of Parent (default False)"""

    use_scale_y: bool
    """ Use Y Scale of Parent (default False)"""

    use_scale_z: bool
    """ Use Z Scale of Parent (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ChildParticle(bpy_struct):
    """Child particle interpolated from simulated or edited particles"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ClampToConstraint(Constraint, bpy_struct):
    """Constrain an objects location to the nearest point along the target path"""

    main_axis: typing.Literal["CLAMPTO_AUTO", "CLAMPTO_X", "CLAMPTO_Y", "CLAMPTO_Z"]
    """ Main axis of movement (default 'CLAMPTO_AUTO')"""

    target: Object | None
    """ Target Object (Curves only)"""

    use_cyclic: bool
    """ Treat curve as cyclic curve (no clamping to curve bounding box) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ClothCollisionSettings(bpy_struct):
    """Cloth simulation settings for self collision and collision with other objects"""

    collection: Collection | None
    """ Limit colliders to this Collection"""

    collision_quality: int
    """ How many collision iterations should be done (higher is better quality but slower) (in [1, 32767], default 2)"""

    damping: float
    """ Amount of velocity lost on collision (in [0, 1], default 1.0)"""

    distance_min: float
    """ Minimum distance between collision objects before collision response takes effect (in [0.001, 1], default 0.015)"""

    friction: float
    """ Friction force if a collision happened (higher = less movement) (in [0, 80], default 5.0)"""

    impulse_clamp: float
    """ Clamp collision impulses to avoid instability (0.0 to disable clamping) (in [0, 100], default 0.0)"""

    self_distance_min: float
    """ Minimum distance between cloth faces before collision response takes effect (in [0.001, 0.1], default 0.015)"""

    self_friction: float
    """ Friction with self contact (in [0, 80], default 5.0)"""

    self_impulse_clamp: float
    """ Clamp collision impulses to avoid instability (0.0 to disable clamping) (in [0, 100], default 0.0)"""

    use_collision: bool
    """ Enable collisions with other objects (default True)"""

    use_self_collision: bool
    """ Enable self collisions (default False)"""

    vertex_group_object_collisions: str
    """ Triangles with all vertices in this group are not used during object collisions (default "", never None)"""

    vertex_group_self_collisions: str
    """ Triangles with all vertices in this group are not used during self collisions (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ClothModifier(Modifier, bpy_struct):
    """Cloth simulation modifier"""

    collision_settings: ClothCollisionSettings | None
    """ (readonly, never None)"""

    hair_grid_max: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    hair_grid_min: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    hair_grid_resolution: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0, 0, 0), readonly)"""

    point_cache: PointCache | None
    """ (readonly, never None)"""

    settings: ClothSettings | None
    """ (readonly, never None)"""

    solver_result: ClothSolverResult | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ClothSettings(bpy_struct):
    """Cloth simulation settings for an object"""

    air_damping: float
    """ Air has normally some thickness which slows falling things down (in [0, 10], default 1.0)"""

    bending_damping: float
    """ Amount of damping in bending behavior (in [0, 1000], default 0.5)"""

    bending_model: typing.Literal["ANGULAR", "LINEAR"]
    """ Physical model for simulating bending forces (default 'ANGULAR')"""

    bending_stiffness: float
    """ How much the material resists bending (in [0, 10000], default 0.5)"""

    bending_stiffness_max: float
    """ Maximum bending stiffness value (in [0, 10000], default 0.5)"""

    collider_friction: float
    """ (in [0, 1], default 0.0)"""

    compression_damping: float
    """ Amount of damping in compression behavior (in [0, 50], default 5.0)"""

    compression_stiffness: float
    """ How much the material resists compression (in [0, 10000], default 15.0)"""

    compression_stiffness_max: float
    """ Maximum compression stiffness value (in [0, 10000], default 15.0)"""

    density_strength: float
    """ Influence of target density on the simulation (in [0, 1], default 0.0)"""

    density_target: float
    """ Maximum density of hair (in [0, 10000], default 0.0)"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    fluid_density: float
    """ Density (kg/l) of the fluid contained inside the object, used to create a hydrostatic pressure gradient simulating the weight of the internal fluid, or buoyancy from the surrounding fluid if negative (in [-inf, inf], default 0.0)"""

    goal_default: float
    """ Default Goal (vertex target position) value, when no Vertex Group used (in [0, 1], default 0.0)"""

    goal_friction: float
    """ Goal (vertex target position) friction (in [0, 50], default 0.0)"""

    goal_max: float
    """ Goal maximum, vertex group weights are scaled to match this range (in [0, 1], default 1.0)"""

    goal_min: float
    """ Goal minimum, vertex group weights are scaled to match this range (in [0, 1], default 0.0)"""

    goal_spring: float
    """ Goal (vertex target position) spring stiffness (in [0, 0.999], default 1.0)"""

    gravity: mathutils.Vector
    """ Gravity or external force vector (array of 3 items, in [-100, 100], default (0.0, 0.0, -9.81))"""

    internal_compression_stiffness: float
    """ How much the material resists compression (in [0, 10000], default 15.0)"""

    internal_compression_stiffness_max: float
    """ Maximum compression stiffness value (in [0, 10000], default 15.0)"""

    internal_friction: float
    """ (in [0, 1], default 0.0)"""

    internal_spring_max_diversion: float
    """ How much the rays used to connect the internal points can diverge from the vertex normal (in [0, 0.785398], default 0.785398)"""

    internal_spring_max_length: float
    """ The maximum length an internal spring can have during creation. If the distance between internal points is greater than this, no internal spring will be created between these points. A length of zero means that there is no length limit. (in [0, 1000], default 0.0)"""

    internal_spring_normal_check: bool
    """ Require the points the internal springs connect to have opposite normal directions (default True)"""

    internal_tension_stiffness: float
    """ How much the material resists stretching (in [0, 10000], default 15.0)"""

    internal_tension_stiffness_max: float
    """ Maximum tension stiffness value (in [0, 10000], default 15.0)"""

    mass: float
    """ The mass of each vertex on the cloth material (in [0, inf], default 0.3)"""

    pin_stiffness: float
    """ Pin (vertex target position) spring stiffness (in [0, 50], default 1.0)"""

    pressure_factor: float
    """ Ambient pressure (kPa) that balances out between the inside and outside of the object when it has the target volume (in [0, 10000], default 1.0)"""

    quality: int
    """ Quality of the simulation in steps per frame (higher is better quality but slower) (in [1, inf], default 5)"""

    rest_shape_key: ShapeKey | None
    """ Shape key to use the rest spring lengths from"""

    sewing_force_max: float
    """ Maximum sewing force (in [0, 10000], default 0.0)"""

    shear_damping: float
    """ Amount of damping in shearing behavior (in [0, 50], default 5.0)"""

    shear_stiffness: float
    """ How much the material resists shearing (in [0, 10000], default 5.0)"""

    shear_stiffness_max: float
    """ Maximum shear scaling value (in [0, 10000], default 5.0)"""

    shrink_max: float
    """ Max amount to shrink cloth by (in [-inf, 1], default 0.0)"""

    shrink_min: float
    """ Factor by which to shrink cloth (in [-inf, 1], default 0.0)"""

    target_volume: float
    """ The mesh volume where the inner/outer pressure will be the same. If set to zero the change in volume will not affect pressure. (in [0, 10000], default 0.0)"""

    tension_damping: float
    """ Amount of damping in stretching behavior (in [0, 50], default 5.0)"""

    tension_stiffness: float
    """ How much the material resists stretching (in [0, 10000], default 15.0)"""

    tension_stiffness_max: float
    """ Maximum tension stiffness value (in [0, 10000], default 15.0)"""

    time_scale: float
    """ Cloth speed is multiplied by this value (in [0, inf], default 1.0)"""

    uniform_pressure_force: float
    """ The uniform pressure that is constantly applied to the mesh, in units of Pressure Scale. Can be negative. (in [-10000, 10000], default 0.0)"""

    use_dynamic_mesh: bool
    """ Make simulation respect deformations in the base mesh (default False)"""

    use_internal_springs: bool
    """ Simulate an internal volume structure by creating springs connecting the opposite sides of the mesh (default False)"""

    use_pressure: bool
    """ Simulate pressure inside a closed cloth mesh (default False)"""

    use_pressure_volume: bool
    """ Use the Target Volume parameter as the initial volume, instead of calculating it from the mesh itself (default False)"""

    use_sewing_springs: bool
    """ Pulls loose edges together (default False)"""

    vertex_group_bending: str
    """ Vertex group for fine control over bending stiffness (default "", never None)"""

    vertex_group_intern: str
    """ Vertex group for fine control over the internal spring stiffness (default "", never None)"""

    vertex_group_mass: str
    """ Vertex Group for pinning of vertices (default "", never None)"""

    vertex_group_pressure: str
    """ Vertex Group for where to apply pressure. Zero weight means no pressure while a weight of one means full pressure. Faces with a vertex that has zero weight will be excluded from the volume calculation. (default "", never None)"""

    vertex_group_shear_stiffness: str
    """ Vertex group for fine control over shear stiffness (default "", never None)"""

    vertex_group_shrink: str
    """ Vertex Group for shrinking cloth (default "", never None)"""

    vertex_group_structural_stiffness: str
    """ Vertex group for fine control over structural stiffness (default "", never None)"""

    voxel_cell_size: float
    """ Size of the voxel grid cells for interaction effects (in [0.0001, 10000], default 0.1)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ClothSolverResult(bpy_struct):
    """Result of cloth solver iteration"""

    avg_error: float
    """ Average error during substeps (in [-inf, inf], default 0.0, readonly)"""

    avg_iterations: float
    """ Average iterations during substeps (in [-inf, inf], default 0.0, readonly)"""

    max_error: float
    """ Maximum error during substeps (in [-inf, inf], default 0.0, readonly)"""

    max_iterations: int
    """ Maximum iterations during substeps (in [-inf, inf], default 0, readonly)"""

    min_error: float
    """ Minimum error during substeps (in [-inf, inf], default 0.0, readonly)"""

    min_iterations: int
    """ Minimum iterations during substeps (in [-inf, inf], default 0, readonly)"""

    status: set[
        typing.Literal["SUCCESS", "NUMERICAL_ISSUE", "NO_CONVERGENCE", "INVALID_INPUT"]
    ]
    """ Status of the solver iteration (default set(), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CloudsTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    cloud_type: typing.Literal["GRAYSCALE", "COLOR"]
    """ Determine whether Noise returns grayscale or RGB values (default 'GRAYSCALE')"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_depth: int
    """ Depth of the cloud calculation (in [0, 30], default 2)"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    noise_type: typing.Literal["SOFT_NOISE", "HARD_NOISE"]
    """ (default 'SOFT_NOISE')"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Collection(ID, bpy_struct):
    """Collection of Object data-blocks"""

    active_exporter_index: int | None
    """ Active index in the exporters list (in [0, inf], default 0)"""

    all_objects: typing.Any
    """ Objects that are in this collection and its child collections (default None, readonly)"""

    children: typing.Any
    """ Collections that are immediate children of this collection (default None, readonly)"""

    collection_children: typing.Any
    """ Children collections with their parent-collection-specific settings (default None, readonly)"""

    collection_objects: typing.Any
    """ Objects of the collection with their parent-collection-specific settings (default None, readonly)"""

    color_tag: Literal[bpy.stub_internal.rna_enums.CollectionColorItems]
    """ Color tag for a collection (default 'COLOR_01')"""

    exporters: typing.Any
    """ Export Handlers configured for the collection (default None, readonly)"""

    hide_render: bool
    """ Globally disable in renders (default False)"""

    hide_select: bool
    """ Disable selection in viewport (default False)"""

    hide_viewport: bool
    """ Globally disable in viewports (default False)"""

    instance_offset: mathutils.Vector
    """ Offset from the origin to use when instancing (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    lineart_intersection_mask: typing.Any
    """ Intersection generated by this collection will have this mask value (array of 8 items, default (False, False, False, False, False, False, False, False))"""

    lineart_intersection_priority: int
    """ The intersection line will be included into the object with the higher intersection priority value (in [0, 255], default 0)"""

    lineart_usage: typing.Literal[
        "INCLUDE",
        "OCCLUSION_ONLY",
        "EXCLUDE",
        "INTERSECTION_ONLY",
        "NO_INTERSECTION",
        "FORCE_INTERSECTION",
    ]
    """ How to use this collection in Line Art calculation (default 'INCLUDE')"""

    lineart_use_intersection_mask: bool
    """ Use custom intersection mask for faces in this collection (default False)"""

    objects: typing.Any
    """ Objects that are directly in this collection (default None, readonly)"""

    use_lineart_intersection_priority: bool
    """ Assign intersection priority value for this collection (default False)"""

    children_recursive: list[Collection]
    """ A list of all children from this collection.(readonly)"""

    users_dupli_group: tuple[Object, ...]
    """ The collection instance objects this collection is used in(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionChild(bpy_struct):
    """Child collection with its collection related settings"""

    light_linking: CollectionLightLinking | None
    """ Light linking settings of the collection object (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionExport(bpy_struct):
    export_properties: PropertyGroup | None
    """ Properties associated with the configured exporter (readonly)"""

    filepath: str
    """ The file path used for exporting (default "", never None, blend relative // prefix supported)"""

    is_open: bool
    """ Whether the panel is expanded or closed (default False)"""

    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionLightLinking(bpy_struct):
    """Light linking settings of objects and children collections of a collection"""

    link_state: typing.Literal["INCLUDE", "EXCLUDE"]
    """ Light or shadow receiving state of the object or collection (default 'INCLUDE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionObject(bpy_struct):
    """Object of a collection with its collection related settings"""

    light_linking: CollectionLightLinking | None
    """ Light linking settings of the collection (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollectionProperty(Property, bpy_struct):
    """RNA collection property to define lists, arrays and mappings"""

    fixed_type: Struct | None
    """ Fixed pointer type, empty if variable type (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollisionModifier(Modifier, bpy_struct):
    """Collision modifier defining modifier stack position used for collision"""

    settings: CollisionSettings | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CollisionSettings(bpy_struct):
    """Collision settings for object in physics simulation"""

    absorption: float
    """ How much of effector force gets lost during collision with this object (in percent) (in [0, 1], default 0.0)"""

    cloth_friction: float
    """ Friction for cloth collisions (in [0, 80], default 0.0)"""

    damping: float
    """ Amount of damping during collision (in [0, 1], default 0.0)"""

    damping_factor: float
    """ Amount of damping during particle collision (in [0, 1], default 0.0)"""

    damping_random: float
    """ Random variation of damping (in [0, 1], default 0.0)"""

    friction_factor: float
    """ Amount of friction during particle collision (in [0, 1], default 0.0)"""

    friction_random: float
    """ Random variation of friction (in [0, 1], default 0.0)"""

    permeability: float
    """ Chance that the particle will pass through the mesh (in [0, 1], default 0.0)"""

    stickiness: float
    """ Amount of stickiness to surface collision (in [0, 10], default 0.0)"""

    thickness_inner: float
    """ Inner face thickness (only used by softbodies) (in [0.001, 1], default 0.0)"""

    thickness_outer: float
    """ Outer face thickness (in [0.001, 1], default 0.0)"""

    use: bool
    """ Enable this object as a collider for physics systems (default False)"""

    use_culling: bool
    """ Cloth collision acts with respect to the collider normals (improves penetration recovery) (default False)"""

    use_normal: bool
    """ Cloth collision impulses act in the direction of the collider normals (more reliable in some cases) (default False)"""

    use_particle_kill: bool
    """ Kill collided particles (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorBalanceModifier(StripModifier, bpy_struct):
    """Color balance modifier for sequence strip"""

    color_balance: StripColorBalanceData | None
    """ (readonly)"""

    color_multiply: float
    """ Multiply the intensity of each pixel (in [0, 20], default 1.0)"""

    open_mask_input_panel: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorManagedDisplaySettings(bpy_struct):
    """Color management specific to display device"""

    display_device: typing.Literal["NONE"]
    """ Display name. For viewing, this is the display device that will be emulated by limiting the gamut and HDR colors. For image and video output, this is the display space used for writing. (default 'NONE')"""

    emulation: typing.Literal["OFF", "AUTO"]
    """ Control how images in the chosen display are mapped to the physical display (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorManagedInputColorspaceSettings(bpy_struct):
    """Input color space settings"""

    is_data: bool
    """ Treat image as non-color data without color management, like normal or displacement maps (default False)"""

    name: Literal[bpy.stub_internal.rna_enums.ColorSpaceConvertDefaultItems]
    """ Color space in the image file, to convert to and from when saving and loading the image (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorManagedSequencerColorspaceSettings(bpy_struct):
    """Input color space settings"""

    name: Literal[bpy.stub_internal.rna_enums.ColorSpaceConvertDefaultItems]
    """ Color space that the sequencer operates in (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorManagedViewSettings(bpy_struct):
    """Color management settings used for displaying images on the display"""

    curve_mapping: CurveMapping | None
    """ Color curve mapping applied before display transform (readonly)"""

    exposure: float
    """ Exposure (stops) applied before display transform, multiplying by 2^exposure (in [-32, 32], default 0.0)"""

    gamma: float
    """ Additional gamma encoding after display transform, for output with custom gamma (in [0, 5], default 1.0)"""

    is_hdr: bool
    """ The display and view transform supports high dynamic range colors (default False, readonly)"""

    look: typing.Literal["NONE"]
    """ Additional transform applied before view transform for artistic needs (default 'NONE')"""

    support_emulation: bool
    """ The display and view transform supports automatic emulation for another display device, using the display color spaces mechanism in OpenColorIO v2 configurations (default False, readonly)"""

    use_curve_mapping: bool
    """ Use RGB curved for pre-display transformation (default False)"""

    use_white_balance: bool
    """ Perform chromatic adaption from a different white point (default False)"""

    view_transform: typing.Literal["NONE"]
    """ View used when converting image to a display space (default 'NONE')"""

    white_balance_temperature: float
    """ Color temperature of the scene's white point (in [1800, 100000], default 6500.0)"""

    white_balance_tint: float
    """ Color tint of the scene's white point (the default of 10 matches daylight) (in [-500, 500], default 10.0)"""

    white_balance_whitepoint: mathutils.Color
    """ The color which gets mapped to white (automatically converted to/from temperature and tint) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorMapping(bpy_struct):
    """Color mapping settings"""

    blend_color: mathutils.Color
    """ Blend color to mix with texture output color (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    blend_factor: float
    """ (in [-inf, inf], default 0.0)"""

    blend_type: typing.Literal[
        "MIX",
        "DARKEN",
        "MULTIPLY",
        "LIGHTEN",
        "SCREEN",
        "ADD",
        "OVERLAY",
        "SOFT_LIGHT",
        "LINEAR_LIGHT",
        "DIFFERENCE",
        "SUBTRACT",
        "DIVIDE",
        "HUE",
        "SATURATION",
        "COLOR",
        "VALUE",
    ]
    """ Mode used to mix with texture output color (default 'MIX')"""

    brightness: float
    """ Adjust the brightness of the texture (in [0, 2], default 0.0)"""

    color_ramp: ColorRamp | None
    """ (readonly)"""

    contrast: float
    """ Adjust the contrast of the texture (in [0, 5], default 0.0)"""

    saturation: float
    """ Adjust the saturation of colors in the texture (in [0, 2], default 0.0)"""

    use_color_ramp: bool
    """ Toggle color ramp operations (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorMixStrip(EffectStrip, Strip, bpy_struct):
    """Color Mix Strip"""

    blend_effect: typing.Literal[
        "DARKEN",
        "MULTIPLY",
        "BURN",
        "LINEAR_BURN",
        "LIGHTEN",
        "SCREEN",
        "DODGE",
        "ADD",
        "OVERLAY",
        "SOFT_LIGHT",
        "HARD_LIGHT",
        "VIVID_LIGHT",
        "LINEAR_LIGHT",
        "PIN_LIGHT",
        "DIFFERENCE",
        "EXCLUSION",
        "SUBTRACT",
        "HUE",
        "SATURATION",
        "COLOR",
        "VALUE",
    ]
    """ Method for controlling how the strip combines with other strips (default 'DARKEN')"""

    factor: float
    """ Percentage of how much the strip's colors affect other strips (in [0, 1], default 0.0)"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorRamp(bpy_struct):
    """Color ramp mapping a scalar value to a color"""

    color_mode: typing.Literal["RGB", "HSV", "HSL"]
    """ Set color mode to use for interpolation (default 'RGB')"""

    elements: typing.Any
    """ (default None, readonly)"""

    hue_interpolation: typing.Literal["NEAR", "FAR", "CW", "CCW"]
    """ Set color interpolation (default 'NEAR')"""

    interpolation: typing.Literal["EASE", "CARDINAL", "LINEAR", "B_SPLINE", "CONSTANT"]
    """ Set interpolation between color stops (default 'LINEAR')"""

    def evaluate(self, position: float | None) -> None:
        """Evaluate Color Ramp

        :param position: Position, Evaluate Color Ramp at position (in [0, 1])
        :return: Color, Color at given position (array of 4 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorRampElement(bpy_struct):
    """Element defining a color at a position in the color ramp"""

    alpha: float
    """ Set alpha of selected color stop (in [0, inf], default 0.0)"""

    color: typing.Any
    """ Set color of selected color stop (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    position: float
    """ Set position of selected color stop (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ColorStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip creating an image filled with a single color"""

    color: mathutils.Color
    """ Effect Strip color (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNode(NodeInternal, Node, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeAlphaOver(CompositorNode, NodeInternal, Node, bpy_struct):
    """Overlay a foreground image onto a background image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeAntiAliasing(CompositorNode, NodeInternal, Node, bpy_struct):
    """Smooth away jagged edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBilateralblur(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adaptively blur image, while retaining sharp edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBlur(CompositorNode, NodeInternal, Node, bpy_struct):
    """Blur an image, using several blur modes"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBokehBlur(CompositorNode, NodeInternal, Node, bpy_struct):
    """Generate a bokeh type blur similar to Defocus. Unlike defocus an in-focus region is defined in the compositor"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBokehImage(CompositorNode, NodeInternal, Node, bpy_struct):
    """Generate image with bokeh shape for use with the Bokeh Blur filter node"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBoxMask(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create rectangular mask suitable for use as a simple matte"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeBrightContrast(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adjust brightness and contrast"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeChannelMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create matte based on differences in color channels"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeChromaMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create matte based on chroma values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeColorBalance(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adjust color and values"""

    input_whitepoint: mathutils.Color
    """ The color which gets mapped to white (automatically converted to/from temperature and tint) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    output_whitepoint: mathutils.Color
    """ The color which gets white gets mapped to (automatically converted to/from temperature and tint) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeColorCorrection(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adjust the color of an image, separately in several tonal ranges (highlights, midtones and shadows)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeColorMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create matte using a given color, for green or blue screen footage"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeColorSpill(CompositorNode, NodeInternal, Node, bpy_struct):
    """Remove colors from a blue or green screen, by reducing one RGB channel compared to the others"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCombineColor(CompositorNode, NodeInternal, Node, bpy_struct):
    """Combine an image from its composite color channels"""

    mode: typing.Literal["RGB", "HSV", "HSL", "YCC", "YUV"]
    """ Mode of color processing (default 'RGB')"""

    ycc_mode: typing.Literal["ITUBT601", "ITUBT709", "JFIF"]
    """ Color space used for YCbCrA processing (default 'ITUBT601')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeConvertColorSpace(CompositorNode, NodeInternal, Node, bpy_struct):
    """Convert between color spaces"""

    from_color_space: Literal[bpy.stub_internal.rna_enums.ColorSpaceConvertDefaultItems]
    """ Color space of the input image (default 'NONE')"""

    to_color_space: Literal[bpy.stub_internal.rna_enums.ColorSpaceConvertDefaultItems]
    """ Color space of the output image (default 'NONE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeConvertToDisplay(CompositorNode, NodeInternal, Node, bpy_struct):
    """Convert from scene linear to display color space, with a view transform and look for tone mapping"""

    display_settings: ColorManagedDisplaySettings | None
    """ Color management display device settings (readonly)"""

    view_settings: ColorManagedViewSettings | None
    """ Color management view transform settings (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeConvolve(CompositorNode, NodeInternal, Node, bpy_struct):
    """Convolves an image with a kernel"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCornerPin(CompositorNode, NodeInternal, Node, bpy_struct):
    """Plane warp transformation using explicit corner values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCrop(CompositorNode, NodeInternal, Node, bpy_struct):
    """Crops image to a smaller region, either making the cropped area transparent or resizing the image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCryptomatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Deprecated. Use Cryptomatte Node instead"""

    add: mathutils.Color
    """ Add object or material to matte, by picking a color from the Pick output (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    matte_id: str
    """ List of object and material crypto IDs to include in matte (default "", never None)"""

    remove: mathutils.Color
    """ Remove object or material from matte, by picking a color from the Pick output (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCryptomatteV2(CompositorNode, NodeInternal, Node, bpy_struct):
    """Generate matte for individual objects and materials using Cryptomatte render passes"""

    add: mathutils.Color
    """ Add object or material to matte, by picking a color from the Pick output (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    entries: typing.Any
    """ (default None, readonly)"""

    frame_duration: int
    """ Number of images of a movie to use (in [0, 1048574], default 0)"""

    frame_offset: int
    """ Offset the number of the frame to use in the animation (in [-1048574, 1048574], default 0)"""

    frame_start: int
    """ Global starting frame of the movie/sequence, assuming first picture has a #1 (in [-1048574, 1048574], default 0)"""

    has_layers: bool
    """ True if this image has any named layer (default False, readonly)"""

    has_views: bool
    """ True if this image has multiple views (default False, readonly)"""

    image: Image | None
    layer: typing.Literal["PLACEHOLDER"]
    """ (default 'PLACEHOLDER')"""

    layer_name: typing.Literal["CryptoObject", "CryptoMaterial", "CryptoAsset"]
    """ What Cryptomatte layer is used (default 'CryptoObject')"""

    matte_id: str
    """ List of object and material crypto IDs to include in matte (default "", never None)"""

    remove: mathutils.Color
    """ Remove object or material from matte, by picking a color from the Pick output (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    scene: Scene | None
    source: typing.Literal["RENDER", "IMAGE"]
    """ Where the Cryptomatte passes are loaded from (default 'RENDER')"""

    use_auto_refresh: bool
    """ Always refresh image on frame changes (default False)"""

    use_cyclic: bool
    """ Cycle the images in the movie (default False)"""

    view: typing.Literal["ALL"]
    """ (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCurveRGB(CompositorNode, NodeInternal, Node, bpy_struct):
    """Perform level adjustments on each color channel of an image"""

    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeCustomGroup(CompositorNode, NodeInternal, Node, bpy_struct):
    """Custom Compositor Group Node for Python nodes"""

    node_tree: CompositorNodeTree | None

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDBlur(CompositorNode, NodeInternal, Node, bpy_struct):
    """Blur an image along a direction"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDefocus(CompositorNode, NodeInternal, Node, bpy_struct):
    """Apply depth of field in 2D, using a Z depth map or mask"""

    angle: float
    """ Bokeh shape rotation offset (in [0, 1.5708], default 0.0)"""

    blur_max: float
    """ Blur limit, maximum CoC radius (in [0, 10000], default 0.0)"""

    bokeh: typing.Literal[
        "OCTAGON", "HEPTAGON", "HEXAGON", "PENTAGON", "SQUARE", "TRIANGLE", "CIRCLE"
    ]
    """ (default 'CIRCLE')"""

    f_stop: float
    """ Amount of focal blur, 128 (infinity) is perfect focus, half the value doubles the blur radius (in [0, 128], default 0.0)"""

    scene: Scene | None
    """ Scene from which to select the active camera (render scene if undefined)"""

    use_zbuffer: bool
    """ Disable when using an image as input instead of actual z-buffer (auto enabled if node not image based, eg. time node) (default True)"""

    z_scale: float
    """ Scale the Z input when not using a z-buffer, controls maximum blur designated by the color white or input value 1 (in [0, 1000], default 0.0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDenoise(CompositorNode, NodeInternal, Node, bpy_struct):
    """Denoise renders from Cycles and other ray tracing renderers"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDespeckle(CompositorNode, NodeInternal, Node, bpy_struct):
    """Smooth areas of an image in which noise is noticeable, while leaving complex areas untouched"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDiffMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Produce a matte that isolates foreground content by comparing it with a reference background image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDilateErode(CompositorNode, NodeInternal, Node, bpy_struct):
    """Expand and shrink masks"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDisplace(CompositorNode, NodeInternal, Node, bpy_struct):
    """Displace pixel position using an offset vector"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDistanceMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create matte based on 3D distance between colors"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeDoubleEdgeMask(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create a gradient between two masks"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeEllipseMask(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create elliptical mask suitable for use as a simple matte or vignette mask"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeExposure(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adjust brightness using a camera exposure parameter"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeFilter(CompositorNode, NodeInternal, Node, bpy_struct):
    """Apply common image enhancement filters"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeFlip(CompositorNode, NodeInternal, Node, bpy_struct):
    """Flip an image along a defined axis"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeGamma(CompositorNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeGlare(CompositorNode, NodeInternal, Node, bpy_struct):
    """Add lens flares, fog and glows around bright parts of the image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeGroup(CompositorNode, NodeInternal, Node, bpy_struct):
    node_tree: CompositorNodeTree | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeHueCorrect(CompositorNode, NodeInternal, Node, bpy_struct):
    """Adjust hue, saturation, and value with a curve"""

    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeHueSat(CompositorNode, NodeInternal, Node, bpy_struct):
    """Apply a color transformation in the HSV color model"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeIDMask(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create a matte from an object or material index pass"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeImage(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input image or movie file"""

    frame_duration: int
    """ Number of images of a movie to use (in [0, 1048574], default 0)"""

    frame_offset: int
    """ Offset the number of the frame to use in the animation (in [-1048574, 1048574], default 0)"""

    frame_start: int
    """ Global starting frame of the movie/sequence, assuming first picture has a #1 (in [-1048574, 1048574], default 0)"""

    has_layers: bool
    """ True if this image has any named layer (default False, readonly)"""

    has_views: bool
    """ True if this image has multiple views (default False, readonly)"""

    image: Image | None
    layer: typing.Literal["PLACEHOLDER"]
    """ (default 'PLACEHOLDER')"""

    use_auto_refresh: bool
    """ Always refresh image on frame changes (default False)"""

    use_cyclic: bool
    """ Cycle the images in the movie (default False)"""

    view: typing.Literal["ALL"]
    """ (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeImageCoordinates(CompositorNode, NodeInternal, Node, bpy_struct):
    """Returns the coordinates of the pixels of an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeImageInfo(CompositorNode, NodeInternal, Node, bpy_struct):
    """Returns information about an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeInpaint(CompositorNode, NodeInternal, Node, bpy_struct):
    """Extend borders of an image into transparent or masked regions"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeInvert(CompositorNode, NodeInternal, Node, bpy_struct):
    """Invert colors, producing a negative"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeKeying(CompositorNode, NodeInternal, Node, bpy_struct):
    """Perform both chroma keying (to remove the backdrop) and despill (to correct color cast from the backdrop)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeKeyingScreen(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create plates for use as a color reference for keying nodes"""

    clip: MovieClip | None
    tracking_object: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeKuwahara(CompositorNode, NodeInternal, Node, bpy_struct):
    """Apply smoothing filter that preserves edges, for stylized and painterly effects"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeLensdist(CompositorNode, NodeInternal, Node, bpy_struct):
    """Simulate distortion and dispersion from camera lenses"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeLevels(CompositorNode, NodeInternal, Node, bpy_struct):
    """Compute average and standard deviation of pixel values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeLumaMatte(CompositorNode, NodeInternal, Node, bpy_struct):
    """Create a matte based on luminance (brightness) difference"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeMapUV(CompositorNode, NodeInternal, Node, bpy_struct):
    """Map a texture using UV coordinates, to apply a texture to objects in compositing"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeMask(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input mask from a mask data-block, created in the image editor"""

    mask: Mask | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeMaskToSDF(CompositorNode, NodeInternal, Node, bpy_struct):
    """Computes a signed distance field from the given mask"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeMovieClip(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input image or movie from a movie clip data-block, typically used for motion tracking"""

    clip: MovieClip | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeMovieDistortion(CompositorNode, NodeInternal, Node, bpy_struct):
    """Remove lens distortion from footage, using motion tracking camera lens settings"""

    clip: MovieClip | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeNormal(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input normalized normal values to other nodes in the tree"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeNormalize(CompositorNode, NodeInternal, Node, bpy_struct):
    """Map values to 0 to 1 range, based on the minimum and maximum pixel values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeOutputFile(CompositorNode, NodeInternal, Node, bpy_struct):
    """Write image file to disk"""

    active_item_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    directory: str
    """ The directory where the image will be written (default "", never None, blend relative // prefix supported, Supports template expressions)"""

    file_name: str
    """ The base name of the file. Other information might be included in the final file name depending on the node options (default "", never None, Supports template expressions)"""

    file_output_items: typing.Any
    """ (default None, readonly)"""

    format: ImageFormatSettings | None
    """ (readonly)"""

    save_as_render: bool
    """ Apply render part of display transform when saving byte image (default False)"""

    use_file_extension: bool
    """ Add the file format extensions to the saved file name (eg: filename + .jpg) (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodePixelate(CompositorNode, NodeInternal, Node, bpy_struct):
    """Reduce detail in an image by making individual pixels more prominent, for a blocky or mosaic-like appearance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodePlaneTrackDeform(CompositorNode, NodeInternal, Node, bpy_struct):
    """Replace flat planes in footage by another image, detected by plane tracks from motion tracking"""

    clip: MovieClip | None
    plane_track_name: str
    """ (default "", never None)"""

    tracking_object: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodePosterize(CompositorNode, NodeInternal, Node, bpy_struct):
    """Reduce number of colors in an image, converting smooth gradients into sharp transitions"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodePremulKey(CompositorNode, NodeInternal, Node, bpy_struct):
    """Convert to and from premultiplied (associated) alpha"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeRGB(CompositorNode, NodeInternal, Node, bpy_struct):
    """A color picker"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeRGBToBW(CompositorNode, NodeInternal, Node, bpy_struct):
    """Convert RGB input into grayscale using luminance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeRLayers(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input render passes from a scene render"""

    layer: typing.Literal["PLACEHOLDER"]
    """ (default 'PLACEHOLDER')"""

    scene: Scene | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeRelativeToPixel(CompositorNode, NodeInternal, Node, bpy_struct):
    """Converts values that are relative to the image size to be in terms of pixels"""

    data_type: typing.Literal["FLOAT", "VECTOR"]
    """ The type of data (default 'FLOAT')"""

    reference_dimension: typing.Literal[
        "PER_DIMENSION", "X", "Y", "Greater", "Smaller", "Diagonal"
    ]
    """ Defines the dimension of the image that the relative value is in reference to (default 'X')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeRotate(CompositorNode, NodeInternal, Node, bpy_struct):
    """Rotate image by specified angle"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeScale(CompositorNode, NodeInternal, Node, bpy_struct):
    """Change the size of the image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSceneTime(CompositorNode, NodeInternal, Node, bpy_struct):
    """Input the current scene time in seconds or frames"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSeparateColor(CompositorNode, NodeInternal, Node, bpy_struct):
    """Split an image into its composite color channels"""

    mode: typing.Literal["RGB", "HSV", "HSL", "YCC", "YUV"]
    """ Mode of color processing (default 'RGB')"""

    ycc_mode: typing.Literal["ITUBT601", "ITUBT709", "JFIF"]
    """ Color space used for YCbCrA processing (default 'ITUBT601')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSequencerStripInfo(CompositorNode, NodeInternal, Node, bpy_struct):
    """Returns information about the active strip of the modifier"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSetAlpha(CompositorNode, NodeInternal, Node, bpy_struct):
    """Add an alpha channel to an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSplit(CompositorNode, NodeInternal, Node, bpy_struct):
    """Combine two images for side-by-side display. Typically used in combination with a Viewer node"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeStabilize(CompositorNode, NodeInternal, Node, bpy_struct):
    """Stabilize footage using 2D stabilization motion tracking settings"""

    clip: MovieClip | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSwitch(CompositorNode, NodeInternal, Node, bpy_struct):
    """Switch between two images using a checkbox"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeSwitchView(CompositorNode, NodeInternal, Node, bpy_struct):
    """Combine the views (left and right) into a single stereo 3D output"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTime(CompositorNode, NodeInternal, Node, bpy_struct):
    """Generate a factor value (from 0.0 to 1.0) between scene start and end time, using a curve mapping"""

    curve: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTonemap(CompositorNode, NodeInternal, Node, bpy_struct):
    """Map one set of colors to another in order to approximate the appearance of high dynamic range"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTrackPos(CompositorNode, NodeInternal, Node, bpy_struct):
    """Provide information about motion tracking points, such as x and y values"""

    clip: MovieClip | None
    track_name: str
    """ (default "", never None)"""

    tracking_object: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTransform(CompositorNode, NodeInternal, Node, bpy_struct):
    """Scale, translate and rotate an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTranslate(CompositorNode, NodeInternal, Node, bpy_struct):
    """Offset an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeTree(NodeTree, ID, bpy_struct):
    """Node tree consisting of linked nodes used for compositing"""

    use_viewer_border: bool
    """ Unused but kept for compatibility reasons. Use boundaries for viewer nodes and composite backdrop (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeVecBlur(CompositorNode, NodeInternal, Node, bpy_struct):
    """Uses the vector speed render pass to blur the image pixels in 2D"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeViewer(CompositorNode, NodeInternal, Node, bpy_struct):
    """Visualize data from inside a node graph, in the image editor or as a backdrop"""

    ui_shortcut: int
    """ (in [-32768, 32767], default 0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorNodeZcombine(CompositorNode, NodeInternal, Node, bpy_struct):
    """Combine two images using depth maps"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CompositorStrip(EffectStrip, Strip, bpy_struct):
    """Compositor Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    node_group: NodeTree | None
    """ Node group that controls what this effect does"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ConsoleLine(bpy_struct):
    """Input line for the interactive console"""

    body: str
    """ Text in the line (default "", never None)"""

    current_character: int
    """ (in [-inf, inf], default 0)"""

    type: typing.Literal["OUTPUT", "INPUT", "INFO", "ERROR"]
    """ Console line type when used in scrollback (default 'OUTPUT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Constraint(bpy_struct):
    """Constraint modifying the transformation of objects and bones"""

    active: bool | None
    """ Constraint is the one being edited (default False)"""

    enabled: bool
    """ Use the results of this constraint (default True)"""

    error_location: float
    """ Amount of residual error in Blender space unit for constraints that work on position (in [-inf, inf], default 0.0, readonly)"""

    error_rotation: float
    """ Amount of residual error in radians for constraints that work on orientation (in [-inf, inf], default 0.0, readonly)"""

    influence: float
    """ Amount of influence constraint will have on the final solution (in [0, 1], default 0.0)"""

    is_override_data: bool
    """ In a local override object, whether this constraint comes from the linked reference object, or is local to the override (default True, readonly)"""

    is_valid: bool
    """ Constraint has valid settings and can be evaluated (default True, readonly)"""

    mute: bool
    """ Enable/Disable Constraint (default False)"""

    name: str
    """ Constraint name (default "", never None)"""

    owner_space: typing.Literal["WORLD", "CUSTOM", "POSE", "LOCAL_WITH_PARENT", "LOCAL"]
    """ Space that owner is evaluated in (default 'WORLD')"""

    show_expanded: bool
    """ Constraint's panel is expanded in UI (default False)"""

    space_object: Object | None
    """ Object for Custom Space"""

    space_subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target_space: typing.Literal[
        "WORLD", "CUSTOM", "POSE", "LOCAL_WITH_PARENT", "LOCAL", "LOCAL_OWNER_ORIENT"
    ]
    """ Space that target is evaluated in (default 'WORLD')"""

    type: Literal[bpy.stub_internal.rna_enums.ConstraintTypeItems]
    """ (default 'CAMERA_SOLVER', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ConstraintTarget(bpy_struct):
    """Target object for multi-target constraints"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ConstraintTargetBone(bpy_struct):
    """Target bone for multi-target constraints"""

    subtarget: str
    """ Target armature bone (default "", never None)"""

    target: Object | None
    """ Target armature"""

    weight: float
    """ Blending weight of this bone (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Context(bpy_struct):
    """Current windowmanager and data contextButtons ContextClip ContextFile ContextImage ContextNode ContextScreen ContextSequencer ContextText ContextView3D ContextMethods"""

    area: Area | None
    """ (readonly)"""

    asset: AssetRepresentation | None
    """ (readonly)"""

    blend_data: BlendData | None
    """ (readonly)"""

    collection: Collection | None
    """ (readonly)"""

    engine: str
    """ (default "", readonly, never None)"""

    gizmo_group: GizmoGroup | None
    """ (readonly)"""

    layer_collection: LayerCollection | None
    """ (readonly)"""

    mode: Literal[bpy.stub_internal.rna_enums.ContextModeItems]
    """ (default 'EDIT_MESH', readonly)"""

    preferences: Preferences | None
    """ (readonly)"""

    region: Region | None
    """ (readonly)"""

    region_data: RegionView3D | None
    """ (readonly)"""

    region_popup: Region | None
    """ The temporary region for pop-ups (including menus and pop-overs) (readonly)"""

    scene: Scene | None
    """ (readonly)"""

    screen: Screen | None
    """ (readonly)"""

    space_data: Space | None
    """ The current space, may be None in background-mode, when the cursor is outside the window or when using menu-search (readonly)"""

    tool_settings: ToolSettings | None
    """ (readonly)"""

    view_layer: ViewLayer | None
    """ (readonly)"""

    window: Window | None
    """ (readonly)"""

    window_manager: WindowManager | None
    """ (readonly)"""

    workspace: WorkSpace | None
    """ (readonly)"""

    texture_slot: TextureSlot | None
    world: World | None
    object: Object | None
    mesh: Mesh | None
    armature: Armature | None
    lattice: Lattice | None
    curve: Curve | None
    meta_ball: MetaBall | None
    light: Light | None
    speaker: Speaker | None
    lightprobe: LightProbe | None
    camera: Camera | None
    material: Material | None
    material_slot: MaterialSlot | None
    texture: Texture | None
    texture_user: ID | None
    texture_user_property: Property | None
    texture_node: Node | None
    bone: Bone | None
    edit_bone: EditBone | None
    pose_bone: PoseBone | None
    particle_system: ParticleSystem | None
    particle_system_editable: ParticleSystem | None
    particle_settings: ParticleSettings | None
    cloth: ClothModifier | None
    soft_body: SoftBodyModifier | None
    fluid: FluidModifier | None
    collision: CollisionModifier | None
    brush: Brush | None
    dynamic_paint: DynamicPaintModifier | None
    line_style: FreestyleLineStyle | None
    gpencil: GreasePencil | None
    grease_pencil: GreasePencil | None
    curves: Curves | None
    pointcloud: PointCloud | None
    volume: Volume | None
    strip: Strip | None
    strip_modifier: StripModifier | None
    edit_movieclip: MovieClip | None
    edit_mask: Mask | None
    active_file: FileSelectEntry | None
    selected_files: collections.abc.Sequence[FileSelectEntry] | None
    asset_library_reference: AssetLibraryReference | None
    selected_assets: collections.abc.Sequence[AssetRepresentation] | None
    id: ID | None
    selected_ids: collections.abc.Sequence[ID] | None
    edit_image: Image | None
    selected_nodes: collections.abc.Sequence[Node] | None
    active_node: Node | None
    visible_objects: collections.abc.Sequence[Object] | None
    selectable_objects: collections.abc.Sequence[Object] | None
    selected_objects: collections.abc.Sequence[Object] | None
    editable_objects: collections.abc.Sequence[Object] | None
    selected_editable_objects: collections.abc.Sequence[Object] | None
    objects_in_mode: collections.abc.Sequence[Object] | None
    objects_in_mode_unique_data: collections.abc.Sequence[Object] | None
    visible_bones: collections.abc.Sequence[EditBone] | None
    editable_bones: collections.abc.Sequence[EditBone] | None
    selected_bones: collections.abc.Sequence[EditBone] | None
    selected_editable_bones: collections.abc.Sequence[EditBone] | None
    visible_pose_bones: collections.abc.Sequence[PoseBone] | None
    selected_pose_bones: collections.abc.Sequence[PoseBone] | None
    selected_pose_bones_from_active_object: collections.abc.Sequence[PoseBone] | None
    active_bone: Bone | EditBone | None
    active_pose_bone: PoseBone | None
    active_object: Object | None
    edit_object: Object | None
    sculpt_object: Object | None
    vertex_paint_object: Object | None
    weight_paint_object: Object | None
    image_paint_object: Object | None
    particle_edit_object: Object | None
    pose_object: Object | None
    active_nla_track: NlaTrack | None
    active_nla_strip: NlaStrip | None
    selected_nla_strips: collections.abc.Sequence[NlaStrip] | None
    selected_movieclip_tracks: collections.abc.Sequence[MovieTrackingTrack] | None
    annotation_data: GreasePencil | None
    annotation_data_owner: ID | None
    active_annotation_layer: AnnotationLayer | None
    active_operator: Operator | None
    active_action: Action | None
    selected_visible_actions: collections.abc.Sequence[Action] | None
    selected_editable_actions: collections.abc.Sequence[Action] | None
    visible_fcurves: collections.abc.Sequence[FCurve] | None
    editable_fcurves: collections.abc.Sequence[FCurve] | None
    selected_visible_fcurves: collections.abc.Sequence[FCurve] | None
    selected_editable_fcurves: collections.abc.Sequence[FCurve] | None
    active_editable_fcurve: FCurve | None
    selected_editable_keyframes: collections.abc.Sequence[Keyframe] | None
    ui_list: UIList | None
    property: typing.Any | None
    """ Get the property associated with a hovered button.
Returns a tuple of the data-block, data path to the property, and array index."""

    active_strip: Strip | None
    strips: collections.abc.Sequence[Strip] | None
    selected_strips: collections.abc.Sequence[Strip] | None
    selected_editable_strips: collections.abc.Sequence[Strip] | None
    sequencer_scene: Scene | None
    edit_text: Text | None
    context: typing_extensions.Self
    """ Access to the current window-manager and data context."""

    def evaluated_depsgraph_get(self) -> Depsgraph:
        """Get the dependency graph for the current scene and view layer, to access to data-blocks with animation and modifiers applied. If any data-blocks have been edited, the dependency graph will be updated. This invalidates all references to evaluated data-blocks from the dependency graph.

        :return: Evaluated dependency graph
        """

    def copy(self) -> dict[str, typing.Any]:
        """Get context members as a dictionary.

        :return:
        """

    def path_resolve(
        self, path: str | None, coerce: bool | None = True
    ) -> bpy_prop | typing.Any:
        """Returns the property from the path, raise an exception when not found.

        :param path: patch which this property resolves.
        :param coerce: optional argument, when True, the property will be converted into its Python representation.
        :return: Property value or property object.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def temp_override(
        self,
        *,
        window: None | Window | None = None,
        screen: None | Screen | None = None,
        area: Area | None | None = None,
        region: None | Region | None = None,
        **keywords,
    ) -> ContextTempOverride:
        """Context manager to temporarily override members in the context.Overriding the context can be used to temporarily activate another window / area & region,
        as well as other members such as the active_object or bone.Notes:Overriding the context can be useful to set the context after loading files
        (which would otherwise be None). For example:This example shows how its possible to add an object to the scene in another window.Logging Context Member AccessContext members can be logged by calling logging_set(True) on the "with" target of a temporary override.
        This will log the members that are being accessed during the operation and may
        assist in debugging when it is unclear which members need to be overridden.In the event an operator fails to execute because of a missing context member, logging may help
        identify which member is required.This example shows how to log which context members are being accessed.
        Log statements are printed to your systems console.

                :param window: Window override or None.
                :param screen: Screen override or None.

        Switching to or away from full-screen areas & temporary screens isnt supported. Passing in these screens will raise an exception, actions that leave the context such screens wont restore the prior screen.

        Changing the screen has wider implications than other arguments as it will also change the works-space and potentially the scene (when pinned).
                :param area: Area override or None.
                :param region: Region override or None.
                :param keywords: Additional keywords override context members.
                :return: The context manager.
        """

class CopyLocationConstraint(Constraint, bpy_struct):
    """Copy the location of the target"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    invert_x: bool
    """ Invert the X location (default False)"""

    invert_y: bool
    """ Invert the Y location (default False)"""

    invert_z: bool
    """ Invert the Z location (default False)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    use_offset: bool
    """ Add original location into copied location (default False)"""

    use_x: bool
    """ Copy the target's X location (default False)"""

    use_y: bool
    """ Copy the target's Y location (default False)"""

    use_z: bool
    """ Copy the target's Z location (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CopyRotationConstraint(Constraint, bpy_struct):
    """Copy the rotation of the target"""

    euler_order: typing.Literal["AUTO", "XYZ", "XZY", "YXZ", "YZX", "ZXY", "ZYX"]
    """ Explicitly specify the euler rotation order (default 'AUTO')"""

    invert_x: bool
    """ Invert the X rotation (default False)"""

    invert_y: bool
    """ Invert the Y rotation (default False)"""

    invert_z: bool
    """ Invert the Z rotation (default False)"""

    mix_mode: typing.Literal["REPLACE", "ADD", "BEFORE", "AFTER", "OFFSET"]
    """ Specify how the copied and existing rotations are combined (default 'REPLACE')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_offset: bool
    """ DEPRECATED: Add original rotation into copied rotation (default False)"""

    use_x: bool
    """ Copy the target's X rotation (default False)"""

    use_y: bool
    """ Copy the target's Y rotation (default False)"""

    use_z: bool
    """ Copy the target's Z rotation (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CopyScaleConstraint(Constraint, bpy_struct):
    """Copy the scale of the target"""

    power: float
    """ Raise the target's scale to the specified power (in [-inf, inf], default 1.0)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_add: bool
    """ Use addition instead of multiplication to combine scale (2.7 compatibility) (default True)"""

    use_make_uniform: bool
    """ Redistribute the copied change in volume equally between the three axes of the owner (default False)"""

    use_offset: bool
    """ Combine original scale with copied scale (default False)"""

    use_x: bool
    """ Copy the target's X scale (default False)"""

    use_y: bool
    """ Copy the target's Y scale (default False)"""

    use_z: bool
    """ Copy the target's Z scale (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CopyTransformsConstraint(Constraint, bpy_struct):
    """Copy all the transforms of the target"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    mix_mode: typing.Literal[
        "REPLACE",
        "BEFORE_FULL",
        "BEFORE",
        "BEFORE_SPLIT",
        "AFTER_FULL",
        "AFTER",
        "AFTER_SPLIT",
    ]
    """ Specify how the copied and existing transformations are combined (default 'REPLACE')"""

    remove_target_shear: bool
    """ Remove shear from the target transformation before combining (default False)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CorrectiveSmoothModifier(Modifier, bpy_struct):
    """Correct distortion caused by deformation"""

    factor: float
    """ Smooth effect factor (in [-inf, inf], default 0.5)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    is_bind: bool
    """ (default False, readonly)"""

    iterations: int
    """ (in [0, 32767], default 5)"""

    rest_source: typing.Literal["ORCO", "BIND"]
    """ Select the source of rest positions (default 'ORCO')"""

    scale: float
    """ Compensate for scale applied by other modifiers (in [-inf, inf], default 1.0)"""

    smooth_type: typing.Literal["SIMPLE", "LENGTH_WEIGHTED"]
    """ Method used for smoothing (default 'SIMPLE')"""

    use_only_smooth: bool
    """ Apply smoothing without reconstructing the surface (default False)"""

    use_pin_boundary: bool
    """ Excludes boundary vertices from being smoothed (default False)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CrossStrip(EffectStrip, Strip, bpy_struct):
    """Crossfade Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CryptomatteEntry(bpy_struct):
    encoded_hash: float
    """ (in [-inf, inf], default 0.0, readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Curve(ID, bpy_struct):
    """Curve data-block storing curves, splines and NURBS"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    bevel_depth: float
    """ Radius of the bevel geometry, not including extrusion (in [-inf, inf], default 0.0)"""

    bevel_factor_end: float
    """ Define where along the spline the curve geometry ends (0 for the beginning, 1 for the end) (in [0, 1], default 1.0)"""

    bevel_factor_mapping_end: typing.Literal["RESOLUTION", "SEGMENTS", "SPLINE"]
    """ Determine how the geometry end factor is mapped to a spline (default 'RESOLUTION')"""

    bevel_factor_mapping_start: typing.Literal["RESOLUTION", "SEGMENTS", "SPLINE"]
    """ Determine how the geometry start factor is mapped to a spline (default 'RESOLUTION')"""

    bevel_factor_start: float
    """ Define where along the spline the curve geometry starts (0 for the beginning, 1 for the end) (in [0, 1], default 0.0)"""

    bevel_mode: typing.Literal["ROUND", "OBJECT", "PROFILE"]
    """ Determine how to build the curve's bevel geometry (default 'ROUND')"""

    bevel_object: Object | None
    """ The name of the Curve object that defines the bevel shape"""

    bevel_profile: CurveProfile | None
    """ The path for the curve's custom profile (readonly)"""

    bevel_resolution: int
    """ The number of segments in each quarter-circle of the bevel (in [0, 32], default 4)"""

    cycles: typing.Any
    """ Cycles mesh settings (readonly)"""

    dimensions: typing.Literal["2D", "3D"]
    """ Select 2D or 3D curve type (default '2D')"""

    eval_time: float
    """ Parametric position along the length of the curve that Objects 'following' it should be at (position is evaluated by dividing by the 'Path Length' value) (in [-inf, inf], default 0.0)"""

    extrude: float
    """ Length of the depth added in the local Z direction along the curve, perpendicular to its normals (in [0, inf], default 0.0)"""

    fill_mode: typing.Literal["FULL", "BACK", "FRONT", "HALF"]
    """ Mode of filling curve (default 'FULL')"""

    fill_rule: typing.Literal["EVEN_ODD", "NONZERO"]
    """ Fill rule for Delaunay fill solver (default 'EVEN_ODD')"""

    fill_solver: typing.Literal["SWEEP_LINE", "CDT"]
    """ Triangulation solver for filling 2D curves (default 'SWEEP_LINE')"""

    is_editmode: bool
    """ True when used in editmode (default False, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    offset: float
    """ Distance to move the curve parallel to its normals (in [-inf, inf], default 0.0)"""

    path_duration: int
    """ The number of frames that are needed to traverse the path, defining the maximum value for the 'Evaluation Time' setting (in [1, 1048574], default 100)"""

    render_resolution_u: int
    """ Surface resolution in U direction used while rendering (zero uses preview resolution) (in [0, 1024], default 0)"""

    render_resolution_v: int
    """ Surface resolution in V direction used while rendering (zero uses preview resolution) (in [0, 1024], default 0)"""

    resolution_u: int
    """ Number of computed points in the U direction between every pair of control points (in [1, 1024], default 12)"""

    resolution_v: int
    """ The number of computed points in the V direction between every pair of control points (in [1, 1024], default 12)"""

    shape_keys: Key | None
    """ (readonly)"""

    splines: typing.Any
    """ Collection of splines in this curve data object (default None, readonly)"""

    taper_object: Object | None
    """ Curve object name that defines the taper (width)"""

    taper_radius_mode: typing.Literal["OVERRIDE", "MULTIPLY", "ADD"]
    """ Determine how the effective radius of the spline point is computed when a taper object is specified (default 'OVERRIDE')"""

    texspace_location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    texspace_size: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    twist_mode: typing.Literal["Z_UP", "MINIMUM", "TANGENT"]
    """ The type of tilt calculation for 3D Curves (default 'MINIMUM')"""

    twist_smooth: float
    """ Smoothing iteration for tangents (in [-inf, inf], default 0.0)"""

    use_auto_texspace: bool
    """ Adjust active object's texture space automatically when transforming object (default True)"""

    use_deform_bounds: bool
    """ Option for curve-deform: Use the mesh bounds to clamp the deformation (default False)"""

    use_fill_caps: bool
    """ Fill caps for beveled curves (default False)"""

    use_map_taper: bool
    """ Map effect of the taper object to the beveled part of the curve (default False)"""

    use_path: bool
    """ Enable the curve to become a translation path (default False)"""

    use_path_clamp: bool
    """ Clamp the curve path children so they cannot travel past the start/end point of the curve (default False)"""

    use_path_follow: bool
    """ Make curve path children rotate along the path (default False)"""

    use_radius: bool
    """ Option for paths and curve-deform: apply the curve radius to objects following it and to deformed objects (default True)"""

    use_stretch: bool
    """ Option for curve-deform: make deformed child stretch along entire path (default False)"""

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        shape_keys: bool | None = False,
    ) -> None:
        """Transform curve by a matrix

        :param matrix: Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param shape_keys: Transform Shape Keys (optional)
        """

    def validate_material_indices(self) -> bool:
        """Validate material indices of splines or letters, return True when the curve has had invalid indices corrected (to default 0)

        :return: Result
        """

    def update_gpu_tag(self) -> None:
        """update_gpu_tag"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveMap(bpy_struct):
    """Curve in a curve mapping"""

    points: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveMapPoint(bpy_struct):
    """Point of a curve used for a curve mapping"""

    handle_type: typing.Literal["AUTO", "AUTO_CLAMPED", "VECTOR"]
    """ Curve interpolation at this point: Bézier or vector (default 'AUTO')"""

    location: mathutils.Vector
    """ X/Y coordinates of the curve point (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    select: bool
    """ Selection state of the curve point (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveMapping(bpy_struct):
    """Curve mapping to map color, vector and scalar values to other values using a user defined curve"""

    black_level: mathutils.Color
    """ For RGB curves, the color that black is mapped to (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    clip_max_x: float
    """ (in [-100, 100], default 0.0)"""

    clip_max_y: float
    """ (in [-100, 100], default 0.0)"""

    clip_min_x: float
    """ (in [-100, 100], default 0.0)"""

    clip_min_y: float
    """ (in [-100, 100], default 0.0)"""

    curves: typing.Any
    """ (default None, readonly)"""

    extend: typing.Literal["HORIZONTAL", "EXTRAPOLATED"]
    """ Extrapolate the curve or extend it horizontally (default 'HORIZONTAL')"""

    tone: typing.Literal["STANDARD", "FILMLIKE"]
    """ Tone of the curve (default 'STANDARD')"""

    use_clip: bool
    """ Force the curve view to fit a defined boundary (default False)"""

    white_level: mathutils.Color
    """ For RGB curves, the color that white is mapped to (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    def update(self) -> None:
        """Update curve mapping after making changes"""

    def reset_view(self) -> None:
        """Reset the curve mapping grid to its clipping size"""

    def initialize(self) -> None:
        """Initialize curve"""

    def evaluate(self, curve: CurveMap | None, position: float | None) -> float:
        """Evaluate curve at given location

        :param curve: curve, Curve to evaluate (never None)
        :param position: Position, Position to evaluate curve at (in [-inf, inf])
        :return: Value, Value of curve at given location (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveModifier(Modifier, bpy_struct):
    """Curve deformation modifier"""

    deform_axis: typing.Literal["POS_X", "POS_Y", "POS_Z", "NEG_X", "NEG_Y", "NEG_Z"]
    """ The axis that the curve deforms along (default 'POS_X')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object: Object | None
    """ Curve object to deform with"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurvePaintSettings(bpy_struct):
    corner_angle: float
    """ Angles above this are considered corners (in [0, 3.14159], default 1.22173)"""

    curve_type: typing.Literal["POLY", "BEZIER"]
    """ Type of curve to use for new strokes (default 'BEZIER')"""

    depth_mode: typing.Literal["CURSOR", "SURFACE"]
    """ Method of projecting depth (default 'CURSOR')"""

    error_threshold: int
    """ Allow deviation for a smoother, less precise line (in [1, 100], default 8)"""

    fit_method: Literal[bpy.stub_internal.rna_enums.CurveFitMethodItems]
    """ Curve fitting method (default 'REFIT')"""

    radius_max: float
    """ Radius to use when the maximum pressure is applied (or when a tablet isn't used) (in [0, 100], default 1.0)"""

    radius_min: float
    """ Minimum radius when the minimum pressure is applied (also the minimum when tapering) (in [0, 100], default 0.0)"""

    radius_taper_end: float
    """ Taper factor for the radius of each point along the curve (in [0, 10], default 0.0)"""

    radius_taper_start: float
    """ Taper factor for the radius of each point along the curve (in [0, 1], default 0.0)"""

    surface_offset: float
    """ Offset the stroke from the surface (in [-10, 10], default 0.0)"""

    surface_plane: typing.Literal["NORMAL_VIEW", "NORMAL_SURFACE", "VIEW"]
    """ Plane for projected stroke (default 'NORMAL_VIEW')"""

    use_corners_detect: bool
    """ Detect corners and use non-aligned handles (default True)"""

    use_offset_absolute: bool
    """ Apply a fixed offset (don't scale by the radius) (default False)"""

    use_pressure_radius: bool
    """ Map tablet pressure to curve radius (default False)"""

    use_project_only_selected: bool
    """ Project the strokes only onto selected objects (default False)"""

    use_stroke_endpoints: bool
    """ Use the start of the stroke for the depth (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurvePoint(bpy_struct):
    """Curve control point"""

    index: int
    """ Index of this point (in [0, inf], default 0, readonly)"""

    position: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    radius: float
    """ (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveProfile(bpy_struct):
    """Profile Path editor used to build a profile path"""

    points: typing.Any
    """ Profile control points (default None, readonly)"""

    preset: typing.Literal["LINE", "SUPPORTS", "CORNICE", "CROWN", "STEPS"]
    """ (default 'LINE')"""

    segments: typing.Any
    """ Segments sampled from control points (default None, readonly)"""

    use_clip: bool
    """ Force the path view to fit a defined boundary (default False)"""

    use_sample_even_lengths: bool
    """ Sample edges with even lengths (default False)"""

    use_sample_straight_edges: bool
    """ Sample edges with vector handles (default False)"""

    def update(self) -> None:
        """Refresh internal data, remove doubles and clip points"""

    def reset_view(self) -> None:
        """Reset the curve profile grid to its clipping size"""

    def initialize(self, totsegments: int | None) -> None:
        """Set the number of display segments and fill tables

        :param totsegments: The number of segment values to initialize the segments table with (in [1, 1000], never None)
        """

    def evaluate(self, length_portion: float | None) -> mathutils.Vector:
        """Evaluate the at the given portion of the path length

        :param length_portion: Length Portion, Portion of the path length to travel before evaluation (in [0, 1])
        :return: Location, The location at the given portion of the profile (array of 2 items, in [-100, 100])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveProfilePoint(bpy_struct):
    """Point of a path used to define a profile"""

    handle_type_1: typing.Literal["AUTO", "VECTOR", "FREE", "ALIGN"]
    """ Path interpolation at this point (default 'FREE')"""

    handle_type_2: typing.Literal["AUTO", "VECTOR", "FREE", "ALIGN"]
    """ Path interpolation at this point (default 'FREE')"""

    location: mathutils.Vector
    """ X/Y coordinates of the path point (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    select: bool
    """ Selection state of the path point (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurveSlice(bpy_struct):
    """A single curve from a curves data-block"""

    first_point_index: int
    """ The index of this curve's first control point (in [0, inf], default 0, readonly)"""

    index: int
    """ Index of this curve (in [0, inf], default 0, readonly)"""

    points: typing.Any
    """ Control points of the curve (default None, readonly)"""

    points_length: int
    """ Number of control points in the curve (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Curves(ID, bpy_struct):
    """Hair data-block for hair curves"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    attributes: typing.Any
    """ Geometry attributes (default None, readonly)"""

    color_attributes: typing.Any
    """ Geometry color attributes (default None, readonly)"""

    curve_offset_data: typing.Any
    """ (default None, readonly)"""

    curves: typing.Any
    """ All curves in the data-block (default None, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    normals: typing.Any
    """ The curve normal value at each of the curve's control points (default None, readonly)"""

    points: typing.Any
    """ Control points of all curves (default None, readonly)"""

    position_data: typing.Any
    """ (default None, readonly)"""

    selection_domain: Literal[bpy.stub_internal.rna_enums.AttributeCurvesDomainItems]
    """ (default 'POINT')"""

    surface: Object | None
    """ Mesh object that the curves can be attached to"""

    surface_collision_distance: float
    """ Distance to keep the curves away from the surface (in [1.192e-07, inf], default 0.005)"""

    surface_uv_map: str
    """ The name of the attribute on the surface mesh used to define the attachment of each curve (default "", never None)"""

    use_mirror_x: bool
    """ Enable symmetry in the X axis (default False)"""

    use_mirror_y: bool
    """ Enable symmetry in the Y axis (default False)"""

    use_mirror_z: bool
    """ Enable symmetry in the Z axis (default False)"""

    use_sculpt_collision: bool
    """ Enable collision with the surface while sculpting (default False)"""

    def add_curves(self, sizes: collections.abc.Sequence[int] | None) -> None:
        """add_curves

        :param sizes: Sizes, The number of points in each curve (array of 1 items, in [0, inf])
        """

    def remove_curves(
        self, *, indices: collections.abc.Sequence[int] | None = (0)
    ) -> None:
        """Remove all curves. If indices are provided, remove only the curves with the given indices.

        :param indices: Indices, The indices of the curves to remove (array of 1 items, in [0, inf], optional)
        """

    def resize_curves(
        self,
        sizes: collections.abc.Sequence[int] | None,
        *,
        indices: collections.abc.Sequence[int] | None = (0),
    ) -> None:
        """Resize all existing curves. If indices are provided, resize only the curves with the given indices. If the new size for a curve is smaller, the curve is trimmed. If the new size for a curve is larger, the new end values are default initialized.

        :param sizes: Sizes, The number of points in each curve (array of 1 items, in [1, inf])
        :param indices: Indices, The indices of the curves to resize (array of 1 items, in [0, inf], optional)
        """

    def reorder_curves(self, new_indices: collections.abc.Sequence[int] | None) -> None:
        """Reorder the curves by the new indices.

        :param new_indices: New indices, The new index for each of the curves (array of 1 items, in [0, inf])
        """

    def set_types(
        self,
        *,
        type: Literal[bpy.stub_internal.rna_enums.CurvesTypeItems]
        | None = "CATMULL_ROM",
        indices: collections.abc.Sequence[int] | None = (0),
    ) -> None:
        """Set the curve type. If indices are provided, set only the types with the given curve indices.

        :param type: Type, (optional)
        :param indices: Indices, The indices of the curves to resize (array of 1 items, in [0, inf], optional)
        """

    def unit_test_compare(
        self,
        *,
        curves: typing_extensions.Self | None = None,
        threshold: float | None = 7.1526e-06,
    ) -> str:
        """unit_test_compare

        :param curves: Curves to compare to (optional)
        :param threshold: Threshold, Comparison tolerance threshold (in [0, inf], optional)
        :return: Return value, String description of result of comparison (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurvesModifier(StripModifier, bpy_struct):
    """RGB curves modifier for sequence strip"""

    curve_mapping: CurveMapping | None
    """ (readonly)"""

    open_mask_input_panel: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class CurvesSculpt(Paint, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DATA_UL_bone_collections(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        armature,
        bcoll,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param armature:
        :param bcoll:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DampedTrackConstraint(Constraint, bpy_struct):
    """Point toward target by taking the shortest rotation path"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    track_axis: typing.Literal[
        "TRACK_X",
        "TRACK_Y",
        "TRACK_Z",
        "TRACK_NEGATIVE_X",
        "TRACK_NEGATIVE_Y",
        "TRACK_NEGATIVE_Z",
    ]
    """ Axis that points to the target object (default 'TRACK_X')"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DataTransferModifier(Modifier, bpy_struct):
    """Modifier transferring some data from a source mesh"""

    data_types_edges: set[
        typing.Literal[
            "SHARP_EDGE", "SEAM", "CREASE", "BEVEL_WEIGHT_EDGE", "FREESTYLE_EDGE"
        ]
    ]
    """ Which edge data layers to transfer (default set())"""

    data_types_loops: set[typing.Literal["CUSTOM_NORMAL", "COLOR_CORNER", "UV"]]
    """ Which face corner data layers to transfer (default set())"""

    data_types_polys: set[typing.Literal["SMOOTH", "FREESTYLE_FACE"]]
    """ Which face data layers to transfer (default set())"""

    data_types_verts: set[
        typing.Literal["VGROUP_WEIGHTS", "BEVEL_WEIGHT_VERT", "COLOR_VERTEX"]
    ]
    """ Which vertex data layers to transfer (default set())"""

    edge_mapping: Literal[bpy.stub_internal.rna_enums.DtMethodEdgeItems]
    """ Method used to map source edges to destination ones (default 'NEAREST')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    islands_precision: float
    """ Factor controlling precision of islands handling (typically, 0.1 should be enough, higher values can make things really slow) (in [0, 1], default 0.0)"""

    layers_uv_select_dst: Literal[bpy.stub_internal.rna_enums.DtLayersSelectDstItems]
    """ How to match source and destination layers (default 'NAME')"""

    layers_uv_select_src: Literal[bpy.stub_internal.rna_enums.DtLayersSelectSrcItems]
    """ Which layers to transfer, in case of multi-layers types (default 'ALL')"""

    layers_vcol_loop_select_dst: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectDstItems
    ]
    """ How to match source and destination layers (default 'NAME')"""

    layers_vcol_loop_select_src: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectSrcItems
    ]
    """ Which layers to transfer, in case of multi-layers types (default 'ALL')"""

    layers_vcol_vert_select_dst: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectDstItems
    ]
    """ How to match source and destination layers (default 'NAME')"""

    layers_vcol_vert_select_src: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectSrcItems
    ]
    """ Which layers to transfer, in case of multi-layers types (default 'ALL')"""

    layers_vgroup_select_dst: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectDstItems
    ]
    """ How to match source and destination layers (default 'NAME')"""

    layers_vgroup_select_src: Literal[
        bpy.stub_internal.rna_enums.DtLayersSelectSrcItems
    ]
    """ Which layers to transfer, in case of multi-layers types (default 'ALL')"""

    loop_mapping: Literal[bpy.stub_internal.rna_enums.DtMethodLoopItems]
    """ Method used to map source faces' corners to destination ones (default 'NEAREST_POLYNOR')"""

    max_distance: float
    """ Maximum allowed distance between source and destination element, for non-topology mappings (in [0, inf], default 1.0)"""

    mix_factor: float
    """ Factor to use when applying data to destination (exact behavior depends on mix mode, multiplied with weights from vertex group when defined) (in [0, 1], default 0.0)"""

    mix_mode: Literal[bpy.stub_internal.rna_enums.DtMixModeItems]
    """ How to affect destination elements with source values (default 'REPLACE')"""

    object: Object | None
    """ Object to transfer data from"""

    poly_mapping: Literal[bpy.stub_internal.rna_enums.DtMethodPolyItems]
    """ Method used to map source faces to destination ones (default 'NEAREST')"""

    ray_radius: float
    """ 'Width' of rays (especially useful when raycasting against vertices or edges) (in [0, inf], default 0.0)"""

    use_edge_data: bool
    """ Enable edge data transfer (default False)"""

    use_loop_data: bool
    """ Enable face corner data transfer (default False)"""

    use_max_distance: bool
    """ Source elements must be closer than given distance from destination one (default False)"""

    use_object_transform: bool
    """ Evaluate source and destination meshes in global space (default True)"""

    use_poly_data: bool
    """ Enable face data transfer (default False)"""

    use_vert_data: bool
    """ Enable vertex data transfer (default False)"""

    vert_mapping: Literal[bpy.stub_internal.rna_enums.DtMethodVertexItems]
    """ Method used to map source vertices to destination ones (default 'NEAREST')"""

    vertex_group: str
    """ Vertex group name for selecting the affected areas (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DecimateModifier(Modifier, bpy_struct):
    """Decimation modifier"""

    angle_limit: float
    """ Only dissolve angles below this (planar only) (in [0, 3.14159], default 0.0872665)"""

    decimate_type: typing.Literal["COLLAPSE", "UNSUBDIV", "DISSOLVE"]
    """ (default 'COLLAPSE')"""

    delimit: set[Literal[bpy.stub_internal.rna_enums.MeshDelimitModeItems]]
    """ Limit merging geometry (default set())"""

    face_count: int
    """ The current number of faces in the decimated mesh (in [-inf, inf], default 0, readonly)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (collapse only) (default False)"""

    iterations: int
    """ Number of times reduce the geometry (unsubdivide only) (in [0, 32767], default 0)"""

    ratio: float
    """ Ratio of triangles to reduce to (collapse only) (in [0, 1], default 1.0)"""

    symmetry_axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Axis of symmetry (default 'X')"""

    use_collapse_triangulate: bool
    """ Keep triangulated faces resulting from decimation (collapse only) (default False)"""

    use_dissolve_boundaries: bool
    """ Dissolve all vertices in between face boundaries (planar only) (default False)"""

    use_symmetry: bool
    """ Maintain symmetry on an axis (default False)"""

    vertex_group: str
    """ Vertex group name (collapse only) (default "", never None)"""

    vertex_group_factor: float
    """ Vertex group strength (in [0, 1000], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Depsgraph(bpy_struct):
    ids: typing.Any
    """ All evaluated data-blocks (default None, readonly)"""

    mode: typing.Literal["VIEWPORT", "RENDER"]
    """ Evaluation mode (default 'VIEWPORT', readonly)"""

    object_instances: typing.Any
    """ All object instances to display or render (Warning: Only use this as an iterator, never as a sequence, and do not keep any references to its items) (default None, readonly)"""

    objects: typing.Any
    """ Evaluated objects in the dependency graph (default None, readonly)"""

    scene: Scene | None
    """ Original scene dependency graph is built for (readonly)"""

    scene_eval: Scene | None
    """ Scene at its evaluated state (readonly)"""

    updates: typing.Any
    """ Updates to data-blocks (default None, readonly)"""

    view_layer: ViewLayer | None
    """ Original view layer dependency graph is built for (readonly)"""

    view_layer_eval: ViewLayer | None
    """ View layer at its evaluated state (readonly)"""

    def debug_relations_graphviz(self, *, filepath: str | None = "") -> str:
        """debug_relations_graphviz

        :param filepath: File Name, Optional output path for the graphviz debug file (optional, never None)
        :return: Dot Graph, Graph in dot format
        """

    def debug_stats_gnuplot(
        self, filepath: str | None, output_filepath: str | None
    ) -> None:
        """debug_stats_gnuplot

        :param filepath: File Name, Output path for the gnuplot debug file (never None)
        :param output_filepath: Output File Name, File name where gnuplot script will save the result (never None)
        """

    def debug_tag_update(self) -> None:
        """debug_tag_update"""

    def debug_stats(self) -> str:
        """Report the number of elements in the Dependency Graph

        :return: result, (never None)
        """

    def update(self) -> None:
        """Re-evaluate any modified data-blocks, for example for animation or modifiers. This invalidates all references to evaluated data-blocks from this dependency graph."""

    def id_eval_get[_GenericType1](self, id: _GenericType1 | None) -> _GenericType1:
        """id_eval_get

        :param id: Original ID to get evaluated complementary part for
        :return: Evaluated ID for the given original one
        """

    def id_type_updated(
        self, id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems] | None
    ) -> bool:
        """id_type_updated

        :param id_type: ID Type
        :return: Updated, True if any data-block with this type was added, updated or removed
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DepsgraphObjectInstance(bpy_struct):
    """Extended information about dependency graph object iterator (Warning: All data here is evaluated one, not original .blend IDs)"""

    instance_object: Object | None
    """ Evaluated object which is being instanced by this iterator (readonly)"""

    is_instance: bool
    """ Denotes if the object is generated by another object (default False, readonly)"""

    matrix_world: mathutils.Matrix
    """ Generated transform matrix in world space (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    object: Object | None
    """ Evaluated object the iterator points to (readonly)"""

    orco: mathutils.Vector
    """ Generated coordinates in parent object space (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    parent: Object | None
    """ If the object is an instance, the parent object that generated it (readonly)"""

    particle_system: ParticleSystem | None
    """ Evaluated particle system that this object was instanced from (readonly)"""

    persistent_id: typing.Any
    """ Persistent identifier for inter-frame matching of objects with motion blur (array of 8 items, in [-inf, inf], default (0, 0, 0, 0, 0, 0, 0, 0), readonly)"""

    random_id: int
    """ Random id for this instance, typically for randomized shading (in [0, inf], default 0, readonly)"""

    show_particles: bool
    """ Particles part of the object should be visible in the render (default False, readonly)"""

    show_self: bool
    """ The object geometry itself should be visible in the render (default False, readonly)"""

    uv: typing.Any
    """ UV coordinates in parent object space (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DepsgraphUpdate(bpy_struct):
    """Information about ID that was updated"""

    id: ID | None
    """ Updated data-block (readonly)"""

    is_updated_geometry: bool
    """ Object geometry is updated (default False, readonly)"""

    is_updated_shading: bool
    """ Object shading is updated (default False, readonly)"""

    is_updated_transform: bool
    """ Object transformation is updated (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DisplaceModifier(Modifier, bpy_struct):
    """Displacement modifier"""

    direction: typing.Literal["X", "Y", "Z", "NORMAL", "CUSTOM_NORMAL", "RGB_TO_XYZ"]
    """ (default 'NORMAL')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    mid_level: float
    """ Material value that gives no displacement (in [-inf, inf], default 0.5)"""

    space: typing.Literal["LOCAL", "GLOBAL"]
    """ (default 'LOCAL')"""

    strength: float
    """ Amount to displace geometry (in [-inf, inf], default 1.0)"""

    texture: Texture | None
    texture_coords: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ (default 'LOCAL')"""

    texture_coords_bone: str
    """ Bone to set the texture coordinates (default "", never None)"""

    texture_coords_object: Object | None
    """ Object to set the texture coordinates"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DisplaySafeAreas(bpy_struct):
    """Safe areas used in 3D view and the sequencer"""

    action: mathutils.Vector
    """ Safe area for general elements (array of 2 items, in [0, 1], default (0.035, 0.035))"""

    action_center: mathutils.Vector
    """ Safe area for general elements in a different aspect ratio (array of 2 items, in [0, 1], default (0.15, 0.05))"""

    title: mathutils.Vector
    """ Safe area for text and graphics (array of 2 items, in [0, 1], default (0.1, 0.05))"""

    title_center: mathutils.Vector
    """ Safe area for text and graphics in a different aspect ratio (array of 2 items, in [0, 1], default (0.175, 0.05))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DistortedNoiseTexture(Texture, ID, bpy_struct):
    """Procedural distorted noise texture"""

    distortion: float
    """ Amount of distortion (in [0, 10], default 1.0)"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_distortion: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis for the distortion (default 'BLENDER_ORIGINAL')"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DopeSheet(bpy_struct):
    """Settings for filtering the channels shown in animation editors"""

    filter_collection: Collection | None
    """ Collection that included object should be a member of"""

    filter_fcurve_name: str
    """ F-Curve live filtering string (default "", never None)"""

    filter_text: str
    """ Live filtering string (default "", never None)"""

    show_armatures: bool
    """ Include visualization of armature related animation data (default True)"""

    show_cache_files: bool
    """ Include visualization of cache file related animation data (default True)"""

    show_cameras: bool
    """ Include visualization of camera related animation data (default True)"""

    show_curves: bool
    """ Include visualization of curve related animation data (default True)"""

    show_datablock_filters: bool
    """ Show options for whether channels related to certain types of data are included (default False)"""

    show_driver_fallback_as_error: bool
    """ Include drivers that relied on any fallback values for their evaluation in the Only Show Errors filter, even if the driver evaluation succeeded (default False)"""

    show_expanded_summary: bool
    """ Collapse summary when shown, so all other channels get hidden (Dope Sheet editors only) (default True)"""

    show_gpencil: bool
    """ Include visualization of Grease Pencil related animation data and frames (default True)"""

    show_hair_curves: bool
    """ Include visualization of hair related animation data (default True)"""

    show_hidden: bool
    """ Include channels from objects/bone that are not visible (default False)"""

    show_lattices: bool
    """ Include visualization of lattice related animation data (default True)"""

    show_lightprobes: bool
    """ Include visualization of lightprobe related animation data (default True)"""

    show_lights: bool
    """ Include visualization of light related animation data (default True)"""

    show_linestyles: bool
    """ Include visualization of Line Style related Animation data (default True)"""

    show_materials: bool
    """ Include visualization of material related animation data (default True)"""

    show_meshes: bool
    """ Include visualization of mesh related animation data (default True)"""

    show_metaballs: bool
    """ Include visualization of metaball related animation data (default True)"""

    show_missing_nla: bool
    """ Include animation data-blocks with no NLA data (NLA editor only) (default True)"""

    show_modifiers: bool
    """ Include visualization of animation data related to data-blocks linked to modifiers (default True)"""

    show_movieclips: bool
    """ Include visualization of movie clip related animation data (default True)"""

    show_nodes: bool
    """ Include visualization of node related animation data (default True)"""

    show_only_errors: bool
    """ Only include F-Curves and drivers that are disabled or have errors (default False)"""

    show_only_selected: bool
    """ Only include channels relating to selected objects and data (default False)"""

    show_only_slot_of_active_object: bool
    """ Only show the slot of the active Object. Otherwise show all the Action's Slots (default False)"""

    show_particles: bool
    """ Include visualization of particle related animation data (default True)"""

    show_pointclouds: bool
    """ Include visualization of point cloud related animation data (default True)"""

    show_scenes: bool
    """ Include visualization of scene related animation data (default True)"""

    show_shapekeys: bool
    """ Include visualization of shape key related animation data (default True)"""

    show_speakers: bool
    """ Include visualization of speaker related animation data (default True)"""

    show_summary: bool
    """ Display an additional 'summary' line (Dope Sheet editors only) (default False)"""

    show_textures: bool
    """ Include visualization of texture related animation data (default True)"""

    show_transforms: bool
    """ Include visualization of object-level animation data (mostly transforms) (default True)"""

    show_volumes: bool
    """ Include visualization of volume related animation data (default True)"""

    show_worlds: bool
    """ Include visualization of world related animation data (default True)"""

    source: ID | None
    """ ID-Block representing source data, usually ID_SCE (i.e. Scene) (readonly)"""

    use_datablock_sort: bool
    """ Alphabetically sorts data-blocks - mainly objects in the scene (disable to increase viewport speed) (default True)"""

    use_filter_invert: bool
    """ Invert filter search (default False)"""

    use_multi_word_filter: bool
    """ Perform fuzzy/multi-word matching.
Warning: May be slow(default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Driver(bpy_struct):
    """Driver for the value of a setting based on an external value"""

    expression: str
    """ Expression to use for Scripted Expression (default "", never None)"""

    is_simple_expression: bool
    """ The scripted expression can be evaluated without using the full Python interpreter (default False, readonly)"""

    is_valid: bool
    """ Driver could not be evaluated in past, so should be skipped (default True)"""

    type: typing.Literal["AVERAGE", "SUM", "SCRIPTED", "MIN", "MAX"]
    """ Driver type (default 'AVERAGE')"""

    use_self: bool
    """ Include a 'self' variable in the name-space, so drivers can easily reference the data being modified (object, bone, etc...) (default False)"""

    variables: typing.Any
    """ Properties acting as inputs for this driver (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DriverTarget(bpy_struct):
    """Source of input values for driver variables"""

    bone_target: str
    """ Name of PoseBone to use as target (default "", never None)"""

    context_property: typing.Literal["ACTIVE_SCENE", "ACTIVE_VIEW_LAYER"]
    """ Type of a context-dependent data-block to access property from (default 'ACTIVE_SCENE')"""

    data_path: str
    """ RNA Path (from ID-block) to property used (default "", never None)"""

    fallback_value: float
    """ The value to use if the data path cannot be resolved (in [-inf, inf], default 0.0)"""

    id: ID | None
    """ ID-block that the specific property used can be found from (id_type property must be set first)"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ Type of ID-block that can be used (default 'OBJECT')"""

    is_fallback_used: bool
    """ Indicates that the most recent variable evaluation used the fallback value (default False, readonly)"""

    rotation_mode: Literal[bpy.stub_internal.rna_enums.DriverTargetRotationModeItems]
    """ Mode for calculating rotation channel values (default 'AUTO')"""

    transform_space: typing.Literal["WORLD_SPACE", "TRANSFORM_SPACE", "LOCAL_SPACE"]
    """ Space in which transforms are used (default 'WORLD_SPACE')"""

    transform_type: typing.Literal[
        "LOC_X",
        "LOC_Y",
        "LOC_Z",
        "ROT_X",
        "ROT_Y",
        "ROT_Z",
        "ROT_W",
        "SCALE_X",
        "SCALE_Y",
        "SCALE_Z",
        "SCALE_AVG",
    ]
    """ Driver variable type (default 'LOC_X')"""

    use_fallback_value: bool
    """ Use the fallback value if the data path cannot be resolved, instead of failing to evaluate the driver (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DriverVariable(bpy_struct):
    """Variable from some source/target for driver relationship"""

    is_name_valid: bool
    """ Is this a valid name for a driver variable (default True, readonly)"""

    name: str
    """ Name to use in scripted expressions/functions (no spaces or dots are allowed, and must start with a letter) (default "", never None)"""

    targets: typing.Any
    """ Sources of input data for evaluating this variable (default None, readonly)"""

    type: typing.Literal[
        "SINGLE_PROP", "TRANSFORMS", "ROTATION_DIFF", "LOC_DIFF", "CONTEXT_PROP"
    ]
    """ Driver variable type (default 'SINGLE_PROP')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DynamicPaintBrushSettings(bpy_struct):
    """Brush settings"""

    invert_proximity: bool
    """ Proximity falloff is applied inside the volume (default False)"""

    paint_alpha: float
    """ Paint alpha (in [0, 1], default 0.0)"""

    paint_color: mathutils.Color
    """ Color of the paint (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    paint_distance: float
    """ Maximum distance from brush to mesh surface to affect paint (in [0, 500], default 0.0)"""

    paint_ramp: ColorRamp | None
    """ Color ramp used to define proximity falloff (readonly)"""

    paint_source: typing.Literal[
        "PARTICLE_SYSTEM", "POINT", "DISTANCE", "VOLUME_DISTANCE", "VOLUME"
    ]
    """ (default 'VOLUME')"""

    paint_wetness: float
    """ Paint wetness, visible in wetmap (some effects only affect wet paint) (in [0, 1], default 0.0)"""

    particle_system: ParticleSystem | None
    """ The particle system to paint with"""

    proximity_falloff: typing.Literal["SMOOTH", "CONSTANT", "RAMP"]
    """ Proximity falloff type (default 'CONSTANT')"""

    ray_direction: typing.Literal["CANVAS", "BRUSH", "Z_AXIS"]
    """ Ray direction to use for projection (if brush object is located in that direction it's painted) (default 'CANVAS')"""

    smooth_radius: float
    """ Smooth falloff added after solid radius (in [0, 10], default 0.0)"""

    smudge_strength: float
    """ Smudge effect strength (in [0, 1], default 0.0)"""

    solid_radius: float
    """ Radius that will be painted solid (in [0.01, 10], default 0.0)"""

    use_absolute_alpha: bool
    """ Only increase alpha value if paint alpha is higher than existing (default False)"""

    use_negative_volume: bool
    """ Negate influence inside the volume (default False)"""

    use_paint_erase: bool
    """ Erase / remove paint instead of adding it (default False)"""

    use_particle_radius: bool
    """ Use radius from particle settings (default False)"""

    use_proximity_project: bool
    """ Brush is projected to canvas from defined direction within brush proximity (default False)"""

    use_proximity_ramp_alpha: bool
    """ Only read color ramp alpha (default False)"""

    use_smudge: bool
    """ Make this brush to smudge existing paint as it moves (default False)"""

    use_velocity_alpha: bool
    """ Multiply brush influence by velocity color ramp alpha (default False)"""

    use_velocity_color: bool
    """ Replace brush color by velocity color ramp (default False)"""

    use_velocity_depth: bool
    """ Multiply brush intersection depth (displace, waves) by velocity ramp alpha (default False)"""

    velocity_max: float
    """ Velocity considered as maximum influence (Blender units per frame) (in [0.0001, 10], default 0.0)"""

    velocity_ramp: ColorRamp | None
    """ Color ramp used to define brush velocity effect (readonly)"""

    wave_clamp: float
    """ Maximum level of surface intersection used to influence waves (use 0.0 to disable) (in [0, 50], default 0.0)"""

    wave_factor: float
    """ Multiplier for wave influence of this brush (in [-2, 2], default 0.0)"""

    wave_type: typing.Literal["CHANGE", "DEPTH", "FORCE", "REFLECT"]
    """ (default 'DEPTH')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DynamicPaintCanvasSettings(bpy_struct):
    """Dynamic Paint canvas settings"""

    canvas_surfaces: typing.Any
    """ Paint surface list (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DynamicPaintModifier(Modifier, bpy_struct):
    """Dynamic Paint modifier"""

    brush_settings: DynamicPaintBrushSettings | None
    """ (readonly)"""

    canvas_settings: DynamicPaintCanvasSettings | None
    """ (readonly)"""

    ui_type: Literal[bpy.stub_internal.rna_enums.PropDynamicpaintTypeItems]
    """ (default 'CANVAS')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class DynamicPaintSurface(bpy_struct):
    """A canvas surface layer"""

    brush_collection: Collection | None
    """ Only use brush objects from this collection"""

    brush_influence_scale: float
    """ Adjust influence brush objects have on this surface (in [0, 1], default 0.0)"""

    brush_radius_scale: float
    """ Adjust radius of proximity brushes or particles for this surface (in [0, 10], default 0.0)"""

    color_dry_threshold: float
    """ The wetness level when colors start to shift to the background (in [0, 1], default 0.0)"""

    color_spread_speed: float
    """ How fast colors get mixed within wet paint (in [0, 2], default 0.0)"""

    depth_clamp: float
    """ Maximum level of depth intersection in object space (use 0.0 to disable) (in [0, 50], default 0.0)"""

    displace_factor: float
    """ Strength of displace when applied to the mesh (in [-50, 50], default 0.0)"""

    displace_type: typing.Literal["DISPLACE", "DEPTH"]
    """ (default 'DISPLACE')"""

    dissolve_speed: int
    """ Approximately in how many frames should dissolve happen (in [1, 10000], default 0)"""

    drip_acceleration: float
    """ How much surface acceleration affects dripping (in [-200, 200], default 0.0)"""

    drip_velocity: float
    """ How much surface velocity affects dripping (in [-200, 200], default 0.0)"""

    dry_speed: int
    """ Approximately in how many frames should drying happen (in [1, 10000], default 0)"""

    effect_ui: typing.Literal["SPREAD", "DRIP", "SHRINK"]
    """ (default 'SPREAD')"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    frame_end: int
    """ Simulation end frame (in [1, 1048574], default 0)"""

    frame_start: int
    """ Simulation start frame (in [1, 1048574], default 0)"""

    frame_substeps: int
    """ Do extra frames between scene frames to ensure smooth motion (in [0, 20], default 0)"""

    image_fileformat: typing.Literal["PNG", "OPENEXR"]
    """ (default 'PNG')"""

    image_output_path: str
    """ Directory to save the textures (default "", never None, blend relative // prefix supported)"""

    image_resolution: int
    """ Output image resolution (in [16, 4096], default 0)"""

    init_color: typing.Any
    """ Initial color of the surface (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    init_color_type: typing.Literal["NONE", "COLOR", "TEXTURE", "VERTEX_COLOR"]
    """ (default 'NONE')"""

    init_layername: str
    """ (default "", never None)"""

    init_texture: Texture | None
    is_active: bool
    """ Toggle whether surface is processed or ignored (default False)"""

    is_cache_user: bool
    """ (default False, readonly)"""

    name: str
    """ Surface name (default "", never None)"""

    output_name_a: str
    """ Name used to save output from this surface (default "", never None)"""

    output_name_b: str
    """ Name used to save output from this surface (default "", never None)"""

    point_cache: PointCache | None
    """ (readonly, never None)"""

    shrink_speed: float
    """ How fast shrink effect moves on the canvas surface (in [0.001, 10], default 0.0)"""

    spread_speed: float
    """ How fast spread effect moves on the canvas surface (in [0.001, 10], default 0.0)"""

    surface_format: typing.Literal["VERTEX", "IMAGE"]
    """ Surface Format (default 'VERTEX')"""

    surface_type: typing.Literal["PAINT"]
    """ Surface Type (default 'PAINT')"""

    use_antialiasing: bool
    """ Use 5× multisampling to smooth paint edges (default False)"""

    use_dissolve: bool
    """ Enable to make surface changes disappear over time (default False)"""

    use_dissolve_log: bool
    """ Use logarithmic dissolve (makes high values to fade faster than low values) (default False)"""

    use_drip: bool
    """ Process drip effect (drip wet paint to gravity direction) (default False)"""

    use_dry_log: bool
    """ Use logarithmic drying (makes high values to dry faster than low values) (default False)"""

    use_drying: bool
    """ Enable to make surface wetness dry over time (default False)"""

    use_incremental_displace: bool
    """ New displace is added cumulatively on top of existing (default False)"""

    use_output_a: bool
    """ Save this output layer (default False)"""

    use_output_b: bool
    """ Save this output layer (default False)"""

    use_premultiply: bool
    """ Multiply color by alpha (recommended for Blender input) (default False)"""

    use_shrink: bool
    """ Process shrink effect (shrink paint areas) (default False)"""

    use_spread: bool
    """ Process spread effect (spread wet paint around surface) (default False)"""

    use_wave_open_border: bool
    """ Pass waves through mesh edges (default False)"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    wave_damping: float
    """ Wave damping factor (in [0, 1], default 0.0)"""

    wave_smoothness: float
    """ Limit maximum steepness of wave slope between simulation points (use higher values for smoother waves at expense of reduced detail) (in [0, 10], default 0.0)"""

    wave_speed: float
    """ Wave propagation speed (in [0.01, 5], default 0.0)"""

    wave_spring: float
    """ Spring force that pulls water level back to zero (in [0, 1], default 0.0)"""

    wave_timescale: float
    """ Wave time scaling factor (in [0.01, 3], default 0.0)"""

    def output_exists(self, object: Object | None, index: int | None) -> bool:
        """Checks if surface output layer of given name exists

        :param object: (never None)
        :param index: Index, (in [0, 1])
        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EQCurveMappingData(bpy_struct):
    """EQCurveMappingData"""

    curve_mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EchoModifier(StripModifier, bpy_struct):
    """Tooltip"""

    delay: float
    """ The delay of the effect in seconds (in [0.05, 5], default 0.0)"""

    feedback: float
    """ The feedback of the effect (in [0, 1], default 0.0)"""

    mix: float
    """ The wet/dry mix of the effect (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EdgeSplitModifier(Modifier, bpy_struct):
    """Edge splitting modifier to create sharp edges"""

    split_angle: float
    """ Angle above which to split edges (in [0, 3.14159], default 0.523599)"""

    use_edge_angle: bool
    """ Split edges with high angle between faces (default True)"""

    use_edge_sharp: bool
    """ Split edges that are marked as sharp (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EditBone(bpy_struct):
    """Edit mode bone in an armature data-block"""

    bbone_curveinx: float
    """ X-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveinz: float
    """ Z-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutx: float
    """ X-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutz: float
    """ Z-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_custom_handle_end: typing_extensions.Self | None
    """ Bone that serves as the end handle for the B-Bone curve"""

    bbone_custom_handle_start: typing_extensions.Self | None
    """ Bone that serves as the start handle for the B-Bone curve"""

    bbone_easein: float
    """ Length of first Bézier Handle (for B-Bones only) (in [-inf, inf], default 1.0)"""

    bbone_easeout: float
    """ Length of second Bézier Handle (for B-Bones only) (in [-inf, inf], default 1.0)"""

    bbone_handle_type_end: typing.Literal["AUTO", "ABSOLUTE", "RELATIVE", "TANGENT"]
    """ Selects how the end handle of the B-Bone is computed (default 'AUTO')"""

    bbone_handle_type_start: typing.Literal["AUTO", "ABSOLUTE", "RELATIVE", "TANGENT"]
    """ Selects how the start handle of the B-Bone is computed (default 'AUTO')"""

    bbone_handle_use_ease_end: bool
    """ Multiply the B-Bone Ease Out channel by the local Y scale value of the end handle. This is done after the Scale Easing option and isn't affected by it. (default False)"""

    bbone_handle_use_ease_start: bool
    """ Multiply the B-Bone Ease In channel by the local Y scale value of the start handle. This is done after the Scale Easing option and isn't affected by it. (default False)"""

    bbone_handle_use_scale_end: typing.Any
    """ Multiply B-Bone Scale Out channels by the local scale values of the end handle. This is done after the Scale Easing option and isn't affected by it. (array of 3 items, default (False, False, False))"""

    bbone_handle_use_scale_start: typing.Any
    """ Multiply B-Bone Scale In channels by the local scale values of the start handle. This is done after the Scale Easing option and isn't affected by it. (array of 3 items, default (False, False, False))"""

    bbone_mapping_mode: typing.Literal["STRAIGHT", "CURVED"]
    """ Selects how the vertices are mapped to B-Bone segments based on their position (default 'STRAIGHT')"""

    bbone_rollin: float
    """ Roll offset for the start of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_rollout: float
    """ Roll offset for the end of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_scalein: mathutils.Vector
    """ Scale factors for the start of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    bbone_scaleout: mathutils.Vector
    """ Scale factors for the end of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    bbone_segments: int
    """ Number of subdivisions of bone (for B-Bones only) (in [1, 32], default 0)"""

    bbone_x: float
    """ B-Bone X size (in [-inf, inf], default 0.0)"""

    bbone_z: float
    """ B-Bone Z size (in [-inf, inf], default 0.0)"""

    collections: typing.Any
    """ Bone Collections that contain this bone (default None, readonly)"""

    color: BoneColor | None
    """ (readonly)"""

    display_type: typing.Literal[
        "ARMATURE_DEFINED", "OCTAHEDRAL", "STICK", "BBONE", "ENVELOPE", "WIRE"
    ]
    """ (default 'OCTAHEDRAL')"""

    envelope_distance: float
    """ Bone deformation distance (for Envelope deform only) (in [0, 1000], default 0.0)"""

    envelope_weight: float
    """ Bone deformation weight (for Envelope deform only) (in [0, 1000], default 0.0)"""

    head: mathutils.Vector
    """ Location of head end of the bone (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    head_radius: float
    """ Radius of head of bone (for Envelope deform only) (in [-inf, inf], default 0.0)"""

    hide: bool
    """ Bone is not visible when in Edit Mode (default False)"""

    hide_select: bool
    """ Bone is able to be selected (default False)"""

    inherit_scale: typing.Literal[
        "FULL", "FIX_SHEAR", "ALIGNED", "AVERAGE", "NONE", "NONE_LEGACY"
    ]
    """ Specifies how the bone inherits scaling from the parent bone (default 'FULL')"""

    length: float
    """ Length of the bone. Changing moves the tail end. (in [0, inf], default 0.0)"""

    lock: bool
    """ Bone is not able to be transformed when in Edit Mode (default False)"""

    matrix: mathutils.Matrix
    """ Matrix combining location and rotation of the bone (head position, direction and roll), in armature space (does not include/support bone's length/size) (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    name: str
    """ (default "", never None)"""

    parent: EditBone | None
    """ Parent edit bone (in same Armature)"""

    roll: float
    """ Bone rotation around head-tail axis (in [-inf, inf], default 0.0)"""

    select: bool
    """ (default False)"""

    select_head: bool
    """ (default False)"""

    select_tail: bool
    """ (default False)"""

    show_wire: bool
    """ Bone is always displayed in wireframe regardless of viewport shading mode (useful for non-obstructive custom bone shapes) (default False)"""

    tail: mathutils.Vector
    """ Location of tail end of the bone (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    tail_radius: float
    """ Radius of tail of bone (for Envelope deform only) (in [-inf, inf], default 0.0)"""

    use_connect: bool
    """ When bone has a parent, bone's head is stuck to the parent's tail (default False)"""

    use_cyclic_offset: bool
    """ When bone does not have a parent, it receives cyclic offset effects (Deprecated) (default False)"""

    use_deform: bool
    """ Enable Bone to deform geometry (default False)"""

    use_endroll_as_inroll: bool
    """ Add Roll Out of the Start Handle bone to the Roll In value (default False)"""

    use_envelope_multiply: bool
    """ When deforming bone, multiply effects of Vertex Group weights with Envelope influence (default False)"""

    use_inherit_rotation: bool
    """ Bone inherits rotation or scale from parent bone (default False)"""

    use_local_location: bool
    """ Bone location is set in local space (default False)"""

    use_relative_parent: bool
    """ Object children will use relative transform, like deform (default False)"""

    use_scale_easing: bool
    """ Multiply the final easing values by the Scale In/Out Y factors (default False)"""

    basename: typing.Any
    """ The name of this bone before any . character.(readonly)"""

    center: typing.Any
    """ The midpoint between the head and the tail.(readonly)"""

    children: typing.Any
    """ A list of all the bones children.(readonly)"""

    children_recursive: typing.Any
    """ A list of all children from this bone.(readonly)"""

    children_recursive_basename: typing.Any
    """ Returns a chain of children with the same base name as this bone.
Only direct chains are supported, forks caused by multiple children
with matching base names will terminate the function
and not be returned.(readonly)"""

    parent_recursive: typing.Any
    """ A list of parents, starting with the immediate parent.(readonly)"""

    vector: typing.Any
    """ The direction this bone is pointing.
Utility function for (tail - head)(readonly)"""

    x_axis: typing.Any
    """ Vector pointing down the x-axis of the bone.(readonly)"""

    y_axis: typing.Any
    """ Vector pointing down the y-axis of the bone.(readonly)"""

    z_axis: typing.Any
    """ Vector pointing down the z-axis of the bone.(readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def align_roll(
        self, vector: collections.abc.Sequence[float] | mathutils.Vector | None
    ) -> None:
        """Align the bone to a local-space roll so the Z axis points in the direction of the vector given

        :param vector: Vector, (array of 3 items, in [-inf, inf])
        """

    def align_orientation(self, other) -> None:
        """Align this bone to another by moving its tail and settings its roll
        the length of the other bone is not used.

                :param other:
        """

    def parent_index(self, parent_test) -> None:
        """The same as bone in other_bone.parent_recursive
        but saved generating a list.

                :param parent_test:
        """

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        scale: bool | None = True,
        roll: bool | None = True,
    ) -> None:
        """Transform the bones head, tail, roll and envelope
        (when the matrix has a scale component).

                :param matrix: 3x3 or 4x4 transformation matrix.
                :param scale: Scale the bone envelope by the matrix.
                :param roll: Correct the roll to point in the same relative
        direction to the head and tail.
        """

    def translate(self, vec) -> None:
        """Utility function to add vec to the head and tail of this bone.

        :param vec:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EffectStrip(Strip, bpy_struct):
    """Sequence strip applying an effect on the images created by other strips"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    crop: StripCrop | None
    """ (readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    proxy: StripProxy | None
    """ (readonly)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_proxy: bool
    """ Use a preview proxy and/or time-code index for this strip (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EffectorWeights(bpy_struct):
    """Effector weights for physics simulation"""

    all: float
    """ All effector's weight (in [-200, 200], default 0.0)"""

    apply_to_hair_growing: bool
    """ Use force fields when growing hair (default False)"""

    boid: float
    """ Boid effector weight (in [-200, 200], default 0.0)"""

    charge: float
    """ Charge effector weight (in [-200, 200], default 0.0)"""

    collection: Collection | None
    """ Limit effectors to this collection"""

    curve_guide: float
    """ Curve guide effector weight (in [-200, 200], default 0.0)"""

    drag: float
    """ Drag effector weight (in [-200, 200], default 0.0)"""

    force: float
    """ Force effector weight (in [-200, 200], default 0.0)"""

    gravity: float
    """ Global gravity weight (in [-200, 200], default 0.0)"""

    harmonic: float
    """ Harmonic effector weight (in [-200, 200], default 0.0)"""

    lennardjones: float
    """ Lennard-Jones effector weight (in [-200, 200], default 0.0)"""

    magnetic: float
    """ Magnetic effector weight (in [-200, 200], default 0.0)"""

    smokeflow: float
    """ Fluid Flow effector weight (in [-200, 200], default 0.0)"""

    texture: float
    """ Texture effector weight (in [-200, 200], default 0.0)"""

    turbulence: float
    """ Turbulence effector weight (in [-200, 200], default 0.0)"""

    vortex: float
    """ Vortex effector weight (in [-200, 200], default 0.0)"""

    wind: float
    """ Wind effector weight (in [-200, 200], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EnumProperty(Property, bpy_struct):
    """RNA enumeration property definition, to choose from a number of predefined options"""

    default: typing.Literal["DEFAULT"]
    """ Default value for this enum (default 'DEFAULT', readonly)"""

    default_flag: set[typing.Literal["DEFAULT"]]
    """ Default value for this enum (default set(), readonly)"""

    enum_items: typing.Any
    """ Possible values for the property (default None, readonly)"""

    enum_items_static: typing.Any
    """ Possible values for the property (never calls optional dynamic generation of those) (default None, readonly)"""

    enum_items_static_ui: typing.Any
    """ Possible values for the property (never calls optional dynamic generation of those). Includes UI elements (separators and section headings). (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EnumPropertyItem(bpy_struct):
    """Definition of a choice in an RNA enum property"""

    description: str
    """ Description of the item's purpose (default "", readonly, never None)"""

    icon: Literal[bpy.stub_internal.rna_enums.IconItems]
    """ Icon of the item (default 'NONE', readonly)"""

    identifier: str
    """ Unique name used in the code and scripting (default "", readonly, never None)"""

    name: str
    """ Human readable name (default "", readonly, never None)"""

    value: int
    """ Value of the item (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class EvaluateClosureNodeViewerPathElem(ViewerPathElem, bpy_struct):
    evaluate_node_id: int
    """ (in [-inf, inf], default 0)"""

    source_node_tree: NodeTree | None
    """ (readonly)"""

    source_output_node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Event(bpy_struct):
    """Window Manager Event"""

    alt: bool
    """ True when the Alt/Option key is held (default False, readonly)"""

    ascii: str
    """ Single ASCII character for this event (default "", readonly, never None)"""

    ctrl: bool
    """ True when the Ctrl key is held (default False, readonly)"""

    direction: Literal[bpy.stub_internal.rna_enums.EventDirectionItems]
    """ The direction (only applies to drag events) (default 'ANY', readonly)"""

    hyper: bool
    """ True when the Hyper key is held (default False, readonly)"""

    is_consecutive: bool
    """ Part of a trackpad or NDOF motion, interrupted by cursor motion, button or key press events (default False, readonly)"""

    is_mouse_absolute: bool
    """ The last motion event was an absolute input (default False, readonly)"""

    is_repeat: bool
    """ The event is generated by holding a key down (default False, readonly)"""

    is_tablet: bool
    """ The event has tablet data (default False, readonly)"""

    mouse_prev_press_x: int
    """ The window relative horizontal location of the last press event (in [-inf, inf], default 0, readonly)"""

    mouse_prev_press_y: int
    """ The window relative vertical location of the last press event (in [-inf, inf], default 0, readonly)"""

    mouse_prev_x: int
    """ The window relative horizontal location of the mouse (in [-inf, inf], default 0, readonly)"""

    mouse_prev_y: int
    """ The window relative vertical location of the mouse (in [-inf, inf], default 0, readonly)"""

    mouse_region_x: int
    """ The region relative horizontal location of the mouse (in [-inf, inf], default 0, readonly)"""

    mouse_region_y: int
    """ The region relative vertical location of the mouse (in [-inf, inf], default 0, readonly)"""

    mouse_x: int
    """ The window relative horizontal location of the mouse (in [-inf, inf], default 0, readonly)"""

    mouse_y: int
    """ The window relative vertical location of the mouse (in [-inf, inf], default 0, readonly)"""

    ndof_motion: NDOFMotionEventData | None
    """ NDOF motion event data (readonly)"""

    oskey: bool
    """ True when the Cmd key is held (default False, readonly)"""

    pressure: float
    """ The pressure of the tablet or 1.0 if no tablet present (in [0, 1], default 1.0, readonly)"""

    shift: bool
    """ True when the Shift key is held (default False, readonly)"""

    tilt: mathutils.Vector
    """ The pressure of the tablet or zeroes if no tablet present (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    type: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
    """ (default 'NONE', readonly)"""

    type_prev: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
    """ (default 'NONE', readonly)"""

    unicode: str
    """ Single unicode character for this event (default "", readonly, never None)"""

    value: Literal[bpy.stub_internal.rna_enums.EventValueItems]
    """ The type of event, only applies to some (default 'NOTHING', readonly)"""

    value_prev: Literal[bpy.stub_internal.rna_enums.EventValueItems]
    """ The type of event, only applies to some (default 'NOTHING', readonly)"""

    xr: XrEventData | None
    """ XR event data (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ExplodeModifier(Modifier, bpy_struct):
    """Explosion effect modifier based on a particle system"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    particle_uv: str
    """ UV map to change with particle age (default "", never None)"""

    protect: float
    """ Clean vertex group edges (in [0, 1], default 0.0)"""

    show_alive: bool
    """ Show mesh when particles are alive (default True)"""

    show_dead: bool
    """ Show mesh when particles are dead (default True)"""

    show_unborn: bool
    """ Show mesh when particles are unborn (default True)"""

    use_edge_cut: bool
    """ Cut face edges for nicer shrapnel (default False)"""

    use_size: bool
    """ Use particle size for the shrapnel (default False)"""

    vertex_group: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FCurve(bpy_struct):
    """F-Curve defining values of a period of time"""

    array_index: int
    """ Index to the specific property affected by F-Curve if applicable (in [0, inf], default 0)"""

    auto_smoothing: Literal[bpy.stub_internal.rna_enums.FcurveAutoSmoothingItems]
    """ Algorithm used to compute automatic handles (default 'NONE')"""

    color: mathutils.Color
    """ Color of the F-Curve in the Graph Editor (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    color_mode: typing.Literal["AUTO_RAINBOW", "AUTO_RGB", "AUTO_YRGB", "CUSTOM"]
    """ Method used to determine color of F-Curve in Graph Editor (default 'AUTO_RAINBOW')"""

    data_path: str
    """ RNA Path to property affected by F-Curve (default "", never None)"""

    driver: Driver | None
    """ Channel Driver (only set for Driver F-Curves) (readonly)"""

    extrapolation: typing.Literal["CONSTANT", "LINEAR"]
    """ Method used for evaluating value of F-Curve outside first and last keyframes (default 'CONSTANT')"""

    group: ActionGroup | None
    """ Action Group that this F-Curve belongs to"""

    hide: bool
    """ F-Curve and its keyframes are hidden in the Graph Editor graphs (default True)"""

    is_empty: bool
    """ True if the curve contributes no animation due to lack of keyframes or useful modifiers, and should be deleted (default False, readonly)"""

    is_valid: bool
    """ False when F-Curve could not be evaluated in past, so should be skipped when evaluating (default True)"""

    keyframe_points: typing.Any
    """ User-editable keyframes (default None, readonly)"""

    lock: bool
    """ F-Curve's settings cannot be edited (default False)"""

    modifiers: typing.Any
    """ Modifiers affecting the shape of the F-Curve (default None, readonly)"""

    mute: bool
    """ Disable F-Curve evaluation (default False)"""

    sampled_points: typing.Any
    """ Sampled animation data (default None, readonly)"""

    select: bool
    """ F-Curve is selected for editing (default False)"""

    def evaluate(self, frame: float | None) -> float:
        """Evaluate F-Curve

        :param frame: Frame, Evaluate F-Curve at given frame (in [-inf, inf])
        :return: Value, Value of F-Curve specific frame (in [-inf, inf])
        """

    def update(self) -> None:
        """Ensure keyframes are sorted in chronological order and handles are set correctly"""

    def range(self) -> mathutils.Vector:
        """Get the time extents for F-Curve

        :return: Range, Min/Max values (array of 2 items, in [-inf, inf])
        """

    def update_autoflags(self, data: typing.Any | None) -> None:
        """Update FCurve flags set automatically from affected property (currently, integer/discrete flags set when the property is not a float)

        :param data: Data, Data containing the property controlled by given FCurve (never None)
        """

    def convert_to_samples(self, start: int | None, end: int | None) -> None:
        """Convert current FCurve from keyframes to sample points, if necessary

        :param start: Start Frame, (in [-1048574, 1048574])
        :param end: End Frame, (in [-1048574, 1048574])
        """

    def convert_to_keyframes(self, start: int | None, end: int | None) -> None:
        """Convert current FCurve from sample points to keyframes (linear interpolation), if necessary

        :param start: Start Frame, (in [-1048574, 1048574])
        :param end: End Frame, (in [-1048574, 1048574])
        """

    def bake(
        self,
        start: int | None,
        end: int | None,
        *,
        step: float | None = 1.0,
        remove: typing.Literal["NONE", "IN_RANGE", "OUT_RANGE", "ALL"]
        | None = "IN_RANGE",
    ) -> None:
        """Place keys at even intervals on the existing curve.

                :param start: Start Frame, Frame at which to start baking (in [-1048574, 1048574])
                :param end: End Frame, Frame at which to end baking (inclusive) (in [-1048574, 1048574])
                :param step: Step, At which interval to add keys (in [0.01, inf], optional)
                :param remove: Remove Options, Choose which keys should be automatically removed by the bake (optional)

        NONE
        None -- Keep all keys.

        IN_RANGE
        In Range -- Remove all keys within the defined range.

        OUT_RANGE
        Outside Range -- Remove all keys outside the defined range.

        ALL
        All -- Remove all existing keys.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FCurveSample(bpy_struct):
    """Sample point for F-Curve"""

    co: mathutils.Vector
    """ Point coordinates (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    select: bool
    """ Selection status (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FFmpegSettings(bpy_struct):
    """FFmpeg related settings for the scene"""

    audio_bitrate: int
    """ Audio bitrate (kb/s) (in [32, 2048], default 192)"""

    audio_channels: typing.Literal[
        "MONO", "STEREO", "SURROUND4", "SURROUND51", "SURROUND71"
    ]
    """ Audio channel count (default 'STEREO')"""

    audio_codec: typing.Literal[
        "NONE", "AAC", "AC3", "FLAC", "MP2", "MP3", "OPUS", "PCM", "VORBIS"
    ]
    """ FFmpeg audio codec to use (default 'NONE')"""

    audio_mixrate: int
    """ Audio sample rate (samples/s) (in [8000, 192000], default 48000)"""

    audio_volume: float
    """ Audio volume (in [0, 1], default 1.0)"""

    buffersize: int
    """ Rate control: buffer size (kb) (in [0, 2000], default 0)"""

    codec: typing.Literal[
        "NONE",
        "AV1",
        "H264",
        "H265",
        "WEBM",
        "DNXHD",
        "DV",
        "FFV1",
        "FLASH",
        "HUFFYUV",
        "MPEG1",
        "MPEG2",
        "MPEG4",
        "PNG",
        "PRORES",
        "QTRLE",
        "THEORA",
    ]
    """ FFmpeg codec to use for video output (default 'H264')"""

    constant_rate_factor: typing.Literal[
        "NONE",
        "LOSSLESS",
        "PERC_LOSSLESS",
        "HIGH",
        "MEDIUM",
        "LOW",
        "VERYLOW",
        "LOWEST",
        "CUSTOM",
    ]
    """ Constant Rate Factor (CRF); tradeoff between video quality and file size (default 'MEDIUM')"""

    custom_constant_rate_factor: int
    """ A smaller Constant Rate Factor (CRF) results in better video quality but larger file size. The range of allowed CRF values is dependent on the codec. (in [0, 63], default 23)"""

    ffmpeg_preset: typing.Literal["BEST", "GOOD", "REALTIME"]
    """ Tradeoff between encoding speed and compression ratio (default 'GOOD')"""

    ffmpeg_prores_profile: typing.Literal[
        "422_PROXY", "422_LT", "422_STD", "422_HQ", "4444", "4444_XQ"
    ]
    """ ProRes Profile (default '422_STD')"""

    format: typing.Literal[
        "MPEG4",
        "MKV",
        "WEBM",
        "AVI",
        "DV",
        "FLASH",
        "MPEG1",
        "MPEG2",
        "OGG",
        "QUICKTIME",
    ]
    """ Output file container (default 'MKV')"""

    gopsize: int
    """ Distance between key frames, also known as GOP size; influences file size and seekability (in [0, 500], default 25)"""

    max_b_frames: int
    """ Maximum number of B-frames between non-B-frames; influences file size and seekability (in [0, 16], default 0)"""

    maxrate: int
    """ Rate control: max rate (kbit/s) (in [-inf, inf], default 0)"""

    minrate: int
    """ Rate control: min rate (kbit/s) (in [-inf, inf], default 0)"""

    muxrate: int
    """ Mux rate (bits/second) (in [0, inf], default 0)"""

    packetsize: int
    """ Mux packet size (byte) (in [0, 16384], default 0)"""

    use_autosplit: bool
    """ Autosplit output at 2GB boundary (default False)"""

    use_lossless_output: bool
    """ Use lossless output for video streams (default False)"""

    use_max_b_frames: bool
    """ Set a maximum number of B-frames (default False)"""

    video_bitrate: int
    """ Video bitrate (kbit/s) (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FILEBROWSER_UL_dir(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifier(bpy_struct):
    """Modifier for values of F-Curve"""

    active: bool | None
    """ F-Curve modifier will show settings in the editor (default False)"""

    blend_in: float
    """ Number of frames from start frame for influence to take effect (in [-inf, inf], default 0.0)"""

    blend_out: float
    """ Number of frames from end frame for influence to fade out (in [-inf, inf], default 0.0)"""

    frame_end: float
    """ Frame that modifier's influence ends (if Restrict Frame Range is in use) (in [-inf, inf], default 0.0)"""

    frame_start: float
    """ Frame that modifier's influence starts (if Restrict Frame Range is in use) (in [-inf, inf], default 0.0)"""

    influence: float
    """ Amount of influence F-Curve Modifier will have when not fading in/out (in [0, 1], default 1.0)"""

    is_valid: bool
    """ F-Curve Modifier has invalid settings and will not be evaluated (default True, readonly)"""

    mute: bool
    """ Enable F-Curve modifier evaluation (default False)"""

    name: str
    """ F-Curve Modifier name (default "", never None)"""

    show_expanded: bool
    """ F-Curve Modifier's panel is expanded in UI (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.FmodifierTypeItems]
    """ F-Curve Modifier Type (default 'NULL', readonly)"""

    use_influence: bool
    """ F-Curve Modifier's effects will be tempered by a default factor (default False)"""

    use_restricted_range: bool
    """ F-Curve Modifier is only applied for the specified frame range to help mask off effects in order to chain them (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierCycles(FModifier, bpy_struct):
    """Repeat the values of the modified F-Curve"""

    cycles_after: int
    """ Maximum number of cycles to allow after last keyframe (0 = infinite) (in [-32768, 32767], default 0)"""

    cycles_before: int
    """ Maximum number of cycles to allow before first keyframe (0 = infinite) (in [-32768, 32767], default 0)"""

    mode_after: typing.Literal["NONE", "REPEAT", "REPEAT_OFFSET", "MIRROR"]
    """ Cycling mode to use after last keyframe (default 'NONE')"""

    mode_before: typing.Literal["NONE", "REPEAT", "REPEAT_OFFSET", "MIRROR"]
    """ Cycling mode to use before first keyframe (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierEnvelope(FModifier, bpy_struct):
    """Scale the values of the modified F-Curve"""

    control_points: typing.Any
    """ Control points defining the shape of the envelope (default None, readonly)"""

    default_max: float
    """ Upper distance from Reference Value for 1:1 default influence (in [-inf, inf], default 1.0)"""

    default_min: float
    """ Lower distance from Reference Value for 1:1 default influence (in [-inf, inf], default -1.0)"""

    reference_value: float
    """ Value that envelope's influence is centered around / based on (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierEnvelopeControlPoint(bpy_struct):
    """Control point for envelope F-Modifier"""

    frame: float
    """ Frame this control-point occurs on (in [-inf, inf], default 0.0)"""

    max: float
    """ Upper bound of envelope at this control-point (in [-inf, inf], default 0.0)"""

    min: float
    """ Lower bound of envelope at this control-point (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierFunctionGenerator(FModifier, bpy_struct):
    """Generate values using a built-in function"""

    amplitude: float
    """ Scale factor determining the maximum/minimum values (in [-inf, inf], default 1.0)"""

    function_type: typing.Literal["SIN", "COS", "TAN", "SQRT", "LN", "SINC"]
    """ Type of built-in function to use (default 'SIN')"""

    phase_multiplier: float
    """ Scale factor determining the 'speed' of the function (in [-inf, inf], default 1.0)"""

    phase_offset: float
    """ Constant factor to offset time by for function (in [-inf, inf], default 0.0)"""

    use_additive: bool
    """ Values generated by this modifier are applied on top of the existing values instead of overwriting them (default False)"""

    value_offset: float
    """ Constant factor to offset values by (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierGenerator(FModifier, bpy_struct):
    """Deterministically generate values for the modified F-Curve"""

    coefficients: typing.Any
    """ Coefficients for 'x' (starting from lowest power of x^0) (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))"""

    mode: typing.Literal["POLYNOMIAL", "POLYNOMIAL_FACTORISED"]
    """ Type of generator to use (default 'POLYNOMIAL')"""

    poly_order: int
    """ The highest power of 'x' for this polynomial (number of coefficients - 1) (in [1, 100], default 0)"""

    use_additive: bool
    """ Values generated by this modifier are applied on top of the existing values instead of overwriting them (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierLimits(FModifier, bpy_struct):
    """Limit the time/value ranges of the modified F-Curve"""

    max_x: float
    """ Highest X value to allow (in [-inf, inf], default 0.0)"""

    max_y: float
    """ Highest Y value to allow (in [-inf, inf], default 0.0)"""

    min_x: float
    """ Lowest X value to allow (in [-inf, inf], default 0.0)"""

    min_y: float
    """ Lowest Y value to allow (in [-inf, inf], default 0.0)"""

    use_max_x: bool
    """ Use the maximum X value (default False)"""

    use_max_y: bool
    """ Use the maximum Y value (default False)"""

    use_min_x: bool
    """ Use the minimum X value (default False)"""

    use_min_y: bool
    """ Use the minimum Y value (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierNoise(FModifier, bpy_struct):
    """Give randomness to the modified F-Curve"""

    blend_type: typing.Literal["REPLACE", "ADD", "SUBTRACT", "MULTIPLY"]
    """ Method of modifying the existing F-Curve (default 'REPLACE')"""

    depth: int
    """ Amount of fine level detail present in the noise (in [0, 32767], default 0)"""

    lacunarity: float
    """ Gap between successive frequencies. Depth needs to be greater than 0 for this to have an effect (in [-inf, inf], default 2.0)"""

    offset: float
    """ Time offset for the noise effect (in [-inf, inf], default 0.0)"""

    phase: float
    """ A random seed for the noise effect (in [-inf, inf], default 1.0)"""

    roughness: float
    """ Amount of high frequency detail. Depth needs to be greater than 0 for this to have an effect (in [-inf, inf], default 0.5)"""

    scale: float
    """ Scaling (in time) of the noise (in [-inf, inf], default 1.0)"""

    strength: float
    """ Amplitude of the noise - the amount that it modifies the underlying curve (in [-inf, inf], default 1.0)"""

    use_legacy_noise: bool
    """ Use the legacy way of generating noise. Has the issue that it can produce values outside of -1/1 (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierSmooth(FModifier, bpy_struct):
    """Smooth curve using Gaussian smoothing"""

    filter_width: int
    """ The number of frames to average around each keyframe. Higher values allow more smoothing, but will decrease performance. (in [1, 32], default 0)"""

    sigma: float
    """ The shape of the Gaussian distribution in frames. Lower values will increase sharpness across the Filter Width. (in [0.1, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FModifierStepped(FModifier, bpy_struct):
    """Hold each interpolated value from the F-Curve for several frames without changing the timing"""

    frame_end: float
    """ Frame that modifier's influence ends (if applicable) (in [-inf, inf], default 0.0)"""

    frame_offset: float
    """ Reference number of frames before frames get held (use to get hold for '1-3' vs '5-7' holding patterns) (in [-inf, inf], default 0.0)"""

    frame_start: float
    """ Frame that modifier's influence starts (if applicable) (in [-inf, inf], default 0.0)"""

    frame_step: float
    """ Number of frames to hold each value (in [-inf, inf], default 2.0)"""

    use_frame_end: bool
    """ Restrict modifier to only act before its 'end' frame (default False)"""

    use_frame_start: bool
    """ Restrict modifier to only act after its 'start' frame (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FieldSettings(bpy_struct):
    """Field settings for an object in physics simulation"""

    apply_to_location: bool
    """ Affect particle's location (default False)"""

    apply_to_rotation: bool
    """ Affect particle's dynamic rotation (default False)"""

    distance_max: float
    """ Maximum distance for the field to work (in [0, inf], default 0.0)"""

    distance_min: float
    """ Minimum distance for the field's falloff (in [0, 1000], default 0.0)"""

    falloff_power: float
    """ How quickly strength falls off with distance from the force field (in [0, 10], default 0.0)"""

    falloff_type: typing.Literal["CONE", "SPHERE", "TUBE"]
    """ (default 'SPHERE')"""

    flow: float
    """ Convert effector force into air flow velocity (in [-inf, inf], default 0.0)"""

    guide_clump_amount: float
    """ Amount of clumping (in [-1, 1], default 0.0)"""

    guide_clump_shape: float
    """ Shape of clumping (in [-0.999, 0.999], default 0.0)"""

    guide_free: float
    """ Guide-free time from particle life's end (in [0, 0.99], default 0.0)"""

    guide_kink_amplitude: float
    """ The amplitude of the offset (in [0, 10], default 0.0)"""

    guide_kink_axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Which axis to use for offset (default 'X')"""

    guide_kink_frequency: float
    """ The frequency of the offset (1/total length) (in [0, 10], default 0.0)"""

    guide_kink_shape: float
    """ Adjust the offset to the beginning/end (in [-0.999, 0.999], default 0.0)"""

    guide_kink_type: typing.Literal[
        "NONE", "BRAID", "CURL", "RADIAL", "ROLL", "ROTATION", "WAVE"
    ]
    """ Type of periodic offset on the curve (default 'NONE')"""

    guide_minimum: float
    """ The distance from which particles are affected fully (in [-inf, inf], default 0.0)"""

    harmonic_damping: float
    """ Damping of the harmonic force (in [-inf, inf], default 0.0)"""

    inflow: float
    """ Inwards component of the vortex force (in [-inf, inf], default 0.0)"""

    linear_drag: float
    """ Drag component proportional to velocity (in [-inf, inf], default 0.0)"""

    noise: float
    """ Amount of noise for the force strength (in [0, 10], default 0.0)"""

    quadratic_drag: float
    """ Drag component proportional to the square of velocity (in [-inf, inf], default 0.0)"""

    radial_falloff: float
    """ Radial falloff power (real gravitational falloff = 2) (in [0, 10], default 0.0)"""

    radial_max: float
    """ Maximum radial distance for the field to work (in [0, 1000], default 0.0)"""

    radial_min: float
    """ Minimum radial distance for the field's falloff (in [0, 1000], default 0.0)"""

    rest_length: float
    """ Rest length of the harmonic force (in [0, inf], default 0.0)"""

    seed: int
    """ Seed of the noise (in [1, 128], default 0)"""

    shape: typing.Literal["POINT", "LINE", "PLANE", "SURFACE", "POINTS"]
    """ Which direction is used to calculate the effector force (default 'POINT')"""

    size: float
    """ Size of the turbulence (in [0, inf], default 0.0)"""

    source_object: Object | None
    """ Select domain object of the smoke simulation"""

    strength: float
    """ Strength of force field (in [-inf, inf], default 0.0)"""

    texture: Texture | None
    """ Texture to use as force"""

    texture_mode: typing.Literal["CURL", "GRADIENT", "RGB"]
    """ How the texture effect is calculated (RGB and Curl need a RGB texture, else Gradient will be used instead) (default 'RGB')"""

    texture_nabla: float
    """ Defines size of derivative offset used for calculating gradient and curl (in [0.0001, 1], default 0.0)"""

    type: typing.Literal[
        "NONE",
        "BOID",
        "CHARGE",
        "GUIDE",
        "DRAG",
        "FLUID_FLOW",
        "FORCE",
        "HARMONIC",
        "LENNARDJ",
        "MAGNET",
        "TEXTURE",
        "TURBULENCE",
        "VORTEX",
        "WIND",
    ]
    """ Type of field (default 'NONE')"""

    use_2d_force: bool
    """ Apply force only in 2D (default False)"""

    use_absorption: bool
    """ Force gets absorbed by collision objects (default False)"""

    use_global_coords: bool
    """ Use effector/global coordinates for turbulence (default False)"""

    use_gravity_falloff: bool
    """ Multiply force by 1/distance² (default False)"""

    use_guide_path_add: bool
    """ Based on distance/falloff it adds a portion of the entire path (default False)"""

    use_guide_path_weight: bool
    """ Use curve weights to influence the particle influence along the curve (default False)"""

    use_max_distance: bool
    """ Use a maximum distance for the field to work (default False)"""

    use_min_distance: bool
    """ Use a minimum distance for the field's falloff (default False)"""

    use_multiple_springs: bool
    """ Every point is affected by multiple springs (default False)"""

    use_object_coords: bool
    """ Use object/global coordinates for texture (default False)"""

    use_radial_max: bool
    """ Use a maximum radial distance for the field to work (default False)"""

    use_radial_min: bool
    """ Use a minimum radial distance for the field's falloff (default False)"""

    use_root_coords: bool
    """ Texture coordinates from root particle locations (default False)"""

    use_smoke_density: bool
    """ Adjust force strength based on smoke density (default False)"""

    wind_factor: float
    """ How much the force is reduced when acting parallel to a surface, e.g. cloth (in [0, 1], default 0.0)"""

    z_direction: typing.Literal["POSITIVE", "NEGATIVE", "BOTH"]
    """ Effect in full or only positive/negative Z direction (default 'BOTH')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileAssetSelectIDFilter(bpy_struct):
    """Which asset types to show/hide, when browsing an asset library"""

    experimental_filter_annotations: bool
    """ Show Annotation data-blocks (default False)"""

    experimental_filter_armature: bool
    """ Show Armature data-blocks (default False)"""

    experimental_filter_cachefile: bool
    """ Show Cache File data-blocks (default False)"""

    experimental_filter_camera: bool
    """ Show Camera data-blocks (default False)"""

    experimental_filter_curve: bool
    """ Show Curve data-blocks (default False)"""

    experimental_filter_curves: bool
    """ Show/hide Curves data-blocks (default False)"""

    experimental_filter_font: bool
    """ Show Font data-blocks (default False)"""

    experimental_filter_grease_pencil: bool
    """ Show Grease Pencil data-blocks (default False)"""

    experimental_filter_image: bool
    """ Show Image data-blocks (default False)"""

    experimental_filter_lattice: bool
    """ Show Lattice data-blocks (default False)"""

    experimental_filter_light: bool
    """ Show Light data-blocks (default False)"""

    experimental_filter_light_probe: bool
    """ Show Light Probe data-blocks (default False)"""

    experimental_filter_linestyle: bool
    """ Show Freestyle's Line Style data-blocks (default False)"""

    experimental_filter_mask: bool
    """ Show Mask data-blocks (default False)"""

    experimental_filter_mesh: bool
    """ Show Mesh data-blocks (default False)"""

    experimental_filter_metaball: bool
    """ Show Metaball data-blocks (default False)"""

    experimental_filter_movie_clip: bool
    """ Show Movie Clip data-blocks (default False)"""

    experimental_filter_paint_curve: bool
    """ Show Paint Curve data-blocks (default False)"""

    experimental_filter_palette: bool
    """ Show Palette data-blocks (default False)"""

    experimental_filter_particle_settings: bool
    """ Show Particle Settings data-blocks (default False)"""

    experimental_filter_pointcloud: bool
    """ Show/hide Point Cloud data-blocks (default False)"""

    experimental_filter_sound: bool
    """ Show Sound data-blocks (default False)"""

    experimental_filter_speaker: bool
    """ Show Speaker data-blocks (default False)"""

    experimental_filter_text: bool
    """ Show Text data-blocks (default False)"""

    experimental_filter_texture: bool
    """ Show Texture data-blocks (default False)"""

    experimental_filter_volume: bool
    """ Show/hide Volume data-blocks (default False)"""

    experimental_filter_work_space: bool
    """ Show workspace data-blocks (default False)"""

    filter_action: bool
    """ Show Action data-blocks (default False)"""

    filter_brush: bool
    """ Show Brushes data-blocks (default False)"""

    filter_group: bool
    """ Show Collection data-blocks (default False)"""

    filter_material: bool
    """ Show Material data-blocks (default False)"""

    filter_node_tree: bool
    """ Show Node Tree data-blocks (default False)"""

    filter_object: bool
    """ Show Object data-blocks (default False)"""

    filter_scene: bool
    """ Show Scene data-blocks (default False)"""

    filter_world: bool
    """ Show World data-blocks (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileAssetSelectParams(FileSelectParams, bpy_struct):
    """Settings for the file selection in Asset Browser mode"""

    asset_library_reference: typing.Literal["ALL", "LOCAL", "ESSENTIALS", "CUSTOM"]
    """ (default 'ALL')"""

    catalog_id: str
    """ The UUID of the catalog shown in the browser (default "", never None)"""

    filter_asset_id: FileAssetSelectIDFilter | None
    """ Which asset types to show/hide, when browsing an asset library (readonly, never None)"""

    import_method: typing.Literal[
        "FOLLOW_PREFS", "LINK", "APPEND", "APPEND_REUSE", "PACK"
    ]
    """ Determine how the asset will be imported (default 'LINK')"""

    instance_collections_on_append: bool
    """ Create instances for collections when appending, rather than adding them directly to the scene (default False)"""

    instance_collections_on_link: bool
    """ Create instances for collections when linking, rather than adding them directly to the scene (default False)"""

    show_online_assets: bool
    """ When internet access is enabled, load and display online assets (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileBrowserFSMenuEntry(bpy_struct):
    """File Select Parameters"""

    icon: int
    """ (in [-inf, inf], default 0)"""

    name: str
    """ (default "", never None)"""

    path: str
    """ (default "", never None)"""

    use_save: bool
    """ Whether this path is saved in bookmarks, or generated from OS (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileHandler(bpy_struct):
    """Extends functionality to operators that manages files, such as adding drag and drop support"""

    bl_export_operator: str
    """ Operator that can handle export for files with the extensions given in bl_file_extensions (default "", never None)"""

    bl_file_extensions: str
    """ Formatted string of file extensions supported by the file handler, each extension should start with a "." and be separated by ";".
For Example: ".blend;.ble"(default "", never None)"""

    bl_idname: str
    """ If this is set, the file handler gets a custom ID, otherwise it takes the name of the class used to define the file handler (for example, if the class name is "OBJECT_FH_hello", and bl_idname is not set by the script, then bl_idname = "OBJECT_FH_hello") (default "", never None)"""

    bl_import_operator: str
    """ Operator that can handle import for files with the extensions given in bl_file_extensions (default "", never None)"""

    bl_label: str
    """ The file handler label (default "", never None)"""

    @classmethod
    def poll_drop(cls, context: Context) -> bool:
        """If this method returns True, can be used to handle the drop of a drag-and-drop action

        :param context:
        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileSelectEntry(bpy_struct):
    """A file viewable in the File Browser"""

    asset_data: AssetMetaData | None
    """ Asset data, valid if the file represents an asset (readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    preview_icon_id: int
    """ Unique integer identifying the preview of this file as an icon (zero means invalid) (in [-inf, inf], default 0, readonly)"""

    relative_path: str
    """ Path relative to the directory currently displayed in the File Browser (includes the file name) (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileSelectIDFilter(bpy_struct):
    """Which ID types to show/hide, when browsing a library"""

    category_animation: bool
    """ Show animation data (default False)"""

    category_environment: bool
    """ Show worlds, lights, cameras and speakers (default False)"""

    category_geometry: bool
    """ Show meshes, curves, lattice, armatures and metaballs data (default False)"""

    category_image: bool
    """ Show images, movie clips, sounds and masks (default False)"""

    category_misc: bool
    """ Show other data types (default False)"""

    category_object: bool
    """ Show objects and collections (default False)"""

    category_scene: bool
    """ Show scenes (default False)"""

    category_shading: bool
    """ Show materials, node-trees, textures and Freestyle's line-styles (default False)"""

    filter_action: bool
    """ Show Action data-blocks (default False)"""

    filter_annotations: bool
    """ Show Annotation data-blocks (default False)"""

    filter_armature: bool
    """ Show Armature data-blocks (default False)"""

    filter_brush: bool
    """ Show Brushes data-blocks (default False)"""

    filter_cachefile: bool
    """ Show Cache File data-blocks (default False)"""

    filter_camera: bool
    """ Show Camera data-blocks (default False)"""

    filter_curve: bool
    """ Show Curve data-blocks (default False)"""

    filter_curves: bool
    """ Show/hide Curves data-blocks (default False)"""

    filter_font: bool
    """ Show Font data-blocks (default False)"""

    filter_grease_pencil: bool
    """ Show Grease Pencil data-blocks (default False)"""

    filter_group: bool
    """ Show Collection data-blocks (default False)"""

    filter_image: bool
    """ Show Image data-blocks (default False)"""

    filter_lattice: bool
    """ Show Lattice data-blocks (default False)"""

    filter_light: bool
    """ Show Light data-blocks (default False)"""

    filter_light_probe: bool
    """ Show Light Probe data-blocks (default False)"""

    filter_linestyle: bool
    """ Show Freestyle's Line Style data-blocks (default False)"""

    filter_mask: bool
    """ Show Mask data-blocks (default False)"""

    filter_material: bool
    """ Show Material data-blocks (default False)"""

    filter_mesh: bool
    """ Show Mesh data-blocks (default False)"""

    filter_metaball: bool
    """ Show Metaball data-blocks (default False)"""

    filter_movie_clip: bool
    """ Show Movie Clip data-blocks (default False)"""

    filter_node_tree: bool
    """ Show Node Tree data-blocks (default False)"""

    filter_object: bool
    """ Show Object data-blocks (default False)"""

    filter_paint_curve: bool
    """ Show Paint Curve data-blocks (default False)"""

    filter_palette: bool
    """ Show Palette data-blocks (default False)"""

    filter_particle_settings: bool
    """ Show Particle Settings data-blocks (default False)"""

    filter_pointcloud: bool
    """ Show/hide Point Cloud data-blocks (default False)"""

    filter_scene: bool
    """ Show Scene data-blocks (default False)"""

    filter_sound: bool
    """ Show Sound data-blocks (default False)"""

    filter_speaker: bool
    """ Show Speaker data-blocks (default False)"""

    filter_text: bool
    """ Show Text data-blocks (default False)"""

    filter_texture: bool
    """ Show Texture data-blocks (default False)"""

    filter_volume: bool
    """ Show/hide Volume data-blocks (default False)"""

    filter_work_space: bool
    """ Show workspace data-blocks (default False)"""

    filter_world: bool
    """ Show World data-blocks (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FileSelectParams(bpy_struct):
    """File Select Parameters"""

    directory: bytes
    """ Directory displayed in the file browser (default b"", never None)"""

    display_size: int
    """ Change the size of thumbnails (in [16, 256], default 96)"""

    display_size_discrete: typing.Literal["TINY", "SMALL", "NORMAL", "BIG", "LARGE"]
    """ Change the size of thumbnails in discrete steps (default 'TINY')"""

    display_type: typing.Literal["LIST_VERTICAL", "LIST_HORIZONTAL", "THUMBNAIL"]
    """ Display mode for the file list (default 'LIST_VERTICAL')"""

    filename: str
    """ Active file in the file browser (default "", never None)"""

    filter_glob: str
    """ UNIX shell-like filename patterns matching, supports wildcards ('*') and list of patterns separated by ';' (default "", never None)"""

    filter_id: FileSelectIDFilter | None
    """ Which ID types to show/hide, when browsing a library (readonly, never None)"""

    filter_search: str
    """ Filter by name or tag, supports '*' wildcard (default "", never None)"""

    list_column_size: int
    """ The width of columns in horizontal list views (in [32, 750], default 32)"""

    list_display_size: int
    """ Change the size of thumbnails in list views (in [16, 128], default 32)"""

    recursion_level: typing.Literal["NONE", "BLEND", "ALL_1", "ALL_2", "ALL_3"]
    """ Numbers of dirtree levels to show simultaneously (default 'NONE')"""

    show_details_datetime: bool
    """ Show a column listing the date and time of modification for each file (default False)"""

    show_details_size: bool
    """ Show a column listing the size of each file (default False)"""

    show_hidden: bool
    """ Show hidden dot files (default True)"""

    sort_method: Literal[bpy.stub_internal.rna_enums.FileselectParamsSortItems]
    """ (default 'FILE_SORT_ALPHA')"""

    title: str
    """ Title for the file browser (default "", readonly, never None)"""

    use_filter: bool
    """ Enable filtering of files (default False)"""

    use_filter_asset_only: bool
    """ Hide .blend files items that are not data-blocks with asset metadata (default False)"""

    use_filter_backup: bool
    """ Show .blend1, .blend2, etc. files (default False)"""

    use_filter_blender: bool
    """ Show .blend files (default False)"""

    use_filter_blendid: bool
    """ Show .blend files items (objects, materials, etc.) (default False)"""

    use_filter_folder: bool
    """ Show folders (default False)"""

    use_filter_font: bool
    """ Show font files (default False)"""

    use_filter_image: bool
    """ Show image files (default False)"""

    use_filter_movie: bool
    """ Show movie files (default False)"""

    use_filter_script: bool
    """ Show script files (default False)"""

    use_filter_sound: bool
    """ Show sound files (default False)"""

    use_filter_text: bool
    """ Show text files (default False)"""

    use_filter_volume: bool
    """ Show 3D volume files (default False)"""

    use_library_browsing: bool
    """ Whether we may browse Blender files' content or not (default False, readonly)"""

    use_sort_invert: bool
    """ Sort items descending, from highest value to lowest (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float2Attribute(Attribute, bpy_struct):
    """Geometry attribute that stores floating-point 2D vectors"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float2AttributeValue(bpy_struct):
    """2D Vector value in geometry attribute"""

    vector: mathutils.Vector
    """ 2D vector (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float4Attribute(Attribute, bpy_struct):
    """Geometry attribute that stores floating-point 4D vectors"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float4AttributeValue(bpy_struct):
    """4D Vector value in geometry attribute"""

    vector: mathutils.Vector
    """ 4D vector (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float4x4Attribute(Attribute, bpy_struct):
    """Geometry attribute that stores a 4 by 4 float matrix"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Float4x4AttributeValue(bpy_struct):
    """Matrix value in geometry attribute"""

    value: mathutils.Matrix
    """ Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores floating-point values"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatAttributeValue(bpy_struct):
    """Floating-point value in geometry attribute"""

    value: float
    """ (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatColorAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores RGBA colors as floating-point values using 32-bits per channel"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatColorAttributeValue(bpy_struct):
    """Color value in geometry attribute"""

    color: typing.Any
    """ RGBA color in scene linear color space (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    color_srgb: typing.Any
    """ RGBA color in sRGB color space (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatProperty(Property, bpy_struct):
    """RNA floating-point number (single precision) property definition"""

    array_dimensions: typing.Any
    """ Length of each dimension of the array (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    array_length: int
    """ Maximum length of the array, 0 means unlimited (in [0, inf], default 0, readonly)"""

    default: float
    """ Default value for this number (in [-inf, inf], default 0.0, readonly)"""

    default_array: typing.Any
    """ Default value for this array (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    hard_max: float
    """ Maximum value used by buttons (in [-inf, inf], default 0.0, readonly)"""

    hard_min: float
    """ Minimum value used by buttons (in [-inf, inf], default 0.0, readonly)"""

    is_array: bool
    """ (default False, readonly)"""

    precision: int
    """ Number of digits after the dot used by buttons. Fraction is automatically hidden for exact integer values of fields with unit 'NONE' or 'TIME' (frame count) and step divisible by 100. (in [0, inf], default 0, readonly)"""

    soft_max: float
    """ Maximum value used by buttons (in [-inf, inf], default 0.0, readonly)"""

    soft_min: float
    """ Minimum value used by buttons (in [-inf, inf], default 0.0, readonly)"""

    step: float
    """ Step size used by number buttons, for floats 1/100th of the step size (in [0, inf], default 0.0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatVectorAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores floating-point 3D vectors"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatVectorAttributeValue(bpy_struct):
    """Vector value in geometry attribute"""

    vector: mathutils.Vector
    """ 3D vector (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloatVectorValueReadOnly(bpy_struct):
    vector: mathutils.Vector
    """ 3D vector (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FloorConstraint(Constraint, bpy_struct):
    """Use the target object for location limitation"""

    floor_location: typing.Literal[
        "FLOOR_X",
        "FLOOR_Y",
        "FLOOR_Z",
        "FLOOR_NEGATIVE_X",
        "FLOOR_NEGATIVE_Y",
        "FLOOR_NEGATIVE_Z",
    ]
    """ Location of target that object will not pass through (default 'FLOOR_X')"""

    offset: float
    """ Offset of floor from object origin (in [-inf, inf], default 0.0)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_rotation: bool
    """ Use the target's rotation to determine floor (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FluidDomainSettings(bpy_struct):
    """Fluid domain settings"""

    adapt_margin: int
    """ Margin added around fluid to minimize boundary interference (in [2, 24], default 4)"""

    adapt_threshold: float
    """ Minimum amount of fluid grid values (smoke density, fuel and heat) a cell can contain, before it is considered empty (in [0, 1], default 0.002)"""

    additional_res: int
    """ Maximum number of additional cells (in [0, 512], default 0)"""

    alpha: float
    """ Buoyant force based on smoke density (higher value results in faster rising smoke) (in [-5, 5], default 1.0)"""

    beta: float
    """ Buoyant force based on smoke heat (higher value results in faster rising smoke) (in [-5, 5], default 1.0)"""

    burning_rate: float
    """ Speed of the burning reaction (higher value results in smaller flames) (in [0.01, 4], default 0.75)"""

    cache_data_format: typing.Literal["UNI", "OPENVDB", "RAW"]
    """ Select the file format to be used for caching volumetric data (default 'OPENVDB')"""

    cache_directory: str
    """ Directory that contains fluid cache files (default "", never None, blend relative // prefix supported)"""

    cache_frame_end: int
    """ Frame on which the simulation stops (last frame baked) (in [-1048574, 1048574], default 250)"""

    cache_frame_offset: int
    """ Frame offset that is used when loading the simulation from the cache. It is not considered when baking the simulation, only when loading it. (in [-1048574, 1048574], default 0)"""

    cache_frame_pause_data: int
    """ (in [-inf, inf], default 0)"""

    cache_frame_pause_guide: int
    """ (in [-inf, inf], default 0)"""

    cache_frame_pause_mesh: int
    """ (in [-inf, inf], default 0)"""

    cache_frame_pause_noise: int
    """ (in [-inf, inf], default 0)"""

    cache_frame_pause_particles: int
    """ (in [-inf, inf], default 0)"""

    cache_frame_start: int
    """ Frame on which the simulation starts (first frame baked) (in [-1048574, 1048574], default 1)"""

    cache_mesh_format: typing.Literal["UNI", "OPENVDB", "RAW"]
    """ Select the file format to be used for caching surface data (default 'UNI')"""

    cache_noise_format: typing.Literal["UNI", "OPENVDB", "RAW"]
    """ Select the file format to be used for caching noise data (default 'OPENVDB')"""

    cache_particle_format: typing.Literal["UNI", "OPENVDB", "RAW"]
    """ Select the file format to be used for caching particle data (default 'OPENVDB')"""

    cache_resumable: bool
    """ Additional data will be saved so that the bake jobs can be resumed after pausing. Because more data will be written to disk it is recommended to avoid enabling this option when baking at high resolutions. (default False)"""

    cache_type: typing.Literal["REPLAY", "MODULAR", "ALL"]
    """ Change the cache type of the simulation (default 'REPLAY')"""

    cell_size: mathutils.Vector
    """ Cell Size (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    cfl_condition: float
    """ Maximal velocity per cell (greater CFL numbers will minimize the number of simulation steps and the computation time.) (in [0, 10], default 2.0)"""

    clipping: float
    """ Value under which voxels are considered empty space to optimize rendering (in [0, 1], default 1e-06)"""

    color_grid: typing.Any
    """ Smoke color grid (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    color_ramp: ColorRamp | None
    """ (readonly)"""

    color_ramp_field: typing.Literal["NONE"]
    """ Simulation field to color map (default 'NONE')"""

    color_ramp_field_scale: float
    """ Multiplier for scaling the selected field to color map (in [0.001, 100000], default 1.0)"""

    delete_in_obstacle: bool
    """ Delete fluid inside obstacles (default False)"""

    density_grid: typing.Any
    """ Smoke density grid (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    display_interpolation: typing.Literal["LINEAR", "CUBIC", "CLOSEST"]
    """ Interpolation method to use for smoke/fire volumes in solid mode (default 'LINEAR')"""

    display_thickness: float
    """ Thickness of smoke display in the viewport (in [0.001, 1000], default 1.0)"""

    dissolve_speed: int
    """ Determine how quickly the smoke dissolves (lower value makes smoke disappear faster) (in [1, 10000], default 5)"""

    domain_resolution: typing.Any
    """ Smoke Grid Resolution (array of 3 items, in [-inf, inf], default (0, 0, 0), readonly)"""

    domain_type: typing.Literal["GAS", "LIQUID"]
    """ Change domain type of the simulation (default 'GAS')"""

    effector_group: Collection | None
    """ Limit effectors to this collection"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    export_manta_script: bool
    """ Generate and export Mantaflow script from current domain settings during bake. This is only needed if you plan to analyze the cache (e.g. view grids, velocity vectors, particles) in Mantaflow directly (outside of Blender) after baking the simulation. (default False)"""

    flame_grid: typing.Any
    """ Smoke flame grid (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    flame_ignition: float
    """ Minimum temperature of the flames (higher value results in faster rising flames) (in [0.5, 5], default 1.5)"""

    flame_max_temp: float
    """ Maximum temperature of the flames (higher value results in faster rising flames) (in [1, 10], default 3.0)"""

    flame_smoke: float
    """ Amount of smoke created by burning fuel (in [0, 8], default 1.0)"""

    flame_smoke_color: mathutils.Color
    """ Color of smoke emitted from burning fuel (array of 3 items, in [0, inf], default (0.7, 0.7, 0.7))"""

    flame_vorticity: float
    """ Additional vorticity for the flames (in [0, 2], default 0.5)"""

    flip_ratio: float
    """ PIC/FLIP Ratio. A value of 1.0 will result in a completely FLIP based simulation. Use a lower value for simulations which should produce smaller splashes. (in [0, 1], default 0.97)"""

    fluid_group: Collection | None
    """ Limit fluid objects to this collection"""

    force_collection: Collection | None
    """ Limit forces to this collection"""

    fractions_distance: float
    """ Determines how far apart fluid and obstacle are (higher values will result in fluid being further away from obstacles, smaller values will let fluid move towards the inside of obstacles) (in [-5, 5], default 0.5)"""

    fractions_threshold: float
    """ Determines how much fluid is allowed in an obstacle cell (higher values will tag a boundary cell as an obstacle easier and reduce the boundary smoothening effect) (in [0.001, 1], default 0.05)"""

    gravity: mathutils.Vector
    """ Gravity in X, Y and Z direction (array of 3 items, in [-1000.1, 1000.1], default (0.0, 0.0, -9.81))"""

    gridlines_cell_filter: typing.Literal[
        "NONE", "FLUID", "OBSTACLE", "EMPTY", "INFLOW", "OUTFLOW"
    ]
    """ Cell type to be highlighted (default 'NONE')"""

    gridlines_color_field: typing.Literal["NONE", "FLAGS", "RANGE"]
    """ Simulation field to color map onto gridlines (default 'NONE')"""

    gridlines_lower_bound: float
    """ Lower bound of the highlighting range (in [-inf, inf], default 0.0)"""

    gridlines_range_color: typing.Any
    """ Color used to highlight the range (array of 4 items, in [0, inf], default (1.0, 0.0, 0.0, 1.0))"""

    gridlines_upper_bound: float
    """ Upper bound of the highlighting range (in [-inf, inf], default 1.0)"""

    guide_alpha: float
    """ Guiding weight (higher value results in greater lag) (in [1, 100], default 2.0)"""

    guide_beta: int
    """ Guiding size (higher value results in larger vortices) (in [1, 50], default 5)"""

    guide_parent: Object | None
    """ Use velocities from this object for the guiding effect (object needs to have fluid modifier and be of type domain))"""

    guide_source: typing.Literal["DOMAIN", "EFFECTOR"]
    """ Choose where to get guiding velocities from (default 'DOMAIN')"""

    guide_vel_factor: float
    """ Guiding velocity factor (higher value results in greater guiding velocities) (in [0, 100], default 2.0)"""

    has_cache_baked_any: bool
    """ (default False)"""

    has_cache_baked_data: bool
    """ (default False)"""

    has_cache_baked_guide: bool
    """ (default False)"""

    has_cache_baked_mesh: bool
    """ (default False)"""

    has_cache_baked_noise: bool
    """ (default False)"""

    has_cache_baked_particles: bool
    """ (default False)"""

    heat_grid: typing.Any
    """ Smoke heat grid (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    highres_sampling: typing.Literal["FULLSAMPLE", "LINEAR", "NEAREST"]
    """ Method for sampling the high resolution flow (default 'FULLSAMPLE')"""

    is_cache_baking_any: bool
    """ (default False)"""

    is_cache_baking_data: bool
    """ (default False)"""

    is_cache_baking_guide: bool
    """ (default False)"""

    is_cache_baking_mesh: bool
    """ (default False)"""

    is_cache_baking_noise: bool
    """ (default False)"""

    is_cache_baking_particles: bool
    """ (default False)"""

    mesh_concave_lower: float
    """ Lower mesh concavity bound (high values tend to smoothen and fill out concave regions) (in [0, 10], default 0.4)"""

    mesh_concave_upper: float
    """ Upper mesh concavity bound (high values tend to smoothen and fill out concave regions) (in [0, 10], default 3.5)"""

    mesh_generator: typing.Literal["IMPROVED", "UNION"]
    """ Which particle level set generator to use (default 'IMPROVED')"""

    mesh_particle_radius: float
    """ Particle radius factor (higher value results in larger (meshed) particles). Needs to be adjusted after changing the mesh scale. (in [0, 10], default 2.0)"""

    mesh_scale: int
    """ The mesh simulation is scaled up by this factor (compared to the base resolution of the domain). For best meshing, it is recommended to adjust the mesh particle radius alongside this value. (in [1, 100], default 2)"""

    mesh_smoothen_neg: int
    """ Negative mesh smoothening (in [0, 100], default 1)"""

    mesh_smoothen_pos: int
    """ Positive mesh smoothening (in [0, 100], default 1)"""

    noise_pos_scale: float
    """ Scale of noise (higher value results in larger vortices) (in [0.0001, 10], default 2.0)"""

    noise_scale: int
    """ The noise simulation is scaled up by this factor (compared to the base resolution of the domain) (in [1, 100], default 2)"""

    noise_strength: float
    """ Strength of noise (in [0, 10], default 1.0)"""

    noise_time_anim: float
    """ Animation time of noise (in [0.0001, 10], default 0.1)"""

    openvdb_cache_compress_type: typing.Literal["ZIP", "NONE"]
    """ Compression method to be used (default 'ZIP')"""

    openvdb_data_depth: typing.Literal["NONE"]
    """ Bit depth for fluid particles and grids (lower bit values reduce file size) (default 'NONE')"""

    particle_band_width: float
    """ Particle (narrow) band width (higher value results in thicker band and more particles) (in [0, 1000], default 3.0)"""

    particle_max: int
    """ Maximum number of particles per cell (ensures that each cell has at most this amount of particles) (in [0, 1000], default 16)"""

    particle_min: int
    """ Minimum number of particles per cell (ensures that each cell has at least this amount of particles) (in [0, 1000], default 8)"""

    particle_number: int
    """ Particle number factor (higher value results in more particles) (in [1, 5], default 2)"""

    particle_radius: float
    """ Particle radius factor. Increase this value if the simulation appears to leak volume, decrease it if the simulation seems to gain volume. (in [0, 10], default 1.0)"""

    particle_randomness: float
    """ Randomness factor for particle sampling (in [0, 10], default 0.1)"""

    particle_scale: int
    """ The particle simulation is scaled up by this factor (compared to the base resolution of the domain) (in [1, 100], default 1)"""

    resolution_max: int
    """ Resolution used for the fluid domain. Value corresponds to the longest domain side (resolution for other domain sides is calculated automatically). (in [6, 10000], default 32)"""

    show_gridlines: bool
    """ Show gridlines (default False)"""

    show_velocity: bool
    """ Visualize vector fields (default False)"""

    simulation_method: typing.Literal["FLIP", "APIC"]
    """ Change the underlying simulation method (default 'FLIP')"""

    slice_axis: typing.Literal["AUTO", "X", "Y", "Z"]
    """ (default 'AUTO')"""

    slice_depth: float
    """ Position of the slice (in [0, 1], default 0.5)"""

    slice_per_voxel: float
    """ How many slices per voxel should be generated (in [0, 100], default 5.0)"""

    sndparticle_boundary: typing.Literal["DELETE", "PUSHOUT"]
    """ How particles that left the domain are treated (default 'DELETE')"""

    sndparticle_bubble_buoyancy: float
    """ Amount of buoyancy force that rises bubbles (high value results in bubble movement mainly upwards) (in [0, 100], default 0.5)"""

    sndparticle_bubble_drag: float
    """ Amount of drag force that moves bubbles along with the fluid (high value results in bubble movement mainly along with the fluid) (in [0, 100], default 0.6)"""

    sndparticle_combined_export: typing.Literal[
        "OFF", "SPRAY_FOAM", "SPRAY_BUBBLES", "FOAM_BUBBLES", "SPRAY_FOAM_BUBBLES"
    ]
    """ Determines which particle systems are created from secondary particles (default 'OFF')"""

    sndparticle_life_max: float
    """ Highest possible particle lifetime (in [0, 10000], default 25.0)"""

    sndparticle_life_min: float
    """ Lowest possible particle lifetime (in [0, 10000], default 10.0)"""

    sndparticle_potential_max_energy: float
    """ Upper clamping threshold that indicates the fluid speed where cells no longer emit more particles (higher value results in generally less particles) (in [0, 1000], default 5.0)"""

    sndparticle_potential_max_trappedair: float
    """ Upper clamping threshold for marking fluid cells where air is trapped (higher value results in less marked cells) (in [0, 1000], default 20.0)"""

    sndparticle_potential_max_wavecrest: float
    """ Upper clamping threshold for marking fluid cells as wave crests (higher value results in less marked cells) (in [0, 1000], default 8.0)"""

    sndparticle_potential_min_energy: float
    """ Lower clamping threshold that indicates the fluid speed where cells start to emit particles (lower values result in generally more particles) (in [0, 1000], default 1.0)"""

    sndparticle_potential_min_trappedair: float
    """ Lower clamping threshold for marking fluid cells where air is trapped (lower value results in more marked cells) (in [0, 1000], default 5.0)"""

    sndparticle_potential_min_wavecrest: float
    """ Lower clamping threshold for marking fluid cells as wave crests (lower value results in more marked cells) (in [0, 1000], default 2.0)"""

    sndparticle_potential_radius: int
    """ Radius to compute potential for each cell (higher values are slower but create smoother potential grids) (in [1, 4], default 2)"""

    sndparticle_sampling_trappedair: int
    """ Maximum number of particles generated per trapped air cell per frame (in [0, 10000], default 40)"""

    sndparticle_sampling_wavecrest: int
    """ Maximum number of particles generated per wave crest cell per frame (in [0, 10000], default 200)"""

    sndparticle_update_radius: int
    """ Radius to compute position update for each particle (higher values are slower but particles move less chaotic) (in [1, 4], default 2)"""

    start_point: mathutils.Vector
    """ Start point (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    surface_tension: float
    """ Surface tension of liquid (higher value results in greater hydrophobic behavior) (in [0, 100], default 0.0)"""

    sys_particle_maximum: int
    """ Maximum number of fluid particles that are allowed in this simulation (in [0, inf], default 0)"""

    temperature_grid: typing.Any
    """ Smoke temperature grid, range 0 to 1 represents 0 to 1000K (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    time_scale: float
    """ Adjust simulation speed (in [0.0001, 10], default 1.0)"""

    timesteps_max: int
    """ Maximum number of simulation steps to perform for one frame (in [1, 100], default 4)"""

    timesteps_min: int
    """ Minimum number of simulation steps to perform for one frame (in [1, 100], default 1)"""

    use_adaptive_domain: bool
    """ Adapt simulation resolution and size to fluid (default False)"""

    use_adaptive_timesteps: bool
    """ Automatically decide when to perform multiple simulation steps per frame (default True)"""

    use_bubble_particles: bool
    """ Create bubble particle system (default False)"""

    use_collision_border_back: bool
    """ Enable collisions with back domain border (default False)"""

    use_collision_border_bottom: bool
    """ Enable collisions with bottom domain border (default False)"""

    use_collision_border_front: bool
    """ Enable collisions with front domain border (default False)"""

    use_collision_border_left: bool
    """ Enable collisions with left domain border (default False)"""

    use_collision_border_right: bool
    """ Enable collisions with right domain border (default False)"""

    use_collision_border_top: bool
    """ Enable collisions with top domain border (default False)"""

    use_color_ramp: bool
    """ Render a simulation field while mapping its voxels values to the colors of a ramp or using a predefined color code (default False)"""

    use_diffusion: bool
    """ Enable fluid diffusion settings (e.g. viscosity, surface tension) (default False)"""

    use_dissolve_smoke: bool
    """ Let smoke disappear over time (default False)"""

    use_dissolve_smoke_log: bool
    """ Dissolve smoke in a logarithmic fashion. Dissolves quickly at first, but lingers longer. (default True)"""

    use_flip_particles: bool
    """ Create liquid particle system (default False)"""

    use_foam_particles: bool
    """ Create foam particle system (default False)"""

    use_fractions: bool
    """ Fractional obstacles improve and smoothen the fluid-obstacle boundary (default False)"""

    use_guide: bool
    """ Enable fluid guiding (default False)"""

    use_mesh: bool
    """ Enable fluid mesh (using amplification) (default True)"""

    use_noise: bool
    """ Enable fluid noise (using amplification) (default False)"""

    use_slice: bool
    """ Perform a single slice of the domain object (default False)"""

    use_speed_vectors: bool
    """ Caches velocities of mesh vertices. These will be used (automatically) when rendering with motion blur enabled. (default False)"""

    use_spray_particles: bool
    """ Create spray particle system (default False)"""

    use_tracer_particles: bool
    """ Create tracer particle system (default False)"""

    use_viscosity: bool
    """ Simulate fluids with high viscosity using a special solver (default False)"""

    vector_display_type: typing.Literal["NEEDLE", "STREAMLINE", "MAC"]
    """ (default 'NEEDLE')"""

    vector_field: typing.Literal["FLUID_VELOCITY", "GUIDE_VELOCITY", "FORCE"]
    """ Vector field to be represented by the display vectors (default 'FLUID_VELOCITY')"""

    vector_scale: float
    """ Multiplier for scaling the vectors (in [0, 1000], default 1.0)"""

    vector_scale_with_magnitude: bool
    """ Scale vectors with their magnitudes (default False)"""

    vector_show_mac_x: bool
    """ Show X-component of MAC Grid (default True)"""

    vector_show_mac_y: bool
    """ Show Y-component of MAC Grid (default True)"""

    vector_show_mac_z: bool
    """ Show Z-component of MAC Grid (default True)"""

    velocity_grid: typing.Any
    """ Smoke velocity grid (array of 32 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0), readonly)"""

    velocity_scale: float
    """ Factor to control the amount of motion blur (in [0, inf], default 1.0)"""

    viscosity_base: float
    """ Viscosity setting: value that is multiplied by 10 to the power of (exponent*-1) (in [0, 10], default 1.0)"""

    viscosity_exponent: int
    """ Negative exponent for the viscosity value (to simplify entering small values e.g. 5*10^-6) (in [0, 10], default 6)"""

    viscosity_value: float
    """ Viscosity of liquid (higher values result in more viscous fluids, a value of 0 will still apply some viscosity) (in [0, 10], default 0.05)"""

    vorticity: float
    """ Amount of turbulence and rotation in smoke (in [0, 4], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FluidEffectorSettings(bpy_struct):
    """Smoke collision settings"""

    effector_type: typing.Literal["COLLISION", "GUIDE"]
    """ Change type of effector in the simulation (default 'COLLISION')"""

    guide_mode: typing.Literal["MAXIMUM", "MINIMUM", "OVERRIDE", "AVERAGED"]
    """ How to create guiding velocities (default 'OVERRIDE')"""

    subframes: int
    """ Number of additional samples to take between frames to improve quality of fast moving effector objects (in [0, 200], default 0)"""

    surface_distance: float
    """ Additional distance around mesh surface to consider as effector (in [0, 10], default 0.0)"""

    use_effector: bool
    """ Control when to apply the effector (default True)"""

    use_plane_init: bool
    """ Treat this object as a planar, unclosed mesh (default False)"""

    velocity_factor: float
    """ Multiplier of obstacle velocity (in [-100, 100], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FluidFlowSettings(bpy_struct):
    """Fluid flow settings"""

    density: float
    """ (in [0, 10], default 1.0)"""

    density_vertex_group: str
    """ Name of vertex group which determines surface emission rate (default "", never None)"""

    flow_behavior: typing.Literal["INFLOW", "OUTFLOW", "GEOMETRY"]
    """ Change flow behavior in the simulation (default 'GEOMETRY')"""

    flow_source: typing.Literal["NONE"]
    """ Change how fluid is emitted (default 'NONE')"""

    flow_type: typing.Literal["SMOKE", "BOTH", "FIRE", "LIQUID"]
    """ Change type of fluid in the simulation (default 'SMOKE')"""

    fuel_amount: float
    """ (in [0, 10], default 1.0)"""

    noise_texture: Texture | None
    """ Texture that controls emission strength"""

    particle_size: float
    """ Particle size in simulation cells (in [0.1, inf], default 1.0)"""

    particle_system: ParticleSystem | None
    """ Particle systems emitted from the object"""

    smoke_color: mathutils.Color
    """ Color of smoke (array of 3 items, in [0, inf], default (0.7, 0.7, 0.7))"""

    subframes: int
    """ Number of additional samples to take between frames to improve quality of fast moving flows (in [0, 200], default 0)"""

    surface_distance: float
    """ Height (in domain grid units) of fluid emission above the mesh surface. Higher values result in emission further away from the mesh surface. If this value and the emitter size are smaller than the domain grid unit, fluid will not be created (in [0, 10], default 1.0)"""

    temperature: float
    """ Temperature difference to ambient temperature (in [-10, 10], default 1.0)"""

    texture_map_type: typing.Literal["AUTO", "UV"]
    """ Texture mapping type (default 'AUTO')"""

    texture_offset: float
    """ Z-offset of texture mapping (in [0, 200], default 0.0)"""

    texture_size: float
    """ Size of texture mapping (in [0.01, 10], default 1.0)"""

    use_absolute: bool
    """ Only allow given density value in emitter area and will not add up (default True)"""

    use_inflow: bool
    """ Control when to apply fluid flow (default True)"""

    use_initial_velocity: bool
    """ Fluid has some initial velocity when it is emitted (default False)"""

    use_particle_size: bool
    """ Set particle size in simulation cells or use nearest cell (default True)"""

    use_plane_init: bool
    """ Treat this object as a planar and unclosed mesh. Fluid will only be emitted from the mesh surface and based on the surface emission value. (default False)"""

    use_texture: bool
    """ Use a texture to control emission strength (default False)"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    velocity_coord: mathutils.Vector
    """ Additional initial velocity in X, Y and Z direction (added to source velocity) (array of 3 items, in [-1000.1, 1000.1], default (0.0, 0.0, 0.0))"""

    velocity_factor: float
    """ Multiplier of source velocity passed to fluid (source velocity is non-zero only if object is moving) (in [-100, 100], default 1.0)"""

    velocity_normal: float
    """ Amount of normal directional velocity (in [-100, 100], default 0.0)"""

    velocity_random: float
    """ Amount of random velocity (in [0, 10], default 0.0)"""

    volume_density: float
    """ Controls fluid emission from within the mesh (higher value results in greater emissions from inside the mesh) (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FluidModifier(Modifier, bpy_struct):
    """Fluid simulation modifier"""

    domain_settings: FluidDomainSettings | None
    """ (readonly)"""

    effector_settings: FluidEffectorSettings | None
    """ (readonly)"""

    flow_settings: FluidFlowSettings | None
    """ (readonly)"""

    fluid_type: typing.Literal["NONE", "DOMAIN", "FLOW", "EFFECTOR"]
    """ (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FollowPathConstraint(Constraint, bpy_struct):
    """Lock motion to the target path"""

    forward_axis: typing.Literal[
        "FORWARD_X",
        "FORWARD_Y",
        "FORWARD_Z",
        "TRACK_NEGATIVE_X",
        "TRACK_NEGATIVE_Y",
        "TRACK_NEGATIVE_Z",
    ]
    """ Axis that points forward along the path (default 'FORWARD_X')"""

    offset: float
    """ Offset from the position corresponding to the time frame (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    offset_factor: float
    """ Percentage value defining target position along length of curve (in [-inf, inf], default 0.0)"""

    target: Object | None
    """ Target Curve object"""

    up_axis: typing.Literal["UP_X", "UP_Y", "UP_Z"]
    """ Axis that points upward (default 'UP_X')"""

    use_curve_follow: bool
    """ Object will follow the heading and banking of the curve (default False)"""

    use_curve_radius: bool
    """ Object is scaled by the curve radius (default False)"""

    use_fixed_location: bool
    """ Object will stay locked to a single point somewhere along the length of the curve regardless of time (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FollowTrackConstraint(Constraint, bpy_struct):
    """Lock motion to the target motion track"""

    camera: Object | None
    """ Camera to which motion is parented (if empty active scene camera is used)"""

    clip: MovieClip | None
    """ Movie Clip to get tracking data from"""

    depth_object: Object | None
    """ Object used to define depth in camera space by projecting onto surface of this object"""

    frame_method: typing.Literal["STRETCH", "FIT", "CROP"]
    """ How the footage fits in the camera frame (default 'STRETCH')"""

    object: str
    """ Movie tracking object to follow (if empty, camera object is used) (default "", never None)"""

    track: str
    """ Movie tracking track to follow (default "", never None)"""

    use_3d_position: bool
    """ Use 3D position of track to parent to (default False)"""

    use_active_clip: bool
    """ Use active clip defined in scene (default False)"""

    use_undistorted_position: bool
    """ Parent to undistorted position of 2D track (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ForeachGeometryElementGenerationItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Domain that the field is evaluated on (default 'POINT')"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ForeachGeometryElementInputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ForeachGeometryElementMainItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ForeachGeometryElementZoneViewerPathElem(ViewerPathElem, bpy_struct):
    zone_output_node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FreestyleLineSet(bpy_struct):
    """Line set for associating lines and style parameters"""

    collection: Collection | None
    """ A collection of objects based on which feature edges are selected"""

    collection_negation: typing.Literal["INCLUSIVE", "EXCLUSIVE"]
    """ Specify either inclusion or exclusion of feature edges belonging to a collection of objects (default 'INCLUSIVE')"""

    edge_type_combination: typing.Literal["OR", "AND"]
    """ Specify a logical combination of selection conditions on feature edge types (default 'OR')"""

    edge_type_negation: typing.Literal["INCLUSIVE", "EXCLUSIVE"]
    """ Specify either inclusion or exclusion of feature edges selected by edge types (default 'INCLUSIVE')"""

    exclude_border: bool
    """ Exclude border edges (default False)"""

    exclude_contour: bool
    """ Exclude contours (default False)"""

    exclude_crease: bool
    """ Exclude crease edges (default False)"""

    exclude_edge_mark: bool
    """ Exclude edge marks (default False)"""

    exclude_external_contour: bool
    """ Exclude external contours (default False)"""

    exclude_material_boundary: bool
    """ Exclude edges at material boundaries (default False)"""

    exclude_ridge_valley: bool
    """ Exclude ridges and valleys (default False)"""

    exclude_silhouette: bool
    """ Exclude silhouette edges (default False)"""

    exclude_suggestive_contour: bool
    """ Exclude suggestive contours (default False)"""

    face_mark_condition: typing.Literal["ONE", "BOTH"]
    """ Specify a feature edge selection condition based on face marks (default 'ONE')"""

    face_mark_negation: typing.Literal["INCLUSIVE", "EXCLUSIVE"]
    """ Specify either inclusion or exclusion of feature edges selected by face marks (default 'INCLUSIVE')"""

    linestyle: FreestyleLineStyle | None
    """ Line style settings (never None)"""

    name: str
    """ Line set name (default "", never None)"""

    qi_end: int
    """ Last QI value of the QI range (in [0, inf], default 0)"""

    qi_start: int
    """ First QI value of the QI range (in [0, inf], default 0)"""

    select_border: bool
    """ Select border edges (open mesh edges) (default False)"""

    select_by_collection: bool
    """ Select feature edges based on a collection of objects (default False)"""

    select_by_edge_types: bool
    """ Select feature edges based on edge types (default False)"""

    select_by_face_marks: bool
    """ Select feature edges by face marks (default False)"""

    select_by_image_border: bool
    """ Select feature edges by image border (less memory consumption) (default False)"""

    select_by_visibility: bool
    """ Select feature edges based on visibility (default False)"""

    select_contour: bool
    """ Select contours (outer silhouettes of each object) (default False)"""

    select_crease: bool
    """ Select crease edges (those between two faces making an angle smaller than the Crease Angle) (default False)"""

    select_edge_mark: bool
    """ Select edge marks (edges annotated by Freestyle edge marks) (default False)"""

    select_external_contour: bool
    """ Select external contours (outer silhouettes of occluding and occluded objects) (default False)"""

    select_material_boundary: bool
    """ Select edges at material boundaries (default False)"""

    select_ridge_valley: bool
    """ Select ridges and valleys (boundary lines between convex and concave areas of surface) (default False)"""

    select_silhouette: bool
    """ Select silhouettes (edges at the boundary of visible and hidden faces) (default False)"""

    select_suggestive_contour: bool
    """ Select suggestive contours (almost silhouette/contour edges) (default False)"""

    show_render: bool
    """ Enable or disable this line set during stroke rendering (default False)"""

    visibility: typing.Literal["VISIBLE", "HIDDEN", "RANGE"]
    """ Determine how to use visibility for feature edge selection (default 'VISIBLE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FreestyleLineStyle(ID, bpy_struct):
    """Freestyle line style, reusable by multiple line sets"""

    active_texture: Texture | None
    """ Active texture slot being displayed"""

    active_texture_index: int | None
    """ Index of active texture slot (in [0, 17], default 0)"""

    alpha: float
    """ Base alpha transparency, possibly modified by alpha transparency modifiers (in [0, 1], default 1.0)"""

    alpha_modifiers: typing.Any
    """ List of alpha transparency modifiers (default None, readonly)"""

    angle_max: float
    """ Maximum 2D angle for splitting chains (in [0, 3.14159], default 0.0)"""

    angle_min: float
    """ Minimum 2D angle for splitting chains (in [0, 3.14159], default 0.0)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    caps: typing.Literal["BUTT", "ROUND", "SQUARE"]
    """ Select the shape of both ends of strokes (default 'BUTT')"""

    chain_count: int
    """ Chain count for the selection of first N chains (in [0, inf], default 10)"""

    chaining: typing.Literal["PLAIN", "SKETCHY"]
    """ Select the way how feature edges are jointed to form chains (default 'PLAIN')"""

    color: mathutils.Color
    """ Base line color, possibly modified by line color modifiers (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    color_modifiers: typing.Any
    """ List of line color modifiers (default None, readonly)"""

    dash1: int
    """ Length of the 1st dash for dashed lines (in [0, 65535], default 0)"""

    dash2: int
    """ Length of the 2nd dash for dashed lines (in [0, 65535], default 0)"""

    dash3: int
    """ Length of the 3rd dash for dashed lines (in [0, 65535], default 0)"""

    gap1: int
    """ Length of the 1st gap for dashed lines (in [0, 65535], default 0)"""

    gap2: int
    """ Length of the 2nd gap for dashed lines (in [0, 65535], default 0)"""

    gap3: int
    """ Length of the 3rd gap for dashed lines (in [0, 65535], default 0)"""

    geometry_modifiers: typing.Any
    """ List of stroke geometry modifiers (default None, readonly)"""

    integration_type: typing.Literal["MEAN", "MIN", "MAX", "FIRST", "LAST"]
    """ Select the way how the sort key is computed for each chain (default 'MEAN')"""

    length_max: float
    """ Maximum curvilinear 2D length for the selection of chains (in [0, 10000], default 10000.0)"""

    length_min: float
    """ Minimum curvilinear 2D length for the selection of chains (in [0, 10000], default 0.0)"""

    material_boundary: bool
    """ If true, chains of feature edges are split at material boundaries (default False)"""

    node_tree: ShaderNodeTree | None
    """ Node tree for node-based shaders"""

    panel: typing.Literal[
        "STROKES", "COLOR", "ALPHA", "THICKNESS", "GEOMETRY", "TEXTURE"
    ]
    """ Select the property panel to be shown (default 'STROKES')"""

    rounds: int
    """ Number of rounds in a sketchy multiple touch (in [1, 1000], default 3)"""

    sort_key: typing.Literal[
        "DISTANCE_FROM_CAMERA", "2D_LENGTH", "PROJECTED_X", "PROJECTED_Y"
    ]
    """ Select the sort key to determine the stacking order of chains (default 'DISTANCE_FROM_CAMERA')"""

    sort_order: typing.Literal["DEFAULT", "REVERSE"]
    """ Select the sort order (default 'DEFAULT')"""

    split_dash1: int
    """ Length of the 1st dash for splitting (in [0, 65535], default 0)"""

    split_dash2: int
    """ Length of the 2nd dash for splitting (in [0, 65535], default 0)"""

    split_dash3: int
    """ Length of the 3rd dash for splitting (in [0, 65535], default 0)"""

    split_gap1: int
    """ Length of the 1st gap for splitting (in [0, 65535], default 0)"""

    split_gap2: int
    """ Length of the 2nd gap for splitting (in [0, 65535], default 0)"""

    split_gap3: int
    """ Length of the 3rd gap for splitting (in [0, 65535], default 0)"""

    split_length: float
    """ Curvilinear 2D length for chain splitting (in [0, 10000], default 100.0)"""

    texture_slots: typing.Any
    """ Texture slots defining the mapping and influence of textures (default None, readonly)"""

    texture_spacing: float
    """ Spacing for textures along stroke length (in [0.01, 100], default 1.0)"""

    thickness: float
    """ Base line thickness, possibly modified by line thickness modifiers (in [0, 10000], default 3.0)"""

    thickness_modifiers: typing.Any
    """ List of line thickness modifiers (default None, readonly)"""

    thickness_position: typing.Literal["CENTER", "INSIDE", "OUTSIDE", "RELATIVE"]
    """ Thickness position of silhouettes and border edges (applicable when plain chaining is used with the Same Object option) (default 'CENTER')"""

    thickness_ratio: float
    """ A number between 0 (inside) and 1 (outside) specifying the relative position of stroke thickness (in [0, 1], default 0.5)"""

    use_angle_max: bool
    """ Split chains at points with angles larger than the maximum 2D angle (default False)"""

    use_angle_min: bool
    """ Split chains at points with angles smaller than the minimum 2D angle (default False)"""

    use_chain_count: bool
    """ Enable the selection of first N chains (default False)"""

    use_chaining: bool
    """ Enable chaining of feature edges (default True)"""

    use_dashed_line: bool
    """ Enable or disable dashed line (default False)"""

    use_length_max: bool
    """ Enable the selection of chains by a maximum 2D length (default False)"""

    use_length_min: bool
    """ Enable the selection of chains by a minimum 2D length (default False)"""

    use_nodes: bool
    """ Use shader nodes for the line style (default False)"""

    use_same_object: bool
    """ If true, only feature edges of the same object are joined (default True)"""

    use_sorting: bool
    """ Arrange the stacking order of strokes (default False)"""

    use_split_length: bool
    """ Enable chain splitting by curvilinear 2D length (default False)"""

    use_split_pattern: bool
    """ Enable chain splitting by dashed line patterns (default False)"""

    use_texture: bool
    """ Enable or disable textured strokes (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FreestyleModuleSettings(bpy_struct):
    """Style module configuration for specifying a style module"""

    script: Text | None
    """ Python script to define a style module"""

    use: bool
    """ Enable or disable this style module during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FreestyleSettings(bpy_struct):
    """Freestyle settings for a ViewLayer data-block"""

    as_render_pass: bool
    """ Renders Freestyle output to a separate pass instead of overlaying it on the Combined pass (default False)"""

    crease_angle: float
    """ Angular threshold for detecting crease edges (in [0, 3.14159], default 0.0)"""

    kr_derivative_epsilon: float
    """ Kr derivative epsilon for computing suggestive contours (in [-1000, 1000], default 0.0)"""

    linesets: typing.Any
    """ (default None, readonly)"""

    mode: typing.Literal["SCRIPT", "EDITOR"]
    """ Select the Freestyle control mode (default 'SCRIPT')"""

    modules: typing.Any
    """ A list of style modules (to be applied from top to bottom) (default None, readonly)"""

    sphere_radius: float
    """ Sphere radius for computing curvatures (in [0, 1000], default 1.0)"""

    use_culling: bool
    """ If enabled, out-of-view edges are ignored (default False)"""

    use_material_boundaries: bool
    """ Enable material boundaries (default False)"""

    use_ridges_and_valleys: bool
    """ Enable ridges and valleys (default False)"""

    use_smoothness: bool
    """ Take face smoothness into account in view map calculation (default False)"""

    use_suggestive_contours: bool
    """ Enable suggestive contours (default False)"""

    use_view_map_cache: bool
    """ Keep the computed view map and avoid recalculating it if mesh geometry is unchanged (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Function(bpy_struct):
    """RNA function definition"""

    description: str
    """ Description of the Function's purpose (default "", readonly, never None)"""

    identifier: str
    """ Unique name used in the code and scripting (default "", readonly, never None)"""

    is_registered: bool
    """ Function is registered as callback as part of type registration (default False, readonly)"""

    is_registered_optional: bool
    """ Function is optionally registered as callback part of type registration (default False, readonly)"""

    parameters: typing.Any
    """ Parameters for the function (default None, readonly)"""

    use_self: bool
    """ Function does not pass itself as an argument (becomes a static method in Python) (default False, readonly)"""

    use_self_type: bool
    """ Function passes itself type as an argument (becomes a class method in Python if use_self is false) (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNode(NodeInternal, Node, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeAlignEulerToVector(FunctionNode, NodeInternal, Node, bpy_struct):
    """Orient an Euler rotation along the given direction"""

    axis: typing.Literal["X", "Y", "Z"]
    """ Axis to align to the vector (default 'X')"""

    pivot_axis: typing.Literal["AUTO", "X", "Y", "Z"]
    """ Axis to rotate around (default 'AUTO')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeAlignRotationToVector(FunctionNode, NodeInternal, Node, bpy_struct):
    """Orient a rotation along the given direction"""

    axis: typing.Literal["X", "Y", "Z"]
    """ Axis to align to the vector (default 'X')"""

    pivot_axis: typing.Literal["AUTO", "X", "Y", "Z"]
    """ Axis to rotate around (default 'AUTO')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeAxesToRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Create a rotation from a primary and (ideally orthogonal) secondary axis"""

    primary_axis: typing.Literal["X", "Y", "Z"]
    """ Axis that is aligned exactly to the provided primary direction (default 'X')"""

    secondary_axis: typing.Literal["X", "Y", "Z"]
    """ Axis that is aligned as well as possible given the alignment of the primary axis (default 'X')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeAxisAngleToRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Build a rotation from an axis and a rotation around that axis"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeBitMath(FunctionNode, NodeInternal, Node, bpy_struct):
    """Perform bitwise operations on 32-bit integers"""

    operation: typing.Literal["AND", "OR", "XOR", "NOT", "SHIFT", "ROTATE"]
    """ (default 'AND')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeBooleanMath(FunctionNode, NodeInternal, Node, bpy_struct):
    """Perform a logical operation on the given boolean inputs"""

    operation: Literal[bpy.stub_internal.rna_enums.NodeBooleanMathItems]
    """ (default 'AND')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeCombineColor(FunctionNode, NodeInternal, Node, bpy_struct):
    """Combine four channels into a single color, based on a particular color model"""

    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeCombineMatrix(FunctionNode, NodeInternal, Node, bpy_struct):
    """Construct a 4x4 matrix from its individual values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeCombineTransform(FunctionNode, NodeInternal, Node, bpy_struct):
    """Combine a translation vector, a rotation, and a scale vector into a transformation matrix"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeCompare(FunctionNode, NodeInternal, Node, bpy_struct):
    """Perform a comparison operation on the two given inputs"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    mode: typing.Literal["ELEMENT", "LENGTH", "AVERAGE", "DOT_PRODUCT", "DIRECTION"]
    """ (default 'ELEMENT')"""

    operation: Literal[bpy.stub_internal.rna_enums.NodeCompareOperationItems]
    """ (default 'EQUAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeEulerToRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Build a rotation from separate angles around each axis"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeFindInString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Find the number of times a given string occurs in another string and the position of the first match"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeFloatToInt(FunctionNode, NodeInternal, Node, bpy_struct):
    """Convert the given floating-point number to an integer, with a choice of methods"""

    rounding_mode: Literal[bpy.stub_internal.rna_enums.NodeFloatToIntItems]
    """ Method used to convert the float to an integer (default 'ROUND')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeFormatString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Insert values into a string using a Python and path template compatible formatting syntax"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    format_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeHashValue(FunctionNode, NodeInternal, Node, bpy_struct):
    """Generate a randomized integer using the given input value as a seed"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'INT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputBool(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide a True/False value that can be connected to other nodes in the tree"""

    boolean: bool
    """ Input value used for unconnected socket (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputColor(FunctionNode, NodeInternal, Node, bpy_struct):
    """Output a color value chosen with the color picker widget"""

    value: typing.Any
    """ (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputInt(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide an integer value that can be connected to other nodes in the tree"""

    integer: int
    """ Input value used for unconnected socket (in [-inf, inf], default 1)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputMenu(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide a menu value that can be connected to other nodes in the tree"""

    value: str
    """ Value of the output socket"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide a rotation value that can be connected to other nodes in the tree"""

    rotation_euler: mathutils.Euler
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputSpecialCharacters(FunctionNode, NodeInternal, Node, bpy_struct):
    """Output string characters that cannot be typed directly with the keyboard"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide a string value that can be connected to other nodes in the tree"""

    string: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInputVector(FunctionNode, NodeInternal, Node, bpy_struct):
    """Provide a vector value that can be connected to other nodes in the tree"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 3)"""

    vector: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeIntegerMath(FunctionNode, NodeInternal, Node, bpy_struct):
    """Perform various math operations on the given integer inputs"""

    operation: Literal[bpy.stub_internal.rna_enums.NodeIntegerMathItems]
    """ (default 'ADD')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInvertMatrix(FunctionNode, NodeInternal, Node, bpy_struct):
    """Compute the inverse of the given matrix, if one exists"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeInvertRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Compute the inverse of the given rotation"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeMatchString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Check if a given string exists within another string"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeMatrixDeterminant(FunctionNode, NodeInternal, Node, bpy_struct):
    """Compute the determinant of the given matrix"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeMatrixMultiply(FunctionNode, NodeInternal, Node, bpy_struct):
    """Perform a matrix multiplication on two input matrices"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeMatrixSVD(FunctionNode, NodeInternal, Node, bpy_struct):
    """Compute the singular value decomposition of the 3x3 part of a matrix"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeProjectPoint(FunctionNode, NodeInternal, Node, bpy_struct):
    """Project a point using a matrix, using location, rotation, scale, and perspective divide"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeQuaternionToRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Build a rotation from quaternion components"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRandomValue(FunctionNode, NodeInternal, Node, bpy_struct):
    """Output a randomized value"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ Type of data stored in attribute (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeReplaceString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Replace a given string segment with another"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotateEuler(FunctionNode, NodeInternal, Node, bpy_struct):
    """Apply a secondary Euler rotation to a given Euler rotation"""

    rotation_type: typing.Literal["AXIS_ANGLE", "EULER"]
    """ Method used to describe the rotation (default 'EULER')"""

    space: typing.Literal["OBJECT", "LOCAL"]
    """ Base orientation for rotation (default 'OBJECT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotateRotation(FunctionNode, NodeInternal, Node, bpy_struct):
    """Apply a secondary rotation to a given rotation value"""

    rotation_space: typing.Literal["GLOBAL", "LOCAL"]
    """ Base orientation for the rotation (default 'GLOBAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotateVector(FunctionNode, NodeInternal, Node, bpy_struct):
    """Apply a rotation to a given vector"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotationToAxisAngle(FunctionNode, NodeInternal, Node, bpy_struct):
    """Convert a rotation to axis angle components"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotationToEuler(FunctionNode, NodeInternal, Node, bpy_struct):
    """Convert a standard rotation value to an Euler rotation"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeRotationToQuaternion(FunctionNode, NodeInternal, Node, bpy_struct):
    """Retrieve the quaternion components representing a rotation"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeSeparateColor(FunctionNode, NodeInternal, Node, bpy_struct):
    """Split a color into separate channels, based on a particular color model"""

    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeSeparateMatrix(FunctionNode, NodeInternal, Node, bpy_struct):
    """Split a 4x4 matrix into its individual values"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeSeparateTransform(FunctionNode, NodeInternal, Node, bpy_struct):
    """Split a transformation matrix into a translation vector, a rotation, and a scale vector"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeSliceString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Extract a string segment from a larger string"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeStringLength(FunctionNode, NodeInternal, Node, bpy_struct):
    """Output the number of characters in the given string"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeStringToValue(FunctionNode, NodeInternal, Node, bpy_struct):
    """Derive a numeric value from a given string representation"""

    data_type: typing.Literal["FLOAT", "INT"]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeTransformDirection(FunctionNode, NodeInternal, Node, bpy_struct):
    """Apply a transformation matrix (excluding translation) to the given vector"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeTransformPoint(FunctionNode, NodeInternal, Node, bpy_struct):
    """Apply a transformation matrix to the given vector"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeTransposeMatrix(FunctionNode, NodeInternal, Node, bpy_struct):
    """Flip a matrix over its diagonal, turning columns into rows and vice-versa"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class FunctionNodeValueToString(FunctionNode, NodeInternal, Node, bpy_struct):
    """Generate a string representation of the given input value"""

    data_type: typing.Literal["FLOAT", "INT"]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GPENCIL_UL_annotation_layer(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GPENCIL_UL_matslots(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GPencilInterpolateSettings(bpy_struct):
    """Settings for Grease Pencil interpolation tools"""

    interpolation_curve: CurveMapping | None
    """ Custom curve to control 'sequence' interpolation between Grease Pencil frames (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GPencilSculptGuide(bpy_struct):
    """Guides for drawing"""

    angle: float
    """ Direction of lines (in [-6.28319, 6.28319], default 0.0)"""

    angle_snap: float
    """ Angle snapping (in [-6.28319, 6.28319], default 0.0)"""

    location: typing.Any
    """ Custom reference point for guides (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    reference_object: Object | None
    """ Object used for reference point"""

    reference_point: typing.Literal["CURSOR", "CUSTOM", "OBJECT"]
    """ Type of speed guide (default 'CURSOR')"""

    spacing: float
    """ Guide spacing (in [0, inf], default 20.0)"""

    type: typing.Literal["CIRCULAR", "RADIAL", "PARALLEL", "GRID", "ISO"]
    """ Type of speed guide (default 'CIRCULAR')"""

    use_guide: bool
    """ Enable speed guides (default False)"""

    use_snapping: bool
    """ Enable snapping to guides angle or spacing options (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GPencilSculptSettings(bpy_struct):
    """General properties for Grease Pencil stroke sculpting tools"""

    guide: GPencilSculptGuide | None
    """ (readonly)"""

    intersection_threshold: float
    """ Threshold for stroke intersections (in [0, 10], default 0.1)"""

    lock_axis: typing.Literal["VIEW", "AXIS_Y", "AXIS_X", "AXIS_Z", "CURSOR"]
    """ (default 'VIEW')"""

    multiframe_falloff_curve: CurveMapping | None
    """ Custom curve to control falloff of brush effect by Grease Pencil frames (readonly)"""

    thickness_primitive_curve: CurveMapping | None
    """ Custom curve to control primitive thickness (readonly)"""

    use_automasking_layer_active: bool
    """ Affect only the Active Layer (default False)"""

    use_automasking_layer_stroke: bool
    """ Affect only strokes below the cursor (default False)"""

    use_automasking_material_active: bool
    """ Affect only the Active Material (default False)"""

    use_automasking_material_stroke: bool
    """ Affect only strokes below the cursor (default False)"""

    use_automasking_stroke: bool
    """ Affect only strokes below the cursor (default False)"""

    use_multiframe_falloff: bool
    """ Use falloff effect when edit in multiframe mode to compute brush effect by frame (default False)"""

    use_scale_thickness: bool
    """ Scale the stroke thickness when transforming strokes (default False)"""

    use_thickness_curve: bool
    """ Use curve to define primitive stroke thickness (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GREASE_PENCIL_UL_attributes(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GREASE_PENCIL_UL_masks(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GammaCrossStrip(EffectStrip, Strip, bpy_struct):
    """Gamma Crossfade Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GaussianBlurStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip creating a gaussian blur"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    size_x: float
    """ Size of the blur along X axis (in [0, inf], default 0.0)"""

    size_y: float
    """ Size of the blur along Y axis (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryAttributeConstraint(Constraint, bpy_struct):
    """Create a constraint-based relationship with an attribute from geometry"""

    apply_target_transform: bool
    """ Apply the target object's world transform on top of the attribute's transform (default False)"""

    attribute_name: str
    """ Name of the attribute to retrieve the transform from (default "", never None)"""

    data_type: typing.Literal["VECTOR", "QUATERNION", "FLOAT4X4"]
    """ Select data type of attribute (default 'VECTOR')"""

    domain: typing.Literal["POINT", "EDGE", "FACE", "FACE_CORNER", "CURVE", "INSTANCE"]
    """ Attribute domain (default 'POINT')"""

    mix_loc: bool
    """ Mix Location (default False)"""

    mix_mode: typing.Literal[
        "REPLACE", "BEFORE_FULL", "BEFORE_SPLIT", "AFTER_FULL", "AFTER_SPLIT"
    ]
    """ Specify how the copied and existing transformations are combined (default 'REPLACE')"""

    mix_rot: bool
    """ Mix Rotation (default False)"""

    mix_scl: bool
    """ Mix Scale (default False)"""

    sample_index: int
    """ Sample Index (in [0, inf], default 0)"""

    target: Object | None
    """ Target geometry object"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNode(NodeInternal, Node, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeAccumulateField(GeometryNode, NodeInternal, Node, bpy_struct):
    """Add the values of an evaluated field together and output the running total for each element"""

    data_type: typing.Literal["FLOAT", "INT", "FLOAT_VECTOR", "TRANSFORM"]
    """ Type of data that is accumulated (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeAttributeDomainSize(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the number of elements in a geometry for each attribute domain"""

    component: Literal[bpy.stub_internal.rna_enums.GeometryComponentTypeItems]
    """ (default 'MESH')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeAttributeStatistic(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate statistics about a data set from a field evaluated on a geometry"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ The data type the attribute is converted to before calculating the results (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Which domain to read the data from (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeBake(GeometryNode, NodeInternal, Node, bpy_struct):
    """Cache the incoming data so that it can be used without recomputation"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: RepeatItem | None
    """ Index of the active item"""

    bake_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeBlurAttribute(GeometryNode, NodeInternal, Node, bpy_struct):
    """Mix attribute values of neighboring elements"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeBoneInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information of armature bones"""

    transform_space: typing.Literal["ORIGINAL", "RELATIVE"]
    """ The transformation of the vector and geometry outputs (default 'ORIGINAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeBoundBox(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the limits of a geometrys positions and generate a box mesh with those dimensions"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCameraInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information from a camera object"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCaptureAttribute(GeometryNode, NodeInternal, Node, bpy_struct):
    """Store the result of a field on a geometry and output the data as a node socket. Allows remembering or interpolating data as the geometry changes, such as positions before deformation"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: RepeatItem | None
    """ Index of the active item"""

    capture_items: typing.Any
    """ (default None, readonly)"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Which domain to store the data in (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCollectionChildren(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a collections object and collection children, in a name-based order"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCollectionInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve geometry instances from a collection"""

    transform_space: typing.Literal["ORIGINAL", "RELATIVE"]
    """ The transformation of the instances output. Does not affect the internal geometry (default 'ORIGINAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeConvexHull(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a mesh that encloses all points in the input geometry with the smallest number of points"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCornersOfEdge(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve face corners connected to edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCornersOfFace(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve corners that make up a face"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCornersOfVertex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve face corners connected to vertices"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCubeGridTopology(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a boolean grid topology with the given dimensions, for use with the Field to Grid node"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveArc(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline arc"""

    mode: typing.Literal["POINTS", "RADIUS"]
    """ Method used to determine radius and placement (default 'RADIUS')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveEndpointSelection(GeometryNode, NodeInternal, Node, bpy_struct):
    """Provide a selection for an arbitrary number of endpoints in each spline"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveHandleTypeSelection(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Provide a selection based on the handle types of Bézier control points"""

    handle_type: typing.Literal["FREE", "AUTO", "VECTOR", "ALIGN"]
    """ (default 'FREE')"""

    mode: set[Literal[bpy.stub_internal.rna_enums.NodeGeometryCurveHandleSideItems]]
    """ Whether to check the type of left and right handles (default set())"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveLength(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the length of all splines added together"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveOfPoint(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the curve a control point is part of"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurvePrimitiveBezierSegment(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Generate a 2D Bézier spline from the given control points and handles"""

    mode: typing.Literal["POSITION", "OFFSET"]
    """ Method used to determine control handles (default 'POSITION')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurvePrimitiveCircle(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline circle"""

    mode: typing.Literal["POINTS", "RADIUS"]
    """ Method used to determine radius and placement (default 'RADIUS')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurvePrimitiveLine(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline line with two points"""

    mode: typing.Literal["POINTS", "DIRECTION"]
    """ Method used to determine radius and placement (default 'POINTS')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurvePrimitiveQuadrilateral(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Generate a polygon with four points"""

    mode: typing.Literal["RECTANGLE", "PARALLELOGRAM", "TRAPEZOID", "KITE", "POINTS"]
    """ (default 'RECTANGLE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveQuadraticBezier(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline in a parabola shape with control points positions"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveSetHandles(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the handle type for the control points of a Bézier curve"""

    handle_type: typing.Literal["FREE", "AUTO", "VECTOR", "ALIGN"]
    """ (default 'FREE')"""

    mode: set[Literal[bpy.stub_internal.rna_enums.NodeGeometryCurveHandleSideItems]]
    """ Whether to update left and right handles (default set())"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveSpiral(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline in a spiral shape"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveSplineType(GeometryNode, NodeInternal, Node, bpy_struct):
    """Change the type of curves"""

    spline_type: Literal[bpy.stub_internal.rna_enums.CurvesTypeItems]
    """ The curve type to change the selected curves to (default 'POLY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveStar(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline in a star pattern by connecting alternating points of two circles"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveToMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert curves into a mesh, optionally with a custom profile shape defined by curves"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurveToPoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a point cloud by sampling positions along curves"""

    mode: typing.Literal["EVALUATED", "COUNT", "LENGTH"]
    """ How to generate points from the input curve (default 'COUNT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCurvesToGreasePencil(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert the curves in each top-level instance into Grease Pencil layer"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeCustomGroup(GeometryNode, NodeInternal, Node, bpy_struct):
    """Custom Geometry Group Node for Python nodes"""

    node_tree: GeometryNodeTree | None

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDeformCurvesOnSurface(GeometryNode, NodeInternal, Node, bpy_struct):
    """Translate and rotate curves based on changes between the objects original and evaluated surface mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDeleteGeometry(GeometryNode, NodeInternal, Node, bpy_struct):
    """Remove selected elements of a geometry"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainWithoutCornerItems]
    """ Which domain to delete in (default 'POINT')"""

    mode: typing.Literal["ALL", "EDGE_FACE", "ONLY_FACE"]
    """ Which parts of the mesh component to delete (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDistributePointsInGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate points inside a volume grid"""

    mode: typing.Literal["DENSITY_RANDOM", "DENSITY_GRID"]
    """ Method to use for scattering points (default 'DENSITY_RANDOM')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDistributePointsInVolume(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Generate points inside a volume"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDistributePointsOnFaces(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate points spread out on the surface of a mesh"""

    distribute_method: typing.Literal["RANDOM", "POISSON"]
    """ Method to use for scattering points (default 'RANDOM')"""

    use_legacy_normal: bool
    """ Output the normal and rotation values that have been output before the node started taking smooth normals into account (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDualMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert Faces into vertices and vertices into faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeDuplicateElements(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate an arbitrary number copies of each selected input element"""

    domain: typing.Literal["POINT", "EDGE", "FACE", "SPLINE", "LAYER", "INSTANCE"]
    """ Which domain to duplicate (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeEdgePathsToCurves(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output curves following paths across mesh edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeEdgePathsToSelection(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output a selection of edges by following paths across mesh edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeEdgesOfCorner(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the edges on both sides of a face corner"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeEdgesOfVertex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the edges connected to each vertex"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeEdgesToFaceGroups(GeometryNode, NodeInternal, Node, bpy_struct):
    """Group faces into regions surrounded by the selected boundary edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeExtrudeMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate new vertices, edges, or faces from selected elements and move them based on an offset while keeping them connected by their boundary"""

    mode: typing.Literal["VERTICES", "EDGES", "FACES"]
    """ (default 'FACES')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFaceOfCorner(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the face each face corner is part of"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldAtIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve data of other elements in the contexts geometry"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Domain the field is evaluated in (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldAverage(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the mean and median of a given field"""

    data_type: typing.Literal["FLOAT", "FLOAT_VECTOR"]
    """ Type of data the outputs are calculated from (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldMinAndMax(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the minimum and maximum of a given field"""

    data_type: typing.Literal["FLOAT", "INT", "FLOAT_VECTOR"]
    """ Type of data the outputs are calculated from (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldOnDomain(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve values from a field on a different domain besides the domain from the context"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Domain the field is evaluated in (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create new grids by evaluating new values on an existing volume grid topology"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: RepeatItem | None
    """ Index of the active item"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Data type for topology grid (default 'FLOAT')"""

    grid_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToGridItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    identifier: int
    """ (in [-inf, inf], default 0, readonly)"""

    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToList(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a list of values"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: GeometryNodeFieldToListItem | None
    """ Index of the active item"""

    list_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldToListItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    identifier: int
    """ (in [-inf, inf], default 0, readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFieldVariance(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the standard deviation and variance of a given field"""

    data_type: typing.Literal["FLOAT", "FLOAT_VECTOR"]
    """ Type of data the outputs are calculated from (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFillCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a mesh on the XY plane with faces on the inside of input curves"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFilletCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Round corners by generating circular arcs on each control point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeFlipFaces(GeometryNode, NodeInternal, Node, bpy_struct):
    """Reverse the order of the vertices and edges of selected faces, flipping their normal direction"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeForeachGeometryElementInput(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    paired_output: Node | None
    """ Zone output node that this input node is paired with (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    def pair_with_output(self, output_node: NodeInternal | None) -> bool:
        """Pair a zone input node with an output node.

        :param output_node: Output Node, Zone output node to pair with
        :return: Result, True if pairing the node was successful
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeForeachGeometryElementOutput(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    active_generation_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_input_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_main_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Geometry domain that is iterated over (default 'POINT')"""

    generation_items: typing.Any
    """ (default None, readonly)"""

    input_items: typing.Any
    """ (default None, readonly)"""

    inspection_index: int
    """ Iteration index that is used by inspection features like the viewer node or socket inspection (in [-inf, inf], default 0)"""

    main_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGeometryToInstance(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert each input geometry into an instance, which can be much faster than the Join Geometry node when the inputs are large"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGetGeometryBundle(GeometryNode, NodeInternal, Node, bpy_struct):
    """Get the bundle of a geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGetNamedGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Get volume grid from a volume geometry with the specified name"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGizmoDial(GeometryNode, NodeInternal, Node, bpy_struct):
    """Show a dial gizmo in the viewport for a value"""

    color_id: Literal[bpy.stub_internal.rna_enums.GeometryNodesGizmoColorItems]
    """ (default 'PRIMARY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGizmoLinear(GeometryNode, NodeInternal, Node, bpy_struct):
    """Show a linear gizmo in the viewport for a value"""

    color_id: Literal[bpy.stub_internal.rna_enums.GeometryNodesGizmoColorItems]
    """ (default 'PRIMARY')"""

    draw_style: Literal[
        bpy.stub_internal.rna_enums.GeometryNodesLinearGizmoDrawStyleItems
    ]
    """ (default 'ARROW')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGizmoTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Show a transform gizmo in the viewport"""

    use_rotation_x: bool
    """ (default False)"""

    use_rotation_y: bool
    """ (default False)"""

    use_rotation_z: bool
    """ (default False)"""

    use_scale_x: bool
    """ (default False)"""

    use_scale_y: bool
    """ (default False)"""

    use_scale_z: bool
    """ (default False)"""

    use_translation_x: bool
    """ (default False)"""

    use_translation_y: bool
    """ (default False)"""

    use_translation_z: bool
    """ (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGreasePencilToCurves(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert Grease Pencil layers into curve instances"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridAdvect(GeometryNode, NodeInternal, Node, bpy_struct):
    """Move grid values through a velocity field using numerical integration. Supports multiple integration schemes for different accuracy and performance trade-offs"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridClip(GeometryNode, NodeInternal, Node, bpy_struct):
    """Deactivate grid voxels outside minimum and maximum coordinates, setting them to the background value."""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridCurl(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the magnitude and direction of circulation of a directional vector grid"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridDilateAndErode(GeometryNode, NodeInternal, Node, bpy_struct):
    """Dilate or erode the active regions of a grid. This changes which voxels are active but does not change their values."""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridDivergence(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the flow into and out of each point of a directional vector grid"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridGradient(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the direction and magnitude of the change in values of a scalar grid"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about a volume grid"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridLaplacian(GeometryNode, NodeInternal, Node, bpy_struct):
    """Compute the divergence of the gradient of the input grid"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridMean(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply mean (box) filter smoothing to a voxel. The mean value from surrounding voxels in a box-shape defined by the radius replaces the voxel value."""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridMedian(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply median (box) filter smoothing to a voxel. The median value from surrounding voxels in a box-shape defined by the radius replaces the voxel value."""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridPrune(GeometryNode, NodeInternal, Node, bpy_struct):
    """Make the storage of a volume grid more efficient by collapsing data into tiles or inner nodes"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridToMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a mesh on the "surface" of a volume grid"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridToPoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a point cloud from a volume grids active voxels"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGridVoxelize(GeometryNode, NodeInternal, Node, bpy_struct):
    """Remove sparseness from a volume grid by making the active tiles into voxels"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeGroup(GeometryNode, NodeInternal, Node, bpy_struct):
    node_tree: GeometryNodeTree | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImageInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about an image"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImageTexture(GeometryNode, NodeInternal, Node, bpy_struct):
    """Sample values from an image texture"""

    extension: typing.Literal["REPEAT", "EXTEND", "CLIP", "MIRROR"]
    """ How the image is extrapolated past its original bounds (default 'REPEAT')"""

    interpolation: typing.Literal["Linear", "Closest", "Cubic"]
    """ Method for smoothing values between pixels (default 'Linear')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportCSV(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import geometry from an CSV file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportOBJ(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import geometry from an OBJ file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportPLY(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import a point cloud from a PLY file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportSTL(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import a mesh from an STL file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportText(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import a string from a text file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeImportVDB(GeometryNode, NodeInternal, Node, bpy_struct):
    """Import volume data from a .vdb file"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeIndexOfNearest(GeometryNode, NodeInternal, Node, bpy_struct):
    """Find the nearest element in a group. Similar to the "Sample Nearest" node"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeIndexSwitch(GeometryNode, NodeInternal, Node, bpy_struct):
    """Choose between an arbitrary number of values with an index"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'GEOMETRY')"""

    index_switch_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputActiveCamera(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the scenes active camera"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputCollection(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output a single collection"""

    collection: Collection | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputCurveHandlePositions(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Retrieve the position of each Bézier control points handles"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputCurveTilt(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the angle at each control point used to twist the curves normal around its tangent"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputEdgeSmooth(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve whether each edge is marked for smooth or split normals"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputFont(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output a font"""

    font: VectorFont | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputID(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a stable random identifier value from the "id" attribute on the point domain, or the index if the attribute does not exist"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputImage(GeometryNode, NodeInternal, Node, bpy_struct):
    """Input an image data-block"""

    image: Image | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve an integer value indicating the position of each element in the list, starting at zero"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputInstanceBounds(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate position bounds of each instances geometry set"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputInstanceRotation(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the rotation of each instance in the geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputInstanceScale(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the scale of each instance in the geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMaterial(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output a single material"""

    material: Material | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMaterialIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the index of the material used for each element in the geometrys list of materials"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshEdgeAngle(GeometryNode, NodeInternal, Node, bpy_struct):
    """The angle between the normals of connected manifold faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshEdgeNeighbors(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the number of faces that use each edge as one of their sides"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshEdgeVertices(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve topology information relating to each edge of a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshFaceArea(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the surface area of a meshs faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshFaceIsPlanar(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve whether all triangles in a face are on the same plane, i.e. whether they have the same normal"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshFaceNeighbors(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve topology information relating to each face of a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshIsland(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about separate connected regions in a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputMeshVertexNeighbors(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Retrieve topology information relating to each vertex of a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputNamedAttribute(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the data of a specified attribute"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ The data type used to read the attribute values (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputNamedLayerSelection(
    GeometryNode, NodeInternal, Node, bpy_struct
):
    """Output a selection of a Grease Pencil layer"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputNormal(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a unit length vector indicating the direction pointing away from the geometry at each element"""

    legacy_corner_normals: bool
    """ Always use face normals for the face corner domain, matching old behavior of the node (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputObject(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output a single object"""

    object: Object | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputPosition(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a vector indicating the location of each element"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputRadius(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the radius at each point on curve or point cloud geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputSceneTime(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the current time in the scenes animation in units of seconds or frames"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputShadeSmooth(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve whether each face is marked for smooth or sharp normals"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputShortestEdgePaths(GeometryNode, NodeInternal, Node, bpy_struct):
    """Find the shortest paths along mesh edges to selected end vertices, with customizable cost per edge"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputSplineCyclic(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve whether each spline endpoint connects to the beginning"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputSplineResolution(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the number of evaluated points that will be generated for every control point on curves"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputTangent(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the direction of curves at each control point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInputVoxelIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the integer coordinates of the voxel that the field is evaluated on"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInstanceOnPoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a reference to geometry at each of the input points, without duplicating its underlying data"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInstanceTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the full transformation of each instance in the geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInstancesToPoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate points at the origins of instances.
    Note: Nested instances are not affected by this node
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeInterpolateCurves(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate new curves on points by interpolating between existing curves"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeIsViewport(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve whether the nodes are being evaluated for the viewport rather than the final render"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeJoinGeometry(GeometryNode, NodeInternal, Node, bpy_struct):
    """Merge separately generated geometries into a single one"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeListGetItem(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a value from a list"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Value may be implicitly converted if the type does not match (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeListLength(GeometryNode, NodeInternal, Node, bpy_struct):
    """Count how many items are in a given list"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'GEOMETRY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMaterialSelection(GeometryNode, NodeInternal, Node, bpy_struct):
    """Provide a selection of faces that use the specified material"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMenuSwitch(GeometryNode, NodeInternal, Node, bpy_struct):
    """Select from multiple inputs by name"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: NodeEnumItem | None
    """ Active item"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'GEOMETRY')"""

    enum_definition: Node | None
    """ The enum definition can now be accessed directly on the node. This exists for backward compatibility. (readonly)"""

    enum_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMergeByDistance(GeometryNode, NodeInternal, Node, bpy_struct):
    """Merge vertices or points within a given distance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMergeLayers(GeometryNode, NodeInternal, Node, bpy_struct):
    """Join groups of Grease Pencil layers into one"""

    mode: typing.Literal["MERGE_BY_NAME", "MERGE_BY_ID"]
    """ Determines how to choose which layers are merged (default 'MERGE_BY_NAME')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshBoolean(GeometryNode, NodeInternal, Node, bpy_struct):
    """Cut, subtract, or join multiple mesh inputs"""

    operation: typing.Literal["INTERSECT", "UNION", "DIFFERENCE"]
    """ (default 'INTERSECT')"""

    solver: typing.Literal["EXACT", "FLOAT", "MANIFOLD"]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshCircle(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a circular ring of edges"""

    fill_type: Literal[bpy.stub_internal.rna_enums.NodeGeometryMeshCircleFillTypeItems]
    """ (default 'NONE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshCone(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a cone mesh"""

    fill_type: Literal[bpy.stub_internal.rna_enums.NodeGeometryMeshCircleFillTypeItems]
    """ (default 'NGON')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshCube(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a cuboid mesh with variable side lengths and subdivisions"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshCylinder(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a cylinder mesh"""

    fill_type: Literal[bpy.stub_internal.rna_enums.NodeGeometryMeshCircleFillTypeItems]
    """ (default 'NGON')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshFaceSetBoundaries(GeometryNode, NodeInternal, Node, bpy_struct):
    """Find edges on the boundaries between groups of faces with the same ID value"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a planar mesh on the XY plane"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshIcoSphere(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a spherical mesh that consists of equally sized triangles"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshLine(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate vertices in a line and connect them with edges"""

    count_mode: typing.Literal["TOTAL", "RESOLUTION"]
    """ (default 'TOTAL')"""

    mode: typing.Literal["OFFSET", "END_POINTS"]
    """ (default 'OFFSET')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshToCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a curve from a mesh"""

    mode: typing.Literal["EDGES", "FACES"]
    """ (default 'EDGES')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshToDensityGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a filled volume grid from a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshToPoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a point cloud from a meshs vertices"""

    mode: typing.Literal["VERTICES", "EDGES", "FACES", "CORNERS"]
    """ (default 'VERTICES')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshToSDFGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a signed distance volume grid from a mesh"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshToVolume(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a fog volume with the shape of the input meshs surface"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeMeshUVSphere(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a spherical mesh with quads, except for triangles at the top and bottom"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeObjectInfo(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve information from an object"""

    transform_space: typing.Literal["ORIGINAL", "RELATIVE"]
    """ The transformation of the vector and geometry outputs (default 'ORIGINAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeOffsetCornerInFace(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve corners in the same face as another"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeOffsetPointInCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Offset a control point index within its curve"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePoints(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a point cloud with positions and radii defined by fields"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePointsOfCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve a point index within a curve"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePointsToCurves(GeometryNode, NodeInternal, Node, bpy_struct):
    """Split all points to curve by its group ID and reorder by weight"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePointsToSDFGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create a signed distance volume grid from points"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePointsToVertices(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a mesh vertex for each point cloud point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodePointsToVolume(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a fog volume sphere around every point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeProximity(GeometryNode, NodeInternal, Node, bpy_struct):
    """Compute the closest location on the target geometry"""

    target_element: typing.Literal["POINTS", "EDGES", "FACES"]
    """ Element of the target geometry to calculate the distance from (default 'FACES')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRaycast(GeometryNode, NodeInternal, Node, bpy_struct):
    """Cast rays from the context geometry onto a target geometry, and retrieve information from each hit point"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ Type of data stored in attribute (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRealizeInstances(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert instances into real geometry data"""

    realize_to_point_domain: bool
    """ Propagate instance attributes to the point domain rather than the curve domain. This property exists for compatibility with 5.0 and earlier. (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRemoveAttribute(GeometryNode, NodeInternal, Node, bpy_struct):
    """Delete an attribute with a specified name from a geometry. Typically used to optimize performance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRepeatInput(GeometryNode, NodeInternal, Node, bpy_struct):
    paired_output: Node | None
    """ Zone output node that this input node is paired with (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    def pair_with_output(self, output_node: NodeInternal | None) -> bool:
        """Pair a zone input node with an output node.

        :param output_node: Output Node, Zone output node to pair with
        :return: Result, True if pairing the node was successful
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRepeatOutput(GeometryNode, NodeInternal, Node, bpy_struct):
    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: RepeatItem | None
    """ Index of the active item"""

    inspection_index: int
    """ Iteration index that is used by inspection features like the viewer node or socket inspection (in [-inf, inf], default 0)"""

    repeat_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeReplaceMaterial(GeometryNode, NodeInternal, Node, bpy_struct):
    """Swap one material with another"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeResampleCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a poly spline for each input spline"""

    keep_last_segment: bool
    """ Do not collapse curves to single points if they are shorter than the given length. The collapsing behavior exists for compatibility reasons. (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeReverseCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Change the direction of curves by swapping their start and end data"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeRotateInstances(GeometryNode, NodeInternal, Node, bpy_struct):
    """Rotate geometry instances in local or global space"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridBoolean(GeometryNode, NodeInternal, Node, bpy_struct):
    """Cut, subtract, or join multiple SDF volume grid inputs"""

    operation: typing.Literal["INTERSECT", "UNION", "DIFFERENCE"]
    """ (default 'DIFFERENCE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridFillet(GeometryNode, NodeInternal, Node, bpy_struct):
    """Round off concave internal corners in a signed distance field. Only affects areas with negative principal curvature, creating smoother transitions between surfaces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridLaplacian(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply Laplacian flow smoothing to a signed distance field. Computationally efficient alternative to mean curvature flow, ideal when combined with SDF normalization"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridMean(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply mean (box) filter smoothing to a signed distance field. Fast separable averaging filter for general smoothing of the distance field"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridMeanCurvature(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply mean curvature flow smoothing to a signed distance field. Evolves the surface based on its mean curvature, naturally smoothing high-curvature regions more than flat areas"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridMedian(GeometryNode, NodeInternal, Node, bpy_struct):
    """Apply median filter to a signed distance field. Reduces noise while preserving sharp features and edges in the distance field"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSDFGridOffset(GeometryNode, NodeInternal, Node, bpy_struct):
    """Offset a signed distance field surface by a world-space distance. Dilates (positive) or erodes (negative) while maintaining the signed distance property"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve data from a point on a curve at a certain distance from its start"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    mode: typing.Literal["FACTOR", "LENGTH"]
    """ Method for sampling input (default 'FACTOR')"""

    use_all_curves: bool
    """ Sample lengths based on the total length of all curves, rather than using a length inside each selected curve (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve values from the specified volume grid"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleGridIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve volume grid values at specific voxels"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve values from specific geometry elements"""

    clamp: bool
    """ Clamp the indices to the size of the attribute domain instead of outputting a default value for invalid indices (default False)"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleNearest(GeometryNode, NodeInternal, Node, bpy_struct):
    """Find the element of a geometry closest to a position. Similar to the "Index of Nearest" node"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainOnlyMeshItems]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleNearestSurface(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the interpolated value of a mesh attribute on the closest point of its surface"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSampleUVSurface(GeometryNode, NodeInternal, Node, bpy_struct):
    """Calculate the interpolated values of a mesh attribute at a UV coordinate"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeScaleElements(GeometryNode, NodeInternal, Node, bpy_struct):
    """Scale groups of connected edges and faces"""

    domain: typing.Literal["FACE", "EDGE"]
    """ Element type to transform (default 'FACE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeScaleInstances(GeometryNode, NodeInternal, Node, bpy_struct):
    """Scale geometry instances in local or global space"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSelfObject(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the object that contains the geometry nodes modifier currently being executed"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSeparateComponents(GeometryNode, NodeInternal, Node, bpy_struct):
    """Split a geometry into a separate output for each type of data in the geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSeparateGeometry(GeometryNode, NodeInternal, Node, bpy_struct):
    """Split a geometry into two geometry outputs based on a selection"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainWithoutCornerItems]
    """ Which domain to separate on (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetCurveHandlePositions(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the positions for the handles of Bézier curves"""

    mode: Literal[bpy.stub_internal.rna_enums.NodeGeometryCurveHandleSideItems]
    """ Whether to update left and right handles (default 'LEFT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetCurveNormal(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the evaluation mode for curve normals"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetCurveOrder(GeometryNode, NodeInternal, Node, bpy_struct):
    """Control how many control points influence each evaluated point by changing the "nurbs_order" attribute"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetCurveRadius(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the radius of the curve at each control point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetCurveTilt(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the tilt angle at each curve control point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGeometryBundle(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the bundle of a geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGeometryName(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the name of a geometry for easier debugging"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGreasePencilColor(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set color and opacity attributes on Grease Pencil geometry"""

    mode: typing.Literal["STROKE", "FILL"]
    """ (default 'STROKE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGreasePencilDepth(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the Grease Pencil depth order to use"""

    depth_order: Literal[bpy.stub_internal.rna_enums.StrokeDepthOrderItems]
    """ (default '2D')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGreasePencilSoftness(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set softness attribute on Grease Pencil geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGridBackground(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the background value used for inactive voxels and tiles"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetGridTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the transform for the grid from index space into object space."""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Node socket data type (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetID(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the id attribute on the input geometry, mainly used internally for randomizing"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetInstanceTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the transformation matrix of every instance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetMaterial(GeometryNode, NodeInternal, Node, bpy_struct):
    """Assign a material to geometry elements"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetMaterialIndex(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the material index for each selected geometry element"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetMeshNormal(GeometryNode, NodeInternal, Node, bpy_struct):
    """Store a normal vector for each mesh element"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainOnlyMeshNoEdgeItems]
    """ Attribute domain to store free custom normals (default 'POINT')"""

    mode: typing.Literal["SHARPNESS", "FREE", "TANGENT_SPACE"]
    """ Storage mode for custom normal data (default 'SHARPNESS')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetPointRadius(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the display size of point cloud points"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetPosition(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set the location of each point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetShadeSmooth(GeometryNode, NodeInternal, Node, bpy_struct):
    """Control the smoothness of mesh normals around each face by changing the "shade smooth" attribute"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainEdgeFaceItems]
    """ (default 'EDGE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetSplineCyclic(GeometryNode, NodeInternal, Node, bpy_struct):
    """Control whether each spline loops back on itself by changing the "cyclic" attribute"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSetSplineResolution(GeometryNode, NodeInternal, Node, bpy_struct):
    """Control how many evaluated points should be generated on every curve segment"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSimulationInput(GeometryNode, NodeInternal, Node, bpy_struct):
    """Input data for the simulation zone"""

    paired_output: Node | None
    """ Zone output node that this input node is paired with (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    def pair_with_output(self, output_node: NodeInternal | None) -> bool:
        """Pair a zone input node with an output node.

        :param output_node: Output Node, Zone output node to pair with
        :return: Result, True if pairing the node was successful
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSimulationOutput(GeometryNode, NodeInternal, Node, bpy_struct):
    """Output data from the simulation zone"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: SimulationStateItem | None
    """ Index of the active item"""

    state_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSortElements(GeometryNode, NodeInternal, Node, bpy_struct):
    """Rearrange geometry elements, changing their indices"""

    domain: typing.Literal["POINT", "EDGE", "FACE", "CURVE", "INSTANCE"]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSplineLength(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the total length of each spline, as a distance or as a number of points"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSplineParameter(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve how far along each spline a control point is"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSplitEdges(GeometryNode, NodeInternal, Node, bpy_struct):
    """Duplicate mesh edges and break connections with the surrounding faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSplitToInstances(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create separate geometries containing the elements from the same group"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainWithoutCornerItems]
    """ Attribute domain for the Selection and Group ID inputs (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeStoreNamedAttribute(GeometryNode, NodeInternal, Node, bpy_struct):
    """Store the result of a field on a geometry as an attribute with the specified name"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ Type of data stored in attribute (default 'FLOAT')"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Which domain to store the data in (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeStoreNamedGrid(GeometryNode, NodeInternal, Node, bpy_struct):
    """Store grid data in a volume geometry with the specified name"""

    data_type: Literal[bpy.stub_internal.rna_enums.VolumeGridDataTypeItems]
    """ Type of grid data (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeStringJoin(GeometryNode, NodeInternal, Node, bpy_struct):
    """Combine any number of input strings"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeStringToCurves(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a paragraph of text with a specific font, using a curve instance to store each character"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSubdivideCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Dividing each curve segment into a specified number of pieces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSubdivideMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Divide mesh faces into smaller ones without changing the shape or volume, using linear interpolation to place the new vertices"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSubdivisionSurface(GeometryNode, NodeInternal, Node, bpy_struct):
    """Divide mesh faces to form a smooth surface, using the Catmull-Clark subdivision method"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeSwitch(GeometryNode, NodeInternal, Node, bpy_struct):
    """Switch between two inputs"""

    input_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'GEOMETRY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTool3DCursor(GeometryNode, NodeInternal, Node, bpy_struct):
    """The scenes 3D cursor location and rotation"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolActiveElement(GeometryNode, NodeInternal, Node, bpy_struct):
    """Active element indices of the edited geometry, for tool execution"""

    domain: typing.Literal["POINT", "EDGE", "FACE", "LAYER"]
    """ (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolFaceSet(GeometryNode, NodeInternal, Node, bpy_struct):
    """Each faces sculpt face set value"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolMousePosition(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the position of the mouse cursor"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolSelection(GeometryNode, NodeInternal, Node, bpy_struct):
    """User selection of the edited geometry, for tool execution"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolSetFaceSet(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set sculpt face set values for faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeToolSetSelection(GeometryNode, NodeInternal, Node, bpy_struct):
    """Set selection of the edited geometry, for tool execution"""

    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainPointEdgeFaceCurveItems]
    """ (default 'POINT')"""

    selection_type: typing.Literal["BOOLEAN", "FLOAT"]
    """ (default 'BOOLEAN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Translate, rotate or scale the geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTranslateInstances(GeometryNode, NodeInternal, Node, bpy_struct):
    """Move top-level geometry instances in local or global space"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTree(NodeTree, ID, bpy_struct):
    """Node tree consisting of linked nodes used for geometries"""

    is_mode_edit: bool
    """ The node group is used in edit mode (default False)"""

    is_mode_object: bool
    """ The node group is used in object mode (default False)"""

    is_mode_paint: bool
    """ The node group is used in paint mode (default False)"""

    is_mode_sculpt: bool
    """ The node group is used in sculpt mode (default False)"""

    is_modifier: bool
    """ The node group is used as a geometry modifier (default False)"""

    is_tool: bool
    """ The node group is used as a tool (default False)"""

    is_type_curve: bool
    """ The node group is used for curves (default False)"""

    is_type_grease_pencil: bool
    """ The node group is used for Grease Pencil (default False)"""

    is_type_mesh: bool
    """ The node group is used for meshes (default False)"""

    is_type_pointcloud: bool
    """ The node group is used for point clouds (default False)"""

    node_tool_idname: str
    """ Unique operator identifier for the node tool (default "", never None)"""

    show_modifier_manage_panel: bool
    """ Turn on the option to display the manage panel when creating a modifier (default True)"""

    use_wait_for_click: bool
    """ Wait for mouse click input before running the operator from a menu (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTriangulate(GeometryNode, NodeInternal, Node, bpy_struct):
    """Convert all faces in a mesh to triangular faces"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeTrimCurve(GeometryNode, NodeInternal, Node, bpy_struct):
    """Shorten curves by removing portions at the start or end"""

    mode: typing.Literal["FACTOR", "LENGTH"]
    """ How to find endpoint positions for the trimmed spline (default 'FACTOR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeUVPackIslands(GeometryNode, NodeInternal, Node, bpy_struct):
    """Scale islands of a UV map and move them so they fill the UV space as much as possible"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeUVTangent(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate tangent directions based on a UV map"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeUVUnwrap(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a UV map based on seam edges"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeVertexOfCorner(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the vertex each face corner is attached to"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeViewer(GeometryNode, NodeInternal, Node, bpy_struct):
    """Display the input data in the Spreadsheet Editor"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_item: NodeGeometryViewerItem | None
    domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainWithAutoItems]
    """ Domain to evaluate fields on (default 'POINT')"""

    ui_shortcut: int
    """ (in [-32768, 32767], default 0)"""

    viewer_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeViewportTransform(GeometryNode, NodeInternal, Node, bpy_struct):
    """Retrieve the view direction and location of the 3D viewport"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeVolumeCube(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a dense volume with a field that controls the density at each grid voxel based on its position"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeVolumeToMesh(GeometryNode, NodeInternal, Node, bpy_struct):
    """Generate a mesh on the "surface" of a volume"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GeometryNodeWarning(GeometryNode, NodeInternal, Node, bpy_struct):
    """Create custom warnings in node groups"""

    warning_type: Literal[bpy.stub_internal.rna_enums.NodeWarningTypeItems]
    """ (default 'ERROR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Gizmo(bpy_struct):
    """Collection of gizmos"""

    alpha: float
    """ (in [0, 1], default 0.0)"""

    alpha_highlight: float
    """ (in [0, 1], default 0.0)"""

    bl_idname: str
    """ (default "", never None)"""

    color: mathutils.Color
    """ (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    color_highlight: mathutils.Color
    """ (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    group: GizmoGroup | None
    """ Gizmo group this gizmo is a member of (readonly)"""

    hide: bool
    """ (default False)"""

    hide_keymap: bool
    """ Ignore the key-map for this gizmo (default False)"""

    hide_select: bool
    """ (default False)"""

    is_highlight: bool
    """ (default False, readonly)"""

    is_modal: bool
    """ (default False, readonly)"""

    line_width: float
    """ (in [0, inf], default 0.0)"""

    matrix_basis: mathutils.Matrix
    """ (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_offset: mathutils.Matrix
    """ (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_space: mathutils.Matrix
    """ (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_world: mathutils.Matrix
    """ (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    properties: GizmoProperties | None
    """ (readonly, never None)"""

    scale_basis: float
    """ (in [0, inf], default 0.0)"""

    select: bool
    """ (default False)"""

    select_bias: float
    """ Depth bias used for selection (in [-inf, inf], default 0.0)"""

    use_draw_hover: bool
    """ (default False)"""

    use_draw_modal: bool
    """ Show while dragging (default False)"""

    use_draw_offset_scale: bool
    """ Scale the offset matrix (use to apply screen-space offset) (default False)"""

    use_draw_scale: bool
    """ Use scale when calculating the matrix (default True)"""

    use_draw_value: bool
    """ Show an indicator for the current value while dragging (default False)"""

    use_event_handle_all: bool
    """ When highlighted, do not pass events through to be handled by other keymaps (default False)"""

    use_grab_cursor: bool
    """ (default False)"""

    use_operator_tool_properties: bool
    """ Merge active tool properties on activation (does not overwrite existing) (default False)"""

    use_select_background: bool
    """ Don't write into the depth buffer (default False)"""

    use_tooltip: bool
    """ Use tooltips when hovering over this gizmo (default True)"""

    use_undo: bool
    """ Push an undo step after each use of the gizmo (default False)"""

    def draw(self, context: Context) -> None:
        """

        :param context: (never None)
        """

    def draw_select(self, context: Context, *, select_id: int | None = 0) -> None:
        """

        :param context: (never None)
        :param select_id: (in [0, inf], optional)
        """

    def test_select(
        self, context: Context, location: collections.abc.Sequence[int] | None
    ) -> int:
        """

        :param context: (never None)
        :param location: Location, Region coordinates (array of 2 items, in [-inf, inf], never None)
        :return: Use -1 to skip this gizmo (in [-1, inf])
        """

    def modal(
        self,
        context: Context,
        event: Event | None,
        tweak: set[typing.Literal["PRECISE", "SNAP"]] | None,
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """

        :param context: (never None)
        :param event: (never None)
        :param tweak: Tweak
        :return: result
        """

    def setup(self) -> None: ...
    def invoke(
        self, context: Context, event: Event | None
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """

        :param context: (never None)
        :param event: (never None)
        :return: result
        """

    def exit(self, context: Context, cancel: bool | None) -> None:
        """

        :param context: (never None)
        :param cancel: Cancel, otherwise confirm
        """

    def select_refresh(self) -> None: ...
    def draw_preset_box(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        select_id: int | None = -1,
    ) -> None:
        """Draw a box

        :param matrix: The matrix to transform (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param select_id: ID to use when gizmo is selectable. Use -1 when not selecting., (in [-1, inf], optional)
        """

    def draw_preset_arrow(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems] | None = "POS_Z",
        select_id: int | None = -1,
    ) -> None:
        """Draw a box

        :param matrix: The matrix to transform (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param axis: Arrow Orientation (optional)
        :param select_id: ID to use when gizmo is selectable. Use -1 when not selecting., (in [-1, inf], optional)
        """

    def draw_preset_circle(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems] | None = "POS_Z",
        select_id: int | None = -1,
    ) -> None:
        """Draw a box

        :param matrix: The matrix to transform (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param axis: Arrow Orientation (optional)
        :param select_id: ID to use when gizmo is selectable. Use -1 when not selecting., (in [-1, inf], optional)
        """

    def target_set_prop(
        self,
        target: str | None,
        data: typing.Any | None,
        property: str | None,
        *,
        index: int | None = -1,
    ) -> None:
        """

        :param target: Target property (never None)
        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param index: (in [-1, inf], optional)
        """

    def target_set_operator(
        self, operator: str | None, *, index: int | None = 0
    ) -> OperatorProperties:
        """Operator to run when activating the gizmo (overrides property targets)

        :param operator: Target operator (never None)
        :param index: Part index, (in [0, 255], optional)
        :return: Operator properties to fill in
        """

    def target_is_valid(self, property: str | None) -> bool:
        """

        :param property: Property identifier (never None)
        :return:
        """

    def draw_custom_shape(
        self,
        shape: typing.Any | None,
        *,
        matrix: None
        | collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None = None,
        select_id: None | int | None = None,
    ) -> None:
        """Draw a shape created form `Gizmo.draw_custom_shape`.

                :param shape: The cached shape to draw.
                :param matrix: 4x4 matrix, when not given `Gizmo.matrix_world` is used.
                :param select_id: The selection id.
        Only use when drawing within `Gizmo.draw_select`.
        """

    @staticmethod
    def new_custom_shape(
        type: typing.Literal["POINTS", "LINES", "TRIS", "LINE_STRIP"] | None,
        verts: collections.abc.Sequence[collections.abc.Sequence[float]] | None,
    ) -> typing.Any:
        """Create a new shape that can be passed to `Gizmo.draw_custom_shape`.

        :param type: The type of shape to create.
        :param verts: Sequence of 2D or 3D coordinates.
        :return: The newly created shape (the return type make change).
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def target_get_range(self, target) -> tuple[float, float]:
        """Get the range for this target property.

        :param target: Target property name.
        :return: The range of this property (min, max).
        """

    def target_get_value(self, target: str | None) -> float | tuple[float, ...]:
        """Get the value of this target property.

        :param target: Target property name.
        :return: The value of the target property as a value or array based on the target type.
        """

    def target_set_handler(
        self,
        target: str | None,
        get: collections.abc.Callable[float | collections.abc.Sequence[float]] | None,
        set: collections.abc.Callable[[tuple[float, ...]], typing.Any] | None,
        range: None | collections.abc.Callable[tuple[float, float]] | None = None,
    ) -> None:
        """Assigns callbacks to a gizmos property.

        :param target: Target property name.
        :param get: Function that returns the value for this property (single value or sequence).
        :param set: Function that takes a single value argument and applies it.
        :param range: Function that returns a (min, max) tuple for gizmos that use a range. The returned value is not used.
        """

    def target_set_value(self, target: str | None) -> None:
        """Set the value of this target property.

        :param target: Target property name.
        """

class GizmoGroup(bpy_struct):
    """Storage of an operator being executed, or registered after execution"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    bl_options: set[
        typing.Literal[
            "3D",
            "SCALE",
            "DEPTH_3D",
            "SELECT",
            "PERSISTENT",
            "SHOW_MODAL_ALL",
            "EXCLUDE_MODAL",
            "TOOL_INIT",
            "TOOL_FALLBACK_KEYMAP",
            "VR_REDRAWS",
        ]
    ]
    """ Options for this operator type (default set())"""

    bl_owner_id: str
    """ (default "", never None)"""

    bl_region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
    """ The region where the panel is going to be used in (default 'WINDOW')"""

    bl_space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ The space where the panel is going to be used in (default 'EMPTY')"""

    gizmos: typing.Any
    """ List of gizmos in the Gizmo Map (default None, readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    @classmethod
    def poll(cls, context: Context) -> bool:
        """Test if the gizmo group can be called or not

        :param context: (never None)
        :return:
        """

    @classmethod
    def setup_keymap(cls, keyconfig: KeyConfig | None) -> KeyMap:
        """Initialize keymaps for this gizmo group, use fallback keymap when not present

        :param keyconfig: (never None)
        :return: (never None)
        """

    def setup(self, context: Context) -> None:
        """Create gizmos function for the gizmo group

        :param context: (never None)
        """

    def refresh(self, context: Context) -> None:
        """Refresh data (called on common state changes such as selection)

        :param context: (never None)
        """

    def draw_prepare(self, context: Context) -> None:
        """Run before each redraw

        :param context: (never None)
        """

    def invoke_prepare(self, context: Context, gizmo: Gizmo | None) -> None:
        """Run before invoke

        :param context: (never None)
        :param gizmo: (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GizmoGroupProperties(bpy_struct):
    """Input properties of a Gizmo Group"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GizmoProperties(bpy_struct):
    """Input properties of a Gizmo"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GlowStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip creating a glow effect"""

    blur_radius: float
    """ Radius of glow effect (in [0.5, 20], default 0.0)"""

    boost_factor: float
    """ Brightness multiplier (in [0, 10], default 0.0)"""

    clamp: float
    """ Brightness limit of intensity (in [0, 1], default 0.0)"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    quality: int
    """ Accuracy of the blur effect (in [1, 5], default 0)"""

    threshold: float
    """ Minimum intensity to trigger a glow (in [0, 1], default 0.0)"""

    use_only_boost: bool
    """ Show the glow buffer only (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GpPaint(Paint, bpy_struct):
    color_mode: typing.Literal["MATERIAL", "VERTEXCOLOR"]
    """ Paint Mode (default 'MATERIAL')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GpSculptPaint(Paint, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GpVertexPaint(Paint, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GpWeightPaint(Paint, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencil(ID, bpy_struct):
    """Grease Pencil data-block"""

    after_color: mathutils.Color
    """ Base color for ghosts after the active frame (array of 3 items, in [0, 1], default (0.12549, 0.082353, 0.529412))"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    attributes: typing.Any
    """ Geometry attributes (default None, readonly)"""

    before_color: mathutils.Color
    """ Base color for ghosts before the active frame (array of 3 items, in [0, 1], default (0.145098, 0.419608, 0.137255))"""

    color_attributes: typing.Any
    """ Geometry color attributes (default None, readonly)"""

    ghost_after_range: int
    """ Maximum number of frames to show after current frame (0 = don't show any frames after current) (in [0, 120], default 1)"""

    ghost_before_range: int
    """ Maximum number of frames to show before current frame (0 = don't show any frames before current) (in [0, 120], default 1)"""

    layer_groups: typing.Any
    """ Grease Pencil layer groups (default None, readonly)"""

    layers: typing.Any
    """ Grease Pencil layers (default None, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    onion_factor: float
    """ Change fade opacity of displayed onion frames (in [0, 1], default 0.5)"""

    onion_keyframe_type: typing.Literal[
        "ALL", "KEYFRAME", "BREAKDOWN", "MOVING_HOLD", "EXTREME", "JITTER", "GENERATED"
    ]
    """ Type of keyframe (for filtering) (default 'ALL')"""

    onion_mode: typing.Literal["ABSOLUTE", "RELATIVE", "SELECTED"]
    """ Mode to display frames (default 'ABSOLUTE')"""

    root_nodes: typing.Any
    """ The root nodes of the layer tree. Ordered by stack order, meaning the first node is the bottom most node in the layer tree. (default None, readonly)"""

    stroke_depth_order: Literal[bpy.stub_internal.rna_enums.StrokeDepthOrderItems]
    """ Defines how the strokes are ordered in 3D space (for objects not displayed 'In Front') (default '2D')"""

    use_autolock_layers: bool
    """ Automatically lock all layers except the active one to avoid accidental changes (default False)"""

    use_ghost_custom_colors: bool
    """ Use custom colors for ghost frames (default False)"""

    use_onion_fade: bool
    """ Display onion keyframes with a fade in color transparency (default False)"""

    use_onion_loop: bool
    """ Display onion keyframes for looping animations (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilArmatureModifier(Modifier, bpy_struct):
    """Deform stroke points using armature object"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    object: Object | None
    """ Armature object to deform with"""

    open_influence_panel: bool
    """ (default False)"""

    use_bone_envelopes: bool
    """ Bind Bone envelopes to armature modifier (default False)"""

    use_deform_preserve_volume: bool
    """ Deform rotation interpolation with quaternions (default False)"""

    use_vertex_groups: bool
    """ Bind vertex groups to armature modifier (default True)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilArrayModifier(Modifier, bpy_struct):
    """Create grid of duplicate instances"""

    constant_offset: mathutils.Vector
    """ Value for the distance between items (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    count: int
    """ Number of items (in [1, 32767], default 2)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    offset_object: Object | None
    """ Use the location and rotation of another object to determine the distance and rotational change between arrayed items"""

    open_constant_offset_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    open_object_offset_panel: bool
    """ (default False)"""

    open_randomize_panel: bool
    """ (default False)"""

    open_relative_offset_panel: bool
    """ (default False)"""

    random_offset: mathutils.Vector
    """ Value for changes in location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    random_rotation: mathutils.Euler
    """ Value for changes in rotation (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    random_scale: mathutils.Vector
    """ Value for changes in scale (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    relative_offset: mathutils.Vector
    """ The size of the geometry will determine the distance between arrayed items (array of 3 items, in [-inf, inf], default (1.0, 0.0, 0.0))"""

    replace_material: int
    """ Index of the material used for generated strokes (0 keep original material) (in [0, 32767], default 0)"""

    seed: int
    """ Random seed (in [0, inf], default 1)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_constant_offset: bool
    """ Enable offset (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_object_offset: bool
    """ Add another object's transformation to the total offset (default False)"""

    use_relative_offset: bool
    """ Add an offset relative to the object's bounding box (default True)"""

    use_uniform_random_scale: bool
    """ Use the same random seed for each scale axis for a uniform scale (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilBuildModifier(Modifier, bpy_struct):
    """Animate strokes appearing and disappearing"""

    concurrent_time_alignment: typing.Literal["START", "END"]
    """ How should strokes start to appear/disappear (default 'START')"""

    fade_factor: float
    """ Defines how much of the stroke is fading in/out (in [0, 1], default 0.0)"""

    fade_opacity_strength: float
    """ How much strength fading applies on top of stroke opacity (in [0, 1], default 0.0)"""

    fade_thickness_strength: float
    """ How much strength fading applies on top of stroke thickness (in [0, 1], default 0.0)"""

    frame_end: float
    """ End Frame (when Restrict Frame Range is enabled) (in [-1.04857e+06, 1.04857e+06], default 125.0)"""

    frame_start: float
    """ Start Frame (when Restrict Frame Range is enabled) (in [-1.04857e+06, 1.04857e+06], default 1.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    length: float
    """ Maximum number of frames that the build effect can run for (unless another GP keyframe occurs before this time has elapsed) (in [1, 1.04857e+06], default 100.0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    mode: typing.Literal["SEQUENTIAL", "CONCURRENT", "ADDITIVE"]
    """ How strokes are being built (default 'SEQUENTIAL')"""

    object: Object | None
    """ Object used as build starting position"""

    open_fading_panel: bool
    """ (default False)"""

    open_frame_range_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    percentage_factor: float
    """ Defines how much of the stroke is visible (in [0, 1], default 0.0)"""

    speed_factor: float
    """ Multiply recorded drawing speed by a factor (in [0, 100], default 1.2)"""

    speed_maxgap: float
    """ The maximum gap between strokes in seconds (in [0, 100], default 0.5)"""

    start_delay: float
    """ Number of frames after each GP keyframe before the modifier has any effect (in [0, 1.04857e+06], default 0.0)"""

    target_vertex_group: str
    """ Output Vertex group (default "", never None)"""

    time_mode: typing.Literal["DRAWSPEED", "FRAMES", "PERCENTAGE"]
    """ Use drawing speed, a number of frames, or a manual factor to build strokes (default 'FRAMES')"""

    transition: typing.Literal["GROW", "SHRINK", "FADE"]
    """ How are strokes animated (i.e. are they appearing or disappearing) (default 'GROW')"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_fading: bool
    """ Fade out strokes instead of directly cutting off (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_percentage: bool
    """ Use a percentage factor to determine the visible points (default False)"""

    use_restrict_frame_range: bool
    """ Only modify strokes during the specified frame range (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilColorModifier(Modifier, bpy_struct):
    color_mode: typing.Literal["BOTH", "STROKE", "FILL"]
    """ Attributes to modify (default 'BOTH')"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    hue: float
    """ Color hue offset (in [0, 1], default 0.5)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    saturation: float
    """ Color saturation factor (in [0, inf], default 0.5)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    value: float
    """ Color value factor (in [0, inf], default 0.5)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilDashModifierData(Modifier, bpy_struct):
    """Create dot-dash effect for strokes"""

    dash_offset: int
    """ Offset into each stroke before the beginning of the dashed segment generation (in [-inf, inf], default 0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    segment_active_index: int
    """ Active index in the segment list (in [0, inf], default 0)"""

    segments: typing.Any
    """ (default None, readonly)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilDashModifierSegment(bpy_struct):
    """Configuration for a single dash segment"""

    dash: int
    """ The number of consecutive points from the original stroke to include in this segment (in [1, 32767], default 2)"""

    gap: int
    """ The number of points skipped after this segment (in [0, 32767], default 1)"""

    material_index: int
    """ Use this index on generated segment. -1 means using the existing material. (in [-1, 32767], default -1)"""

    name: str
    """ Name of the dash segment (default "", never None)"""

    opacity: float
    """ The factor to apply to the original point's opacity for the new points (in [0, 1], default 1.0)"""

    radius: float
    """ The factor to apply to the original point's radius for the new points (in [0, 1], default 1.0)"""

    use_cyclic: bool
    """ Enable cyclic on individual stroke dashes (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilDrawing(bpy_struct):
    """A Grease Pencil drawing"""

    attributes: typing.Any
    """ Geometry attributes (default None, readonly)"""

    color_attributes: typing.Any
    """ Geometry color attributes (default None, readonly)"""

    curve_offsets: typing.Any
    """ Offset indices of the first point of each curve (default None, readonly)"""

    type: typing.Literal["DRAWING", "REFERENCE"]
    """ Drawing type (default 'DRAWING', readonly)"""

    user_count: int
    """ The number of keyframes this drawing is used by (in [-inf, inf], default 0, readonly)"""

    strokes: typing.Any
    """ Return a collection of all the Grease Pencil strokes in this drawing.(readonly)"""

    def add_strokes(self, sizes: collections.abc.Sequence[int] | None) -> None:
        """Add new strokes with provided sizes at the end

        :param sizes: Sizes, The number of points in each stroke (array of 1 items, in [1, inf])
        """

    def remove_strokes(
        self, *, indices: collections.abc.Sequence[int] | None = (0)
    ) -> None:
        """Remove all strokes. If indices are provided, remove only the strokes with the given indices.

        :param indices: Indices, The indices of the strokes to remove (array of 1 items, in [0, inf], optional)
        """

    def resize_strokes(
        self,
        sizes: collections.abc.Sequence[int] | None,
        *,
        indices: collections.abc.Sequence[int] | None = (0),
    ) -> None:
        """Resize all existing strokes. If indices are provided, resize only the strokes with the given indices. If the new size for a stroke is smaller, the stroke is trimmed. If the new size for a stroke is larger, the new end values are default initialized.

        :param sizes: Sizes, The number of points in each stroke (array of 1 items, in [1, inf])
        :param indices: Indices, The indices of the stroke to resize (array of 1 items, in [0, inf], optional)
        """

    def reorder_strokes(
        self, new_indices: collections.abc.Sequence[int] | None
    ) -> None:
        """Reorder the strokes by the new indices.

        :param new_indices: New indices, The new index for each of the strokes (array of 1 items, in [0, inf])
        """

    def set_types(
        self,
        *,
        type: Literal[bpy.stub_internal.rna_enums.CurvesTypeItems]
        | None = "CATMULL_ROM",
        indices: collections.abc.Sequence[int] | None = (0),
    ) -> None:
        """Set the curve type. If indices are provided, set only the types with the given curve indices.

        :param type: Type, (optional)
        :param indices: Indices, The indices of the curves to resize (array of 1 items, in [0, inf], optional)
        """

    def tag_positions_changed(self) -> None:
        """Indicate that the positions of points in the drawing have changed"""

    def vertex_group_assign(
        self,
        vgroup_name: str | None,
        indices_ptr: collections.abc.Sequence[int] | None,
        weight: float | None,
    ) -> None:
        """Assign points to vertex group

        :param vgroup_name: Vertex Group Name, Name of the vertex group (never None)
        :param indices_ptr: Indices, The point indices to assign the weight to (array of 1 items, in [-inf, inf])
        :param weight: Vertex weight (in [0, 1])
        """

    def vertex_group_remove(
        self, vgroup_name: str | None, indices_ptr: collections.abc.Sequence[int] | None
    ) -> None:
        """Remove points from vertex group

        :param vgroup_name: Vertex Group Name, Name of the vertex group (never None)
        :param indices_ptr: Indices, The point indices to remove from the vertex group (array of 1 items, in [-inf, inf])
        """

    def set_vertex_weights(
        self,
        vertex_group_name: str | None,
        indices: collections.abc.Sequence[int] | None,
        weights: collections.abc.Sequence[float] | None,
        *,
        assign_mode: typing.Literal["REPLACE", "ADD", "SUBTRACT"] | None = "REPLACE",
    ) -> None:
        """Set the weights of vertices in a grease pencil drawing

                :param vertex_group_name: Vertex Group Name, Name of the vertex group (never None)
                :param indices: Indices, The point indices in the vertex group to modify (array of 1 items, in [-inf, inf])
                :param weights: Weights, The weight for each corresponding index in the indices array (array of 1 items, in [0, 1])
                :param assign_mode: (optional)

        REPLACE
        Replace -- Replace.

        ADD
        Add -- Add.

        SUBTRACT
        Subtract -- Subtract.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilEnvelopeModifier(Modifier, bpy_struct):
    """Envelope stroke effect modifier"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    mat_nr: int
    """ The material to use for the new strokes (in [-1, 32767], default -1)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    mode: typing.Literal["DEFORM", "SEGMENTS", "FILLS"]
    """ Algorithm to use for generating the envelope (default 'SEGMENTS')"""

    open_influence_panel: bool
    """ (default False)"""

    skip: int
    """ The number of generated segments to skip to reduce complexity (in [0, inf], default 0)"""

    spread: int
    """ The number of points to skip to create straight segments (in [1, inf], default 10)"""

    strength: float
    """ Multiplier for the strength of the new strokes (in [0, inf], default 1.0)"""

    thickness: float
    """ Multiplier for the thickness of the new strokes (in [0, inf], default 1.0)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilFrame(bpy_struct):
    """A Grease Pencil keyframe"""

    drawing: GreasePencilDrawing | None
    """ A Grease Pencil drawing"""

    frame_number: int
    """ The frame number in the scene (in [-1048574, 1048574], default 0, readonly)"""

    keyframe_type: typing.Literal[
        "KEYFRAME", "BREAKDOWN", "MOVING_HOLD", "EXTREME", "JITTER", "GENERATED"
    ]
    """ Type of keyframe (default 'KEYFRAME')"""

    select: bool
    """ Frame Selection in the Dope Sheet (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilHookModifier(Modifier, bpy_struct):
    """Hook modifier to modify the location of stroke points"""

    center: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    falloff_radius: float
    """ If not zero, the distance from the hook where influence ends (in [0, inf], default 0.0)"""

    falloff_type: typing.Literal[
        "NONE",
        "CURVE",
        "SMOOTH",
        "SPHERE",
        "ROOT",
        "INVERSE_SQUARE",
        "SHARP",
        "LINEAR",
        "CONSTANT",
    ]
    """ (default 'SMOOTH')"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    matrix_inverse: mathutils.Matrix
    """ Reverse the transformation between this object and its target (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((1.0, 0.0, 0.0, 0.0), (0.0, 1.0, 0.0, 0.0), (0.0, 0.0, 1.0, 0.0), (0.0, 0.0, 0.0, 1.0)))"""

    object: Object | None
    """ Parent Object for hook, also recalculates and clears offset"""

    open_falloff_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    strength: float
    """ Relative force of the hook (in [0, 1], default 0.5)"""

    subtarget: str
    """ Name of Parent Bone for hook (if applicable), also recalculates and clears offset (default "", never None)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_falloff_uniform: bool
    """ Compensate for non-uniform object scale (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLatticeModifier(Modifier, bpy_struct):
    """Deform strokes using a lattice object"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    object: Object | None
    """ Lattice object to deform with"""

    open_influence_panel: bool
    """ (default False)"""

    strength: float
    """ Strength of modifier effect (in [-inf, inf], default 1.0)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLayer(GreasePencilTreeNode, bpy_struct):
    """Collection of related drawings"""

    blend_mode: typing.Literal[
        "REGULAR", "HARDLIGHT", "ADD", "SUBTRACT", "MULTIPLY", "DIVIDE"
    ]
    """ Blend mode (default 'REGULAR')"""

    frames: typing.Any
    """ Grease Pencil frames (default None, readonly)"""

    ignore_locked_materials: bool
    """ Allow editing strokes even if they use locked materials (default False)"""

    lock_frame: bool
    """ Lock current frame displayed by layer (default False)"""

    mask_layers: typing.Any
    """ List of Masking Layers (default None, readonly)"""

    matrix_local: mathutils.Matrix
    """ Local transformation matrix of the layer (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    matrix_parent_inverse: mathutils.Matrix
    """ Inverse of layer's parent transformation matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    opacity: float
    """ Layer Opacity (in [0, 1], default 0.0)"""

    parent: Object | None
    """ Parent object"""

    parent_bone: str
    """ Name of parent bone. Only used when the parent object is an armature. (default "", never None)"""

    pass_index: int
    """ Index number for the "Layer Index" pass (in [0, inf], default 0)"""

    radius_offset: float
    """ Radius change to apply to current strokes (in [-inf, inf], default 0.0)"""

    rotation: mathutils.Euler
    """ Euler rotation of the layer (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    scale: mathutils.Vector
    """ Scale of the layer (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    tint_color: mathutils.Color
    """ Color for tinting stroke colors (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    tint_factor: float
    """ Factor of tinting color (in [0, 1], default 0.0)"""

    translation: mathutils.Vector
    """ Translation of the layer (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    use_lights: bool
    """ Enable the use of lights on stroke and fill materials (default False)"""

    use_viewlayer_masks: bool
    """ Include the mask layers when rendering the view-layer (default True)"""

    viewlayer_render: str
    """ Only include Layer in this View Layer render output (leave blank to include always) (default "", never None)"""

    def get_frame_at(self, frame_number: int | None) -> GreasePencilFrame:
        """Get the frame at given frame number

        :param frame_number: Frame Number, (in [-1048574, 1048574])
        :return: Frame
        """

    def current_frame(self) -> GreasePencilFrame:
        """The Grease Pencil frame at the current scene time on this layer

        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLayerGroup(GreasePencilTreeNode, bpy_struct):
    """Group of Grease Pencil layers"""

    children: typing.Any
    """ The direct children of this layer group. Ordered by stack order, meaning the first child is the bottom most child in the layer tree. (default None, readonly)"""

    color_tag: typing.Literal[
        "NONE",
        "COLOR1",
        "COLOR2",
        "COLOR3",
        "COLOR4",
        "COLOR5",
        "COLOR6",
        "COLOR7",
        "COLOR8",
    ]
    """ (default 'COLOR1')"""

    is_expanded: bool
    """ The layer group is expanded in the UI (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLayerMask(bpy_struct):
    """List of Mask Layers"""

    hide: bool
    """ Set mask Visibility (default False)"""

    invert: bool
    """ Invert mask (default False)"""

    name: str
    """ Mask layer name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLengthModifier(Modifier, bpy_struct):
    """Stretch or shrink strokes"""

    end_factor: float
    """ Added length to the end of each stroke relative to its length (in [-inf, inf], default 0.1)"""

    end_length: float
    """ Absolute added length to the end of each stroke (in [-inf, inf], default 0.1)"""

    invert_curvature: bool
    """ Invert the curvature of the stroke's extension (default False)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    max_angle: float
    """ Ignore points on the stroke that deviate from their neighbors by more than this angle when determining the extrapolation shape (in [0, 3.14159], default 2.96706)"""

    mode: typing.Literal["RELATIVE", "ABSOLUTE"]
    """ Mode to define length (default 'RELATIVE')"""

    open_curvature_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    open_random_panel: bool
    """ (default False)"""

    overshoot_factor: float
    """ Defines what portion of the stroke is used for the calculation of the extension (in [0, 1], default 0.1)"""

    point_density: float
    """ Multiplied by Start/End for the total added point count (in [0.1, 1000], default 30.0)"""

    random_end_factor: float
    """ Size of random length added to the end of each stroke (in [-inf, inf], default 0.0)"""

    random_offset: float
    """ Smoothly offset each stroke's random value (in [-inf, inf], default 0.0)"""

    random_start_factor: float
    """ Size of random length added to the start of each stroke (in [-inf, inf], default 0.0)"""

    seed: int
    """ Random seed (in [0, inf], default 0)"""

    segment_influence: float
    """ Factor to determine how much the length of the individual segments should influence the final computed curvature. Higher factors makes small segments influence the overall curvature less. (in [-2, 3], default 0.0)"""

    start_factor: float
    """ Added length to the start of each stroke relative to its length (in [-inf, inf], default 0.1)"""

    start_length: float
    """ Absolute added length to the start of each stroke (in [-inf, inf], default 0.1)"""

    step: int
    """ Number of frames between randomization steps (in [1, 100], default 4)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_curvature: bool
    """ Follow the curvature of the stroke (default True)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_random: bool
    """ Use random values over time (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilLineartModifier(Modifier, bpy_struct):
    """Generate Line Art strokes from selected source"""

    chaining_image_threshold: float
    """ Segments with an image distance smaller than this will be chained together (in [0, 0.3], default 0.001)"""

    crease_threshold: float
    """ Angles smaller than this will be treated as creases. Crease angle priority: object Line Art crease override > mesh auto smooth angle > Line Art default crease. (in [0, 3.14159], default 2.44346)"""

    invert_source_vertex_group: bool
    """ Invert source vertex group values (default False)"""

    is_baked: bool
    """ This modifier has baked data (default False)"""

    level_end: int
    """ Maximum number of occlusions for the generated strokes (in [0, 128], default 0)"""

    level_start: int
    """ Minimum number of occlusions for the generated strokes (in [0, 128], default 0)"""

    light_contour_object: Object | None
    """ Use this light object to generate light contour"""

    opacity: float
    """ The strength value for the generate strokes (in [0, 1], default 1.0)"""

    overscan: float
    """ A margin to prevent strokes from ending abruptly at the edge of the image (in [0, 0.5], default 0.1)"""

    radius: float
    """ The radius for the generated strokes (in [0, 1], default 0.0025)"""

    shadow_camera_far: float
    """ Far clipping distance of shadow camera (in [0, 10000], default 200.0)"""

    shadow_camera_near: float
    """ Near clipping distance of shadow camera (in [0, 10000], default 0.1)"""

    shadow_camera_size: float
    """ Represents the "Orthographic Scale" of an orthographic camera. If the camera is positioned at the light's location with this scale, it will represent the coverage of the shadow "camera". (in [0, 10000], default 200.0)"""

    shadow_region_filtering: typing.Literal[
        "NONE", "ILLUMINATED", "SHADED", "ILLUMINATED_ENCLOSED"
    ]
    """ Select feature lines that comes from lit or shaded regions. Will not affect cast shadow and light contour since they are at the border. (default 'NONE')"""

    silhouette_filtering: typing.Literal["NONE", "GROUP", "INDIVIDUAL"]
    """ Select contour or silhouette (default 'NONE')"""

    smooth_tolerance: float
    """ Strength of smoothing applied on jagged chains (in [0, 30], default 0.0)"""

    source_camera: Object | None
    """ Use specified camera object for generating Line Art strokes"""

    source_collection: Collection | None
    """ Generate strokes from the objects in this collection"""

    source_object: Object | None
    """ Generate strokes from this object"""

    source_type: typing.Literal["COLLECTION", "OBJECT", "SCENE"]
    """ Line Art stroke source type (default 'COLLECTION')"""

    source_vertex_group: str
    """ Match the beginning of vertex group names from mesh objects, match all when left empty (default "", never None)"""

    split_angle: float
    """ Angle in screen space below which a stroke is split in two (in [0, 3.14159], default 0.0)"""

    stroke_depth_offset: float
    """ Move strokes slightly towards the camera to avoid clipping while preserve depth for the viewport (in [-0.1, inf], default 0.05)"""

    target_layer: str
    """ Grease Pencil layer to which assign the generated strokes (default "", never None)"""

    target_material: Material | None
    """ Grease Pencil material assigned to the generated strokes"""

    use_back_face_culling: bool
    """ Remove all back faces to speed up calculation, this will create edges in different occlusion levels than when disabled (default False)"""

    use_cache: bool
    """ Use cached scene data from the first Line Art modifier in the stack. Certain settings will be unavailable. (default False)"""

    use_clip_plane_boundaries: bool
    """ Allow lines generated by the near/far clipping plane to be shown (default True)"""

    use_contour: bool
    """ Generate strokes from contours lines (default False)"""

    use_crease: bool
    """ Generate strokes from creased edges (default False)"""

    use_crease_on_sharp: bool
    """ Allow crease to show on sharp edges (default True)"""

    use_crease_on_smooth: bool
    """ Allow crease edges to show inside smooth surfaces (default False)"""

    use_custom_camera: bool
    """ Use custom camera instead of the active camera (default False)"""

    use_detail_preserve: bool
    """ Keep the zig-zag "noise" in initial chaining (default False)"""

    use_edge_mark: bool
    """ Generate strokes from Freestyle marked edges (default False)"""

    use_edge_overlap: bool
    """ Allow edges in the same location (i.e. from edge split) to show properly. May run slower. (default False)"""

    use_face_mark: bool
    """ Filter feature lines using Freestyle face marks (default False)"""

    use_face_mark_boundaries: bool
    """ Filter feature lines based on face mark boundaries (default False)"""

    use_face_mark_invert: bool
    """ Invert face mark filtering (default False)"""

    use_face_mark_keep_contour: bool
    """ Preserve contour lines while filtering (default True)"""

    use_fuzzy_all: bool
    """ Treat all lines as the same line type so they can be chained together (default False)"""

    use_fuzzy_intersections: bool
    """ Treat intersection and contour lines as if they were the same type so they can be chained together (default False)"""

    use_geometry_space_chain: bool
    """ Use geometry distance for chaining instead of image space (default False)"""

    use_image_boundary_trimming: bool
    """ Trim all edges right at the boundary of image (including overscan region) (default False)"""

    use_intersection: bool
    """ Generate strokes from intersections (default False)"""

    use_intersection_mask: typing.Any
    """ Mask bits to match from Collection Line Art settings (array of 8 items, default (False, False, False, False, False, False, False, False))"""

    use_intersection_match: bool
    """ Require matching all intersection masks instead of just one (default False)"""

    use_invert_collection: bool
    """ Select everything except lines from specified collection (default False)"""

    use_invert_silhouette: bool
    """ Select anti-silhouette lines (default False)"""

    use_light_contour: bool
    """ Generate light/shadow separation lines from a reference light object (default False)"""

    use_loose: bool
    """ Generate strokes from loose edges (default False)"""

    use_loose_as_contour: bool
    """ Loose edges will have contour type (default False)"""

    use_loose_edge_chain: bool
    """ Allow loose edges to be chained together (default False)"""

    use_material: bool
    """ Generate strokes from borders between materials (default False)"""

    use_material_mask: bool
    """ Use material masks to filter out occluded strokes (default False)"""

    use_material_mask_bits: typing.Any
    """ Mask bits to match from Material Line Art settings (array of 8 items, default (False, False, False, False, False, False, False, False))"""

    use_material_mask_match: bool
    """ Require matching all material masks instead of just one (default False)"""

    use_multiple_levels: bool
    """ Generate strokes from a range of occlusion levels (default False)"""

    use_object_instances: bool
    """ Allow particle objects and face/vertex instances to show in Line Art (default True)"""

    use_offset_towards_custom_camera: bool
    """ Offset strokes towards selected camera instead of the active camera (default False)"""

    use_output_vertex_group_match_by_name: bool
    """ Match output vertex group based on name (default True)"""

    use_overlap_edge_type_support: bool
    """ Allow an edge to have multiple overlapping types. This will create a separate stroke for each overlapping type. (default False)"""

    use_shadow: bool
    """ Project contour lines using a light source object (default False)"""

    vertex_group: str
    """ Vertex group name for selected strokes (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilMirrorModifier(Modifier, bpy_struct):
    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    object: Object | None
    """ Object used as center"""

    open_influence_panel: bool
    """ (default False)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_axis_x: bool
    """ Mirror the X axis (default True)"""

    use_axis_y: bool
    """ Mirror the Y axis (default False)"""

    use_axis_z: bool
    """ Mirror the Z axis (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilMultiplyModifier(Modifier, bpy_struct):
    """Generate multiple strokes from one stroke"""

    distance: float
    """ Distance of duplications (in [-inf, inf], default 0.1)"""

    duplicates: int
    """ How many copies of strokes be displayed (in [0, 999], default 3)"""

    fading_center: float
    """ Fade center (in [0, 1], default 0.5)"""

    fading_opacity: float
    """ Fade influence of stroke's opacity (in [0, 1], default 0.5)"""

    fading_thickness: float
    """ Fade influence of stroke's thickness (in [0, 1], default 0.5)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    offset: float
    """ Offset of duplicates, -1 to 1 (inner to outer) (in [-inf, inf], default 0.0)"""

    open_fading_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_fade: bool
    """ Fade the stroke thickness for each generated stroke (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilNoiseModifier(Modifier, bpy_struct):
    """Noise effect modifier"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    factor: float
    """ Amount of noise to apply (in [0, inf], default 0.5)"""

    factor_strength: float
    """ Amount of noise to apply to opacity (in [0, inf], default 0.0)"""

    factor_thickness: float
    """ Amount of noise to apply to thickness (in [0, inf], default 0.0)"""

    factor_uvs: float
    """ Amount of noise to apply to UV rotation (in [0, inf], default 0.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    noise_offset: float
    """ Offset the noise along the strokes (in [0, inf], default 0.0)"""

    noise_scale: float
    """ Scale the noise frequency (in [0, 1], default 0.0)"""

    open_influence_panel: bool
    """ (default False)"""

    open_random_panel: bool
    """ (default False)"""

    random_mode: typing.Literal["STEP", "KEYFRAME"]
    """ Where to perform randomization (default 'STEP')"""

    seed: int
    """ Random seed (in [0, inf], default 1)"""

    step: int
    """ Number of frames between randomization steps (in [1, 100], default 4)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_random: bool
    """ Use random values over time (default True)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilOffsetModifier(Modifier, bpy_struct):
    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    location: mathutils.Vector
    """ Values for change location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    offset_mode: typing.Literal["RANDOM", "LAYER", "STROKE", "MATERIAL"]
    """ (default 'RANDOM')"""

    open_general_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    rotation: mathutils.Euler
    """ Values for changes in rotation (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    scale: mathutils.Vector
    """ Values for changes in scale (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    seed: int
    """ Random seed (in [0, inf], default 0)"""

    stroke_location: mathutils.Vector
    """ Value for changes in location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    stroke_rotation: mathutils.Euler
    """ Value for changes in rotation (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    stroke_scale: mathutils.Vector
    """ Value for changes in scale (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    stroke_start_offset: int
    """ Offset starting point (in [0, inf], default 0)"""

    stroke_step: int
    """ Number of elements that will be grouped (in [1, 500], default 1)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_uniform_random_scale: bool
    """ Use the same random seed for each scale axis for a uniform scale (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilOpacityModifier(Modifier, bpy_struct):
    color_factor: float
    """ Factor of opacity (in [-inf, inf], default 1.0)"""

    color_mode: typing.Literal["BOTH", "STROKE", "FILL", "HARDNESS"]
    """ Attributes to modify (default 'BOTH')"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    hardness_factor: float
    """ Factor of stroke hardness (in [0, inf], default 1.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_uniform_opacity: bool
    """ Replace the stroke opacity instead of modulating each point (default False)"""

    use_weight_as_factor: bool
    """ Use vertex group weight as factor instead of influence (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilOutlineModifier(Modifier, bpy_struct):
    """Outline of Strokes modifier from camera view"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    object: Object | None
    """ Target object to define stroke start"""

    open_influence_panel: bool
    """ (default False)"""

    outline_material: Material | None
    """ Material used for outline strokes"""

    sample_length: float
    """ (in [-inf, inf], default 0.0)"""

    subdivision: int
    """ Number of subdivisions (in [0, 10], default 3)"""

    thickness: int
    """ Thickness of the perimeter stroke (in [1, 1000], default 1)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_keep_shape: bool
    """ Try to keep global shape (default True)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilShrinkwrapModifier(Modifier, bpy_struct):
    """Shrink wrapping modifier to shrink wrap an object to a target"""

    auxiliary_target: Object | None
    """ Additional mesh target to shrink to"""

    cull_face: Literal[bpy.stub_internal.rna_enums.ShrinkwrapFaceCullItems]
    """ Stop vertices from projecting to a face on the target when facing towards/away (default 'OFF')"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    offset: float
    """ Distance to keep from the target (in [-inf, inf], default 0.05)"""

    open_influence_panel: bool
    """ (default False)"""

    project_limit: float
    """ Limit the distance used for projection (zero disables) (in [0, inf], default 0.0)"""

    smooth_factor: float
    """ Amount of smoothing to apply (in [0, 1], default 0.05)"""

    smooth_step: int
    """ Number of times to apply smooth (high numbers can reduce FPS) (in [1, 10], default 1)"""

    subsurf_levels: int
    """ Number of subdivisions that must be performed before extracting vertices' positions and normals (in [0, 6], default 0)"""

    target: Object | None
    """ Mesh target to shrink to"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_invert_cull: bool
    """ When projecting in the negative direction invert the face cull mode (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_negative_direction: bool
    """ Allow vertices to move in the negative direction of axis (default False)"""

    use_positive_direction: bool
    """ Allow vertices to move in the positive direction of axis (default True)"""

    use_project_x: bool
    """ (default False)"""

    use_project_y: bool
    """ (default False)"""

    use_project_z: bool
    """ (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    wrap_method: Literal[bpy.stub_internal.rna_enums.ShrinkwrapTypeItems]
    """ (default 'NEAREST_SURFACEPOINT')"""

    wrap_mode: Literal[bpy.stub_internal.rna_enums.ModifierShrinkwrapModeItems]
    """ Select how vertices are constrained to the target surface (default 'ON_SURFACE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilSimplifyModifier(Modifier, bpy_struct):
    """Simplify Stroke modifier"""

    distance: float
    """ Distance between points (in [0, inf], default 0.1)"""

    factor: float
    """ Factor of Simplify (in [0, 100], default 0.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    length: float
    """ Length of each segment (in [0, inf], default 0.1)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    mode: typing.Literal["FIXED", "ADAPTIVE", "SAMPLE", "MERGE"]
    """ How to simplify the stroke (default 'FIXED')"""

    open_influence_panel: bool
    """ (default False)"""

    sharp_threshold: float
    """ Preserve corners that have sharper angle than this threshold (in [0, 3.14159], default 0.0)"""

    step: int
    """ Number of times to apply simplify (in [1, 50], default 1)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilSmoothModifier(Modifier, bpy_struct):
    """Smooth effect modifier"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    factor: float
    """ Amount of smooth to apply (in [0, 1], default 1.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    step: int
    """ Number of times to apply smooth (high numbers can reduce fps) (in [1, 1000], default 1)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_edit_position: bool
    """ The modifier affects the position of the point (default True)"""

    use_edit_strength: bool
    """ The modifier affects the color strength of the point (default False)"""

    use_edit_thickness: bool
    """ The modifier affects the thickness of the point (default False)"""

    use_edit_uv: bool
    """ The modifier affects the UV rotation factor of the point (default False)"""

    use_keep_shape: bool
    """ Smooth the details, but keep the overall shape (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_smooth_ends: bool
    """ Smooth ends of strokes (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilSubdivModifier(Modifier, bpy_struct):
    """Subdivide Stroke modifier"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    level: int
    """ Level of subdivision (in [0, 16], default 1)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    subdivision_type: typing.Literal["CATMULL_CLARK", "SIMPLE"]
    """ Select type of subdivision algorithm (default 'CATMULL_CLARK')"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilTextureModifier(Modifier, bpy_struct):
    """Transform stroke texture coordinates Modifier"""

    alignment_rotation: float
    """ Additional rotation applied to dots and square strokes (in [-1.5708, 1.5708], default 0.0)"""

    fill_offset: mathutils.Vector
    """ Additional offset of the fill UV (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    fill_rotation: float
    """ Additional rotation of the fill UV (in [-inf, inf], default 0.0)"""

    fill_scale: float
    """ Additional scale of the fill UV (in [0.01, 100], default 1.0)"""

    fit_method: typing.Literal["CONSTANT_LENGTH", "FIT_STROKE"]
    """ (default 'CONSTANT_LENGTH')"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    mode: typing.Literal["STROKE", "FILL", "STROKE_AND_FILL"]
    """ (default 'STROKE')"""

    open_influence_panel: bool
    """ (default False)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    uv_offset: float
    """ Offset value to add to stroke UVs (in [-inf, inf], default 0.0)"""

    uv_scale: float
    """ Factor to scale the UVs (in [0, inf], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilThickModifierData(Modifier, bpy_struct):
    """Adjust stroke thickness"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    open_influence_panel: bool
    """ (default False)"""

    thickness: float
    """ Absolute thickness to apply everywhere (in [-10, 100], default 0.02)"""

    thickness_factor: float
    """ Factor to multiply the thickness with (in [0, inf], default 1.0)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_uniform_thickness: bool
    """ Replace the stroke thickness (default False)"""

    use_weight_factor: bool
    """ Use weight to modulate effect (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilTimeModifier(Modifier, bpy_struct):
    """Offset keyframes"""

    frame_end: int
    """ Final frame of the range (in [0, 1048574], default 250)"""

    frame_scale: float
    """ Evaluation time in seconds (in [0.001, 100], default 1.0)"""

    frame_start: int
    """ First frame of the range (in [0, 1048574], default 1)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    mode: typing.Literal["NORMAL", "REVERSE", "FIX", "PINGPONG", "CHAIN"]
    """ (default 'NORMAL')"""

    offset: int
    """ Number of frames to offset original keyframe number or frame to fix (in [-32768, 32767], default 1)"""

    open_custom_range_panel: bool
    """ (default False)"""

    open_influence_panel: bool
    """ (default False)"""

    segment_active_index: int
    """ Active index in the segment list (in [0, inf], default 0)"""

    segments: typing.Any
    """ (default None, readonly)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_frame_range: bool
    """ Define a custom range of frames to use in modifier (default False)"""

    use_keep_loop: bool
    """ Retiming end frames and move to start of animation to keep loop (default True)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilTimeModifierSegment(bpy_struct):
    """Configuration for a single dash segment"""

    name: str
    """ Name of the dash segment (default "", never None)"""

    segment_end: int
    """ Last frame of the segment (in [0, 32767], default 2)"""

    segment_mode: typing.Literal["NORMAL", "REVERSE", "PINGPONG"]
    """ (default 'NORMAL')"""

    segment_repeat: int
    """ Number of cycle repeats (in [1, 32767], default 1)"""

    segment_start: int
    """ First frame of the segment (in [0, 32767], default 1)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilTintModifier(Modifier, bpy_struct):
    color: mathutils.Color
    """ Color used for tinting (array of 3 items, in [0, 1], default (1.0, 1.0, 1.0))"""

    color_mode: typing.Literal["BOTH", "STROKE", "FILL"]
    """ Attributes to modify (default 'BOTH')"""

    color_ramp: ColorRamp | None
    """ Gradient tinting colors (readonly)"""

    custom_curve: CurveMapping | None
    """ Custom curve to apply effect (readonly)"""

    factor: float
    """ Factor for tinting (in [0, 2], default 0.5)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    object: Object | None
    """ Object used for the gradient direction"""

    open_influence_panel: bool
    """ (default False)"""

    radius: float
    """ Influence distance from the object (in [1e-06, inf], default 1.0)"""

    tint_mode: typing.Literal["UNIFORM", "GRADIENT"]
    """ (default 'UNIFORM')"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_custom_curve: bool
    """ Use a custom curve to define a factor along the strokes (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_weight_as_factor: bool
    """ Use vertex group weight as factor instead of influence (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilTreeNode(bpy_struct):
    """Grease Pencil node in the layer tree. Either a layer or a group"""

    channel_color: mathutils.Color
    """ Color of the channel in the dope sheet (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    hide: bool
    """ Set tree node visibility (default False)"""

    lock: bool
    """ Protect tree node from editing (default False)"""

    name: str
    """ The name of the tree node (default "", never None)"""

    next_node: typing_extensions.Self | None
    """ The layer tree node after (i.e. above) this one (readonly)"""

    parent_group: GreasePencilLayerGroup | None
    """ The parent group of this layer tree node (readonly)"""

    prev_node: typing_extensions.Self | None
    """ The layer tree node before (i.e. below) this one (readonly)"""

    select: bool
    """ Tree node is selected (default False)"""

    use_masks: bool
    """ The visibility of drawings in this tree node is affected by the layers in the masks list (default True)"""

    use_onion_skinning: bool
    """ Display onion skins before and after the current frame (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilWeightAngleModifier(Modifier, bpy_struct):
    """Calculate Vertex Weight dynamically"""

    angle: float
    """ Angle (in [0, 3.14159], default 0.0)"""

    axis: typing.Literal["X", "Y", "Z"]
    """ (default 'Y')"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    minimum_weight: float
    """ Minimum value for vertex weight (in [0, 1], default 0.0)"""

    open_influence_panel: bool
    """ (default False)"""

    space: typing.Literal["LOCAL", "WORLD"]
    """ Coordinates space (default 'LOCAL')"""

    target_vertex_group: str
    """ Output Vertex group (default "", never None)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_invert_output: bool
    """ Invert output weight values (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_multiply: bool
    """ Multiply the calculated weights with the existing values in the vertex group (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GreasePencilWeightProximityModifier(Modifier, bpy_struct):
    """Calculate Vertex Weight dynamically"""

    distance_end: float
    """ Distance mapping to 1.0 weight (in [0, inf], default 20.0)"""

    distance_start: float
    """ Distance mapping to 0.0 weight (in [0, inf], default 0.0)"""

    invert_layer_filter: bool
    """ Invert layer filter (default False)"""

    invert_layer_pass_filter: bool
    """ Invert layer pass filter (default False)"""

    invert_material_filter: bool
    """ Invert material filter (default False)"""

    invert_material_pass_filter: bool
    """ Invert material pass filter (default False)"""

    invert_vertex_group: bool
    """ Invert vertex group weights (default False)"""

    layer_pass_filter: int
    """ Layer pass filter (in [0, 100], default 0)"""

    material_filter: Material | None
    """ Material used for filtering"""

    material_pass_filter: int
    """ Material pass (in [0, 100], default 0)"""

    minimum_weight: float
    """ Minimum value for vertex weight (in [0, 1], default 0.0)"""

    object: Object | None
    """ Object used as distance reference"""

    open_influence_panel: bool
    """ (default False)"""

    target_vertex_group: str
    """ Output Vertex group (default "", never None)"""

    tree_node_filter: str
    """ Layer name (default "", never None)"""

    use_invert_output: bool
    """ Invert output weight values (default False)"""

    use_layer_group_filter: bool
    """ Filter by layer group name (default False)"""

    use_layer_pass_filter: bool
    """ Use layer pass filter (default False)"""

    use_material_pass_filter: bool
    """ Use material pass filter (default False)"""

    use_multiply: bool
    """ Multiply the calculated weights with the existing values in the vertex group (default False)"""

    vertex_group_name: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class GroupNodeViewerPathElem(ViewerPathElem, bpy_struct):
    node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Header(bpy_struct):
    """Editor header containing UI elements"""

    bl_idname: str
    """ If this is set, the header gets a custom ID, otherwise it takes the name of the class used to define the header; for example, if the class name is "OBJECT_HT_hello", and bl_idname is not set by the script, then bl_idname = "OBJECT_HT_hello" (default "", never None)"""

    bl_region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
    """ The region where the header is going to be used in (defaults to header region) (default 'HEADER')"""

    bl_space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ The space where the header is going to be used in (default 'EMPTY')"""

    layout: UILayout | None
    """ Structure of the header in the UI (readonly)"""

    def draw(self, context: Context) -> None:
        """Draw UI elements into the header UI layout

        :param context:
        """

    @classmethod
    def append(cls, draw_func) -> None:
        """Append a draw function to this menu,
        takes the same arguments as the menus draw function

                :param draw_func:
        """

    @classmethod
    def is_extended(cls) -> None: ...
    @classmethod
    def prepend(cls, draw_func) -> None:
        """Prepend a draw function to this menu, takes the same arguments as
        the menus draw function

                :param draw_func:
        """

    @classmethod
    def remove(cls, draw_func) -> None:
        """Remove a draw function that has been added to this menu.

        :param draw_func:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Histogram(bpy_struct):
    """Statistical view of the levels of color in an image"""

    mode: typing.Literal["LUMA", "RGB", "R", "G", "B", "A"]
    """ Channels to display in the histogram (default 'LUMA')"""

    show_line: bool
    """ Display lines rather than filled shapes (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class HookModifier(Modifier, bpy_struct):
    """Hook modifier to modify the location of vertices"""

    center: mathutils.Vector
    """ Center of the hook, used for falloff and display (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    falloff_curve: CurveMapping | None
    """ Custom falloff curve (readonly)"""

    falloff_radius: float
    """ If not zero, the distance from the hook where influence ends (in [0, inf], default 0.0)"""

    falloff_type: typing.Literal[
        "NONE",
        "CURVE",
        "SMOOTH",
        "SPHERE",
        "ROOT",
        "INVERSE_SQUARE",
        "SHARP",
        "LINEAR",
        "CONSTANT",
    ]
    """ (default 'SMOOTH')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    matrix_inverse: mathutils.Matrix
    """ Reverse the transformation between this object and its target (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((1.0, 0.0, 0.0, 0.0), (0.0, 1.0, 0.0, 0.0), (0.0, 0.0, 1.0, 0.0), (0.0, 0.0, 0.0, 1.0)))"""

    object: Object | None
    """ Parent Object for hook, also recalculates and clears offset"""

    strength: float
    """ Relative force of the hook (in [0, 1], default 1.0)"""

    subtarget: str
    """ Name of Parent Bone for hook (if applicable), also recalculates and clears offset (default "", never None)"""

    use_falloff_uniform: bool
    """ Compensate for non-uniform object scale (default False)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    vertex_indices: typing.Any
    """ Indices of vertices bound to the modifier. For Bézier curves, handles count as additional vertices. (array of 64 items, in [0, inf], default (0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0), readonly)"""

    def vertex_indices_set(self, indices: collections.abc.Sequence[int] | None) -> None:
        """Validates and assigns the array of vertex indices bound to the modifier

        :param indices: Vertex Indices (array of 64 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class HueCorrectModifier(StripModifier, bpy_struct):
    """Hue correction modifier for sequence strip"""

    curve_mapping: CurveMapping | None
    """ (readonly)"""

    open_mask_input_panel: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class HydraRenderEngine(RenderEngine, bpy_struct):
    """Base class from USD Hydra based renderers"""

    def get_render_settings(self, engine_type) -> None:
        """Provide render settings for HdRenderDelegate.

        :param engine_type:
        """

    def render(self, depsgraph) -> None:
        """

        :param depsgraph:
        """

    def update(self, data, depsgraph) -> None:
        """

        :param data:
        :param depsgraph:
        """

    def view_draw(self, context, depsgraph) -> None:
        """

        :param context:
        :param depsgraph:
        """

    def view_update(self, context, depsgraph) -> None:
        """

        :param context:
        :param depsgraph:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ID(bpy_struct):
    """Base type for data-blocks, defining a unique name, linking from other libraries and garbage collection"""

    asset_data: AssetMetaData | None
    """ Additional data for an asset data-block"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ Type identifier of this data-block (default 'ACTION', readonly)"""

    is_editable: bool
    """ This data-block is editable in the user interface. Linked data-blocks are not editable, except if they were loaded as editable assets. (default False, readonly)"""

    is_embedded_data: bool
    """ This data-block is not an independent one, but is actually a sub-data of another ID (typical example: root node trees or master collections) (default False, readonly)"""

    is_evaluated: bool
    """ Whether this ID is runtime-only, evaluated data-block, or actual data from .blend file (default False, readonly)"""

    is_library_indirect: bool
    """ Is this ID block linked indirectly (default False, readonly)"""

    is_linked_packed: bool
    """ This data-block is linked and packed into the .blend file (default False, readonly)"""

    is_missing: bool
    """ This data-block is a place-holder for missing linked data (i.e. it is [an override of] a linked data that could not be found anymore) (default False, readonly)"""

    is_runtime_data: bool
    """ This data-block is runtime data, i.e. it won't be saved in .blend file. Note that e.g. evaluated IDs are always runtime, so this value is only editable for data-blocks in Main data-base. (default False)"""

    library: Library
    """ Library file the data-block is linked from (readonly)"""

    library_weak_reference: LibraryWeakReference | None
    """ Weak reference to a data-block in another library .blend file (used to re-use already appended data instead of appending new copies) (readonly)"""

    name: str
    """ Unique data-block ID name (within a same type and library) (default "", never None)"""

    name_full: str
    """ Unique data-block ID name, including library one if any (default "", readonly, never None)"""

    original: typing_extensions.Self | None
    """ Actual data-block from .blend file (Main database) that generated that evaluated one (readonly)"""

    override_library: IDOverrideLibrary | None
    """ Library override data (readonly)"""

    preview: ImagePreview | None
    """ Preview image and icon of this data-block (always None if not supported for this type of data) (readonly)"""

    session_uid: int
    """ A session-wide unique identifier for the data block that remains the same across renames and internal reallocations, unchanged when reloading the file (in [-inf, inf], default 0, readonly)"""

    tag: bool
    """ Tools can use this to tag data for their own purposes (initial state is undefined) (default False)"""

    use_extra_user: bool
    """ Indicates whether an extra user is set or not (mainly for internal/debug usages) (default False)"""

    use_fake_user: bool
    """ Save this data-block even if it has no users (default False)"""

    users: int
    """ Number of times this data-block is referenced (in [0, inf], default 0, readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def rename(
        self,
        name: str | None,
        *,
        mode: typing.Literal["NEVER", "ALWAYS", "SAME_ROOT"] | None = "NEVER",
    ) -> typing.Literal[
        "UNCHANGED",
        "UNCHANGED_COLLISION",
        "RENAMED_NO_COLLISION",
        "RENAMED_COLLISION_ADJUSTED",
        "RENAMED_COLLISION_FORCED",
    ]:
        """More refined handling in case the new name collides with another IDs name

                :param name: New name to rename the ID to, if empty will re-use the current ID name (never None)
                :param mode: How to handle name collision, in case the requested new name is already used by another ID of the same type (optional)

        NEVER
        Never Rename -- Never rename an existing ID whose name would conflict, the currently renamed ID will get a numeric suffix appended to its new name.

        ALWAYS
        Always Rename -- Always rename an existing ID whose name would conflict, ensuring that the currently renamed ID will get requested name.

        SAME_ROOT
        Rename If Same Root -- Only rename an existing ID whose name would conflict if its name root (everything besides the numerical suffix) is the same as the existing name of the currently renamed ID.
                :return: How did the renaming of the data-block went on

        UNCHANGED
        Unchanged -- The ID was not renamed, e.g. because it is already named as requested.

        UNCHANGED_COLLISION
        Unchanged Due to Collision -- The ID was not renamed, because requested name would have collided with another existing IDs name, and the automatically adjusted name was the same as the current IDs name.

        RENAMED_NO_COLLISION
        Renamed Without Collision -- The ID was renamed as requested, without creating any name collision.

        RENAMED_COLLISION_ADJUSTED
        Renamed With Collision -- The ID was renamed with adjustment of the requested name, to avoid a name collision.

        RENAMED_COLLISION_FORCED
        Renamed Enforced With Collision -- The ID was renamed as requested, also renaming another ID to avoid a name collision.
        """

    def evaluated_get(self, depsgraph: Depsgraph | None) -> typing_extensions.Self:
        """Get corresponding evaluated ID from the given dependency graph. Note that this does not ensure the dependency graph is fully evaluated, it just returns the result of the last evaluation.

        :param depsgraph: Dependency graph to perform lookup in (never None)
        :return: New copy of the ID
        """

    def copy(self) -> typing_extensions.Self:
        """Create a copy of this data-block (not supported for all data-blocks). The result is added to the Blend-File Data (Main database), with all references to other data-blocks ensured to be from within the same Blend-File Data.

        :return: New copy of the ID
        """

    def asset_mark(self) -> None:
        """Enable easier reuse of the data-block through the Asset Browser, with the help of customizable metadata (like previews, descriptions and tags)"""

    def asset_clear(self) -> None:
        """Delete all asset metadata and turn the asset data-block back into a normal data-block"""

    def asset_generate_preview(self) -> None:
        """Generate preview image (might be scheduled in a background thread)"""

    def override_create(
        self, *, remap_local_usages: bool | None = False
    ) -> typing_extensions.Self:
        """Create an overridden local copy of this linked data-block (not supported for all data-blocks)

        :param remap_local_usages: Whether local usages of the linked ID should be remapped to the new library override of it (optional)
        :return: New overridden local copy of the ID
        """

    def override_hierarchy_create(
        self,
        scene: Scene | None,
        view_layer: ViewLayer | None,
        *,
        reference: typing_extensions.Self | None = None,
        do_fully_editable: bool | None = False,
    ) -> typing_extensions.Self:
        """Create an overridden local copy of this linked data-block, and most of its dependencies when it is a Collection or and Object

        :param scene: In which scene the new overrides should be instantiated (never None)
        :param view_layer: In which view layer the new overrides should be instantiated (never None)
        :param reference: Another ID (usually an Object or Collection) used as a hint to decide where to instantiate the new overrides (optional)
        :param do_fully_editable: Make all library overrides generated by this call fully editable by the user (none will be system overrides) (optional)
        :return: New overridden local copy of the root ID
        """

    def user_clear(self) -> None:
        """Clear the user count of a data-block so its not saved, on reload the data will be removedThis function is for advanced use only, misuse can crash Blender since the user
        count is used to prevent data being removed when it is used.

        """

    def user_remap(self, new_id: typing_extensions.Self | None) -> None:
        """Replace all usage in the .blend file of this ID by new given one

        :param new_id: New ID to use (never None)
        """

    def make_local(
        self,
        *,
        clear_proxy: bool | None = True,
        clear_liboverride: bool | None = False,
        clear_asset_data: bool | None = True,
    ) -> typing_extensions.Self:
        """Make this data-block local, return local one (may be a copy of the original, in case it is also indirectly used)

        :param clear_proxy: Deprecated, has no effect (optional)
        :param clear_liboverride: Remove potential library override data from the newly made local data (optional)
        :param clear_asset_data: Remove potential asset metadata so the newly local data-block is not treated as asset data-block and wont show up in asset libraries (optional)
        :return: This ID, or the new ID if it was copied
        """

    def user_of_id(self, id: typing_extensions.Self | None) -> int:
        """Count the number of times that ID uses/references given one

        :param id: ID to count usages (never None)
        :return: Number of usages/references of given id by current data-block (in [0, inf])
        """

    def animation_data_create(self) -> AnimData:
        """Create animation data to this ID, note that not all ID types support this

        :return: New animation data or None
        """

    def animation_data_clear(self) -> None:
        """Clear animation on this ID"""

    def update_tag(
        self, *, refresh: set[typing.Literal["OBJECT", "DATA", "TIME"]] | None = set()
    ) -> None:
        """Tag the ID to update its display data, e.g. when calling `bpy.types.Scene.update`

        :param refresh: Type of updates to perform (optional)
        """

    def preview_ensure(self) -> ImagePreview:
        """Ensure that this ID has preview data (if ID type supports it)

        :return: The existing or created preview
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDOverrideLibrary(bpy_struct):
    """Struct gathering all data needed by overridden linked IDs"""

    hierarchy_root: ID | None
    """ Library override ID used as root of the override hierarchy this ID is a member of (readonly)"""

    is_in_hierarchy: bool
    """ Whether this library override is defined as part of a library hierarchy, or as a single, isolated and autonomous override (default True)"""

    is_system_override: bool
    """ Whether this library override exists only for the override hierarchy, or if it is actually editable by the user (default False)"""

    properties: typing.Any
    """ List of overridden properties (default None, readonly)"""

    reference: ID | None
    """ Linked ID used as reference by this override (readonly)"""

    def operations_update(self) -> None:
        """Update the library override operations based on the differences between this override ID and its reference"""

    def reset(
        self,
        *,
        do_hierarchy: bool | None = True,
        set_system_override: bool | None = False,
    ) -> None:
        """Reset this override to match again its linked reference ID

        :param do_hierarchy: Also reset all the dependencies of this override to match their reference linked IDs (optional)
        :param set_system_override: Reset all user-editable overrides as (non-editable) system overrides (optional)
        """

    def destroy(self, *, do_hierarchy: bool | None = True) -> None:
        """Delete this override ID and remap its usages to its linked reference ID instead

        :param do_hierarchy: Also delete all the dependencies of this override and remap their usages to their reference linked IDs (optional)
        """

    def resync(
        self,
        scene: Scene | None,
        *,
        view_layer: ViewLayer | None = None,
        residual_storage: Collection | None = None,
        do_hierarchy_enforce: bool | None = False,
        do_whole_hierarchy: bool | None = False,
    ) -> bool:
        """Resync the data-block and its sub-hierarchy, or the whole hierarchy if requested

        :param scene: The scene to operate in (for contextual things like keeping active object active, ensuring all overridden objects remain instantiated, etc.) (never None)
        :param view_layer: The view layer to operate in (same usage as the scene data, in case it is not provided the scenes collection will be used instead) (optional)
        :param residual_storage: Collection where to store objects that are instantiated in any other collection anymore (garbage collection, will be created if needed and none is provided) (optional)
        :param do_hierarchy_enforce: Enforce restoring the dependency hierarchy between data-blocks to match the one from the reference linked hierarchy (WARNING: if some ID pointers have been purposely overridden, these will be reset to their default value) (optional)
        :param do_whole_hierarchy: Resync the whole hierarchy this data-block belongs to, not only its own sub-hierarchy (optional)
        :return: Success, Whether the resync process was successful or not
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDOverrideLibraryProperty(bpy_struct):
    """Description of an overridden property"""

    operations: typing.Any
    """ List of overriding operations for a property (default None, readonly)"""

    rna_path: str
    """ RNA path leading to that property, from owning ID (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDOverrideLibraryPropertyOperation(bpy_struct):
    """Description of an override operation over an overridden property"""

    flag: set[
        typing.Literal[
            "MANDATORY", "LOCKED", "IDPOINTER_MATCH_REFERENCE", "IDPOINTER_ITEM_USE_ID"
        ]
    ]
    """ Status flags (default set(), readonly)"""

    operation: typing.Literal[
        "NOOP",
        "REPLACE",
        "DIFF_ADD",
        "DIFF_SUB",
        "FACT_MULTIPLY",
        "INSERT_AFTER",
        "INSERT_BEFORE",
    ]
    """ What override operation is performed (default 'REPLACE', readonly)"""

    subitem_local_id: ID | None
    """ Collection of IDs only, used to disambiguate between potential IDs with same name from different libraries (readonly)"""

    subitem_local_index: int
    """ Used to handle changes into collection (in [-1, inf], default -1, readonly)"""

    subitem_local_name: str
    """ Used to handle changes into collection (default "", readonly, never None)"""

    subitem_reference_id: ID | None
    """ Collection of IDs only, used to disambiguate between potential IDs with same name from different libraries (readonly)"""

    subitem_reference_index: int
    """ Used to handle changes into collection (in [-1, inf], default -1, readonly)"""

    subitem_reference_name: str
    """ Used to handle changes into collection (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDPropertyWrapPtr(bpy_struct):
    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IDViewerPathElem(ViewerPathElem, bpy_struct):
    id: ID | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IKParam(bpy_struct):
    """Base type for IK solver parameters"""

    ik_solver: typing.Literal["LEGACY", "ITASC"]
    """ IK solver for which these parameters are defined (default 'LEGACY', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IMAGE_AST_brush_paint(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IMAGE_FH_drop_handler(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IMAGE_UL_render_slots(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IMAGE_UL_udim_tiles(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IO_FH_gltf2(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IO_FH_svg_as_curves(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Image(ID, bpy_struct):
    """Image data-block referencing an external or packed image"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL", "CHANNEL_PACKED", "NONE"]
    """ Representation of alpha in the image file, to convert to and from when saving and loading the image (default 'STRAIGHT')"""

    channels: int
    """ Number of channels in pixels buffer (in [0, inf], default 0, readonly)"""

    colorspace_settings: ColorManagedInputColorspaceSettings | None
    """ Input color space settings (readonly)"""

    depth: int
    """ Image bit depth (in [0, inf], default 0, readonly)"""

    display_aspect: mathutils.Vector
    """ Display Aspect for this image, does not affect rendering (array of 2 items, in [0.1, inf], default (1.0, 1.0))"""

    file_format: Literal[bpy.stub_internal.rna_enums.ImageTypeAllItems]
    """ Format used for re-saving this file (default 'TARGA')"""

    filepath: str
    """ Image/Movie file name (default "", never None, blend relative // prefix supported)"""

    filepath_raw: str
    """ Image/Movie file name (without data refreshing) (default "", never None, blend relative // prefix supported)"""

    frame_duration: int
    """ Duration (in frames) of the image (1 when not a video/sequence) (in [0, inf], default 0, readonly)"""

    generated_color: typing.Any
    """ Fill color for the generated image (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    generated_height: int
    """ Generated image height (in [1, 65536], default 1024)"""

    generated_type: Literal[bpy.stub_internal.rna_enums.ImageGeneratedTypeItems]
    """ Generated image type (default 'UV_GRID')"""

    generated_width: int
    """ Generated image width (in [1, 65536], default 1024)"""

    has_data: bool
    """ True if the image data is loaded into memory (default False, readonly)"""

    is_dirty: bool
    """ Image has changed and is not saved (default False, readonly)"""

    is_float: bool
    """ True if this image is stored in floating-point buffer (default False, readonly)"""

    is_multiview: bool
    """ Image has more than one view (default False, readonly)"""

    is_stereo_3d: bool
    """ Image has left and right views (default False, readonly)"""

    packed_file: PackedFile | None
    """ First packed file of the image (readonly)"""

    packed_files: typing.Any
    """ Collection of packed images (default None, readonly)"""

    pixels: float
    """ Image buffer pixels in floating-point values (in [-inf, inf], default 0.0)"""

    render_slots: typing.Any
    """ Render slots of the image (default None, readonly)"""

    resolution: mathutils.Vector
    """ X/Y pixels per meter, for the image buffer (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    seam_margin: int
    """ Margin to take into account when fixing UV seams during painting. Higher number would improve seam-fixes for mipmaps, but decreases performance. (in [-32768, 32767], default 8)"""

    size: typing.Any
    """ Width and height of the image buffer in pixels, zero when image data cannot be loaded (array of 2 items, in [-inf, inf], default (0, 0), readonly)"""

    source: typing.Literal["FILE", "SEQUENCE", "MOVIE", "GENERATED", "VIEWER", "TILED"]
    """ Where the image comes from (default 'FILE')"""

    stereo_3d_format: Stereo3dFormat | None
    """ Settings for stereo 3d (readonly, never None)"""

    tiles: typing.Any
    """ Tiles of the image (default None, readonly)"""

    type: typing.Literal[
        "IMAGE", "MULTILAYER", "UV_TEST", "RENDER_RESULT", "COMPOSITING"
    ]
    """ How to generate the image (default 'IMAGE', readonly)"""

    use_deinterlace: bool
    """ Deinterlace movie file on load (default False)"""

    use_generated_float: bool
    """ Generate floating-point buffer (default False)"""

    use_half_precision: bool
    """ Use 16 bits per channel to lower the memory usage during rendering (default True)"""

    use_multiview: bool
    """ Use Multiple Views (when available) (default False)"""

    use_view_as_render: bool
    """ Apply render part of display transformation when displaying this image on the screen (default False)"""

    views_format: Literal[bpy.stub_internal.rna_enums.ViewsFormatItems]
    """ Mode to load image views (default 'INDIVIDUAL')"""

    def save_render(
        self,
        filepath: str | None,
        *,
        scene: Scene | None = None,
        quality: int | None = 0,
    ) -> None:
        """Save image to a specific path using a scenes render settings

        :param filepath: Output path (never None)
        :param scene: Scene to take image parameters from (optional)
        :param quality: Quality, Quality for image formats that support lossy compression, uses default quality if not specified (in [0, 100], optional)
        """

    def save(
        self,
        *,
        filepath: str | None = "",
        quality: int | None = 0,
        save_copy: bool | None = False,
    ) -> None:
        """Save image

        :param filepath: Output path, uses image data-block filepath if not specified (optional, never None)
        :param quality: Quality, Quality for image formats that support lossy compression, uses default quality if not specified (in [0, 100], optional)
        :param save_copy: Save Copy, Save the image as a copy, without updating current images filepath (optional)
        """

    def pack(self, *, data: bytes | None = b"", data_len: int | None = 0) -> None:
        """Pack an image as embedded data into the .blend file

        :param data: data, Raw data (bytes, exact content of the embedded file) (optional, never None)
        :param data_len: data_len, length of given data (mandatory if data is provided) (in [0, inf], optional)
        """

    def unpack(
        self,
        *,
        method: Literal[bpy.stub_internal.rna_enums.UnpackMethodItems]
        | None = "USE_LOCAL",
    ) -> None:
        """Save an image packed in the .blend file to disk

        :param method: method, How to unpack (optional)
        """

    def reload(self) -> None:
        """Reload the image from its source path"""

    def update(self) -> None:
        """Update the display image from the floating-point buffer"""

    def scale(
        self,
        width: int | None,
        height: int | None,
        *,
        frame: int | None = 0,
        tile_index: int | None = 0,
    ) -> None:
        """Scale the buffer of the image, in pixels

        :param width: Width (in [1, inf])
        :param height: Height (in [1, inf])
        :param frame: Frame, Frame (for image sequences) (in [0, inf], optional)
        :param tile_index: Tile, Tile index (for tiled images) (in [0, inf], optional)
        """

    def gl_touch(
        self,
        *,
        frame: int | None = 0,
        layer_index: int | None = 0,
        pass_index: int | None = 0,
    ) -> int:
        """Delay the image from being cleaned from the cache due inactivity

        :param frame: Frame, Frame of image sequence or movie (in [0, inf], optional)
        :param layer_index: Layer, Index of layer that should be loaded (in [0, inf], optional)
        :param pass_index: Pass, Index of pass that should be loaded (in [0, inf], optional)
        :return: Error, OpenGL error value (in [-inf, inf])
        """

    def gl_load(
        self,
        *,
        frame: int | None = 0,
        layer_index: int | None = 0,
        pass_index: int | None = 0,
    ) -> int:
        """Load the image into an OpenGL texture. On success, image.bindcode will contain the OpenGL texture bindcode. Colors read from the texture will be in scene linear color space and have premultiplied or straight alpha matching the image alpha mode.

        :param frame: Frame, Frame of image sequence or movie (in [0, inf], optional)
        :param layer_index: Layer, Index of layer that should be loaded (in [0, inf], optional)
        :param pass_index: Pass, Index of pass that should be loaded (in [0, inf], optional)
        :return: Error, OpenGL error value (in [-inf, inf])
        """

    def gl_free(self) -> None:
        """Free the image from OpenGL graphics memory"""

    def filepath_from_user(self, *, image_user: ImageUser | None = None) -> str:
        """Return the absolute path to the filepath of an image frame specified by the image user

        :param image_user: Image user of the image to get filepath for (optional)
        :return: File Path, The resulting filepath from the image and its user (never None)
        """

    def buffers_free(self) -> None:
        """Free the image buffers from memory"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImageFormatSettings(bpy_struct):
    """Settings for image formats"""

    cineon_black: int
    """ Log conversion reference blackpoint (in [0, 1024], default 0)"""

    cineon_gamma: float
    """ Log conversion gamma (in [0, 10], default 0.0)"""

    cineon_white: int
    """ Log conversion reference whitepoint (in [0, 1024], default 0)"""

    color_depth: Literal[bpy.stub_internal.rna_enums.ImageColorDepthItems]
    """ Bit depth per channel (default '8')"""

    color_management: typing.Literal["FOLLOW_SCENE", "OVERRIDE"]
    """ Which color management settings to use for file saving (default 'FOLLOW_SCENE')"""

    color_mode: Literal[bpy.stub_internal.rna_enums.ImageColorModeItems]
    """ Choose BW for saving grayscale images, RGB for saving red, green and blue channels, and RGBA for saving red, green, blue and alpha channels (default 'RGBA')"""

    compression: int
    """ Amount of time to determine best compression: 0 = no compression with fast file output, 100 = maximum lossless compression with slow file output (in [0, 100], default 15)"""

    display_settings: ColorManagedDisplaySettings | None
    """ Settings of device saved image would be displayed on (readonly)"""

    exr_codec: Literal[bpy.stub_internal.rna_enums.ExrCodecItems]
    """ Compression codec settings for OpenEXR (default 'NONE')"""

    file_format: Literal[bpy.stub_internal.rna_enums.ImageTypeAllItems]
    """ File format to save the rendered images as (default 'PNG')"""

    has_linear_colorspace: bool
    """ File format expects linear color space (default False, readonly)"""

    jpeg2k_codec: typing.Literal["JP2", "J2K"]
    """ Codec settings for JPEG 2000 (default 'JP2')"""

    linear_colorspace_settings: ColorManagedInputColorspaceSettings | None
    """ Output color space settings (readonly)"""

    media_type: typing.Literal["IMAGE", "MULTI_LAYER_IMAGE", "VIDEO"]
    """ The type of media to save (default 'IMAGE')"""

    quality: int
    """ Quality for image formats that support lossy compression (in [0, 100], default 90)"""

    stereo_3d_format: Stereo3dFormat | None
    """ Settings for stereo 3D (readonly, never None)"""

    tiff_codec: typing.Literal["NONE", "DEFLATE", "LZW", "PACKBITS"]
    """ Compression mode for TIFF (default 'DEFLATE')"""

    use_cineon_log: bool
    """ Convert to logarithmic color space (default False)"""

    use_exr_interleave: bool
    """ Use legacy interleaved storage of views, layers and passes for compatibility with applications that do not support more efficient multi-part OpenEXR files. (default False)"""

    use_jpeg2k_cinema_48: bool
    """ Use OpenJPEG Cinema Preset (48fps) (default False)"""

    use_jpeg2k_cinema_preset: bool
    """ Use OpenJPEG Cinema Preset (default False)"""

    use_jpeg2k_ycc: bool
    """ Save luminance-chrominance-chrominance channels instead of RGB colors (default False)"""

    use_preview: bool
    """ When rendering animations, save JPG preview images in same directory (default False)"""

    view_settings: ColorManagedViewSettings | None
    """ Color management settings applied on image before saving (readonly)"""

    views_format: Literal[bpy.stub_internal.rna_enums.ViewsFormatMultiviewItems]
    """ Format of multiview media (default 'INDIVIDUAL')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImagePackedFile(bpy_struct):
    filepath: str
    """ (default "", never None, blend relative // prefix supported)"""

    packed_file: PackedFile | None
    """ (readonly)"""

    tile_number: int
    """ (in [-inf, inf], default 0, readonly)"""

    view: int
    """ (in [-inf, inf], default 0, readonly)"""

    def save(self) -> None:
        """Save the packed file to its filepath"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImagePaint(Paint, bpy_struct):
    """Properties of image and texture painting mode"""

    canvas: Image | None
    """ Image used as canvas"""

    clone_alpha: float
    """ Opacity of clone image display (in [0, 1], default 0.5)"""

    clone_image: Image | None
    """ Image used as clone source"""

    clone_offset: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dither: float
    """ Amount of dithering when painting on byte images (in [0, 2], default 0.0)"""

    interpolation: typing.Literal["LINEAR", "CLOSEST"]
    """ Texture filtering type (default 'LINEAR')"""

    invert_stencil: bool
    """ Invert the stencil layer (default False)"""

    missing_materials: bool
    """ The mesh is missing materials (default False, readonly)"""

    missing_stencil: bool
    """ Image Painting does not have a stencil (default False, readonly)"""

    missing_texture: bool
    """ Image Painting does not have a texture to paint on (default False, readonly)"""

    missing_uvs: bool
    """ A UV layer is missing on the mesh (default False, readonly)"""

    mode: typing.Literal["MATERIAL", "IMAGE"]
    """ Mode of operation for projection painting (default 'MATERIAL')"""

    normal_angle: int
    """ Paint most on faces pointing towards the view according to this angle (in [0, 90], default 80)"""

    screen_grab_size: typing.Any
    """ Size to capture the image for re-projecting (array of 2 items, in [512, 16384], default (0, 0))"""

    seam_bleed: int
    """ Extend paint beyond the faces' UVs to reduce seams (in pixels, slower) (in [-32768, 32767], default 2)"""

    stencil_color: mathutils.Color
    """ Stencil color in the viewport (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    stencil_image: Image | None
    """ Image used as stencil"""

    use_backface_culling: bool
    """ Ignore faces pointing away from the view (faster) (default True)"""

    use_clone_layer: bool
    """ Use another UV map as clone source, otherwise use the 3D cursor as the source (default False)"""

    use_normal_falloff: bool
    """ Paint most on faces pointing towards the view (default True)"""

    use_occlude: bool
    """ Only paint onto the faces directly under the brush (slower) (default True)"""

    use_stencil_layer: bool
    """ Set the mask layer from the UV map buttons (default False)"""

    def detect_data(self) -> bool:
        """Check if required texpaint data exist

        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImagePreview(bpy_struct):
    """Preview image and icon"""

    icon_id: int
    """ Unique integer identifying this preview as an icon (zero means invalid) (in [-inf, inf], default 0, readonly)"""

    icon_pixels: int
    """ Icon pixels, as bytes (always 32-bit RGBA) (in [-inf, inf], default 0)"""

    icon_pixels_float: float
    """ Icon pixels components, as floats (RGBA concatenated values) (in [-inf, inf], default 0.0)"""

    icon_size: typing.Any
    """ Width and height in pixels (array of 2 items, in [-inf, inf], default (0, 0))"""

    image_pixels: int
    """ Image pixels, as bytes (always 32-bit RGBA) (in [-inf, inf], default 0)"""

    image_pixels_float: float
    """ Image pixels components, as floats (RGBA concatenated values) (in [-inf, inf], default 0.0)"""

    image_size: typing.Any
    """ Width and height in pixels (array of 2 items, in [-inf, inf], default (0, 0))"""

    is_icon_custom: bool
    """ True if this preview icon has been modified by py script, and is no more auto-generated by Blender (default False)"""

    is_image_custom: bool
    """ True if this preview image has been modified by py script, and is no more auto-generated by Blender (default False)"""

    def reload(self) -> None:
        """Reload the preview from its source path"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImageStrip(Strip, bpy_struct):
    """Sequence strip to load one or more images"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    colorspace_settings: ColorManagedInputColorspaceSettings | None
    """ Input color space settings (readonly)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    directory: str
    """ (default "", never None, blend relative // prefix supported)"""

    elements: typing.Any
    """ (default None, readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    proxy: StripProxy | None
    """ (readonly)"""

    retiming_keys: typing.Any
    """ (default None, readonly)"""

    stereo_3d_format: Stereo3dFormat | None
    """ Settings for stereo 3D (readonly, never None)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_multiview: bool
    """ Use Multiple Views (when available) (default False)"""

    use_proxy: bool
    """ Use a preview proxy and/or time-code index for this strip (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    views_format: Literal[bpy.stub_internal.rna_enums.ViewsFormatItems]
    """ Mode to load image views (default 'INDIVIDUAL')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImageTexture(Texture, ID, bpy_struct):
    checker_distance: float
    """ Distance between checker tiles (in [0, 0.99], default 0.0)"""

    crop_max_x: float
    """ Maximum X value to crop the image (in [-10, 10], default 1.0)"""

    crop_max_y: float
    """ Maximum Y value to crop the image (in [-10, 10], default 1.0)"""

    crop_min_x: float
    """ Minimum X value to crop the image (in [-10, 10], default 0.0)"""

    crop_min_y: float
    """ Minimum Y value to crop the image (in [-10, 10], default 0.0)"""

    extension: typing.Literal["EXTEND", "CLIP", "CLIP_CUBE", "REPEAT", "CHECKER"]
    """ How the image is extrapolated past its original bounds (default 'REPEAT')"""

    filter_size: float
    """ Multiply the filter size used by interpolation (in [0.1, 50], default 1.0)"""

    image: Image | None
    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly)"""

    invert_alpha: bool
    """ Invert all the alpha values in the image (default False)"""

    repeat_x: int
    """ Repetition multiplier in the X direction (in [1, 512], default 1)"""

    repeat_y: int
    """ Repetition multiplier in the Y direction (in [1, 512], default 1)"""

    use_alpha: bool
    """ Use the alpha channel information in the image (default True)"""

    use_calculate_alpha: bool
    """ Calculate an alpha channel based on RGB values in the image (default False)"""

    use_checker_even: bool
    """ Even checker tiles (default False)"""

    use_checker_odd: bool
    """ Odd checker tiles (default True)"""

    use_flip_axis: bool
    """ Flip the texture's X and Y axis (default False)"""

    use_interpolation: bool
    """ Interpolate pixels using selected filter (default True)"""

    use_mirror_x: bool
    """ Mirror the image repetition on the X direction (default False)"""

    use_mirror_y: bool
    """ Mirror the image repetition on the Y direction (default False)"""

    use_normal_map: bool
    """ Use image RGB values for normal mapping (default False)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ImageUser(bpy_struct):
    """Parameters defining how an Image data-block is used by another data-block"""

    frame_current: int
    """ Current frame number in image sequence or movie (in [-1048574, 1048574], default 0)"""

    frame_duration: int
    """ Number of images of a movie to use (in [0, 1048574], default 0)"""

    frame_offset: int
    """ Offset the number of the frame to use in the animation (in [-inf, inf], default 0)"""

    frame_start: int
    """ Global starting frame of the movie/sequence, assuming first picture has a #1 (in [-1048574, 1048574], default 0)"""

    multilayer_layer: int
    """ Layer in multilayer image (in [0, 32767], default 0, readonly)"""

    multilayer_pass: int
    """ Pass in multilayer image (in [0, 32767], default 0, readonly)"""

    multilayer_view: int
    """ View in multilayer image (in [0, 32767], default 0, readonly)"""

    tile: int
    """ Tile in tiled image (in [0, inf], default 0)"""

    use_auto_refresh: bool
    """ Always refresh image on frame changes (default False)"""

    use_cyclic: bool
    """ Cycle the images in the movie (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IndexSwitchItem(bpy_struct):
    identifier: int
    """ Consistent identifier used for the item (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Int2Attribute(Attribute, bpy_struct):
    """Geometry attribute that stores 2D integer vectors"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Int2AttributeValue(bpy_struct):
    """2D value in geometry attribute"""

    value: typing.Any
    """ 2D vector (array of 2 items, in [-inf, inf], default (0, 0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IntAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores integer values"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IntAttributeValue(bpy_struct):
    """Integer value in geometry attribute"""

    value: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class IntProperty(Property, bpy_struct):
    """RNA integer number property definition"""

    array_dimensions: typing.Any
    """ Length of each dimension of the array (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    array_length: int
    """ Maximum length of the array, 0 means unlimited (in [0, inf], default 0, readonly)"""

    default: int
    """ Default value for this number (in [-inf, inf], default 0, readonly)"""

    default_array: typing.Any
    """ Default value for this array (array of 3 items, in [-inf, inf], default (0, 0, 0), readonly)"""

    hard_max: int
    """ Maximum value used by buttons (in [-inf, inf], default 0, readonly)"""

    hard_min: int
    """ Minimum value used by buttons (in [-inf, inf], default 0, readonly)"""

    is_array: bool
    """ (default False, readonly)"""

    soft_max: int
    """ Maximum value used by buttons (in [-inf, inf], default 0, readonly)"""

    soft_min: int
    """ Minimum value used by buttons (in [-inf, inf], default 0, readonly)"""

    step: int
    """ Step size used by number buttons, for floats 1/100th of the step size (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Itasc(IKParam, bpy_struct):
    """Parameters for the iTaSC IK solver"""

    damping_epsilon: float
    """ Singular value under which damping is progressively applied (higher values produce results with more stability, less reactivity) (in [0, 1], default 0.0)"""

    damping_max: float
    """ Maximum damping coefficient when singular value is nearly 0 (higher values produce results with more stability, less reactivity) (in [0, 1], default 0.0)"""

    feedback: float
    """ Feedback coefficient for error correction, average response time is 1/feedback (in [0, 100], default 0.0)"""

    iterations: int
    """ Maximum number of iterations for convergence in case of reiteration (in [0, 1000], default 0)"""

    mode: typing.Literal["ANIMATION", "SIMULATION"]
    """ (default 'ANIMATION')"""

    precision: float
    """ Precision of convergence in case of reiteration (in [0, 0.1], default 0.0)"""

    reiteration_method: typing.Literal["NEVER", "INITIAL", "ALWAYS"]
    """ Defines if the solver is allowed to reiterate (converge until precision is met) on none, first or all frames (default 'NEVER')"""

    solver: typing.Literal["SDLS", "DLS"]
    """ Solving method selection: automatic damping or manual damping (default 'SDLS')"""

    step_count: int
    """ Divide the frame interval into this many steps (in [1, 50], default 0)"""

    step_max: float
    """ Higher bound for timestep in second in case of automatic substeps (in [0, 1], default 0.0)"""

    step_min: float
    """ Lower bound for timestep in second in case of automatic substeps (in [0, 0.1], default 0.0)"""

    translate_root_bones: bool
    """ Translate root (i.e. parentless) bones to the armature origin (default False)"""

    use_auto_step: bool
    """ Automatically determine the optimal number of steps for best performance/accuracy trade off (default False)"""

    velocity_max: float
    """ Maximum joint velocity in radians/second (in [0, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Key(ID, bpy_struct):
    """Shape keys data-block containing different shapes of geometric data-blocks"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    eval_time: float
    """ Evaluation time for absolute shape keys (in [0, 1.04857e+06], default 0.0)"""

    key_blocks: typing.Any
    """ Shape keys (default None, readonly)"""

    reference_key: ShapeKey | None
    """ (readonly, never None)"""

    use_relative: bool
    """ Make shape keys relative, otherwise play through shapes as a sequence using the evaluation time (default False)"""

    user: ID | None
    """ Data-block using these shape keys (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyConfig(bpy_struct):
    """Input configuration, including keymaps"""

    is_user_defined: bool
    """ Indicates that a keyconfig was defined by the user (default False, readonly)"""

    keymaps: typing.Any
    """ Key maps configured as part of this configuration (default None, readonly)"""

    name: str
    """ Name of the key configuration (default "", never None)"""

    preferences: KeyConfigPreferences | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyConfigPreferences(bpy_struct):
    bl_idname: str
    """ (default "", never None)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyMap(bpy_struct):
    """Input configuration, including keymaps"""

    bl_owner_id: str
    """ Internal owner (default "", never None)"""

    is_modal: bool
    """ Indicates that a keymap is used for translate modal events for an operator (default False, readonly)"""

    is_user_modified: bool
    """ Keymap is defined by the user (default False)"""

    keymap_items: typing.Any
    """ Items in the keymap, linking an operator to an input event (default None, readonly)"""

    modal_event_values: typing.Any
    """ Give access to the possible event values of this modal keymap's items (#KeyMapItem.propvalue), for API introspection (default None, readonly)"""

    name: str
    """ Name of the key map (default "", readonly, never None)"""

    region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
    """ Optional region type keymap is associated with (default 'WINDOW', readonly)"""

    show_expanded_children: bool
    """ Children expanded in the user interface (default False)"""

    show_expanded_items: bool
    """ Expanded in the user interface (default False)"""

    space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ Optional space type keymap is associated with (default 'EMPTY', readonly)"""

    def active(self) -> typing_extensions.Self:
        """active

        :return: Key Map, Active key map
        """

    def restore_to_default(self) -> None:
        """restore_to_default"""

    def restore_item_to_default(self, item: KeyMapItem | None) -> None:
        """restore_item_to_default

        :param item: Item, (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyMapItem(bpy_struct):
    """Item in a Key Map"""

    active: bool | None
    """ Activate or deactivate item (default False)"""

    alt: int
    """ Alt key pressed, -1 for any state (in [-1, 1], default 0)"""

    alt_ui: bool
    """ Alt key pressed (default False)"""

    any: bool
    """ Any modifier keys pressed (default False)"""

    ctrl: int
    """ Control key pressed, -1 for any state (in [-1, 1], default 0)"""

    ctrl_ui: bool
    """ Control key pressed (default False)"""

    direction: Literal[bpy.stub_internal.rna_enums.EventDirectionItems]
    """ The direction (only applies to drag events) (default 'ANY')"""

    hyper: int
    """ Hyper key pressed, -1 for any state (in [-1, 1], default 0)"""

    hyper_ui: bool
    """ Hyper key pressed. An additional modifier which can be configured on Linux, typically replacing CapsLock (default False)"""

    id: int
    """ ID of the item (in [-32768, 32767], default 0, readonly)"""

    idname: str
    """ Identifier of operator to call on input event (default "", never None)"""

    is_user_defined: bool
    """ Is this keymap item user defined (does not just replace a builtin item) (default False, readonly)"""

    is_user_modified: bool
    """ Is this keymap item modified by the user (default False, readonly)"""

    key_modifier: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
    """ Regular key pressed as a modifier (default 'NONE')"""

    map_type: typing.Literal["KEYBOARD", "MOUSE", "NDOF", "TEXTINPUT", "TIMER"]
    """ Type of event mapping (default 'KEYBOARD')"""

    name: str
    """ Name of operator (translated) to call on input event (default "", readonly, never None)"""

    oskey: int
    """ Operating system key pressed, -1 for any state (in [-1, 1], default 0)"""

    oskey_ui: bool
    """ Operating system key pressed (default False)"""

    properties: OperatorProperties | None
    """ Properties to set when the operator is called (readonly)"""

    propvalue: Literal[bpy.stub_internal.rna_enums.KeymapPropvalueItems]
    """ The value this event translates to in a modal keymap (default 'NONE')"""

    repeat: bool
    """ Active on key-repeat events (when a key is held) (default False)"""

    shift: int
    """ Shift key pressed, -1 for any state (in [-1, 1], default 0)"""

    shift_ui: bool
    """ Shift key pressed (default False)"""

    show_expanded: bool
    """ Show key map event and property details in the user interface (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.EventTypeItems]
    """ Type of event (default 'NONE')"""

    value: Literal[bpy.stub_internal.rna_enums.EventValueItems]
    """ (default 'NOTHING')"""

    def compare(self, item: typing_extensions.Self | None) -> bool:
        """compare

        :param item: Item
        :return: Comparison result
        """

    def to_string(self, *, compact: bool | None = False) -> str:
        """to_string

        :param compact: Compact, (optional)
        :return: result, (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Keyframe(bpy_struct):
    """Bézier curve point with two handles defining a Keyframe on an F-Curve"""

    amplitude: float
    """ Amount to boost elastic bounces for 'elastic' easing (in [0, inf], default 0.0)"""

    back: float
    """ Amount of overshoot for 'back' easing (in [-inf, inf], default 0.0)"""

    co: mathutils.Vector
    """ Coordinates of the control point (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    co_ui: mathutils.Vector
    """ Coordinates of the control point. Note: Changing this value also updates the handles similar to using the graph editor transform operator (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    easing: Literal[bpy.stub_internal.rna_enums.BeztripleInterpolationEasingItems]
    """ Which ends of the segment between this and the next keyframe easing interpolation is applied to (default 'AUTO')"""

    handle_left: mathutils.Vector
    """ Coordinates of the left handle (before the control point) (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    handle_left_type: Literal[bpy.stub_internal.rna_enums.KeyframeHandleTypeItems]
    """ Handle types (default 'FREE')"""

    handle_right: mathutils.Vector
    """ Coordinates of the right handle (after the control point) (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    handle_right_type: Literal[bpy.stub_internal.rna_enums.KeyframeHandleTypeItems]
    """ Handle types (default 'FREE')"""

    interpolation: Literal[bpy.stub_internal.rna_enums.BeztripleInterpolationModeItems]
    """ Interpolation method to use for segment of the F-Curve from this Keyframe until the next Keyframe (default 'CONSTANT')"""

    period: float
    """ Time between bounces for elastic easing (in [-inf, inf], default 0.0)"""

    select_control_point: bool
    """ Control point selection status (default False)"""

    select_left_handle: bool
    """ Left handle selection status (default False)"""

    select_right_handle: bool
    """ Right handle selection status (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.BeztripleKeyframeTypeItems]
    """ Type of keyframe (for visual purposes only) (default 'KEYFRAME')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSet(bpy_struct):
    """Settings that should be keyframed together"""

    bl_description: str
    """ A short description of the keying set (default "", never None)"""

    bl_idname: str
    """ If this is set, the Keying Set gets a custom ID, otherwise it takes the name of the class used to define the Keying Set (for example, if the class name is "BUILTIN_KSI_location", and bl_idname is not set by the script, then bl_idname = "BUILTIN_KSI_location") (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    is_path_absolute: bool
    """ Keying Set defines specific paths/settings to be keyframed (i.e. is not reliant on context info) (default False, readonly)"""

    paths: typing.Any
    """ Keying Set Paths to define settings that get keyframed together (default None, readonly)"""

    type_info: KeyingSetInfo | None
    """ Callback function defines for built-in Keying Sets (readonly)"""

    use_insertkey_needed: bool
    """ Only insert keyframes where they're needed in the relevant F-Curves (default False)"""

    use_insertkey_override_needed: bool
    """ Override default setting to only insert keyframes where they're needed in the relevant F-Curves (default False)"""

    use_insertkey_override_visual: bool
    """ Override default setting to insert keyframes based on 'visual transforms' (default False)"""

    use_insertkey_visual: bool
    """ Insert keyframes based on 'visual transforms' (default False)"""

    def refresh(self) -> None:
        """Refresh Keying Set to ensure that it is valid for the current context (call before each use of one)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSetInfo(bpy_struct):
    """Callback function defines for builtin Keying Sets"""

    bl_description: str
    """ A short description of the keying set (default "", never None)"""

    bl_idname: str
    """ If this is set, the Keying Set gets a custom ID, otherwise it takes the name of the class used to define the Keying Set (for example, if the class name is "BUILTIN_KSI_location", and bl_idname is not set by the script, then bl_idname = "BUILTIN_KSI_location") (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    bl_options: set[Literal[bpy.stub_internal.rna_enums.KeyingFlagItems]]
    """ Keying Set options to use when inserting keyframes (default set())"""

    def poll(self, context: Context) -> bool:
        """Test if Keying Set can be used or not

        :param context:
        :return:
        """

    def iterator(self, context: Context, ks: KeyingSet | None) -> None:
        """Call generate() on the structs which have properties to be keyframed

        :param context:
        :param ks:
        """

    def generate(
        self, context: Context, ks: KeyingSet | None, data: typing.Any | None
    ) -> None:
        """Add Paths to the Keying Set to keyframe the properties of the given data

        :param context:
        :param ks:
        :param data: (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KeyingSetPath(bpy_struct):
    """Path to a setting for use in a Keying Set"""

    array_index: int
    """ Index to the specific setting if applicable (in [-inf, inf], default 0)"""

    data_path: str
    """ Path to property setting (default "", never None)"""

    group: str
    """ Name of Action Group to assign setting(s) for this path to (default "", never None)"""

    group_method: Literal[bpy.stub_internal.rna_enums.KeyingsetPathGroupingItems]
    """ Method used to define which Group-name to use (default 'NAMED')"""

    id: ID | None
    """ ID-Block that keyframes for Keying Set should be added to (for Absolute Keying Sets only)"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ Type of ID-block that can be used (default 'OBJECT')"""

    use_entire_array: bool
    """ When an 'array/vector' type is chosen (Location, Rotation, Color, etc.), entire array is to be used (default False)"""

    use_insertkey_needed: bool
    """ Only insert keyframes where they're needed in the relevant F-Curves (default False)"""

    use_insertkey_override_needed: bool
    """ Override default setting to only insert keyframes where they're needed in the relevant F-Curves (default False)"""

    use_insertkey_override_visual: bool
    """ Override default setting to insert keyframes based on 'visual transforms' (default False)"""

    use_insertkey_visual: bool
    """ Insert keyframes based on 'visual transforms' (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class KinematicConstraint(Constraint, bpy_struct):
    """Inverse Kinematics"""

    chain_count: int
    """ How many bones are included in the IK effect - 0 uses all bones (in [0, 255], default 0)"""

    distance: float
    """ Radius of limiting sphere (in [0, 100], default 0.0)"""

    ik_type: typing.Literal["COPY_POSE", "DISTANCE"]
    """ (default 'COPY_POSE')"""

    iterations: int
    """ Maximum number of solving iterations (in [0, 10000], default 0)"""

    limit_mode: typing.Literal[
        "LIMITDIST_INSIDE", "LIMITDIST_OUTSIDE", "LIMITDIST_ONSURFACE"
    ]
    """ Distances in relation to sphere of influence to allow (default 'LIMITDIST_INSIDE')"""

    lock_location_x: bool
    """ Constraint position along X axis (default True)"""

    lock_location_y: bool
    """ Constraint position along Y axis (default True)"""

    lock_location_z: bool
    """ Constraint position along Z axis (default True)"""

    lock_rotation_x: bool
    """ Constraint rotation along X axis (default True)"""

    lock_rotation_y: bool
    """ Constraint rotation along Y axis (default True)"""

    lock_rotation_z: bool
    """ Constraint rotation along Z axis (default True)"""

    orient_weight: float
    """ For Tree-IK: Weight of orientation control for this target (in [0.01, 1], default 0.0)"""

    pole_angle: float
    """ Pole rotation offset (in [-3.14159, 3.14159], default 0.0)"""

    pole_subtarget: str
    """ (default "", never None)"""

    pole_target: Object | None
    """ Object for pole rotation"""

    reference_axis: typing.Literal["BONE", "TARGET"]
    """ Constraint axis Lock options relative to Bone or Target reference (default 'BONE')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_location: bool
    """ Chain follows position of target (default False)"""

    use_rotation: bool
    """ Chain follows rotation of target (default False)"""

    use_stretch: bool
    """ Enable IK Stretching (default False)"""

    use_tail: bool
    """ Include bone's tail as last element in chain (default False)"""

    weight: float
    """ For Tree-IK: Weight of position control for this target (in [0.01, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LaplacianDeformModifier(Modifier, bpy_struct):
    """Mesh deform modifier"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    is_bind: bool
    """ Whether geometry has been bound to anchors (default False, readonly)"""

    iterations: int
    """ (in [0, inf], default 1)"""

    vertex_group: str
    """ Name of Vertex Group which determines Anchors (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LaplacianSmoothModifier(Modifier, bpy_struct):
    """Smoothing effect modifier"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    iterations: int
    """ (in [0, 32767], default 1)"""

    lambda_border: float
    """ Lambda factor in border (in [-inf, inf], default 0.01)"""

    lambda_factor: float
    """ Smooth effect factor (in [-inf, inf], default 0.01)"""

    use_normalized: bool
    """ Improve and stabilize the enhanced shape (default True)"""

    use_volume_preserve: bool
    """ Apply volume preservation after smooth (default True)"""

    use_x: bool
    """ Smooth object along X axis (default True)"""

    use_y: bool
    """ Smooth object along Y axis (default True)"""

    use_z: bool
    """ Smooth object along Z axis (default True)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Lattice(ID, bpy_struct):
    """Lattice data-block defining a grid for deforming other objects"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    interpolation_type_u: typing.Literal[
        "KEY_LINEAR", "KEY_CARDINAL", "KEY_CATMULL_ROM", "KEY_BSPLINE"
    ]
    """ (default 'KEY_BSPLINE')"""

    interpolation_type_v: typing.Literal[
        "KEY_LINEAR", "KEY_CARDINAL", "KEY_CATMULL_ROM", "KEY_BSPLINE"
    ]
    """ (default 'KEY_BSPLINE')"""

    interpolation_type_w: typing.Literal[
        "KEY_LINEAR", "KEY_CARDINAL", "KEY_CATMULL_ROM", "KEY_BSPLINE"
    ]
    """ (default 'KEY_BSPLINE')"""

    is_editmode: bool
    """ True when used in editmode (default False, readonly)"""

    points: typing.Any
    """ Points of the lattice (default None, readonly)"""

    points_u: int
    """ Points in U direction (cannot be changed when there are shape keys) (in [1, 64], default 0)"""

    points_v: int
    """ Points in V direction (cannot be changed when there are shape keys) (in [1, 64], default 0)"""

    points_w: int
    """ Points in W direction (cannot be changed when there are shape keys) (in [1, 64], default 0)"""

    shape_keys: Key | None
    """ (readonly)"""

    use_outside: bool
    """ Only display and take into account the outer vertices (default False)"""

    vertex_group: str
    """ Vertex group to apply the influence of the lattice (default "", never None)"""

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        shape_keys: bool | None = False,
    ) -> None:
        """Transform lattice by a matrix

        :param matrix: Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param shape_keys: Transform Shape Keys (optional)
        """

    def update_gpu_tag(self) -> None:
        """update_gpu_tag"""

    def unit_test_compare(
        self,
        *,
        lattice: typing_extensions.Self | None = None,
        threshold: float | None = 7.1526e-06,
    ) -> str:
        """unit_test_compare

        :param lattice: Lattice to compare to (optional)
        :param threshold: Threshold, Comparison tolerance threshold (in [0, inf], optional)
        :return: Return value, String description of result of comparison (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LatticeModifier(Modifier, bpy_struct):
    """Lattice deformation modifier"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object: Object | None
    """ Lattice object to deform with"""

    strength: float
    """ Strength of modifier effect (in [-inf, inf], default 1.0)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LatticePoint(bpy_struct):
    """Point in the lattice grid"""

    co: mathutils.Vector
    """ Original undeformed location used to calculate the strength of the deform effect (edit/animate the Deformed Location instead) (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    co_deform: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    groups: typing.Any
    """ Weights for the vertex groups this point is member of (default None, readonly)"""

    select: bool
    """ Selection status (default False)"""

    weight_softbody: float
    """ Softbody goal weight (in [0.01, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LayerCollection(bpy_struct):
    """Layer collection"""

    children: typing.Any
    """ Layer collection children (default None, readonly)"""

    collection: Collection | None
    """ Collection this layer collection is wrapping (readonly, never None)"""

    exclude: bool
    """ Exclude from view layer (default False)"""

    hide_viewport: bool
    """ Temporarily hide in viewport (default False)"""

    holdout: bool
    """ Mask out objects in collection from view layer (default False)"""

    indirect_only: bool
    """ Objects in collection only contribute indirectly (through shadows and reflections) in the view layer (default False)"""

    is_visible: bool
    """ Whether this collection is visible for the view layer, take into account the collection parent (default False, readonly)"""

    name: str
    """ Name of this layer collection (same as its collection one) (default "", readonly, never None)"""

    def visible_get(self) -> bool:
        """Whether this collection is visible, take into account the collection parent and the viewport

        :return:
        """

    def has_objects(self) -> bool:
        """

        :return:
        """

    def has_selected_objects(self, view_layer: ViewLayer | None) -> bool:
        """

        :param view_layer: View layer the layer collection belongs to
        :return:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LayoutPanelState(bpy_struct):
    is_open: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Library(ID, bpy_struct):
    """External .blend file from which data is linked"""

    archive_libraries: typing.Any
    """ Archive libraries of packed IDs, generated (and owned) by this source library (default None, readonly)"""

    archive_parent_library: typing_extensions.Self | None
    """ Source library from which this archive of packed IDs was generated (readonly)"""

    filepath: str
    """ Path to the library .blend file (default "", never None, blend relative // prefix supported)"""

    is_archive: bool
    """ This library is an 'archive' storage for packed linked IDs originally linked from its 'archive parent' library. (default False, readonly)"""

    is_editable: bool
    """ Data-blocks in this library are editable despite being linked. Used by brush assets and their dependencies. (default False, readonly)"""

    needs_liboverride_resync: bool
    """ True if this library contains library overrides that are linked in current blendfile, and that had to be recursively resynced on load (it is recommended to open and re-save that library blendfile then) (default False)"""

    packed_file: PackedFile | None
    """ (readonly)"""

    parent: Library | None
    """ (readonly)"""

    version: typing.Any
    """ Version of Blender the library .blend was saved with (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    users_id: tuple[ID, ...]
    """ ID data-blocks that use this library(readonly)"""

    def reload(self) -> None:
        """Reload this library and all its linked data-blocks"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LibraryWeakReference(bpy_struct):
    """Read-only external reference to a linked data-block and its library file"""

    filepath: str
    """ Path to the library .blend file (default "", never None, blend relative // prefix supported)"""

    id_name: str
    """ Full ID name in the library .blend file (including the two leading 'id type' chars) (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Light(ID, bpy_struct):
    """Light data-block for lighting a scene"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    color: mathutils.Color
    """ Light color (array of 3 items, in [0, inf], default (1.0, 1.0, 1.0))"""

    cutoff_distance: float
    """ Distance at which the light influence will be set to 0 (in [0, inf], default 40.0)"""

    cycles: typing.Any
    """ Cycles light settings (readonly)"""

    diffuse_factor: float
    """ Diffuse reflection multiplier (in [0, inf], default 1.0)"""

    exposure: float
    """ Scales the power of the light exponentially, multiplying the intensity by 2^exposure (in [-32, 32], default 0.0)"""

    node_tree: ShaderNodeTree | None
    """ Node tree for node based lights"""

    normalize: bool
    """ Normalize intensity by light area, for consistent total light output regardless of size and shape (default True)"""

    specular_factor: float
    """ Specular reflection multiplier (in [0, inf], default 1.0)"""

    temperature: float
    """ Light color temperature in Kelvin (in [800, 20000], default 6500.0)"""

    temperature_color: mathutils.Color
    """ Color from Temperature (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0), readonly)"""

    transmission_factor: float
    """ Transmission light multiplier (in [0, inf], default 1.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LightTypeItems]
    """ Type of light (default 'POINT')"""

    use_custom_distance: bool
    """ Use custom attenuation distance instead of global light threshold (default False)"""

    use_nodes: bool
    """ Use shader nodes to render the light (default False)Unused but kept for compatibility reasons. Setting the property has no effect, and getting it always returns True.5.10 removal planned in version 6.0"""

    use_shadow: bool
    """ (default True)"""

    use_temperature: bool
    """ Use blackbody temperature to define a natural light color (default False)"""

    volume_factor: float
    """ Volume light multiplier (in [0, inf], default 1.0)"""

    def area(
        self,
        *,
        matrix_world: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None = (
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
        ),
    ) -> float:
        """Compute light area based on type and shape. The normalize option divides light intensity by this area

        :param matrix_world: Object to world space transformation matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], optional)
        :return: area, (in [-inf, inf])
        """

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this light. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LightProbe(ID, bpy_struct):
    """Light Probe data-block for lighting capture objects"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    clip_start: float
    """ Probe clip start, below which objects will not appear in reflections (in [1e-06, inf], default 0.8)"""

    data_display_size: float
    """ Viewport display size of the sampled data (in [0, inf], default 0.1)"""

    influence_distance: float
    """ Influence distance of the probe (in [0, inf], default 2.5)"""

    invert_visibility_collection: bool
    """ Invert visibility collection (Deprecated) (default False)"""

    show_clip: bool
    """ Show the clipping distances in the 3D view (default False)"""

    show_data: bool
    """ Deprecated, use use_data_display instead (default False)"""

    show_influence: bool
    """ Show the influence volume in the 3D view (default True)"""

    type: typing.Literal["SPHERE", "PLANE", "VOLUME"]
    """ Type of light probe (default 'SPHERE', readonly)"""

    use_data_display: bool
    """ Display sampled data in the viewport to debug captured light (default False)"""

    visibility_bleed_bias: float
    """ Bias for reducing light-bleed on variance shadow maps (Deprecated) (in [0, 1], default 0.0)"""

    visibility_blur: float
    """ Filter size of the visibility blur (Deprecated) (in [0, 1], default 0.2)"""

    visibility_buffer_bias: float
    """ Bias for reducing self shadowing (Deprecated) (in [0.001, 9999], default 1.0)"""

    visibility_collection: Collection | None
    """ Restrict objects visible for this probe (Deprecated)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LightProbePlane(LightProbe, ID, bpy_struct):
    """Light probe that captures incoming light from a single direction on a plane"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LightProbeSphere(LightProbe, ID, bpy_struct):
    """Light probe that captures precise lighting from all directions at a single point in space"""

    clip_end: float
    """ Probe clip end, beyond which objects will not appear in reflections (in [1e-06, inf], default 20.0)"""

    falloff: float
    """ Control how fast the probe influence decreases (in [0, 1], default 0.2)"""

    influence_type: typing.Literal["ELIPSOID", "BOX"]
    """ Type of influence volume (default 'ELIPSOID')"""

    parallax_distance: float
    """ Lowest corner of the parallax bounding box (in [0, inf], default 2.5)"""

    parallax_type: typing.Literal["ELIPSOID", "BOX"]
    """ Type of parallax volume (default 'ELIPSOID')"""

    show_parallax: bool
    """ Show the parallax correction volume in the 3D view (default False)"""

    use_custom_parallax: bool
    """ Enable custom settings for the parallax correction volume (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LightProbeVolume(LightProbe, ID, bpy_struct):
    """Light probe that captures low frequency lighting inside a volume"""

    bake_samples: int
    """ Number of ray directions to evaluate when baking (in [1, inf], default 2048)"""

    capture_distance: float
    """ Distance around the probe volume that will be considered during the bake (in [1e-06, inf], default 20.0)"""

    capture_emission: bool
    """ Bake emissive surfaces for more accurate lighting (default True)"""

    capture_indirect: bool
    """ Bake light bounces from light sources for more accurate lighting (default True)"""

    capture_world: bool
    """ Bake incoming light from the world instead of just the visibility for more accurate lighting, but lose correct blending to surrounding irradiance volumes (default False)"""

    clamp_direct: float
    """ Clamp the direct lighting intensity to reduce noise (0 to disable) (in [0, inf], default 0.0)"""

    clamp_indirect: float
    """ Clamp the indirect lighting intensity to reduce noise (0 to disable) (in [0, inf], default 10.0)"""

    dilation_radius: float
    """ Radius in grid sample to search valid grid samples to copy into invalid grid samples (in [1, 5], default 1.0)"""

    dilation_threshold: float
    """ Ratio of front-facing surface hits under which a grid sample will reuse neighbors grid sample lighting (in [0, 1], default 0.5)"""

    escape_bias: float
    """ Distance to search for valid capture positions to prevent lighting artifacts (in [0, 1], default 0.1)"""

    facing_bias: float
    """ Smoother irradiance interpolation but introduce light bleeding (in [0, inf], default 0.5)"""

    intensity: float
    """ Modify the intensity of the lighting captured by this probe (in [0, inf], default 1.0)"""

    normal_bias: float
    """ Offset sampling of the irradiance grid in the surface normal direction to reduce light bleeding (in [0, inf], default 0.3)"""

    resolution_x: int
    """ Number of samples along the x axis of the volume (in [1, 256], default 4)"""

    resolution_y: int
    """ Number of samples along the y axis of the volume (in [1, 256], default 4)"""

    resolution_z: int
    """ Number of samples along the z axis of the volume (in [1, 256], default 4)"""

    surface_bias: float
    """ Moves capture points away from surfaces to prevent artifacts (in [0, 1], default 0.05)"""

    surfel_density: int
    """ Number of surfels to spawn in one local unit distance (higher values improve quality) (in [1, inf], default 20)"""

    validity_threshold: float
    """ Ratio of front-facing surface hits under which a grid sample will not be considered for lighting (in [0, 1], default 0.4)"""

    view_bias: float
    """ Offset sampling of the irradiance grid in the viewing direction to reduce light bleeding (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Lightgroup(bpy_struct):
    name: str
    """ Name of the Lightgroup (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LimitDistanceConstraint(Constraint, bpy_struct):
    """Limit the distance from target object"""

    distance: float
    """ Radius of limiting sphere (in [-inf, inf], default 0.0)"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    limit_mode: typing.Literal[
        "LIMITDIST_INSIDE", "LIMITDIST_OUTSIDE", "LIMITDIST_ONSURFACE"
    ]
    """ Distances in relation to sphere of influence to allow (default 'LIMITDIST_INSIDE')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    use_transform_limit: bool
    """ Transforms are affected by this constraint as well (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LimitLocationConstraint(Constraint, bpy_struct):
    """Limit the location of the constrained object"""

    max_x: float
    """ Highest X value to allow (in [-inf, inf], default 0.0)"""

    max_y: float
    """ Highest Y value to allow (in [-inf, inf], default 0.0)"""

    max_z: float
    """ Highest Z value to allow (in [-inf, inf], default 0.0)"""

    min_x: float
    """ Lowest X value to allow (in [-inf, inf], default 0.0)"""

    min_y: float
    """ Lowest Y value to allow (in [-inf, inf], default 0.0)"""

    min_z: float
    """ Lowest Z value to allow (in [-inf, inf], default 0.0)"""

    use_max_x: bool
    """ Use the maximum X value (default False)"""

    use_max_y: bool
    """ Use the maximum Y value (default False)"""

    use_max_z: bool
    """ Use the maximum Z value (default False)"""

    use_min_x: bool
    """ Use the minimum X value (default False)"""

    use_min_y: bool
    """ Use the minimum Y value (default False)"""

    use_min_z: bool
    """ Use the minimum Z value (default False)"""

    use_transform_limit: bool
    """ Transform tools are affected by this constraint as well (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LimitRotationConstraint(Constraint, bpy_struct):
    """Limit the rotation of the constrained object"""

    euler_order: typing.Literal["AUTO", "XYZ", "XZY", "YXZ", "YZX", "ZXY", "ZYX"]
    """ Explicitly specify the euler rotation order (default 'AUTO')"""

    max_x: float
    """ Upper X angle bound (in [-1000, 1000], default 0.0)"""

    max_y: float
    """ Upper Y angle bound (in [-1000, 1000], default 0.0)"""

    max_z: float
    """ Upper Z angle bound (in [-1000, 1000], default 0.0)"""

    min_x: float
    """ Lower X angle bound (in [-1000, 1000], default 0.0)"""

    min_y: float
    """ Lower Y angle bound (in [-1000, 1000], default 0.0)"""

    min_z: float
    """ Lower Z angle bound (in [-1000, 1000], default 0.0)"""

    use_legacy_behavior: bool
    """ Use the old semi-broken behavior that does not understand that rotations loop around (default False)"""

    use_limit_x: bool
    """ Use the minimum X value (default False)"""

    use_limit_y: bool
    """ Use the minimum Y value (default False)"""

    use_limit_z: bool
    """ Use the minimum Z value (default False)"""

    use_transform_limit: bool
    """ Transform tools are affected by this constraint as well (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LimitScaleConstraint(Constraint, bpy_struct):
    """Limit the scaling of the constrained object"""

    max_x: float
    """ Highest X value to allow (in [-1000, 1000], default 0.0)"""

    max_y: float
    """ Highest Y value to allow (in [-1000, 1000], default 0.0)"""

    max_z: float
    """ Highest Z value to allow (in [-1000, 1000], default 0.0)"""

    min_x: float
    """ Lowest X value to allow (in [-1000, 1000], default 0.0)"""

    min_y: float
    """ Lowest Y value to allow (in [-1000, 1000], default 0.0)"""

    min_z: float
    """ Lowest Z value to allow (in [-1000, 1000], default 0.0)"""

    use_max_x: bool
    """ Use the maximum X value (default False)"""

    use_max_y: bool
    """ Use the maximum Y value (default False)"""

    use_max_z: bool
    """ Use the maximum Z value (default False)"""

    use_min_x: bool
    """ Use the minimum X value (default False)"""

    use_min_y: bool
    """ Use the minimum Y value (default False)"""

    use_min_z: bool
    """ Use the minimum Z value (default False)"""

    use_transform_limit: bool
    """ Transform tools are affected by this constraint as well (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier(LineStyleModifier, bpy_struct):
    """Base type to define alpha transparency modifiers"""

    name: str
    """ Name of the modifier (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_AlongStroke(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Change alpha transparency along stroke"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_CreaseAngle(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Alpha transparency based on the angle between two adjacent faces"""

    angle_max: float
    """ Maximum angle to modify thickness (in [-inf, inf], default 0.0)"""

    angle_min: float
    """ Minimum angle to modify thickness (in [-inf, inf], default 0.0)"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_Curvature_3D(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Alpha transparency based on the radial curvature of 3D mesh surfaces"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curvature_max: float
    """ Maximum Curvature (in [0, 10000], default 0.0)"""

    curvature_min: float
    """ Minimum Curvature (in [0, 10000], default 0.0)"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_DistanceFromCamera(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Change alpha transparency based on the distance from the camera"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_DistanceFromObject(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Change alpha transparency based on the distance from an object"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    target: Object | None
    """ Target object from which the distance is measured"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_Material(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Change alpha transparency based on a material attribute"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    material_attribute: typing.Literal[
        "LINE",
        "LINE_R",
        "LINE_G",
        "LINE_B",
        "LINE_A",
        "DIFF",
        "DIFF_R",
        "DIFF_G",
        "DIFF_B",
        "SPEC",
        "SPEC_R",
        "SPEC_G",
        "SPEC_B",
        "SPEC_HARD",
        "ALPHA",
    ]
    """ Specify which material attribute is used (default 'LINE')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_Noise(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Alpha transparency based on random noise"""

    amplitude: float
    """ Amplitude of the noise (in [-inf, inf], default 0.0)"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    period: float
    """ Period of the noise (in [-inf, inf], default 0.0)"""

    seed: int
    """ Seed for the noise generation (in [1, 32767], default 0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleAlphaModifier_Tangent(
    LineStyleAlphaModifier, LineStyleModifier, bpy_struct
):
    """Alpha transparency based on the direction of the stroke"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleAlphaModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier(LineStyleModifier, bpy_struct):
    """Base type to define line color modifiers"""

    name: str
    """ Name of the modifier (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_AlongStroke(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color along stroke"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_CreaseAngle(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on the underlying crease angle"""

    angle_max: float
    """ Maximum angle to modify thickness (in [-inf, inf], default 0.0)"""

    angle_min: float
    """ Minimum angle to modify thickness (in [-inf, inf], default 0.0)"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_Curvature_3D(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on the radial curvature of 3D mesh surfaces"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    curvature_max: float
    """ Maximum Curvature (in [-inf, inf], default 0.0)"""

    curvature_min: float
    """ Minimum Curvature (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_DistanceFromCamera(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on the distance from the camera"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_DistanceFromObject(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on the distance from an object"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    target: Object | None
    """ Target object from which the distance is measured"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_Material(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on a material attribute"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    material_attribute: typing.Literal[
        "LINE",
        "LINE_R",
        "LINE_G",
        "LINE_B",
        "LINE_A",
        "DIFF",
        "DIFF_R",
        "DIFF_G",
        "DIFF_B",
        "SPEC",
        "SPEC_R",
        "SPEC_G",
        "SPEC_B",
        "SPEC_HARD",
        "ALPHA",
    ]
    """ Specify which material attribute is used (default 'LINE')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    use_ramp: bool
    """ Use color ramp to map the BW average into an RGB color (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_Noise(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on random noise"""

    amplitude: float
    """ Amplitude of the noise (in [-inf, inf], default 0.0)"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    period: float
    """ Period of the noise (in [-inf, inf], default 0.0)"""

    seed: int
    """ Seed for the noise generation (in [1, 32767], default 0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleColorModifier_Tangent(
    LineStyleColorModifier, LineStyleModifier, bpy_struct
):
    """Change line color based on the direction of a stroke"""

    blend: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    color_ramp: ColorRamp | None
    """ Color ramp used to change line color (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleColorModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier(LineStyleModifier, bpy_struct):
    """Base type to define stroke geometry modifiers"""

    name: str
    """ Name of the modifier (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_2DOffset(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Add two-dimensional offsets to stroke backbone geometry"""

    end: float
    """ Displacement that is applied from the end of the stroke (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    start: float
    """ Displacement that is applied from the beginning of the stroke (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    x: float
    """ Displacement that is applied to the X coordinates of stroke vertices (in [-inf, inf], default 0.0)"""

    y: float
    """ Displacement that is applied to the Y coordinates of stroke vertices (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_2DTransform(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Apply two-dimensional scaling and rotation to stroke backbone geometry"""

    angle: float
    """ Rotation angle (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    pivot: typing.Literal["CENTER", "START", "END", "PARAM", "ABSOLUTE"]
    """ Pivot of scaling and rotation operations (default 'CENTER')"""

    pivot_u: float
    """ Pivot in terms of the stroke point parameter u (0 <= u <= 1) (in [0, 1], default 0.0)"""

    pivot_x: float
    """ 2D X coordinate of the absolute pivot (in [-inf, inf], default 0.0)"""

    pivot_y: float
    """ 2D Y coordinate of the absolute pivot (in [-inf, inf], default 0.0)"""

    scale_x: float
    """ Scaling factor that is applied along the X axis (in [-inf, inf], default 0.0)"""

    scale_y: float
    """ Scaling factor that is applied along the Y axis (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_BackboneStretcher(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Stretch the beginning and the end of stroke backbone"""

    backbone_length: float
    """ Amount of backbone stretching (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_BezierCurve(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Replace stroke backbone geometry by a Bézier curve approximation of the original backbone geometry"""

    error: float
    """ Maximum distance allowed between the new Bézier curve and the original backbone geometry (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_Blueprint(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Produce a blueprint using circular, elliptic, and square contour strokes"""

    backbone_length: float
    """ Amount of backbone stretching (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    random_backbone: int
    """ Randomness of the backbone stretching (in [0, inf], default 0)"""

    random_center: int
    """ Randomness of the center (in [0, inf], default 0)"""

    random_radius: int
    """ Randomness of the radius (in [0, inf], default 0)"""

    rounds: int
    """ Number of rounds in contour strokes (in [1, 1000], default 0)"""

    shape: typing.Literal["CIRCLES", "ELLIPSES", "SQUARES"]
    """ Select the shape of blueprint contour strokes (default 'CIRCLES')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_GuidingLines(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Modify the stroke geometry so that it corresponds to its main direction line"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    offset: float
    """ Displacement that is applied to the main direction line along its normal (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_PerlinNoise1D(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Add one-dimensional Perlin noise to stroke backbone geometry"""

    amplitude: float
    """ Amplitude of the Perlin noise (in [-inf, inf], default 0.0)"""

    angle: float
    """ Displacement direction (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    frequency: float
    """ Frequency of the Perlin noise (in [-inf, inf], default 0.0)"""

    octaves: int
    """ Number of octaves (i.e., the amount of detail of the Perlin noise) (in [0, inf], default 0)"""

    seed: int
    """ Seed for random number generation (if negative, time is used as a seed instead) (in [-inf, inf], default 0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_PerlinNoise2D(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Add two-dimensional Perlin noise to stroke backbone geometry"""

    amplitude: float
    """ Amplitude of the Perlin noise (in [-inf, inf], default 0.0)"""

    angle: float
    """ Displacement direction (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    frequency: float
    """ Frequency of the Perlin noise (in [-inf, inf], default 0.0)"""

    octaves: int
    """ Number of octaves (i.e., the amount of detail of the Perlin noise) (in [0, inf], default 0)"""

    seed: int
    """ Seed for random number generation (if negative, time is used as a seed instead) (in [-inf, inf], default 0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_Polygonalization(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Modify the stroke geometry so that it looks more polygonal"""

    error: float
    """ Maximum distance between the original stroke and its polygonal approximation (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_Sampling(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Specify a new sampling value that determines the resolution of stroke polylines"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    sampling: float
    """ New sampling value to be used for subsequent modifiers (in [0, 10000], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_Simplification(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Simplify the stroke set"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    tolerance: float
    """ Distance below which segments will be merged (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_SinusDisplacement(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Add sinus displacement to stroke backbone geometry"""

    amplitude: float
    """ Amplitude of the sinus displacement (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    phase: float
    """ Phase of the sinus displacement (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    wavelength: float
    """ Wavelength of the sinus displacement (in [0.0001, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_SpatialNoise(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Add spatial noise to stroke backbone geometry"""

    amplitude: float
    """ Amplitude of the spatial noise (in [-inf, inf], default 0.0)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    octaves: int
    """ Number of octaves (i.e., the amount of detail of the spatial noise) (in [0, inf], default 0)"""

    scale: float
    """ Scale of the spatial noise (in [-inf, inf], default 0.0)"""

    smooth: bool
    """ If true, the spatial noise is smooth (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    use_pure_random: bool
    """ If true, the spatial noise does not show any coherence (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleGeometryModifier_TipRemover(
    LineStyleGeometryModifier, LineStyleModifier, bpy_struct
):
    """Remove a piece of stroke at the beginning and the end of stroke backbone"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    tip_length: float
    """ Length of tips to be removed (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleGeometryModifierTypeItems]
    """ Type of the modifier (default '2D_OFFSET', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleModifier(bpy_struct):
    """Base type to define modifiers"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleTextureSlot(TextureSlot, bpy_struct):
    """Texture slot for textures in a LineStyle data-block"""

    alpha_factor: float
    """ Amount texture affects alpha (in [-inf, inf], default 1.0)"""

    diffuse_color_factor: float
    """ Amount texture affects diffuse color (in [-inf, inf], default 1.0)"""

    mapping: typing.Literal["FLAT", "CUBE", "TUBE", "SPHERE"]
    """ (default 'FLAT')"""

    mapping_x: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'X')"""

    mapping_y: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'Y')"""

    mapping_z: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'Z')"""

    texture_coords: typing.Literal["WINDOW", "GLOBAL", "ALONG_STROKE", "ORCO"]
    """ Texture coordinates used to map the texture onto the background (default 'ALONG_STROKE')"""

    use_map_alpha: bool
    """ The texture affects the alpha value (default False)"""

    use_map_color_diffuse: bool
    """ The texture affects basic color of the stroke (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier(LineStyleModifier, bpy_struct):
    """Base type to define line thickness modifiers"""

    name: str
    """ Name of the modifier (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_AlongStroke(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Change line thickness along stroke"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    value_max: float
    """ Maximum output value of the mapping (in [-inf, inf], default 0.0)"""

    value_min: float
    """ Minimum output value of the mapping (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_Calligraphy(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Change line thickness so that stroke looks like made with a calligraphic pen"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    orientation: float
    """ Angle of the main direction (in [-inf, inf], default 0.0)"""

    thickness_max: float
    """ Maximum thickness in the main direction (in [0, 10000], default 0.0)"""

    thickness_min: float
    """ Minimum thickness in the direction perpendicular to the main direction (in [0, 10000], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_CreaseAngle(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Line thickness based on the angle between two adjacent faces"""

    angle_max: float
    """ Maximum angle to modify thickness (in [-inf, inf], default 0.0)"""

    angle_min: float
    """ Minimum angle to modify thickness (in [-inf, inf], default 0.0)"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    thickness_max: float
    """ Maximum thickness (in [0, 10000], default 0.0)"""

    thickness_min: float
    """ Minimum thickness (in [0, 10000], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_Curvature_3D(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Line thickness based on the radial curvature of 3D mesh surfaces"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curvature_max: float
    """ Maximum Curvature (in [0, 10000], default 0.0)"""

    curvature_min: float
    """ Minimum Curvature (in [0, 10000], default 0.0)"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    thickness_max: float
    """ Maximum thickness (in [0, 10000], default 0.0)"""

    thickness_min: float
    """ Minimum thickness (in [0, 10000], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_DistanceFromCamera(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Change line thickness based on the distance from the camera"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    value_max: float
    """ Maximum output value of the mapping (in [-inf, inf], default 0.0)"""

    value_min: float
    """ Minimum output value of the mapping (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_DistanceFromObject(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Change line thickness based on the distance from an object"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    range_max: float
    """ Upper bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    range_min: float
    """ Lower bound of the input range the mapping is applied (in [-inf, inf], default 0.0)"""

    target: Object | None
    """ Target object from which the distance is measured"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    value_max: float
    """ Maximum output value of the mapping (in [-inf, inf], default 0.0)"""

    value_min: float
    """ Minimum output value of the mapping (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_Material(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Change line thickness based on a material attribute"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    material_attribute: typing.Literal[
        "LINE",
        "LINE_R",
        "LINE_G",
        "LINE_B",
        "LINE_A",
        "DIFF",
        "DIFF_R",
        "DIFF_G",
        "DIFF_B",
        "SPEC",
        "SPEC_R",
        "SPEC_G",
        "SPEC_B",
        "SPEC_HARD",
        "ALPHA",
    ]
    """ Specify which material attribute is used (default 'LINE')"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    value_max: float
    """ Maximum output value of the mapping (in [-inf, inf], default 0.0)"""

    value_min: float
    """ Minimum output value of the mapping (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_Noise(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Line thickness based on random noise"""

    amplitude: float
    """ Amplitude of the noise (in [-inf, inf], default 0.0)"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    period: float
    """ Period of the noise (in [-inf, inf], default 0.0)"""

    seed: int
    """ Seed for the noise generation (in [1, 32767], default 0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    use_asymmetric: bool
    """ Allow thickness to be assigned asymmetrically (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LineStyleThicknessModifier_Tangent(
    LineStyleThicknessModifier, LineStyleModifier, bpy_struct
):
    """Thickness based on the direction of the stroke"""

    blend: typing.Literal[
        "MIX",
        "ADD",
        "SUBTRACT",
        "MULTIPLY",
        "DIVIDE",
        "DIFFERENCE",
        "MINIMUM",
        "MAXIMUM",
    ]
    """ Specify how the modifier value is blended into the base value (default 'MIX')"""

    curve: CurveMapping | None
    """ Curve used for the curve mapping (readonly)"""

    expanded: bool
    """ True if the modifier tab is expanded (default False)"""

    influence: float
    """ Influence factor by which the modifier changes the property (in [0, 1], default 0.0)"""

    invert: bool
    """ Invert the fade-out direction of the linear mapping (default False)"""

    mapping: typing.Literal["LINEAR", "CURVE"]
    """ Select the mapping type (default 'LINEAR')"""

    thickness_max: float
    """ Maximum thickness (in [0, 10000], default 0.0)"""

    thickness_min: float
    """ Minimum thickness (in [0, 10000], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.LinestyleThicknessModifierTypeItems]
    """ Type of the modifier (default 'ALONG_STROKE', readonly)"""

    use: bool
    """ Enable or disable this modifier during stroke rendering (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class LockedTrackConstraint(Constraint, bpy_struct):
    """Point toward the target along the track axis, while locking the other axis"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    lock_axis: typing.Literal["LOCK_X", "LOCK_Y", "LOCK_Z"]
    """ Axis that points upward (default 'LOCK_X')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    track_axis: typing.Literal[
        "TRACK_X",
        "TRACK_Y",
        "TRACK_Z",
        "TRACK_NEGATIVE_X",
        "TRACK_NEGATIVE_Y",
        "TRACK_NEGATIVE_Z",
    ]
    """ Axis that points to the target object (default 'TRACK_X')"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MASK_UL_layers(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MATERIAL_UL_matslots(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MESH_UL_attributes(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MESH_UL_color_attributes(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MESH_UL_color_attributes_selector(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MESH_UL_uvmaps(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MESH_UL_vgroups(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data_,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data_:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Macro(bpy_struct):
    """Storage of a macro operator being executed, or registered after execution"""

    bl_cursor_pending: Literal[bpy.stub_internal.rna_enums.WindowCursorItems]
    """ Cursor to use when waiting for the user to select a location to activate the operator (when bl_options has DEPENDS_ON_CURSOR set) (default 'DEFAULT')"""

    bl_description: str
    """ (default "", never None)"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    bl_options: set[Literal[bpy.stub_internal.rna_enums.OperatorTypeFlagItems]]
    """ Options for this operator type (default set())"""

    bl_translation_context: str
    """ (default "Operator", never None)"""

    bl_undo_group: str
    """ (default "", never None)"""

    has_reports: bool
    """ Operator has a set of reports (warnings and errors) from last execution (default False, readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    properties: OperatorProperties | None
    """ (readonly, never None)"""

    def report(
        self,
        type: set[Literal[bpy.stub_internal.rna_enums.WmReportItems]] | None,
        message: str | None,
    ) -> None:
        """report

        :param type: Type
        :param message: Report Message, (never None)
        """

    @classmethod
    def poll(cls, context: Context) -> bool:
        """Test if the operator can be called or not

        :param context: (never None)
        :return:
        """

    def draw(self, context: Context) -> None:
        """Draw function for the operator

        :param context: (never None)
        """

    @classmethod
    def define(cls, operator: str | None) -> OperatorMacro:
        """Append an operator to a registered macro class.

        :param operator: Identifier of the operator. This does not have to be defined when this function is called.
        :return: The operator macro for property access.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MagicTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    noise_depth: int
    """ Depth of the noise (in [0, 30], default 2)"""

    turbulence: float
    """ Turbulence of the noise (in [0.0001, inf], default 5.0)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaintainVolumeConstraint(Constraint, bpy_struct):
    """Maintain a constant volume along a single scaling axis"""

    free_axis: typing.Literal["SAMEVOL_X", "SAMEVOL_Y", "SAMEVOL_Z"]
    """ The free scaling axis of the object (default 'SAMEVOL_X')"""

    mode: typing.Literal["STRICT", "UNIFORM", "SINGLE_AXIS"]
    """ The way the constraint treats original non-free axis scaling (default 'STRICT')"""

    volume: float
    """ Volume of the bone at rest (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MarbleTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    marble_type: typing.Literal["SOFT", "SHARP", "SHARPER"]
    """ (default 'SOFT')"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_basis_2: typing.Literal["SIN", "SAW", "TRI"]
    """ (default 'SIN')"""

    noise_depth: int
    """ Depth of the cloud calculation (in [0, 30], default 2)"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    noise_type: typing.Literal["SOFT_NOISE", "HARD_NOISE"]
    """ (default 'SOFT_NOISE')"""

    turbulence: float
    """ Turbulence of the bandnoise and ringnoise types (in [0.0001, inf], default 5.0)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Mask(ID, bpy_struct):
    """Mask data-block defining mask for compositing"""

    active_layer_index: int | None
    """ Index of active layer in list of all mask's layers (in [-inf, inf], default 0)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    frame_end: int
    """ Final frame of the mask (used for sequencer) (in [0, 1048574], default 0)"""

    frame_start: int
    """ First frame of the mask (used for sequencer) (in [0, 1048574], default 0)"""

    layers: typing.Any
    """ Collection of layers which defines this mask (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskLayer(bpy_struct):
    """Single layer used for masking pixels"""

    alpha: float
    """ Render Opacity (in [-inf, inf], default 0.0)"""

    blend: typing.Literal[
        "MERGE_ADD",
        "MERGE_SUBTRACT",
        "ADD",
        "SUBTRACT",
        "LIGHTEN",
        "DARKEN",
        "MUL",
        "REPLACE",
        "DIFFERENCE",
    ]
    """ Method of blending mask layers (default 'ADD')"""

    falloff: Literal[bpy.stub_internal.rna_enums.ProportionalFalloffCurveOnlyItems]
    """ Falloff type of the feather (default 'SMOOTH')"""

    hide: bool
    """ Restrict visibility in the viewport (default False)"""

    hide_render: bool
    """ Restrict renderability (default False)"""

    hide_select: bool
    """ Restrict selection in the viewport (default False)"""

    invert: bool
    """ Invert the mask black/white (default False)"""

    name: str
    """ Unique name of layer (default "", never None)"""

    select: bool
    """ Layer is selected for editing in the Dope Sheet (default False)"""

    splines: typing.Any
    """ Collection of splines which defines this layer (default None, readonly)"""

    use_fill_holes: bool
    """ Calculate holes when filling overlapping curves (default True)"""

    use_fill_overlap: bool
    """ Calculate self intersections and overlap before filling (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskModifier(Modifier, bpy_struct):
    """Mask modifier to hide parts of the mesh"""

    armature: Object | None
    """ Armature to use as source of bones to mask"""

    invert_vertex_group: bool
    """ Use vertices that are not part of region defined (default False)"""

    mode: typing.Literal["VERTEX_GROUP", "ARMATURE"]
    """ (default 'VERTEX_GROUP')"""

    threshold: float
    """ Weights over this threshold remain (in [0, 1], default 0.0)"""

    use_smooth: bool
    """ Use vertex group weights to cut faces at the weight contour (default False)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskParent(bpy_struct):
    """Parenting settings for masking element"""

    id: ID | None
    """ ID-block to which masking element would be parented to or to its property"""

    id_type: typing.Literal["MOVIECLIP"]
    """ Type of ID-block that can be used (default 'MOVIECLIP')"""

    parent: str
    """ Name of parent object in specified data-block to which parenting happens (default "", never None)"""

    sub_parent: str
    """ Name of parent sub-object in specified data-block to which parenting happens (default "", never None)"""

    type: typing.Literal["POINT_TRACK", "PLANE_TRACK"]
    """ Parent Type (default 'POINT_TRACK')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskSpline(bpy_struct):
    """Single spline used for defining mask shape"""

    offset_mode: typing.Literal["EVEN", "SMOOTH"]
    """ The method used for calculating the feather offset (default 'EVEN')"""

    points: typing.Any
    """ Collection of points (default None, readonly)"""

    use_cyclic: bool
    """ Make this spline a closed loop (default False)"""

    use_fill: bool
    """ Make this spline filled (default True)"""

    use_self_intersection_check: bool
    """ Prevent feather from self-intersections (default False)"""

    weight_interpolation: typing.Literal["LINEAR", "EASE"]
    """ The type of weight interpolation for spline (default 'LINEAR')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskSplinePoint(bpy_struct):
    """Single point in spline used for defining mask"""

    co: mathutils.Vector
    """ Coordinates of the control point (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    feather_points: typing.Any
    """ Points defining feather (default None, readonly)"""

    handle_left: mathutils.Vector
    """ Coordinates of the first handle (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    handle_left_type: typing.Literal[
        "AUTO", "VECTOR", "ALIGNED", "ALIGNED_DOUBLESIDE", "FREE"
    ]
    """ Handle type (default 'FREE')"""

    handle_right: mathutils.Vector
    """ Coordinates of the second handle (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    handle_right_type: typing.Literal[
        "AUTO", "VECTOR", "ALIGNED", "ALIGNED_DOUBLESIDE", "FREE"
    ]
    """ Handle type (default 'FREE')"""

    handle_type: typing.Literal[
        "AUTO", "VECTOR", "ALIGNED", "ALIGNED_DOUBLESIDE", "FREE"
    ]
    """ Handle type (default 'FREE')"""

    parent: MaskParent | None
    """ (readonly)"""

    select: bool
    """ Selection status of the control point. (Deprecated: use Select Control Point instead) (default False)"""

    select_control_point: bool
    """ Selection status of the control point (default False)"""

    select_left_handle: bool
    """ Selection status of the left handle (default False)"""

    select_right_handle: bool
    """ Selection status of the right handle (default False)"""

    select_single_handle: bool
    """ Selection status of the Aligned Single handle (default False)"""

    weight: float
    """ Weight of the point (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskSplinePointUW(bpy_struct):
    """Single point in spline segment defining feather"""

    select: bool
    """ Selection status (default False)"""

    u: float
    """ U coordinate of point along spline segment (in [0, 1], default 0.0)"""

    weight: float
    """ Weight of feather point (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskStrip(Strip, bpy_struct):
    """Sequence strip to load a video from a mask"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    mask: Mask | None
    """ Mask that this strip uses"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaskStripModifier(StripModifier, bpy_struct):
    """Mask modifier for sequence strip"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Material(ID, bpy_struct):
    """Material data-block to define the appearance of geometric objects for rendering"""

    alpha_threshold: float
    """ A pixel is rendered only if its alpha value is above this threshold (in [0, 1], default 0.5)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    blend_method: typing.Literal["OPAQUE", "CLIP", "HASHED", "BLEND"]
    """ Blend Mode for Transparent Faces (Deprecated: use 'surface_render_method') (default 'OPAQUE')"""

    cycles: typing.Any
    """ Cycles material settings (readonly)"""

    diffuse_color: typing.Any
    """ Diffuse color of the material (array of 4 items, in [0, inf], default (0.8, 0.8, 0.8, 1.0))"""

    displacement_method: typing.Literal["BUMP", "DISPLACEMENT", "BOTH"]
    """ Method to use for the displacement (default 'BUMP')"""

    grease_pencil: MaterialGPencilStyle | None
    """ Grease Pencil color settings for material (readonly)"""

    is_grease_pencil: bool
    """ True if this material has Grease Pencil data (default False, readonly)"""

    line_color: typing.Any
    """ Line color used for Freestyle line rendering (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    line_priority: int
    """ The line color of a higher priority is used at material boundaries (in [0, 32767], default 0)"""

    lineart: MaterialLineArt | None
    """ Line Art settings for material (readonly)"""

    max_vertex_displacement: float
    """ The max distance a vertex can be displaced. Displacements over this threshold may cause visibility issues. (in [0, inf], default 0.0)"""

    metallic: float
    """ Amount of mirror reflection for raytrace (in [0, 1], default 0.0)"""

    node_tree: ShaderNodeTree | None
    """ Node tree for node based materials"""

    paint_active_slot: int
    """ Index of active texture paint slot (in [0, 32767], default 0)"""

    paint_clone_slot: int
    """ Index of clone texture paint slot (in [0, 32767], default 0)"""

    pass_index: int
    """ Index number for the "Material Index" render pass (in [0, 32767], default 0)"""

    preview_render_type: typing.Literal[
        "FLAT", "SPHERE", "CUBE", "HAIR", "SHADERBALL", "CLOTH", "FLUID"
    ]
    """ Type of preview render (default 'SPHERE')"""

    refraction_depth: float
    """ Approximate the thickness of the object to compute two refraction events (0 is disabled) (Deprecated) (in [0, inf], default 0.0)"""

    roughness: float
    """ Roughness of the material (in [0, 1], default 0.4)"""

    show_transparent_back: bool
    """ Render multiple transparent layers (may introduce transparency sorting problems) (Deprecated: use 'use_tranparency_overlap') (default True)"""

    specular_color: mathutils.Color
    """ Specular color of the material (array of 3 items, in [0, inf], default (1.0, 1.0, 1.0))"""

    specular_intensity: float
    """ How intense (bright) the specular reflection is (in [0, 1], default 0.5)"""

    surface_render_method: typing.Literal["DITHERED", "BLENDED"]
    """ Controls the blending and the compatibility with certain features (default 'DITHERED')"""

    texture_paint_images: typing.Any
    """ Texture images used for texture painting (default None, readonly)"""

    texture_paint_slots: typing.Any
    """ Texture slots defining the mapping and influence of textures (default None, readonly)"""

    thickness_mode: typing.Literal["SPHERE", "SLAB"]
    """ Approximation used to model the light interactions inside the object (default 'SPHERE')"""

    use_backface_culling: bool
    """ Use back face culling to hide the back side of faces (default False)"""

    use_backface_culling_lightprobe_volume: bool
    """ Consider material single sided for light probe volume capture. Additionally helps rejecting probes inside the object to avoid light leaks. (default True)"""

    use_backface_culling_shadow: bool
    """ Use back face culling when casting shadows (default False)"""

    use_nodes: bool
    """ Use shader nodes to render the material (default False)Unused but kept for compatibility reasons. Setting the property has no effect, and getting it always returns True.5.0 removal planned in version 6.0"""

    use_preview_world: bool
    """ Use the current world background to light the preview render (default False)"""

    use_raytrace_refraction: bool
    """ Use raytracing to determine transmitted color instead of using only light probes. This prevents the surface from contributing to the lighting of surfaces not using this setting. (default False)"""

    use_screen_refraction: bool
    """ Use raytracing to determine transmitted color instead of using only light probes. This prevents the surface from contributing to the lighting of surfaces not using this setting. Deprecated: use 'use_raytrace_refraction'. (default False)"""

    use_sss_translucency: bool
    """ Add translucency effect to subsurface (Deprecated) (default False)"""

    use_thickness_from_shadow: bool
    """ Use the shadow maps from shadow casting lights to refine the thickness defined by the material node tree (default False)"""

    use_transparency_overlap: bool
    """ Render multiple transparent layers (may introduce transparency sorting problems) (default True)"""

    use_transparent_shadow: bool
    """ Use transparent shadows for this material if it contains a Transparent BSDF, disabling will render faster but not give accurate shadows (default True)"""

    volume_intersection_method: typing.Literal["FAST", "ACCURATE"]
    """ Determines which inner part of the mesh will produce volumetric effect (default 'FAST')"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this material. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaterialGPencilStyle(bpy_struct):
    alignment_mode: typing.Literal["PATH", "OBJECT", "FIXED"]
    """ Defines how align Dots and Boxes with drawing path and object rotation (default 'PATH')"""

    alignment_rotation: float
    """ Additional rotation applied to dots and square texture of strokes. Only applies in texture shading mode. (in [-1.5708, 1.5708], default 0.0)"""

    color: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    fill_color: typing.Any
    """ Color for filling region bounded by each stroke (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    fill_image: Image | None
    fill_style: typing.Literal["SOLID", "GRADIENT", "TEXTURE"]
    """ Select style used to fill strokes (default 'SOLID')"""

    flip: bool
    """ Flip filling colors (default False)"""

    ghost: bool
    """ Display strokes using this color when showing onion skins (default False)"""

    gradient_type: typing.Literal["LINEAR", "RADIAL"]
    """ Select type of gradient used to fill strokes (default 'LINEAR')"""

    hide: bool
    """ Set color Visibility (default False)"""

    is_fill_visible: bool
    """ True when opacity of fill is set high enough to be visible (default False, readonly)"""

    is_stroke_visible: bool
    """ True when opacity of stroke is set high enough to be visible (default False, readonly)"""

    lock: bool
    """ Protect color from further editing and/or frame changes (default False)"""

    mix_color: typing.Any
    """ Color for mixing with primary filling color (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    mix_factor: float
    """ Mix Factor (in [0, 1], default 0.0)"""

    mix_stroke_factor: float
    """ Mix Stroke Factor (in [0, 1], default 0.0)"""

    mode: typing.Literal["LINE", "DOTS", "BOX"]
    """ Select line type for strokes (default 'LINE')"""

    pass_index: int
    """ Index number for the "Color Index" pass (in [0, 32767], default 0)"""

    pixel_size: float
    """ Texture Pixel Size factor along the stroke (in [1, 5000], default 0.0)"""

    show_fill: bool
    """ Show stroke fills of this material (default False)Unused but kept for compatibility with older versions of Blender.5.10 removal planned in version 6.0"""

    show_stroke: bool
    """ Show stroke lines of this material (default False)Unused but kept for compatibility with older versions of Blender.5.10 removal planned in version 6.0"""

    stroke_image: Image | None
    stroke_style: typing.Literal["SOLID", "TEXTURE"]
    """ Select style used to draw strokes (default 'SOLID')"""

    texture_angle: float
    """ Texture Orientation Angle (in [-inf, inf], default 0.0)"""

    texture_clamp: bool
    """ Do not repeat texture and clamp to one instance only (default False)"""

    texture_offset: mathutils.Vector
    """ Shift Texture in 2d Space (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    texture_scale: mathutils.Vector
    """ Scale Factor for Texture (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    use_fill_holdout: bool
    """ Remove the color from underneath this stroke by using it as a mask (default False)"""

    use_overlap_strokes: bool
    """ Disable stencil and overlap self intersections with alpha materials (default False)"""

    use_stroke_holdout: bool
    """ Remove the color from underneath this stroke by using it as a mask (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaterialLineArt(bpy_struct):
    intersection_priority: int
    """ The intersection line will be included into the object with the higher intersection priority value (in [0, 255], default 0)"""

    mat_occlusion: int
    """ Faces with this material will behave as if it has set number of layers in occlusion (in [0, 255], default 1)"""

    use_intersection_priority_override: bool
    """ Override object and collection intersection priority value (default False)"""

    use_material_mask: bool
    """ Use material masks to filter out occluded strokes (default False)"""

    use_material_mask_bits: typing.Any
    """ (array of 8 items, default (False, False, False, False, False, False, False, False))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MaterialSlot(bpy_struct):
    """Material slot in an object"""

    link: typing.Literal["OBJECT", "DATA"]
    """ Link material to object or the object's data (default 'DATA')"""

    material: Material | None
    """ Material data-block used by this material slot"""

    name: str
    """ Material slot name (default "", readonly, never None)"""

    slot_index: int
    """ (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Menu(bpy_struct):
    """Editor menu containing buttons"""

    bl_description: str
    """ (default "")"""

    bl_idname: str
    """ If this is set, the menu gets a custom ID, otherwise it takes the name of the class used to define the menu (for example, if the class name is "OBJECT_MT_hello", and bl_idname is not set by the script, then bl_idname = "OBJECT_MT_hello") (default "", never None)"""

    bl_label: str
    """ The menu label (default "", never None)"""

    bl_options: set[typing.Literal["SEARCH_ON_KEY_PRESS"]]
    """ Options for this menu type (default set())"""

    bl_owner_id: str
    """ (default "", never None)"""

    bl_translation_context: str
    """ (default "*", never None)"""

    layout: UILayout | None
    """ Defines the structure of the menu in the UI (readonly)"""

    @classmethod
    def poll(cls, context: Context) -> bool:
        """If this method returns a non-null output, then the menu can be drawn

        :param context:
        :return:
        """

    def draw(self, context: Context) -> None:
        """Draw UI elements into the menu UI layout

        :param context:
        """

    @classmethod
    def append(cls, draw_func) -> None:
        """Append a draw function to this menu,
        takes the same arguments as the menus draw function

                :param draw_func:
        """

    @classmethod
    def draw_collapsible(cls, context, layout) -> None:
        """

        :param context:
        :param layout:
        """

    def draw_preset(self, _context) -> None:
        """Define these on the subclass:
        - preset_operator (string)
        - preset_subdir (string)Optionally:
        - preset_add_operator (string)
        - preset_extensions (set of strings)
        - preset_operator_defaults (dict of keyword args)

                :param _context:
        """

    @classmethod
    def is_extended(cls) -> None: ...
    def path_menu(
        self,
        searchpaths: collections.abc.Sequence[str] | None,
        operator: str | None,
        *,
        props_default: None | dict[str, typing.Any] | None = None,
        prop_filepath: str | None = "filepath",
        filter_ext: None | collections.abc.Callable[str, bool] | None = None,
        filter_path=None,
        display_name: None | collections.abc.Callable[str, str] | None = None,
        add_operator=None,
        add_operator_props=None,
        translate=True,
    ) -> None:
        """Populate a menu from a list of paths.

                :param searchpaths: Paths to scan.
                :param operator: The operator id to use with each file.
                :param props_default: Properties to assign to each operator.
                :param prop_filepath: Optional operator filepath property (defaults to "filepath").
                :param filter_ext: Optional callback that takes the file extensions.

        Returning false excludes the file from the list.
                :param filter_path:
                :param display_name: Optional callback that takes the full path, returns the name to display.
                :param add_operator:
                :param add_operator_props:
                :param translate:
        """

    @classmethod
    def prepend(cls, draw_func) -> None:
        """Prepend a draw function to this menu, takes the same arguments as
        the menus draw function

                :param draw_func:
        """

    @classmethod
    def remove(cls, draw_func) -> None:
        """Remove a draw function that has been added to this menu.

        :param draw_func:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Mesh(ID, bpy_struct):
    """Mesh data-block defining geometric surfaces"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    attributes: typing.Any
    """ Geometry attributes (default None, readonly)"""

    auto_texspace: bool
    """ Adjust active object's texture space automatically when transforming object (default True)"""

    color_attributes: typing.Any
    """ Geometry color attributes (default None, readonly)"""

    corner_normals: typing.Any
    """ The "slit" normal direction of each face corner, influenced by vertex normals, sharp faces, sharp edges, and custom normals. May be empty. (default None, readonly)"""

    cycles: typing.Any
    """ Cycles mesh settings (readonly)"""

    edges: typing.Any
    """ Edges of the mesh (default None, readonly)"""

    has_custom_normals: bool
    """ True if there is custom normal data for this mesh (default False, readonly)"""

    is_editmode: bool
    """ True when used in editmode (default False, readonly)"""

    loop_triangle_polygons: typing.Any
    """ The face index for each loop triangle (default None, readonly)"""

    loop_triangles: typing.Any
    """ Tessellation of mesh polygons into triangles (default None, readonly)"""

    loops: typing.Any
    """ Loops of the mesh (face corners) (default None, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    normals_domain: typing.Literal["POINT", "FACE", "CORNER"]
    """ The attribute domain that gives enough information to represent the mesh's normals (default 'FACE', readonly)"""

    polygon_normals: typing.Any
    """ The normal direction of each face, defined by the winding order and position of its vertices (default None, readonly)"""

    polygons: typing.Any
    """ Polygons of the mesh (default None, readonly)"""

    radial_symmetry: typing.Any
    """ Number of mirrored regions around a central axis (array of 3 items, in [1, 64], default (1, 1, 1))"""

    remesh_mode: typing.Literal["VOXEL", "QUAD"]
    """ (default 'VOXEL')"""

    remesh_voxel_adaptivity: float
    """ Reduces the final face count by simplifying geometry where detail is not needed, generating triangles. A value greater than 0 disables Fix Poles. (in [0, 1], default 0.0)"""

    remesh_voxel_size: float
    """ Size of the voxel in object space used for volume evaluation. Lower values preserve finer details. (in [0, inf], default 0.1)"""

    shape_keys: Key | None
    """ (readonly)"""

    skin_vertices: typing.Any
    """ All skin vertices (default None, readonly)"""

    texco_mesh: typing_extensions.Self | None
    """ Derive texture coordinates from another mesh"""

    texspace_location: mathutils.Vector
    """ Texture space location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    texspace_size: mathutils.Vector
    """ Texture space size (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    texture_mesh: typing_extensions.Self | None
    """ Use another mesh for texture indices (vertex indices must be aligned)"""

    total_edge_sel: int
    """ Selected edge count in editmode (in [0, inf], default 0, readonly)"""

    total_face_sel: int
    """ Selected face count in editmode (in [0, inf], default 0, readonly)"""

    total_vert_sel: int
    """ Selected vertex count in editmode (in [0, inf], default 0, readonly)"""

    use_auto_texspace: bool
    """ Adjust active object's texture space automatically when transforming object (default True)"""

    use_mirror_topology: bool
    """ Use topology based mirroring (for when both sides of mesh have matching, unique topology) (default False)"""

    use_mirror_vertex_groups: bool
    """ Mirror the left/right vertex groups when painting. The symmetry axis is determined by the symmetry settings. (default True)"""

    use_mirror_x: bool
    """ Enable symmetry in the X axis (default False)"""

    use_mirror_y: bool
    """ Enable symmetry in the Y axis (default False)"""

    use_mirror_z: bool
    """ Enable symmetry in the Z axis (default False)"""

    use_paint_bone_selection: bool
    """ Bone selection during painting (default True)"""

    use_paint_mask: bool
    """ Face selection masking for painting (default False)"""

    use_paint_mask_vertex: bool
    """ Vertex selection masking for painting (default False)"""

    use_remesh_fix_poles: bool
    """ Produces fewer poles and a better topology flow (default False)"""

    use_remesh_preserve_attributes: bool
    """ Transfer all attributes to the new mesh (default False)"""

    use_remesh_preserve_volume: bool
    """ Projects the mesh to preserve the volume and details of the original mesh (default False)"""

    uv_layer_clone: MeshUVLoopLayer | None
    """ UV loop layer to be used as cloning source"""

    uv_layer_clone_index: int
    """ Clone UV loop layer index (in [0, inf], default 0)"""

    uv_layer_stencil: MeshUVLoopLayer | None
    """ UV loop layer to mask the painted area"""

    uv_layer_stencil_index: int
    """ Mask UV loop layer index (in [0, inf], default 0)"""

    uv_layers: typing.Any
    """ All UV loop layers (default None, readonly)"""

    vertex_colors: typing.Any
    """ Legacy vertex color layers. Deprecated, use color attributes instead. (default None, readonly)"""

    vertex_normals: typing.Any
    """ The normal direction of each vertex, defined as the average of the surrounding face normals (default None, readonly)"""

    vertices: typing.Any
    """ Vertices of the mesh (default None, readonly)"""

    edge_creases: typing.Any
    """ Edge crease values for subdivision surface, corresponding to the "crease_edge" attribute.(readonly)"""

    edge_keys: typing.Any
    """ (readonly)"""

    vertex_creases: typing.Any
    """ Vertex crease values for subdivision surface, corresponding to the "crease_vert" attribute.(readonly)"""

    vertex_paint_mask: typing.Any
    """ Mask values for sculpting and painting, corresponding to the ".sculpt_mask" attribute.(readonly)"""

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
        *,
        shape_keys: bool | None = False,
    ) -> None:
        """Transform mesh vertices by a matrix (Warning: inverts normals if matrix is negative)

        :param matrix: Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        :param shape_keys: Transform Shape Keys (optional)
        """

    def flip_normals(self) -> None:
        """Invert winding of all polygons (clears tessellation, does not handle custom normals)"""

    def set_sharp_from_angle(self, *, angle: float | None = 3.14159) -> None:
        """Reset and fill the "sharp_edge" attribute based on the angle of faces neighboring manifold edges

        :param angle: Angle, Angle between faces beyond which edges are marked sharp (in [0, 3.14159], optional)
        """

    def split_faces(self) -> None:
        """Split faces based on the edge angle"""

    def calc_tangents(self, *, uvmap: str | None = "") -> None:
        """Compute tangents and bitangent signs, to be used together with the custom normals to get a complete tangent space for normal mapping (custom normals are also computed if not yet present)

        :param uvmap: Name of the UV map to use for tangent space computation (optional, never None)
        """

    def free_tangents(self) -> None:
        """Free tangents"""

    def calc_loop_triangles(self) -> None:
        """Calculate loop triangle tessellation (supports editmode too)"""

    def calc_smooth_groups(
        self,
        *,
        use_bitflags: bool | None = False,
        use_boundary_vertices_for_bitflags: bool | None = False,
    ) -> tuple[int]:
        """Calculate smooth groups from sharp edges

                :param use_bitflags: Produce bitflags groups instead of simple numeric values (optional)
                :param use_boundary_vertices_for_bitflags: Also consider different smoothgroups sharing only vertices (but without any common edge) as neighbors, preventing them from sharing the same bitflag value. Only effective when use_bitflags is set. WARNING: Will overflow (run out of available bits) easily with some types of topology, e.g. large fans of sharp edges (optional)
                :return: poly_groups, Smooth Groups, `bpy_prop_array`[int]

        groups, Total number of groups, int
        """

    def normals_split_custom_set(
        self, normals: collections.abc.Sequence[float] | None
    ) -> None:
        """Define custom normals of this mesh (use zero-vectors to keep auto ones)

        :param normals: Normals (multi-dimensional array of 1 * 3 items, in [-1, 1])
        """

    def normals_split_custom_set_from_vertices(
        self, normals: collections.abc.Sequence[float] | None
    ) -> None:
        """Define custom normals of this mesh, from vertices normals (use zero-vectors to keep auto ones)

        :param normals: Normals (multi-dimensional array of 1 * 3 items, in [-1, 1])
        """

    def update(
        self, *, calc_edges: bool | None = False, calc_edges_loose: bool | None = False
    ) -> None:
        """update

        :param calc_edges: Calculate Edges, Force recalculation of edges (optional)
        :param calc_edges_loose: Calculate Loose Edges, Calculate the loose state of each edge (optional)
        """

    def update_gpu_tag(self) -> None:
        """update_gpu_tag"""

    def unit_test_compare(
        self,
        *,
        mesh: typing_extensions.Self | None = None,
        threshold: float | None = 7.1526e-06,
    ) -> str:
        """unit_test_compare

        :param mesh: Mesh to compare to (optional)
        :param threshold: Threshold, Comparison tolerance threshold (in [0, inf], optional)
        :return: Return value, String description of result of comparison (never None)
        """

    def clear_geometry(self) -> None:
        """Remove all geometry from the mesh. Note that this does not free shape keys or materials."""

    def validate(
        self, *, verbose: bool | None = False, clean_customdata: bool | None = True
    ) -> bool:
        """Validate geometry, return True when the mesh has had invalid geometry corrected/removed

        :param verbose: Verbose, Output information about the errors found (optional)
        :param clean_customdata: Clean Custom Data, Deprecated, has no effect (optional)
        :return: Result
        """

    def validate_material_indices(self) -> bool:
        """Validate material indices of polygons, return True when the mesh has had invalid indices corrected (to default 0)

        :return: Result
        """

    def count_selected_items(self) -> None:
        """Return the number of selected items (vert, edge, face)

        :return: Result, (array of 3 items, in [0, inf])
        """

    def edge_creases_ensure(self) -> None: ...
    def edge_creases_remove(self) -> None: ...
    def from_pydata(
        self,
        vertices: collections.abc.Iterable[
            collections.abc.Sequence[float] | mathutils.Vector
        ]
        | None,
        edges: collections.abc.Iterable[collections.abc.Sequence[int]] | None,
        faces: collections.abc.Iterable[collections.abc.Sequence[int]] | None,
        shade_flat=True,
    ) -> None:
        """Make a mesh from a list of vertices/edges/faces
        Until we have a nicer way to make geometry, use this.

                :param vertices: float triplets each representing (X, Y, Z)
        eg: [(0.0, 1.0, 0.5), ...].
                :param edges: int pairs, each pair contains two indices to the
        vertices argument. eg: [(1, 2), ...]

        When an empty iterable is passed in, the edges are inferred from the polygons.
                :param faces: iterator of faces, each faces contains three or more indices to
        the vertices argument. eg: [(5, 6, 8, 9), (1, 2, 3), ...]
                :param shade_flat:
        """

    def shade_flat(self) -> None:
        """Render and display faces uniform, using face normals,
        setting the "sharp_face" attribute true for every face

        """

    def shade_smooth(self) -> None:
        """Render and display faces smooth, using interpolated vertex normals,
        removing the "sharp_face" attribute

        """

    def vertex_creases_ensure(self) -> None: ...
    def vertex_creases_remove(self) -> None: ...
    def vertex_paint_mask_ensure(self) -> None: ...
    def vertex_paint_mask_remove(self) -> None: ...
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshCacheModifier(Modifier, bpy_struct):
    """Cache Mesh"""

    cache_format: typing.Literal["MDD", "PC2"]
    """ (default 'MDD')"""

    deform_mode: typing.Literal["OVERWRITE", "INTEGRATE"]
    """ (default 'OVERWRITE')"""

    eval_factor: float
    """ Evaluation time in seconds (in [0, 1], default 0.0)"""

    eval_frame: float
    """ The frame to evaluate (starting at 0) (in [0, 1.04857e+06], default 0.0)"""

    eval_time: float
    """ Evaluation time in seconds (in [0, inf], default 0.0)"""

    factor: float
    """ Influence of the deformation (in [0, 1], default 1.0)"""

    filepath: str
    """ Path to external displacements file (default "", never None, blend relative // prefix supported)"""

    flip_axis: typing.Any
    """ (array of 3 items, default (False, False, False))"""

    forward_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ (default 'POS_Y')"""

    frame_scale: float
    """ Evaluation time in seconds (in [0, 100], default 1.0)"""

    frame_start: float
    """ Add this to the start frame (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    interpolation: typing.Literal["NONE", "LINEAR"]
    """ (default 'LINEAR')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    play_mode: typing.Literal["SCENE", "CUSTOM"]
    """ (default 'SCENE')"""

    time_mode: typing.Literal["FRAME", "TIME", "FACTOR"]
    """ Method to control playback time (default 'FRAME')"""

    up_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ (default 'POS_Z')"""

    vertex_group: str
    """ Name of the Vertex Group which determines the influence of the modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshDeformModifier(Modifier, bpy_struct):
    """Mesh deformation modifier to deform with other meshes"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    is_bound: bool
    """ Whether geometry has been bound to control cage (default False, readonly)"""

    object: Object | None
    """ Mesh object to deform with"""

    precision: int
    """ The grid size for binding (in [2, 10], default 5)"""

    use_dynamic_bind: bool
    """ Recompute binding dynamically on top of other deformers (slower and more memory consuming) (default False)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshEdge(bpy_struct):
    """Edge in a Mesh data-block"""

    hide: bool
    """ (default False)"""

    index: int
    """ Index of this edge (in [0, inf], default 0, readonly)"""

    is_loose: bool
    """ Edge is not connected to any faces (default False, readonly)"""

    select: bool
    """ (default False)"""

    use_edge_sharp: bool
    """ Sharp edge for shading (default False)"""

    use_seam: bool
    """ Seam edge for UV unwrapping (default False)"""

    vertices: typing.Any
    """ Vertex indices (array of 2 items, in [0, inf], default (0, 0))"""

    key: typing.Any
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoop(bpy_struct):
    """Loop in a Mesh data-block"""

    bitangent: mathutils.Vector
    """ Bitangent vector of this vertex for this face (must be computed beforehand using calc_tangents, use it only if really needed, slower access than bitangent_sign) (array of 3 items, in [-1, 1], default (0.0, 0.0, 0.0), readonly)"""

    bitangent_sign: float
    """ Sign of the bitangent vector of this vertex for this face (must be computed beforehand using calc_tangents, bitangent = bitangent_sign * cross(normal, tangent)) (in [-1, 1], default 0.0, readonly)"""

    edge_index: int
    """ Edge index (in [0, inf], default 0)"""

    index: int
    """ Index of this loop (in [0, inf], default 0, readonly)"""

    normal: mathutils.Vector
    """ The normal direction of the face corner, taking into account sharp faces, sharp edges, and custom normal data (array of 3 items, in [-1, 1], default (0.0, 0.0, 0.0), readonly)"""

    tangent: mathutils.Vector
    """ Local space unit length tangent vector of this vertex for this face (must be computed beforehand using calc_tangents) (array of 3 items, in [-1, 1], default (0.0, 0.0, 0.0), readonly)"""

    vertex_index: int
    """ Vertex index (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoopColor(bpy_struct):
    """Vertex loop colors in a Mesh"""

    color: typing.Any
    """ Color in sRGB color space (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoopColorLayer(bpy_struct):
    """Layer of vertex colors in a Mesh data-block"""

    active: bool | None
    """ Sets the layer as active for display and editing (default False)"""

    active_render: bool | None
    """ Sets the layer as active for rendering (default False)"""

    data: typing.Any
    """ (default None, readonly)"""

    name: str
    """ Name of Vertex color layer (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshLoopTriangle(bpy_struct):
    """Tessellated triangle in a Mesh data-block"""

    area: float
    """ Area of this triangle (in [0, inf], default 0.0, readonly)"""

    index: int
    """ Index of this loop triangle (in [0, inf], default 0, readonly)"""

    loops: typing.Any
    """ Indices of mesh loops that make up the triangle (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    material_index: int
    """ Material slot index of this triangle (in [0, inf], default 0, readonly)"""

    normal: mathutils.Vector
    """ Local space unit length normal vector for this triangle (array of 3 items, in [-1, 1], default (0.0, 0.0, 0.0), readonly)"""

    polygon_index: int
    """ Index of mesh face that the triangle is a part of (in [0, inf], default 0, readonly)"""

    split_normals: typing.Any
    """ Local space unit length custom normal vectors of the face corners of this triangle (multi-dimensional array of 3 * 3 items, in [-1, 1], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), readonly)"""

    use_smooth: bool
    """ (default False, readonly)"""

    vertices: typing.Any
    """ Indices of triangle vertices (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    center: typing.Any
    """ The midpoint of the face.(readonly)"""

    edge_keys: typing.Any
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshNormalValue(bpy_struct):
    """Vector in a mesh normal array"""

    vector: mathutils.Vector
    """ 3D vector (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshPolygon(bpy_struct):
    """Polygon in a Mesh data-block"""

    area: float
    """ Read only area of this face (in [0, inf], default 0.0, readonly)"""

    center: mathutils.Vector
    """ Center of this face (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    hide: bool
    """ (default False)"""

    index: int
    """ Index of this face (in [0, inf], default 0, readonly)"""

    loop_start: int
    """ Index of the first loop of this face (in [0, inf], default 0)"""

    loop_total: int
    """ Number of loops used by this face (in [0, inf], default 0, readonly)"""

    material_index: int
    """ Material slot index of this face (in [0, inf], default 0)"""

    normal: mathutils.Vector
    """ Local space unit length normal vector for this face (array of 3 items, in [-1, 1], default (0.0, 0.0, 0.0), readonly)"""

    select: bool
    """ (default False)"""

    use_smooth: bool
    """ (default False)"""

    vertices: typing.Any
    """ Vertex indices (array of 3 items, in [0, inf], default (0, 0, 0))"""

    edge_keys: typing.Any
    """ (readonly)"""

    loop_indices: typing.Any
    """ (readonly)"""

    def flip(self) -> None:
        """Invert winding of this face (flip its normal)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshSequenceCacheModifier(Modifier, bpy_struct):
    """Cache Mesh"""

    cache_file: CacheFile | None
    object_path: str
    """ Path to the object in the Alembic archive used to lookup geometric data (default "", never None)"""

    read_data: set[typing.Literal["VERT", "POLY", "UV", "COLOR", "ATTRIBUTES"]]
    """ Data to read from the cache (default {'ATTRIBUTES', 'COLOR', 'POLY', 'UV', 'VERT'})"""

    use_vertex_interpolation: bool
    """ Allow interpolation of vertex positions (default True)"""

    velocity_scale: float
    """ Multiplier used to control the magnitude of the velocity vectors for time effects (in [0, inf], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshSkinVertex(bpy_struct):
    """Per-vertex skin data for use with the Skin modifier"""

    radius: typing.Any
    """ Radius of the skin (array of 2 items, in [0, inf], default (0.0, 0.0))"""

    use_loose: bool
    """ If vertex has multiple adjacent edges, it is hulled to them directly (default False)"""

    use_root: bool
    """ Vertex is a root for rotation calculations and armature generation, setting this flag does not clear other roots in the same mesh island (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshSkinVertexLayer(bpy_struct):
    """Per-vertex skin data for use with the Skin modifier"""

    data: typing.Any
    """ (default None, readonly)"""

    name: str
    """ Name of skin layer (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshStatVis(bpy_struct):
    distort_max: float
    """ Maximum angle to display (in [0, 3.14159], default 0.785398)"""

    distort_min: float
    """ Minimum angle to display (in [0, 3.14159], default 0.0872665)"""

    overhang_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ (default 'NEG_Z')"""

    overhang_max: float
    """ Maximum angle to display (in [0, 3.14159], default 0.785398)"""

    overhang_min: float
    """ Minimum angle to display (in [0, 3.14159], default 0.0)"""

    sharp_max: float
    """ Maximum angle to display (in [-3.14159, 3.14159], default 3.14159)"""

    sharp_min: float
    """ Minimum angle to display (in [-3.14159, 3.14159], default 1.5708)"""

    thickness_max: float
    """ Maximum for measuring thickness (in [0, 1000], default 0.1)"""

    thickness_min: float
    """ Minimum for measuring thickness (in [0, 1000], default 0.0)"""

    thickness_samples: int
    """ Number of samples to test per face (in [1, 32], default 1)"""

    type: typing.Literal["OVERHANG", "THICKNESS", "INTERSECT", "DISTORT", "SHARP"]
    """ Type of data to visualize/check (default 'OVERHANG')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshToVolumeModifier(Modifier, bpy_struct):
    density: float
    """ Density of the new volume (in [0, inf], default 0.0)"""

    interior_band_width: float
    """ Width of the gradient inside of the mesh (in [0, inf], default 0.0)"""

    object: Object | None
    """ Object"""

    resolution_mode: typing.Literal["VOXEL_AMOUNT", "VOXEL_SIZE"]
    """ Mode for how the desired voxel size is specified (default 'VOXEL_AMOUNT')"""

    voxel_amount: int
    """ Approximate number of voxels along one axis (in [0, inf], default 0)"""

    voxel_size: float
    """ Smaller values result in a higher resolution output (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshUVLoop(bpy_struct):
    """(Deprecated) Layer of UV coordinates in a Mesh data-block"""

    pin_uv: bool
    """ (default False)"""

    uv: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshUVLoopLayer(bpy_struct):
    active: bool | None
    """ Set the map as active for display and editing (default False)"""

    active_clone: bool | None
    """ Set the map as active for cloning (default False)"""

    active_render: bool | None
    """ Set the UV map as active for rendering (default False)"""

    data: typing.Any
    """ Deprecated, use 'uv', 'vertex_select', 'edge_select' or 'pin' properties instead (default None, readonly)"""

    name: str
    """ Name of UV map (default "", never None)"""

    pin: typing.Any
    """ UV pinned state in the UV editor (default None, readonly)"""

    uv: typing.Any
    """ UV coordinates on face corners (default None, readonly)"""

    def pin_ensure(self) -> BoolAttribute:
        """pin_ensure

        :return: The boolean attribute
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MeshVertex(bpy_struct):
    """Vertex in a Mesh data-block"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    groups: typing.Any
    """ Weights for the vertex groups this vertex is member of (default None, readonly)"""

    hide: bool
    """ (default False)"""

    index: int
    """ Index of this vertex (in [0, inf], default 0, readonly)"""

    normal: mathutils.Vector
    """ Vertex Normal (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    select: bool
    """ (default False)"""

    undeformed_co: mathutils.Vector
    """ For meshes with modifiers applied, the coordinate of the vertex with no deforming modifiers applied, as used for generated texture coordinates (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MetaBall(ID, bpy_struct):
    """Metaball data-block to define blobby surfaces"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    cycles: typing.Any
    """ Cycles mesh settings (readonly)"""

    elements: typing.Any
    """ Metaball elements (default None, readonly)"""

    is_editmode: bool
    """ True when used in editmode (default False, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    render_resolution: float
    """ Polygonization resolution in rendering (in [0.005, 10000], default 0.2)"""

    resolution: float
    """ Polygonization resolution in the 3D viewport (in [0.005, 10000], default 0.4)"""

    texspace_location: mathutils.Vector
    """ Texture space location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    texspace_size: mathutils.Vector
    """ Texture space size (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    threshold: float
    """ Influence of metaball elements (in [0, 5], default 0.6)"""

    update_method: typing.Literal["UPDATE_ALWAYS", "HALFRES", "FAST", "NEVER"]
    """ Metaball edit update behavior (default 'UPDATE_ALWAYS')"""

    use_auto_texspace: bool
    """ Adjust active object's texture space automatically when transforming object (default True)"""

    def transform(
        self,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None,
    ) -> None:
        """Transform metaball elements by a matrix

        :param matrix: Matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    def update_gpu_tag(self) -> None:
        """update_gpu_tag"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MetaElement(bpy_struct):
    """Blobby element in a metaball data-block"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    hide: bool
    """ Hide element (default False)"""

    radius: float
    """ (in [0, inf], default 0.0)"""

    rotation: mathutils.Quaternion
    """ Normalized quaternion rotation (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    select: bool
    """ Select element (default False)"""

    size_x: float
    """ Size of element, use of components depends on element type (in [0, 20], default 0.0)"""

    size_y: float
    """ Size of element, use of components depends on element type (in [0, 20], default 0.0)"""

    size_z: float
    """ Size of element, use of components depends on element type (in [0, 20], default 0.0)"""

    stiffness: float
    """ Stiffness defines how much of the element to fill (in [0, 10], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.MetaelemTypeItems]
    """ Metaball type (default 'BALL')"""

    use_negative: bool
    """ Set metaball as negative one (default False)"""

    use_scale_stiffness: bool
    """ Scale stiffness instead of radius (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MetaStrip(Strip, bpy_struct):
    """Sequence strip to group other strips as a single sequence strip"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    channels: typing.Any
    """ (default None, readonly)"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    proxy: StripProxy | None
    """ (readonly)"""

    strips: typing.Any
    """ Strips nested in meta strip (default None, readonly)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_proxy: bool
    """ Use a preview proxy and/or time-code index for this strip (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    volume: float
    """ Playback volume of the sound (in [0, 100], default 1.0)"""

    def separate(self) -> None:
        """Separate meta"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MirrorModifier(Modifier, bpy_struct):
    """Mirroring modifier"""

    bisect_threshold: float
    """ Distance from the bisect plane within which vertices are removed (in [0, inf], default 0.001)"""

    merge_threshold: float
    """ Distance within which mirrored vertices are merged (in [0, inf], default 0.001)"""

    mirror_object: Object | None
    """ Object to use as mirror"""

    mirror_offset_u: float
    """ Amount to offset mirrored UVs flipping point from the 0.5 on the U axis (in [-1, 1], default 0.0)"""

    mirror_offset_v: float
    """ Amount to offset mirrored UVs flipping point from the 0.5 point on the V axis (in [-1, 1], default 0.0)"""

    offset_u: float
    """ Mirrored UV offset on the U axis (in [-10000, 10000], default 0.0)"""

    offset_v: float
    """ Mirrored UV offset on the V axis (in [-10000, 10000], default 0.0)"""

    use_axis: typing.Any
    """ Enable axis mirror (array of 3 items, default (False, False, False))"""

    use_bisect_axis: typing.Any
    """ Cuts the mesh across the mirror plane (array of 3 items, default (False, False, False))"""

    use_bisect_flip_axis: typing.Any
    """ Flips the direction of the slice (array of 3 items, default (False, False, False))"""

    use_clip: bool
    """ Prevent vertices from going through the mirror during transform (default False)"""

    use_mirror_merge: bool
    """ Merge vertices within the merge threshold (default True)"""

    use_mirror_u: bool
    """ Mirror the U texture coordinate around the flip offset point (default False)"""

    use_mirror_udim: bool
    """ Mirror the texture coordinate around each tile center (default False)"""

    use_mirror_v: bool
    """ Mirror the V texture coordinate around the flip offset point (default False)"""

    use_mirror_vertex_groups: bool
    """ Mirror vertex groups (e.g. .R->.L) (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Modifier(bpy_struct):
    """Modifier affecting the geometry data of an object"""

    execution_time: float
    """ Time in seconds that the modifier took to evaluate. This is only set on evaluated objects. If multiple modifiers run in parallel, execution time is not a reliable metric. (in [-inf, inf], default 0.0, readonly)"""

    is_active: bool
    """ The active modifier in the list (default False)"""

    is_override_data: bool
    """ In a local override object, whether this modifier comes from the linked reference object, or is local to the override (default True, readonly)"""

    name: str
    """ Modifier name (default "", never None)"""

    persistent_uid: int
    """ Uniquely identifies the modifier within the modifier stack that it is part of (in [-inf, inf], default 0, readonly)"""

    show_expanded: bool
    """ Set modifier expanded in the user interface (default False)"""

    show_in_editmode: bool
    """ Display modifier in Edit mode (default False)"""

    show_on_cage: bool
    """ Adjust edit cage to modifier result (default False)"""

    show_render: bool
    """ Use modifier during render (default False)"""

    show_viewport: bool
    """ Display modifier in viewport (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.ObjectModifierTypeItems]
    """ (default 'GREASE_PENCIL_VERTEX_WEIGHT_PROXIMITY', readonly)"""

    use_apply_on_spline: bool
    """ Apply this and all preceding deformation modifiers on splines' points rather than on filled curve/surface (default False)"""

    use_pin_to_last: bool
    """ Keep the modifier at the end of the list (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ModifierViewerPathElem(ViewerPathElem, bpy_struct):
    modifier_uid: int
    """ The persistent UID of the modifier (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MotionPath(bpy_struct):
    """Cache of the world-space positions of an element over a frame range"""

    color: mathutils.Color
    """ Custom color for motion path before the current frame (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    color_post: mathutils.Color
    """ Custom color for motion path after the current frame (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    frame_end: int
    """ End frame of the stored range (in [-inf, inf], default 0, readonly)"""

    frame_start: int
    """ Starting frame of the stored range (in [-inf, inf], default 0, readonly)"""

    is_modified: bool
    """ Path is being edited (default False)"""

    length: int
    """ Number of frames cached (in [-inf, inf], default 0, readonly)"""

    line_thickness: int
    """ Line thickness for motion path (in [1, 6], default 0)"""

    lines: bool
    """ Use straight lines between keyframe points (default False)"""

    points: typing.Any
    """ Cached positions per frame (default None, readonly)"""

    use_bone_head: bool
    """ For PoseBone paths, use the bone head location when calculating this path (default False, readonly)"""

    use_custom_color: bool
    """ Use custom color for this motion path (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MotionPathVert(bpy_struct):
    """Cached location on path"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    select: bool
    """ Path point is selected for editing (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieClip(ID, bpy_struct):
    """MovieClip data-block referencing an external movie file"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    annotation: Annotation | None
    """ Annotation data for this movie clip"""

    colorspace_settings: ColorManagedInputColorspaceSettings | None
    """ Input color space settings (readonly)"""

    display_aspect: mathutils.Vector
    """ Display Aspect for this clip, does not affect rendering (array of 2 items, in [0.1, inf], default (1.0, 1.0))"""

    filepath: str
    """ Filename of the movie or sequence file (default "", never None, blend relative // prefix supported)"""

    fps: float
    """ Detected frame rate of the movie clip in frames per second (in [-inf, inf], default 0.0, readonly)"""

    frame_duration: int
    """ Detected duration of movie clip in frames (in [-inf, inf], default 0, readonly)"""

    frame_offset: int
    """ Offset of footage first frame relative to its file name (affects only how footage is loading, does not change data associated with a clip) (in [-inf, inf], default 0)"""

    frame_start: int
    """ Global scene frame number at which this movie starts playing (affects all data associated with a clip) (in [-inf, inf], default 1)"""

    proxy: MovieClipProxy | None
    """ (readonly)"""

    size: typing.Any
    """ Width and height in pixels, zero when image data cannot be loaded (array of 2 items, in [-inf, inf], default (0, 0), readonly)"""

    source: typing.Literal["SEQUENCE", "MOVIE"]
    """ Where the clip comes from (default 'SEQUENCE', readonly)"""

    tracking: MovieTracking | None
    """ (readonly)"""

    use_proxy: bool
    """ Use a preview proxy and/or timecode index for this clip (default False)"""

    use_proxy_custom_directory: bool
    """ Create proxy images in a custom directory (default is movie location) (default False)"""

    def metadata(self) -> IDPropertyWrapPtr:
        """Retrieve metadata of the movie file

        :return: Dict-like object containing the metadata
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieClipProxy(bpy_struct):
    """Proxy parameters for a movie clip"""

    build_100: bool
    """ Build proxy resolution 100% of the original footage dimension (default False)"""

    build_25: bool
    """ Build proxy resolution 25% of the original footage dimension (default True)"""

    build_50: bool
    """ Build proxy resolution 50% of the original footage dimension (default False)"""

    build_75: bool
    """ Build proxy resolution 75% of the original footage dimension (default False)"""

    build_record_run: bool
    """ Build record run time code index (default True)"""

    build_undistorted_100: bool
    """ Build proxy resolution 100% of the original undistorted footage dimension (default False)"""

    build_undistorted_25: bool
    """ Build proxy resolution 25% of the original undistorted footage dimension (default False)"""

    build_undistorted_50: bool
    """ Build proxy resolution 50% of the original undistorted footage dimension (default False)"""

    build_undistorted_75: bool
    """ Build proxy resolution 75% of the original undistorted footage dimension (default False)"""

    directory: str
    """ Location to store the proxy files (default "", never None, blend relative // prefix supported)"""

    quality: int
    """ JPEG quality of proxy images (in [0, 32767], default 50)"""

    timecode: typing.Literal["NONE", "RECORD_RUN", "FREE_RUN_NO_GAPS"]
    """ (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieClipScopes(bpy_struct):
    """Scopes for statistical view of a movie clip"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieClipStrip(Strip, bpy_struct):
    """Sequence strip to load a video from the clip editor"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    clip: MovieClip | None
    """ Movie clip that this strip uses"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    fps: float
    """ Frames per second (in [-inf, inf], default 0.0, readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    stabilize2d: bool
    """ Use the 2D stabilized version of the clip (default False)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    undistort: bool
    """ Use the undistorted version of the clip (default False)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieClipUser(bpy_struct):
    """Parameters defining how a MovieClip data-block is used by another data-block"""

    frame_current: int
    """ Current frame number in movie or image sequence (in [-1048574, 1048574], default 1)"""

    proxy_render_size: typing.Literal[
        "PROXY_25", "PROXY_50", "PROXY_75", "PROXY_100", "FULL"
    ]
    """ Display preview using full resolution or different proxy resolutions (default 'FULL')"""

    use_render_undistorted: bool
    """ Render preview using undistorted proxy (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieReconstructedCamera(bpy_struct):
    """Match-moving reconstructed camera data from tracker"""

    average_error: float
    """ Average error of reconstruction (in [-inf, inf], default 0.0, readonly)"""

    frame: int
    """ Frame number marker is keyframed on (in [-inf, inf], default 0, readonly)"""

    matrix: mathutils.Matrix
    """ Worldspace transformation matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieStrip(Strip, bpy_struct):
    """Sequence strip to load a video"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    colorspace_settings: ColorManagedInputColorspaceSettings | None
    """ Input color space settings (readonly)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    elements: typing.Any
    """ (default None, readonly)"""

    filepath: str
    """ (default "", never None, blend relative // prefix supported)"""

    fps: float
    """ Frames per second (in [-inf, inf], default 0.0, readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    proxy: StripProxy | None
    """ (readonly)"""

    retiming_keys: typing.Any
    """ (default None, readonly)"""

    stereo_3d_format: Stereo3dFormat | None
    """ Settings for stereo 3D (readonly, never None)"""

    stream_index: int
    """ For files with several movie streams, use the stream with the given index (in [0, 20], default 0)"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_multiview: bool
    """ Use Multiple Views (when available) (default False)"""

    use_proxy: bool
    """ Use a preview proxy and/or time-code index for this strip (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    views_format: Literal[bpy.stub_internal.rna_enums.ViewsFormatItems]
    """ Mode to load movie views (default 'INDIVIDUAL')"""

    def reload_if_needed(self) -> bool:
        """reload_if_needed

        :return: True if the strip can produce frames, False otherwise
        """

    def metadata(self) -> IDPropertyWrapPtr:
        """Retrieve metadata of the movie file

        :return: Dict-like object containing the metadata
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTracking(bpy_struct):
    """Match-moving data for tracking"""

    active_object_index: int | None
    """ Index of active object (in [-inf, inf], default 0)"""

    camera: MovieTrackingCamera | None
    """ (readonly)"""

    dopesheet: MovieTrackingDopesheet | None
    """ (readonly)"""

    objects: typing.Any
    """ Collection of objects in this tracking data object (default None, readonly)"""

    plane_tracks: typing.Any
    """ Collection of plane tracks in this tracking data object. Deprecated, use objects[name].plane_tracks (default None, readonly)"""

    reconstruction: MovieTrackingReconstruction | None
    """ (readonly)"""

    settings: MovieTrackingSettings | None
    """ (readonly)"""

    stabilization: MovieTrackingStabilization | None
    """ (readonly)"""

    tracks: typing.Any
    """ Collection of tracks in this tracking data object. Deprecated, use objects[name].tracks (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingCamera(bpy_struct):
    """Match-moving camera data for tracking"""

    brown_k1: float
    """ First coefficient of fourth order Brown-Conrady radial distortion (in [-inf, inf], default 0.0)"""

    brown_k2: float
    """ Second coefficient of fourth order Brown-Conrady radial distortion (in [-inf, inf], default 0.0)"""

    brown_k3: float
    """ Third coefficient of fourth order Brown-Conrady radial distortion (in [-inf, inf], default 0.0)"""

    brown_k4: float
    """ Fourth coefficient of fourth order Brown-Conrady radial distortion (in [-inf, inf], default 0.0)"""

    brown_p1: float
    """ First coefficient of second order Brown-Conrady tangential distortion (in [-inf, inf], default 0.0)"""

    brown_p2: float
    """ Second coefficient of second order Brown-Conrady tangential distortion (in [-inf, inf], default 0.0)"""

    distortion_model: typing.Literal["POLYNOMIAL", "DIVISION", "NUKE", "BROWN"]
    """ Distortion model used for camera lenses (default 'POLYNOMIAL')"""

    division_k1: float
    """ First coefficient of second order division distortion (in [-inf, inf], default 0.0)"""

    division_k2: float
    """ Second coefficient of second order division distortion (in [-inf, inf], default 0.0)"""

    focal_length: float
    """ Camera's focal length (in [0.0001, inf], default 0.0)"""

    focal_length_pixels: float
    """ Camera's focal length (in [0, inf], default 0.0)"""

    k1: float
    """ First coefficient of third order polynomial radial distortion (in [-inf, inf], default 0.0)"""

    k2: float
    """ Second coefficient of third order polynomial radial distortion (in [-inf, inf], default 0.0)"""

    k3: float
    """ Third coefficient of third order polynomial radial distortion (in [-inf, inf], default 0.0)"""

    nuke_k1: float
    """ First coefficient of second order Nuke distortion (in [-inf, inf], default 0.0)"""

    nuke_k2: float
    """ Second coefficient of second order Nuke distortion (in [-inf, inf], default 0.0)"""

    nuke_p1: float
    """ First coefficient of tangential Nuke distortion (in [-inf, inf], default 0.0)"""

    nuke_p2: float
    """ Second coefficient of tangential Nuke distortion (in [-inf, inf], default 0.0)"""

    pixel_aspect: float
    """ Pixel aspect ratio (in [0.1, inf], default 1.0)"""

    principal_point: typing.Any
    """ Optical center of lens (array of 2 items, in [-1, 1], default (0.0, 0.0))"""

    principal_point_pixels: typing.Any
    """ Optical center of lens in pixels (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    sensor_width: float
    """ Width of CCD sensor in millimeters (in [0, 500], default 0.0)"""

    units: typing.Literal["PIXELS", "MILLIMETERS"]
    """ Units used for camera focal length (default 'PIXELS')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingDopesheet(bpy_struct):
    """Match-moving dopesheet data"""

    show_hidden: bool
    """ Include channels from objects/bone that are not visible (default False)"""

    show_only_selected: bool
    """ Only include channels relating to selected objects and data (default False)"""

    sort_method: typing.Literal[
        "NAME", "LONGEST", "TOTAL", "AVERAGE_ERROR", "START", "END"
    ]
    """ Method to be used to sort channels in dopesheet view (default 'NAME')"""

    use_invert_sort: bool
    """ Invert sort order of dopesheet channels (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingMarker(bpy_struct):
    """Match-moving marker data for tracking"""

    co: mathutils.Vector
    """ Marker position at frame in normalized coordinates (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    frame: int
    """ Frame number marker is keyframed on (in [-inf, inf], default 0)"""

    is_keyed: bool
    """ Whether the position of the marker is keyframed or tracked (default True)"""

    mute: bool
    """ Is marker muted for current frame (default False)"""

    pattern_bound_box: typing.Any
    """ Pattern area bounding box in normalized coordinates (multi-dimensional array of 2 * 2 items, in [-inf, inf], default ((0.0, 0.0), (0.0, 0.0)), readonly)"""

    pattern_corners: typing.Any
    """ Array of coordinates which represents pattern's corners in normalized coordinates relative to marker position (multi-dimensional array of 4 * 2 items, in [-inf, inf], default ((0.0, 0.0), (0.0, 0.0), (0.0, 0.0), (0.0, 0.0)))"""

    search_max: mathutils.Vector
    """ Right-bottom corner of search area in normalized coordinates relative to marker position (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    search_min: mathutils.Vector
    """ Left-bottom corner of search area in normalized coordinates relative to marker position (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingObject(bpy_struct):
    """Match-moving object tracking and reconstruction data"""

    is_camera: bool
    """ Object is used for camera tracking (default False, readonly)"""

    keyframe_a: int
    """ First keyframe used for reconstruction initialization (in [-inf, inf], default 0)"""

    keyframe_b: int
    """ Second keyframe used for reconstruction initialization (in [-inf, inf], default 0)"""

    name: str
    """ Unique name of object (default "", never None)"""

    plane_tracks: typing.Any
    """ Collection of plane tracks in this tracking data object (default None, readonly)"""

    reconstruction: MovieTrackingReconstruction | None
    """ (readonly)"""

    scale: float
    """ Scale of object solution in camera space (in [0.0001, 10000], default 1.0)"""

    tracks: typing.Any
    """ Collection of tracks in this tracking data object (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingPlaneMarker(bpy_struct):
    """Match-moving plane marker data for tracking"""

    corners: typing.Any
    """ Array of coordinates which represents UI rectangle corners in frame normalized coordinates (multi-dimensional array of 4 * 2 items, in [-inf, inf], default ((0.0, 0.0), (0.0, 0.0), (0.0, 0.0), (0.0, 0.0)))"""

    frame: int
    """ Frame number marker is keyframed on (in [-inf, inf], default 0)"""

    mute: bool
    """ Is marker muted for current frame (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingPlaneTrack(bpy_struct):
    """Match-moving plane track data for tracking"""

    image: Image | None
    """ Image displayed in the track during editing in clip editor"""

    image_opacity: float
    """ Opacity of the image (in [0, 1], default 0.0)"""

    markers: typing.Any
    """ Collection of markers in track (default None, readonly)"""

    name: str
    """ Unique name of track (default "", never None)"""

    select: bool
    """ Plane track is selected (default False)"""

    use_auto_keying: bool
    """ Automatic keyframe insertion when moving plane corners (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingReconstruction(bpy_struct):
    """Match-moving reconstruction data from tracker"""

    average_error: float
    """ Average error of reconstruction (in [-inf, inf], default 0.0, readonly)"""

    cameras: typing.Any
    """ Collection of solved cameras (default None, readonly)"""

    is_valid: bool
    """ Whether the tracking data contains valid reconstruction information (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingSettings(bpy_struct):
    """Match moving settings"""

    clean_action: typing.Literal["SELECT", "DELETE_TRACK", "DELETE_SEGMENTS"]
    """ Cleanup action to execute (default 'SELECT')"""

    clean_error: float
    """ Effect on tracks which have a larger re-projection error (in [0, inf], default 0.0)"""

    clean_frames: int
    """ Effect on tracks which are tracked less than the specified amount of frames (in [0, inf], default 0)"""

    default_correlation_min: float
    """ Default minimum value of correlation between matched pattern and reference that is still treated as successful tracking (in [0, 1], default 0.0)"""

    default_frames_limit: int
    """ Every tracking cycle, this number of frames are tracked (in [0, 32767], default 0)"""

    default_margin: int
    """ Default distance from image boundary at which marker stops tracking (in [0, 300], default 0)"""

    default_motion_model: typing.Literal[
        "Perspective", "Affine", "LocRotScale", "LocScale", "LocRot", "Loc"
    ]
    """ Default motion model to use for tracking (default 'Loc')"""

    default_pattern_match: typing.Literal["KEYFRAME", "PREV_FRAME"]
    """ Track pattern from given frame when tracking marker to next frame (default 'KEYFRAME')"""

    default_pattern_size: int
    """ Size of pattern area for newly created tracks (in [5, 1000], default 0)"""

    default_search_size: int
    """ Size of search area for newly created tracks (in [5, 1000], default 0)"""

    default_weight: float
    """ Influence of newly created track on a final solution (in [0, 1], default 0.0)"""

    distance: float
    """ Distance between two bundles used for scene scaling (in [-inf, inf], default 1.0)"""

    object_distance: float
    """ Distance between two bundles used for object scaling (in [0.001, 10000], default 1.0)"""

    refine_intrinsics_focal_length: bool
    """ Refine focal length during camera solving (default False)"""

    refine_intrinsics_principal_point: bool
    """ Refine principal point during camera solving (default False)"""

    refine_intrinsics_radial_distortion: bool
    """ Refine radial coefficients of distortion model during camera solving (default False)"""

    refine_intrinsics_tangential_distortion: bool
    """ Refine tangential coefficients of distortion model during camera solving (default False)"""

    speed: typing.Literal["FASTEST", "DOUBLE", "REALTIME", "HALF", "QUARTER"]
    """ Limit speed of tracking to make visual feedback easier (this does not affect the tracking quality) (default 'FASTEST')"""

    use_default_blue_channel: bool
    """ Use blue channel from footage for tracking (default True)"""

    use_default_brute: bool
    """ Use a brute-force translation-only initialization when tracking (default False)"""

    use_default_green_channel: bool
    """ Use green channel from footage for tracking (default True)"""

    use_default_mask: bool
    """ Use a Grease Pencil data-block as a mask to use only specified areas of pattern when tracking (default False)"""

    use_default_normalization: bool
    """ Normalize light intensities while tracking (slower) (default False)"""

    use_default_red_channel: bool
    """ Use red channel from footage for tracking (default True)"""

    use_keyframe_selection: bool
    """ Automatically select keyframes when solving camera/object motion (default False)"""

    use_tripod_solver: bool
    """ Use special solver to track a stable camera position, such as a tripod (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingStabilization(bpy_struct):
    """2D stabilization based on tracking markers"""

    active_rotation_track_index: int | None
    """ Index of active track in rotation stabilization tracks list (in [-inf, inf], default 0)"""

    active_track_index: int | None
    """ Index of active track in translation stabilization tracks list (in [-inf, inf], default 0)"""

    anchor_frame: int
    """ Reference point to anchor stabilization (other frames will be adjusted relative to this frame's position) (in [0, 1048574], default 0)"""

    filter_type: typing.Literal["NEAREST", "BILINEAR", "BICUBIC"]
    """ Interpolation to use for sub-pixel shifts and rotations due to stabilization (default 'NEAREST')"""

    influence_location: float
    """ Influence of stabilization algorithm on footage location (in [0, 1], default 0.0)"""

    influence_rotation: float
    """ Influence of stabilization algorithm on footage rotation (in [0, 1], default 0.0)"""

    influence_scale: float
    """ Influence of stabilization algorithm on footage scale (in [0, 1], default 0.0)"""

    rotation_tracks: typing.Any
    """ Collection of tracks used for 2D stabilization (translation) (default None, readonly)"""

    scale_max: float
    """ Limit the amount of automatic scaling (in [0, 10], default 0.0)"""

    show_tracks_expanded: bool
    """ Show UI list of tracks participating in stabilization (default False)"""

    target_position: mathutils.Vector
    """ Known relative offset of original shot, will be subtracted (e.g. for panning shot, can be animated) (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    target_rotation: float
    """ Rotation present on original shot, will be compensated (e.g. for deliberate tilting) (in [-inf, inf], default 0.0)"""

    target_scale: float
    """ Explicitly scale resulting frame to compensate zoom of original shot (in [1.192e-07, inf], default 0.0)"""

    tracks: typing.Any
    """ Collection of tracks used for 2D stabilization (translation) (default None, readonly)"""

    use_2d_stabilization: bool
    """ Use 2D stabilization for footage (default False)"""

    use_autoscale: bool
    """ Automatically scale footage to cover unfilled areas when stabilizing (default False)"""

    use_stabilize_rotation: bool
    """ Stabilize detected rotation around center of frame (default False)"""

    use_stabilize_scale: bool
    """ Compensate any scale changes relative to center of rotation (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MovieTrackingTrack(bpy_struct):
    """Match-moving track data for tracking"""

    annotation: Annotation | None
    """ Annotation data for this track"""

    average_error: float
    """ Average error of re-projection (in [-inf, inf], default 0.0, readonly)"""

    bundle: mathutils.Vector
    """ Position of bundle reconstructed from this track (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    color: mathutils.Color
    """ Color of the track in the Movie Clip Editor and the 3D viewport after a solve (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    correlation_min: float
    """ Minimal value of correlation between matched pattern and reference that is still treated as successful tracking (in [0, 1], default 0.0)"""

    frames_limit: int
    """ Every tracking cycle, this number of frames are tracked (in [0, 32767], default 0)"""

    has_bundle: bool
    """ True if track has a valid bundle (default False, readonly)"""

    hide: bool
    """ Track is hidden (default False)"""

    lock: bool
    """ Track is locked and all changes to it are disabled (default False)"""

    margin: int
    """ Distance from image boundary at which marker stops tracking (in [0, 300], default 0)"""

    markers: typing.Any
    """ Collection of markers in track (default None, readonly)"""

    motion_model: typing.Literal[
        "Perspective", "Affine", "LocRotScale", "LocScale", "LocRot", "Loc"
    ]
    """ Default motion model to use for tracking (default 'Loc')"""

    name: str
    """ Unique name of track (default "", never None)"""

    offset: mathutils.Vector
    """ Offset of track from the parenting point (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    pattern_match: typing.Literal["KEYFRAME", "PREV_FRAME"]
    """ Track pattern from given frame when tracking marker to next frame (default 'KEYFRAME')"""

    select: bool
    """ Track is selected (default False)"""

    select_anchor: bool
    """ Track's anchor point is selected (default False)"""

    select_pattern: bool
    """ Track's pattern area is selected (default False)"""

    select_search: bool
    """ Track's search area is selected (default False)"""

    use_alpha_preview: bool
    """ Apply track's mask on displaying preview (default False)"""

    use_blue_channel: bool
    """ Use blue channel from footage for tracking (default True)"""

    use_brute: bool
    """ Use a brute-force translation only pre-track before refinement (default False)"""

    use_custom_color: bool
    """ Use custom color instead of theme-defined (default False)"""

    use_grayscale_preview: bool
    """ Display what the tracking algorithm sees in the preview (default False)"""

    use_green_channel: bool
    """ Use green channel from footage for tracking (default True)"""

    use_mask: bool
    """ Use a Grease Pencil data-block as a mask to use only specified areas of pattern when tracking (default False)"""

    use_normalization: bool
    """ Normalize light intensities while tracking (slower) (default False)"""

    use_red_channel: bool
    """ Use red channel from footage for tracking (default True)"""

    weight: float
    """ Influence of this track on a final solution (in [0, 1], default 0.0)"""

    weight_stab: float
    """ Influence of this track on 2D stabilization (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MulticamStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip to perform multicam editing"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    multicam_source: int
    """ (in [0, 127], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MultiplyStrip(EffectStrip, Strip, bpy_struct):
    """Multiply Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MultiresModifier(Modifier, bpy_struct):
    """Multiresolution mesh modifier"""

    boundary_smooth: Literal[bpy.stub_internal.rna_enums.SubdivisionBoundarySmoothItems]
    """ Controls how open boundaries are smoothed (default 'ALL')"""

    filepath: str
    """ Path to external displacements file (default "", never None, blend relative // prefix supported)"""

    is_external: bool
    """ Store multires displacements outside the .blend file, to save memory (default False, readonly)"""

    levels: int
    """ Number of subdivisions to use in the viewport (in [0, 255], default 0)"""

    quality: int
    """ Accuracy of vertex positions, lower value is faster but less precise (in [1, 10], default 4)"""

    render_levels: int
    """ The subdivision level visible at render time (in [0, 255], default 0)"""

    sculpt_levels: int
    """ Number of subdivisions to use in sculpt mode (in [0, 255], default 0)"""

    show_only_control_edges: bool
    """ Skip drawing/rendering of interior subdivided edges (default True)"""

    total_levels: int
    """ Number of subdivisions for which displacements are stored (in [0, 255], default 0, readonly)"""

    use_creases: bool
    """ Use mesh crease information to sharpen edges or corners (default True)"""

    use_custom_normals: bool
    """ Interpolates existing custom normals to resulting mesh (default False)"""

    use_sculpt_base_mesh: bool
    """ Make Sculpt Mode tools deform the base mesh while previewing the displacement of higher subdivision levels (default False)"""

    uv_smooth: Literal[bpy.stub_internal.rna_enums.SubdivisionUvSmoothItems]
    """ Controls how smoothing is applied to UVs (default 'PRESERVE_BOUNDARIES')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class MusgraveTexture(Texture, ID, bpy_struct):
    """Procedural musgrave texture"""

    dimension_max: float
    """ Highest fractal dimension (in [0.0001, 2], default 1.0)"""

    gain: float
    """ The gain multiplier (in [0, 6], default 1.0)"""

    lacunarity: float
    """ Gap between successive frequencies (in [0, 6], default 2.0)"""

    musgrave_type: typing.Literal[
        "MULTIFRACTAL",
        "RIDGED_MULTIFRACTAL",
        "HYBRID_MULTIFRACTAL",
        "FBM",
        "HETERO_TERRAIN",
    ]
    """ Fractal noise algorithm (default 'MULTIFRACTAL')"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_intensity: float
    """ Intensity of the noise (in [0, 10], default 1.0)"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    octaves: float
    """ Number of frequencies used (in [0, 8], default 2.0)"""

    offset: float
    """ The fractal offset (in [0, 6], default 1.0)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NDOFMotionEventData(bpy_struct):
    """NDOF motion data for window manager events"""

    progress: typing.Literal["STARTING", "IN_PROGRESS", "FINISHING"]
    """ Indicates the gesture phase (default 'STARTING', readonly)"""

    rotation: mathutils.Vector
    """ Axis-angle rotation of this motion event. The vector magnitude is the angle where 1.0 represents 360 degrees. The angle is typically scaled by the time-delta before use. (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    time_delta: float
    """ Time since previous motion event (in seconds) (in [-inf, inf], default 0.0, readonly)"""

    translation: mathutils.Vector
    """ The translation of this motion event. The range on each axis is [-1 to 1], before being multiplied by the sensitivity preference. This is typically scaled by the time-delta before use. (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NODE_AST_compositor(AssetShelf, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NODE_FH_image_node(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NlaStrip(bpy_struct):
    """A container referencing an existing Action"""

    action: Action | None
    """ Action referenced by this strip"""

    action_frame_end: float
    """ Last frame from action to use (in [-inf, inf], default 0.0)"""

    action_frame_start: float
    """ First frame from action to use (in [-inf, inf], default 0.0)"""

    action_slot: ActionSlot | None
    """ The slot identifies which sub-set of the Action is considered to be for this strip, and its name is used to find the right slot when assigning another Action"""

    action_slot_handle: int
    """ A number that identifies which sub-set of the Action is considered to be for this NLA strip (in [-inf, inf], default 0)"""

    action_suitable_slots: typing.Any
    """ The list of action slots suitable for this NLA strip (default None, readonly)"""

    active: bool | None
    """ NLA Strip is active (default False, readonly)"""

    blend_in: float
    """ Number of frames at start of strip to fade in influence (in [-inf, inf], default 0.0)"""

    blend_out: float
    """ (in [-inf, inf], default 0.0)"""

    blend_type: typing.Literal["REPLACE", "COMBINE", "ADD", "SUBTRACT", "MULTIPLY"]
    """ Method used for combining strip's result with accumulated result (default 'REPLACE')"""

    extrapolation: typing.Literal["NOTHING", "HOLD", "HOLD_FORWARD"]
    """ Action to take for gaps past the strip extents (default 'HOLD')"""

    fcurves: typing.Any
    """ F-Curves for controlling the strip's influence and timing (default None, readonly)"""

    frame_end: float
    """ (in [-inf, inf], default 0.0)"""

    frame_end_raw: float
    """ Same as frame_end, except that any value can be set, including ones that create an invalid state (in [-inf, inf], default 0.0)"""

    frame_end_ui: float
    """ End frame of the NLA strip. Note: changing this value also updates the value of the strip's repeats or its action's end frame. If only the end frame should be changed, see the "frame_end" property instead. (in [-inf, inf], default 0.0)"""

    frame_start: float
    """ (in [-inf, inf], default 0.0)"""

    frame_start_raw: float
    """ Same as frame_start, except that any value can be set, including ones that create an invalid state (in [-inf, inf], default 0.0)"""

    frame_start_ui: float
    """ Start frame of the NLA strip. Note: changing this value also updates the value of the strip's end frame. If only the start frame should be changed, see the "frame_start" property instead. (in [-inf, inf], default 0.0)"""

    influence: float
    """ Amount the strip contributes to the current result (in [0, 1], default 0.0)"""

    last_slot_identifier: str
    """ The identifier of the most recently assigned action slot. The slot identifies which sub-set of the Action is considered to be for this strip, and its identifier is used to find the right slot when assigning an Action. (default "", never None)"""

    modifiers: typing.Any
    """ Modifiers affecting all the F-Curves in the referenced Action (default None, readonly)"""

    mute: bool
    """ Disable NLA Strip evaluation (default False)"""

    name: str
    """ (default "", never None)"""

    repeat: float
    """ Number of times to repeat the action range (in [0.1, 1000], default 1.0)"""

    scale: float
    """ Scaling factor for action (in [0.0001, 1000], default 1.0)"""

    select: bool
    """ NLA Strip is selected (default False)"""

    strip_time: float
    """ Frame of referenced Action to evaluate (in [-inf, inf], default 0.0)"""

    strips: typing.Any
    """ NLA Strips that this strip acts as a container for (if it is of type Meta) (default None, readonly)"""

    type: typing.Literal["CLIP", "TRANSITION", "META", "SOUND"]
    """ Type of NLA Strip (default 'CLIP', readonly)"""

    use_animated_influence: bool
    """ Influence setting is controlled by an F-Curve rather than automatically determined (default False)"""

    use_animated_time: bool
    """ Strip time is controlled by an F-Curve rather than automatically determined (default False)"""

    use_animated_time_cyclic: bool
    """ Cycle the animated time within the action start and end (default False)"""

    use_auto_blend: bool
    """ Number of frames for Blending In/Out is automatically determined from overlapping strips (default False)"""

    use_reverse: bool
    """ NLA Strip is played back in reverse order (only when timing is automatically determined) (default False)"""

    use_sync_length: bool
    """ Update range of frames referenced from action after tweaking strip and its keyframes (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NlaTrack(bpy_struct):
    """An animation layer containing Actions referenced as NLA strips"""

    active: bool | None
    """ NLA Track is active (default False, readonly)"""

    is_override_data: bool
    """ In a local override data, whether this NLA track comes from the linked reference data, or is local to the override (default True, readonly)"""

    is_solo: bool
    """ NLA Track is evaluated itself (i.e. active Action and all other NLA Tracks in the same AnimData block are disabled) (default False)"""

    lock: bool
    """ NLA Track is locked (default False)"""

    mute: bool
    """ Disable NLA Track evaluation (default False)"""

    name: str
    """ (default "", never None)"""

    select: bool
    """ NLA Track is selected (default False)"""

    strips: typing.Any
    """ NLA Strips on this NLA-track (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Node(bpy_struct):
    """Node in a node tree"""

    bl_description: str
    """ (default "", never None)"""

    bl_height_default: float
    """ (in [0, inf], default 0.0)"""

    bl_height_max: float
    """ (in [0, inf], default 0.0)"""

    bl_height_min: float
    """ (in [0, inf], default 0.0)"""

    bl_icon: Literal[bpy.stub_internal.rna_enums.IconItems]
    """ The node icon (default 'NODE')"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ The node label (default "", never None)"""

    bl_static_type: str
    """ Legacy unique node type identifier, redundant with bl_idname property (default "", readonly, never None)"""

    bl_width_default: float
    """ (in [0, inf], default 0.0)"""

    bl_width_max: float
    """ (in [0, inf], default 0.0)"""

    bl_width_min: float
    """ (in [0, inf], default 0.0)"""

    color: mathutils.Color
    """ Custom color of the node body (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    color_tag: typing.Literal[
        "NONE",
        "ATTRIBUTE",
        "COLOR",
        "CONVERTER",
        "DISTORT",
        "FILTER",
        "GEOMETRY",
        "INPUT",
        "MATTE",
        "OUTPUT",
        "SCRIPT",
        "SHADER",
        "TEXTURE",
        "VECTOR",
        "PATTERN",
        "INTERFACE",
        "GROUP",
    ]
    """ Node header color tag (default 'NONE', readonly)"""

    dimensions: mathutils.Vector
    """ Absolute bounding box dimensions of the node (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    height: float
    """ Height of the node (in [-inf, inf], default 0.0)"""

    hide: bool
    """ (default False)"""

    inputs: typing.Any
    """ (default None, readonly)"""

    internal_links: typing.Any
    """ Internal input-to-output connections for muting (default None, readonly)"""

    label: str
    """ Optional custom node label (default "", never None)"""

    location: mathutils.Vector
    """ Location of the node within its parent frame (array of 2 items, in [-1e+06, 1e+06], default (0.0, 0.0))"""

    location_absolute: mathutils.Vector
    """ Location of the node in the entire canvas (array of 2 items, in [-1e+06, 1e+06], default (0.0, 0.0))"""

    mute: bool
    """ (default False)"""

    name: str
    """ Unique node identifier (default "", never None)"""

    outputs: typing.Any
    """ (default None, readonly)"""

    parent: Node | None
    """ Parent this node is attached to"""

    select: bool
    """ Node selection state (default False)"""

    show_options: bool
    """ (default False)"""

    show_preview: bool
    """ (default False)"""

    show_texture: bool
    """ Display node in viewport textured shading mode (default False)"""

    type: str
    """ Legacy unique node type identifier, redundant with bl_idname property (default "", readonly, never None)"""

    use_custom_color: bool
    """ Use custom color for the node (default False)"""

    warning_propagation: typing.Literal["ALL", "ERRORS_AND_WARNINGS", "ERRORS", "NONE"]
    """ The kinds of messages that should be propagated from this node to the parent group node (default 'ALL')"""

    width: float
    """ Width of the node (in [-inf, inf], default 0.0)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def socket_value_update(self, context: Context) -> None:
        """Update after property changes

        :param context: (never None)
        """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def poll(cls, node_tree: NodeTree | None) -> bool:
        """If non-null output is returned, the node type can be added to the tree

        :param node_tree: Node Tree
        :return:
        """

    def poll_instance(self, node_tree: NodeTree | None) -> bool:
        """If non-null output is returned, the node can be added to the tree

        :param node_tree: Node Tree
        :return:
        """

    def update(self) -> None:
        """Update on node graph topology changes (adding or removing nodes and links)"""

    def insert_link(self, link: NodeLink | None) -> None:
        """Handle creation of a link to or from the node

        :param link: Link, Node link that will be inserted (never None)
        """

    def init(self, context: Context) -> None:
        """Initialize a new instance of this node

        :param context: (never None)
        """

    def copy(self, node: typing_extensions.Self | None) -> None:
        """Initialize a new instance of this node from an existing node

        :param node: Node, Existing node to copy (never None)
        """

    def free(self) -> None:
        """Clean up node on removal"""

    def draw_buttons(self, context: Context, layout: UILayout | None) -> None:
        """Draw node buttons

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def draw_buttons_ext(self, context: Context, layout: UILayout | None) -> None:
        """Draw node buttons in the sidebar

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def draw_label(self) -> str:
        """Returns a dynamic label string

        :return: Label, (never None)
        """

    def debug_zone_body_lazy_function_graph(self) -> str:
        """Get the internal lazy-function graph for the body of this zone

        :return: Dot Graph, Graph in dot format
        """

    def debug_zone_lazy_function_graph(self) -> str:
        """Get the internal lazy-function graph for this zone

        :return: Dot Graph, Graph in dot format
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureInput(NodeInternal, Node, bpy_struct):
    paired_output: Node | None
    """ Zone output node that this input node is paired with (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    def pair_with_output(self, output_node: NodeInternal | None) -> bool:
        """Pair a zone input node with an output node.

        :param output_node: Output Node, Zone output node to pair with
        :return: Result, True if pairing the node was successful
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureInputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureOutput(NodeInternal, Node, bpy_struct):
    active_input_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_output_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    define_signature: bool
    """ This zone defines a closure signature that should be used by other nodes (default False)"""

    input_items: typing.Any
    """ (default None, readonly)"""

    output_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeClosureOutputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCombineBundle(NodeInternal, Node, bpy_struct):
    """Combine multiple socket values into one."""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    bundle_items: typing.Any
    """ (default None, readonly)"""

    define_signature: bool
    """ This node defines a bundle signature that should be used by other nodes (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCombineBundleItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCompositorFileOutputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    format: ImageFormatSettings | None
    """ (readonly)"""

    name: str
    """ (default "", never None)"""

    override_node_format: bool
    """ Use a different format instead of the node format for this file (default False)"""

    save_as_render: bool
    """ Apply render part of display transform when saving byte image (default False)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    vector_socket_dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeCustomGroup(Node, bpy_struct):
    """Base node type for custom registered node group types"""

    node_tree: NodeTree | None

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEnableOutput(NodeInternal, Node, bpy_struct):
    """Either pass through the input value or output the fallback value"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEnumItem(bpy_struct):
    description: str
    """ (default "", never None)"""

    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEvaluateClosure(NodeInternal, Node, bpy_struct):
    """Execute a given closure"""

    active_input_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    active_output_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    define_signature: bool
    """ This node defines a closure signature that should be used by other nodes (default False)"""

    input_items: typing.Any
    """ (default None, readonly)"""

    output_items: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEvaluateClosureInputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeEvaluateClosureOutputItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeFrame(NodeInternal, Node, bpy_struct):
    """Collect related nodes together in a common area. Useful for organization when the re-usability of a node group is not required"""

    label_size: int
    """ Font size to use for displaying the label (in [8, 64], default 0)"""

    shrink: bool
    """ Shrink the frame to minimal bounding box (default False)"""

    text: Text | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeFunctionFormatStringItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryBakeItem(bpy_struct):
    attribute_domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Attribute domain where the attribute is stored in the baked data (default 'POINT')"""

    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    is_attribute: bool
    """ Bake item is an attribute stored on a geometry (default False)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryCaptureAttributeItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    data_type: Literal[bpy.stub_internal.rna_enums.AttributeTypeItems]
    """ (default 'FLOAT')"""

    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGeometryViewerItem(bpy_struct):
    auto_remove: bool
    """ Remove the item automatically when it is unlinked (default False)"""

    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGetBundleItem(NodeInternal, Node, bpy_struct):
    """Retrieve a bundle item by path."""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ Value may be implicitly converted if the type does not match (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGroup(NodeInternal, Node, bpy_struct):
    node_tree: NodeTree | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGroupInput(NodeInternal, Node, bpy_struct):
    """Expose connected data from inside a node group as inputs to its interface"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeGroupOutput(NodeInternal, Node, bpy_struct):
    """Output data from inside of a node group"""

    is_active_output: bool
    """ True if this node is used as the active group output (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeImplicitConversion(NodeInternal, Node, bpy_struct):
    """Implicitly convert the input value to a fixed socket type"""

    data_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    socket_idname: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeInstanceHash(bpy_struct):
    """Hash table containing node instance data"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeInternal(Node, bpy_struct):
    @classmethod
    def poll(cls, node_tree: NodeTree | None) -> bool:
        """If non-null output is returned, the node type can be added to the tree

        :param node_tree: Node Tree
        :return:
        """

    def poll_instance(self, node_tree: NodeTree | None) -> bool:
        """If non-null output is returned, the node can be added to the tree

        :param node_tree: Node Tree
        :return:
        """

    def update(self) -> None:
        """Update on node graph topology changes (adding or removing nodes and links)"""

    def draw_buttons(self, context: Context, layout: UILayout | None) -> None:
        """Draw node buttons

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def draw_buttons_ext(self, context: Context, layout: UILayout | None) -> None:
        """Draw node buttons in the sidebar

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeInternalSocketTemplate(bpy_struct):
    """Type and default value of a node socket"""

    identifier: str
    """ Identifier of the socket (default "", readonly, never None)"""

    name: str
    """ Name of the socket (default "", readonly, never None)"""

    type: Literal[bpy.stub_internal.rna_enums.NodeSocketTypeItems]
    """ Data type of the socket (default 'VALUE', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeJoinBundle(NodeInternal, Node, bpy_struct):
    """Join multiple bundles together"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeLink(bpy_struct):
    """Link between nodes in a node tree"""

    from_node: Node | None
    """ (readonly)"""

    from_socket: NodeSocket | None
    """ (readonly)"""

    is_hidden: bool
    """ Link is hidden due to invisible sockets (default False, readonly)"""

    is_muted: bool
    """ Link is muted and can be ignored (default False)"""

    is_valid: bool
    """ Link is valid (default False)"""

    multi_input_sort_id: int
    """ Used to sort multiple links coming into the same input. The highest ID is at the top. (in [0, inf], default 0, readonly)"""

    to_node: Node | None
    """ (readonly)"""

    to_socket: NodeSocket | None
    """ (readonly)"""

    def swap_multi_input_sort_id(self, other: typing_extensions.Self | None) -> None:
        """Swap the order of two links connected to the same multi-input socket

        :param other: Other, The other link. Must link to the same multi-input socket. (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeReroute(NodeInternal, Node, bpy_struct):
    """A single-socket organization tool that supports one input and multiple outputs"""

    socket_idname: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSeparateBundle(NodeInternal, Node, bpy_struct):
    """Split a bundle into multiple sockets."""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    bundle_items: typing.Any
    """ (default None, readonly)"""

    define_signature: bool
    """ This node defines a bundle signature that should be used by other nodes (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSeparateBundleItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocket(bpy_struct):
    """Input or output socket of a node"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ Label to display for the socket type in the UI (default "", never None)"""

    bl_subtype_label: str
    """ Label to display for the socket subtype in the UI (default "", never None)"""

    description: str
    """ Socket tooltip (default "", never None)"""

    display_shape: typing.Literal[
        "CIRCLE",
        "SQUARE",
        "DIAMOND",
        "CIRCLE_DOT",
        "SQUARE_DOT",
        "DIAMOND_DOT",
        "LINE",
        "VOLUME_GRID",
        "LIST",
    ]
    """ Socket shape (default 'CIRCLE')"""

    enabled: bool
    """ Enable the socket (default True)"""

    hide: bool
    """ Hide the socket (default False)"""

    hide_value: bool
    """ Hide the socket input value (default False)"""

    identifier: str
    """ Unique identifier for mapping sockets (default "", readonly, never None)"""

    inferred_structure_type: Literal[
        bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems
    ]
    """ Best known structure type of the socket. This may not match the socket shape, e.g. for unlinked input sockets (default 'AUTO', readonly)"""

    is_icon_visible: bool
    """ Socket is drawn as interactive icon in the node editor (default False, readonly)"""

    is_inactive: bool
    """ Socket is grayed out because it has been detected to not have any effect on the output (default False, readonly)"""

    is_linked: bool
    """ True if the socket is connected (default False, readonly)"""

    is_multi_input: bool
    """ True if the socket can accept multiple ordered input links (default False, readonly)"""

    is_output: bool
    """ True if the socket is an output, otherwise input (default False, readonly)"""

    is_unavailable: bool
    """ True if the socket is unavailable (default False, readonly)"""

    label: str
    """ Custom dynamic defined UI label for the socket. Can be translated if translation is enabled in the preferences (default "", readonly, never None)"""

    link_limit: int
    """ Max number of links allowed for this socket (in [1, 4095], default 0)"""

    name: str
    """ Socket name (default "", never None)"""

    node: Node | None
    """ Node owning this socket (readonly)"""

    pin_gizmo: bool
    """ Keep gizmo visible even when the node is not selected (default False)"""

    select: bool
    """ True if the socket is selected (default False, readonly)"""

    show_expanded: bool
    """ Socket links are expanded in the user interface (default True)"""

    type: Literal[bpy.stub_internal.rna_enums.NodeSocketTypeItems]
    """ Data type (default 'VALUE')"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def draw(
        self,
        context: Context,
        layout: UILayout | None,
        node: Node | None,
        text: str | None,
    ) -> None:
        """Draw socket

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        :param node: Node, Node the socket belongs to (never None)
        :param text: Text, Text label to draw alongside properties (never None)
        """

    def draw_color(self, context: Context, node: Node | None) -> None:
        """Color of the socket icon

        :param context: (never None)
        :param node: Node, Node the socket belongs to (never None)
        :return: Color, (array of 4 items, in [0, 1])
        """

    @classmethod
    def draw_color_simple(cls) -> None:
        """Color of the socket icon. Used to draw sockets in places where the socket does not belong to a node, like the node interface panel. Also used to draw node sockets if draw_color is not defined.

        :return: Color, (array of 4 items, in [0, 1])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketBool(NodeSocketStandard, NodeSocket, bpy_struct):
    """Boolean value socket of a node"""

    default_value: bool
    """ (default False)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketBundle(NodeSocketStandard, NodeSocket, bpy_struct):
    """Bundle socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketClosure(NodeSocketStandard, NodeSocket, bpy_struct):
    """Closure socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketCollection(NodeSocketStandard, NodeSocket, bpy_struct):
    """Collection socket of a node"""

    default_value: Collection | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketColor(NodeSocketStandard, NodeSocket, bpy_struct):
    """RGBA color socket of a node"""

    default_value: typing.Any
    """ (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloat(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatAngle(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatColorTemperature(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatDistance(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatFactor(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [0, 1], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatFrequency(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatMass(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatPercentage(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatTime(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatTimeAbsolute(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatUnsigned(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [0, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFloatWavelength(NodeSocketStandard, NodeSocket, bpy_struct):
    """Floating-point number socket of a node"""

    default_value: float
    """ (in [-inf, inf], default 0.0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketFont(NodeSocketStandard, NodeSocket, bpy_struct):
    """Font socket of a node"""

    default_value: VectorFont | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketGeometry(NodeSocketStandard, NodeSocket, bpy_struct):
    """Geometry socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketImage(NodeSocketStandard, NodeSocket, bpy_struct):
    """Image socket of a node"""

    default_value: Image | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketInt(NodeSocketStandard, NodeSocket, bpy_struct):
    """Integer number socket of a node"""

    default_value: int
    """ (in [-inf, inf], default 0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketIntFactor(NodeSocketStandard, NodeSocket, bpy_struct):
    """Integer number socket of a node"""

    default_value: int
    """ (in [0, inf], default 1)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketIntPercentage(NodeSocketStandard, NodeSocket, bpy_struct):
    """Integer number socket of a node"""

    default_value: int
    """ (in [0, inf], default 100)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketIntUnsigned(NodeSocketStandard, NodeSocket, bpy_struct):
    """Integer number socket of a node"""

    default_value: int
    """ (in [0, inf], default 0)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketMask(NodeSocketStandard, NodeSocket, bpy_struct):
    """Mask socket of a node"""

    default_value: Mask | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketMaterial(NodeSocketStandard, NodeSocket, bpy_struct):
    """Material socket of a node"""

    default_value: Material | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketMatrix(NodeSocketStandard, NodeSocket, bpy_struct):
    """Matrix value socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketMenu(NodeSocketStandard, NodeSocket, bpy_struct):
    """Menu socket of a node"""

    default_value: str
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketObject(NodeSocketStandard, NodeSocket, bpy_struct):
    """Object socket of a node"""

    default_value: Object | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketRotation(NodeSocketStandard, NodeSocket, bpy_struct):
    """Rotation value socket of a node"""

    default_value: mathutils.Euler
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketScene(NodeSocketStandard, NodeSocket, bpy_struct):
    """Scene socket of a node"""

    default_value: Scene | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketShader(NodeSocketStandard, NodeSocket, bpy_struct):
    """Shader socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketSound(NodeSocketStandard, NodeSocket, bpy_struct):
    """Sound socket of a node"""

    default_value: Sound | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketStandard(NodeSocket, bpy_struct):
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    def draw(
        self,
        context: Context,
        layout: UILayout | None,
        node: Node | None,
        text: str | None,
    ) -> None:
        """Draw socket

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        :param node: Node, Node the socket belongs to (never None)
        :param text: Text, Text label to draw alongside properties (never None)
        """

    def draw_color(self, context: Context, node: Node | None) -> None:
        """Color of the socket icon

        :param context: (never None)
        :param node: Node, Node the socket belongs to (never None)
        :return: Color, (array of 4 items, in [0, 1])
        """

    @classmethod
    def draw_color_simple(cls) -> None:
        """Color of the socket icon

        :return: Color, (array of 4 items, in [0, 1])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketString(NodeSocketStandard, NodeSocket, bpy_struct):
    """String socket of a node"""

    default_value: str
    """ (default "", never None)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketStringFilePath(NodeSocketStandard, NodeSocket, bpy_struct):
    """String socket of a node"""

    default_value: str
    """ (default "", never None, blend relative // prefix supported)"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketText(NodeSocketStandard, NodeSocket, bpy_struct):
    """Text socket of a node"""

    default_value: Text | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketTexture(NodeSocketStandard, NodeSocket, bpy_struct):
    """Texture socket of a node"""

    default_value: Texture | None
    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVector(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVector2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVector4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorAcceleration(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorAcceleration2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorAcceleration4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorDirection(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorDirection2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorDirection4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorEuler(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Euler
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorEuler2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorEuler4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Quaternion
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorFactor(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorFactor2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 2 items, in [0, 1], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorFactor4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorPercentage(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorPercentage2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorPercentage4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorTranslation(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorTranslation2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorTranslation4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorVelocity(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorVelocity2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorVelocity4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorXYZ(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorXYZ2D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVectorXYZ4D(NodeSocketStandard, NodeSocket, bpy_struct):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeSocketVirtual(NodeSocketStandard, NodeSocket, bpy_struct):
    """Virtual socket of a node"""

    links: NodeLinks | None
    """ List of node links from or to this socket.(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeStoreBundleItem(NodeInternal, Node, bpy_struct):
    """Store a bundle item by path and data type."""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTree(ID, bpy_struct):
    """Node tree consisting of linked nodes used for shading, textures and compositing"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    annotation: Annotation | None
    """ Annotation data"""

    bl_description: str
    """ (default "", never None)"""

    bl_icon: Literal[bpy.stub_internal.rna_enums.IconItems]
    """ The node tree icon (default 'NODETREE')"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ The node tree label (default "", never None)"""

    bl_use_group_interface: bool
    """ Determines the visibility of some UI elements related to node groups (default True)"""

    color_tag: typing.Literal[
        "NONE",
        "ATTRIBUTE",
        "COLOR",
        "CONVERTER",
        "DISTORT",
        "FILTER",
        "GEOMETRY",
        "INPUT",
        "MATTE",
        "OUTPUT",
        "SCRIPT",
        "SHADER",
        "TEXTURE",
        "VECTOR",
        "PATTERN",
        "INTERFACE",
        "GROUP",
    ]
    """ Color tag of the node group which influences the header color (default 'NONE')"""

    default_group_node_width: int
    """ The width for newly created group nodes (in [60, 700], default 140)"""

    description: str
    """ Description of the node tree (default "", never None)"""

    interface: NodeTreeInterface | None
    """ Interface declaration for this node tree (readonly)"""

    links: typing.Any
    """ (default None, readonly)"""

    nodes: typing.Any
    """ (default None, readonly)"""

    type: typing.Literal[
        "UNDEFINED", "CUSTOM", "SHADER", "TEXTURE", "COMPOSITING", "GEOMETRY"
    ]
    """ Node Tree type (deprecated, bl_idname is the actual node tree type identifier) (default 'SHADER', readonly)"""

    view_center: mathutils.Vector
    """ The current location (offset) of the view for this Node Tree (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    def interface_update(self, context: Context) -> None:
        """Updated node group interface

        :param context: (never None)
        """

    def contains_tree(self, sub_tree: typing_extensions.Self | None) -> bool:
        """Check if the node tree contains another. Used to avoid creating recursive node groups.

        :param sub_tree: Node Tree, Node tree for recursive check (never None)
        :return: contained
        """

    @classmethod
    def poll(cls, context: Context) -> bool:
        """Check visibility in the editor

        :param context: (never None)
        :return:
        """

    def update(self) -> None:
        """Update on editor changes"""

    @classmethod
    def get_from_context(cls, context: Context) -> tuple[NodeTree, ID, ID]:
        """Get a node tree from the context

                :param context: (never None)
                :return: result_1, Active node tree from context, `NodeTree`

        result_2, ID data-block that owns the node tree, `ID`

        result_3, Original ID data-block selected from the context, `ID`
        """

    @classmethod
    def valid_socket_type(cls, idname: str | None) -> bool:
        """Check if the socket type is valid for the node tree

        :param idname: Socket Type, Identifier of the socket type (never None)
        :return:
        """

    def debug_lazy_function_graph(self) -> str:
        """Get the internal lazy-function graph for this node tree

        :return: Dot Graph, Graph in dot format
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterface(bpy_struct):
    """Declaration of sockets and ui panels of a node group"""

    active: NodeTreeInterfaceItem | None
    """ Active item"""

    active_index: int | None
    """ Index of the active item (in [0, inf], default 0)"""

    items_tree: typing.Any
    """ Items in the node interface (default None, readonly)"""

    def new_socket(
        self,
        name: str | None,
        *,
        description: str | None = "",
        in_out: typing.Literal["INPUT", "OUTPUT"] | None = "INPUT",
        socket_type: typing.Literal["DEFAULT"] | None = "DEFAULT",
        parent: NodeTreeInterfacePanel | None = None,
    ) -> NodeTreeInterfaceSocket:
        """Add a new socket to the interface

                :param name: Name, Name of the socket (never None)
                :param description: Description, Description of the socket (optional, never None)
                :param in_out: Input/Output Type, Create an input or output socket (optional)

        INPUT
        Input -- Generate a input node socket.

        OUTPUT
        Output -- Generate a output node socket.
                :param socket_type: Socket Type, Type of socket generated on nodes (optional)
                :param parent: Parent, Panel to add the socket in (optional)
                :return: Socket, New socket
        """

    def new_panel(
        self,
        name: str | None,
        *,
        description: str | None = "",
        default_closed: bool | None = False,
    ) -> NodeTreeInterfacePanel:
        """Add a new panel to the interface

        :param name: Name, Name of the new panel (never None)
        :param description: Description, Description of the panel (optional, never None)
        :param default_closed: Default Closed, Panel is closed by default on new nodes (optional)
        :return: Panel, New panel
        """

    def copy(self, item: NodeTreeInterfaceItem | None) -> NodeTreeInterfaceItem:
        """Add a copy of an item to the interface

        :param item: Item, Item to copy (never None)
        :return: Item Copy, Copy of the item
        """

    def remove(
        self,
        item: NodeTreeInterfaceItem | None,
        *,
        move_content_to_parent: bool | None = True,
    ) -> None:
        """Remove an item from the interface

        :param item: Item, The item to remove (never None)
        :param move_content_to_parent: Move Content, If the item is a panel, move the contents to the parent instead of deleting it (optional)
        """

    def clear(self) -> None:
        """Remove all items from the interface"""

    def move(self, item: NodeTreeInterfaceItem | None, to_position: int | None) -> None:
        """Move an item to another position

        :param item: Item, The item to move (never None)
        :param to_position: To Position, Target position for the item in its current panel (in [0, inf])
        """

    def move_to_parent(
        self,
        item: NodeTreeInterfaceItem | None,
        parent: NodeTreeInterfacePanel | None,
        to_position: int | None,
    ) -> None:
        """Move an item to a new panel and/or position.

        :param item: Item, The item to move (never None)
        :param parent: Parent, New parent of the item
        :param to_position: To Position, Target position for the item in the new parent panel (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceItem(bpy_struct):
    """Item in a node tree interface"""

    index: int
    """ Global index of the item among all items in the interface (in [-1, inf], default 0, readonly)"""

    item_type: Literal[bpy.stub_internal.rna_enums.NodeTreeInterfaceItemTypeItems]
    """ Type of interface item (default 'PANEL', readonly)"""

    parent: NodeTreeInterfacePanel | None
    """ Panel that contains the item (readonly)"""

    position: int
    """ Position of the item in its parent panel (in [-1, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfacePanel(NodeTreeInterfaceItem, bpy_struct):
    """Declaration of a node panel"""

    default_closed: bool
    """ Panel is closed by default on new nodes (default False)"""

    description: str
    """ Panel description (default "", never None)"""

    interface_items: typing.Any
    """ Items in the node panel (default None, readonly)"""

    name: str
    """ Panel name (default "", never None)"""

    persistent_uid: int
    """ Unique identifier for this panel within this node tree (in [-inf, inf], default 0, readonly)"""

    select: bool
    """ Panel is selected in the interface (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocket(NodeTreeInterfaceItem, bpy_struct):
    """Declaration of a node socket"""

    attribute_domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Attribute domain used by the geometry nodes modifier to create an attribute output (default 'POINT')"""

    bl_socket_idname: str
    """ Name of the socket type (default "", never None)"""

    default_attribute_name: str
    """ The attribute name used by default when the node group is used by a geometry nodes modifier (default "", never None)"""

    default_input: typing.Literal[
        "VALUE",
        "INDEX",
        "ID_OR_INDEX",
        "NORMAL",
        "POSITION",
        "INSTANCE_TRANSFORM",
        "HANDLE_LEFT",
        "HANDLE_RIGHT",
    ]
    """ Input to use when the socket is unconnected. Requires "Hide Value". (default 'VALUE')"""

    description: str
    """ Socket description (default "", never None)"""

    force_non_field: bool
    """ Only allow single value inputs rather than field.
Deprecated. Will be remove in 5.0.(default False)"""

    hide_in_modifier: bool
    """ Don't show the input value in the geometry nodes modifier interface (default False)"""

    hide_value: bool
    """ Hide the socket input value even when the socket is not connected (default False)"""

    identifier: str
    """ Unique identifier for mapping sockets (default "", readonly, never None)"""

    in_out: typing.Literal["INPUT", "OUTPUT"]
    """ Input or output socket type (default 'INPUT', readonly)"""

    is_inspect_output: bool
    """ Take link out of node group to connect to root tree output node (default False)"""

    is_panel_toggle: bool
    """ This socket is meant to be used as the toggle in its panel header (default False)"""

    layer_selection_field: bool
    """ Take Grease Pencil Layer or Layer Group as selection field (default False)"""

    menu_expanded: bool
    """ Draw the menu socket as an expanded drop-down menu (default False)"""

    name: str
    """ Socket name (default "", never None)"""

    optional_label: bool
    """ Indicate that the label of this socket is not necessary to understand its meaning. This may result in the label being skipped in some cases (default False)"""

    select: bool
    """ Socket is selected in the interface (default False)"""

    socket_type: typing.Literal["DEFAULT"]
    """ Type of the socket generated by this interface item (default 'DEFAULT')"""

    structure_type: Literal[bpy.stub_internal.rna_enums.NodeSocketStructureTypeItems]
    """ What kind of higher order types are expected to flow through this socket (default 'AUTO')"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw properties of the socket interface

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketBool(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Boolean value socket of a node"""

    default_value: bool
    """ Input value used for unconnected socket (default False)"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketBundle(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Bundle socket of a node"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketClosure(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Closure socket of a node"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketCollection(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Collection socket of a node"""

    default_value: Collection | None
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketColor(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """RGBA color socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloat(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatAngle(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatColorTemperature(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatDistance(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatFactor(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [0, 1], default 1.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatFrequency(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatMass(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatPercentage(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 100.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatTime(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatTimeAbsolute(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatUnsigned(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [0, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFloatWavelength(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Floating-point number socket of a node"""

    default_value: float
    """ Input value used for unconnected socket (in [-inf, inf], default 0.0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketFont(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Font socket of a node"""

    default_value: VectorFont | None
    """ Input value used for unconnected socket"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketGeometry(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Geometry socket of a node"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketImage(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Image socket of a node"""

    default_value: Image | None
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketInt(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Integer number socket of a node"""

    default_value: int
    """ Input value used for unconnected socket (in [-inf, inf], default 0)"""

    max_value: int
    """ Maximum value (in [-inf, inf], default 0)"""

    min_value: int
    """ Minimum value (in [-inf, inf], default 0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketIntFactor(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Integer number socket of a node"""

    default_value: int
    """ Input value used for unconnected socket (in [0, inf], default 0)"""

    max_value: int
    """ Maximum value (in [-inf, inf], default 0)"""

    min_value: int
    """ Minimum value (in [-inf, inf], default 0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketIntPercentage(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Integer number socket of a node"""

    default_value: int
    """ Input value used for unconnected socket (in [0, inf], default 0)"""

    max_value: int
    """ Maximum value (in [-inf, inf], default 0)"""

    min_value: int
    """ Minimum value (in [-inf, inf], default 0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketIntUnsigned(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Integer number socket of a node"""

    default_value: int
    """ Input value used for unconnected socket (in [0, inf], default 0)"""

    max_value: int
    """ Maximum value (in [-inf, inf], default 0)"""

    min_value: int
    """ Minimum value (in [-inf, inf], default 0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketMask(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Mask socket of a node"""

    default_value: Mask | None
    """ Input value used for unconnected socket"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketMaterial(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Material socket of a node"""

    default_value: Material | None
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketMatrix(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Matrix value socket of a node"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketMenu(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Menu socket of a node"""

    default_value: str
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketObject(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Object socket of a node"""

    default_value: Object | None
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketRotation(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Rotation value socket of a node"""

    default_value: mathutils.Euler
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketScene(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Scene socket of a node"""

    default_value: Scene | None
    """ Input value used for unconnected socket"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketShader(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Shader socket of a node"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketSound(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Sound socket of a node"""

    default_value: Sound | None
    """ Input value used for unconnected socket"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketString(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """String socket of a node"""

    default_value: str
    """ Input value used for unconnected socket (default "", never None)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketStringFilePath(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """String socket of a node"""

    default_value: str
    """ Input value used for unconnected socket (default "", never None)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketText(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Text socket of a node"""

    default_value: Text | None
    """ Input value used for unconnected socket"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketTexture(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """Texture socket of a node"""

    default_value: Texture | None
    """ Input value used for unconnected socket"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVector(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVector2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVector4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorAcceleration(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorAcceleration2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorAcceleration4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorDirection(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorDirection2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorDirection4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorEuler(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Euler
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorEuler2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorEuler4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Quaternion
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorFactor(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorFactor2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 2 items, in [0, 1], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorFactor4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorPercentage(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorPercentage2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorPercentage4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: typing.Any
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorTranslation(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorTranslation2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorTranslation4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorVelocity(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorVelocity2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorVelocity4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorXYZ(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorXYZ2D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreeInterfaceSocketVectorXYZ4D(
    NodeTreeInterfaceSocket, NodeTreeInterfaceItem, bpy_struct
):
    """3D vector socket of a node"""

    default_value: mathutils.Vector
    """ Input value used for unconnected socket (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    dimensions: int
    """ Dimensions of the vector socket (in [2, 4], default 0)"""

    max_value: float
    """ Maximum value (in [-inf, inf], default 0.0)"""

    min_value: float
    """ Minimum value (in [-inf, inf], default 0.0)"""

    subtype: typing.Literal["DEFAULT"]
    """ Subtype of the default value (default 'DEFAULT')"""

    def draw(self, context: Context, layout: UILayout | None) -> None:
        """Draw interface socket settings

        :param context: (never None)
        :param layout: Layout, Layout in the UI (never None)
        """

    def init_socket(
        self, node: Node | None, socket: NodeSocket | None, data_path: str | None
    ) -> None:
        """Initialize a node socket instance

        :param node: Node, Node of the socket to initialize (never None)
        :param socket: Socket, Socket to initialize (never None)
        :param data_path: Data Path, Path to specialized socket data (never None)
        """

    def from_socket(self, node: Node | None, socket: NodeSocket | None) -> None:
        """Setup template parameters from an existing socket

        :param node: Node, Node of the original socket (never None)
        :param socket: Socket, Original socket (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodeTreePath(bpy_struct):
    """Element of the node space tree path"""

    node_tree: NodeTree | None
    """ Base node tree from context (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifier(Modifier, bpy_struct):
    bake_directory: str
    """ Location on disk where the bake data is stored (default "", never None, blend relative // prefix supported)"""

    bake_target: typing.Literal["PACKED", "DISK"]
    """ Where to store the baked data (default 'PACKED')"""

    bakes: typing.Any
    """ (default None, readonly)"""

    node_group: NodeTree | None
    """ Node group that controls what this modifier does"""

    node_warnings: typing.Any
    """ (default None, readonly)"""

    open_bake_data_blocks_panel: bool
    """ (default False)"""

    open_bake_panel: bool
    """ (default False)"""

    open_manage_panel: bool
    """ (default False)"""

    open_named_attributes_panel: bool
    """ (default False)"""

    open_output_attributes_panel: bool
    """ (default False)"""

    open_warnings_panel: bool
    """ (default False)"""

    panels: typing.Any
    """ (default None, readonly)"""

    show_group_selector: bool
    """ (default False)"""

    show_manage_panel: bool
    """ (default False)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def is_input_visible(self, identifier: str | None) -> bool:
        """Check whether an input is currently visible based on modifier settings.

        :param identifier: The identifier of the input (never None)
        :return: Result
        """

    def is_input_used(self, identifier: str | None) -> bool:
        """Check whether an input is currently used based on modifier settings.

        :param identifier: The identifier of the input (never None)
        :return: Result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierBake(bpy_struct):
    bake_id: int
    """ Identifier for this bake which remains unchanged even when the bake node is renamed, grouped or ungrouped (in [-inf, inf], default 0, readonly)"""

    bake_mode: typing.Literal["ANIMATION", "STILL"]
    """ (default 'ANIMATION')"""

    bake_target: typing.Literal["INHERIT", "PACKED", "DISK"]
    """ Where to store the baked data (default 'INHERIT')"""

    data_blocks: typing.Any
    """ (default None, readonly)"""

    directory: str
    """ Location on disk where the bake data is stored (default "", never None, blend relative // prefix supported)"""

    frame_end: int
    """ Frame where the baking ends (in [-inf, inf], default 0)"""

    frame_start: int
    """ Frame where the baking starts (in [-inf, inf], default 0)"""

    node: Node | None
    """ Bake node or simulation output node that corresponds to this bake. This node may be deeply nested in the modifier node group. It can be none in some cases like missing linked data blocks. (readonly)"""

    use_custom_path: bool
    """ Specify a path where the baked data should be stored manually (default False)"""

    use_custom_simulation_frame_range: bool
    """ Override the simulation frame range from the scene (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierDataBlock(bpy_struct):
    id: ID | None
    id_name: str
    """ Name that is mapped to the referenced data-block (default "", readonly, never None)"""

    id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ (default 'ACTION', readonly)"""

    lib_name: str
    """ Used when the data block is not local to the current .blend file but is linked from some library (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierPanel(bpy_struct):
    is_open: bool
    """ Whether the panel is expanded or closed (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NodesModifierWarning(bpy_struct):
    """Warning created during evaluation of a geometry nodes modifier"""

    message: str
    """ (default "", readonly, never None)"""

    type: Literal[bpy.stub_internal.rna_enums.NodeWarningTypeItems]
    """ (default 'ERROR', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NoiseTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class NormalEditModifier(Modifier, bpy_struct):
    """Modifier affecting/generating custom normals"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    mix_factor: float
    """ How much of generated normals to mix with existing ones (in [0, 1], default 1.0)"""

    mix_limit: float
    """ Maximum angle between old and new normals (in [0, 3.14159], default 3.14159)"""

    mix_mode: typing.Literal["COPY", "ADD", "SUB", "MUL"]
    """ How to mix generated normals with existing ones (default 'COPY')"""

    mode: typing.Literal["RADIAL", "DIRECTIONAL"]
    """ How to affect (generate) normals (default 'RADIAL')"""

    no_polynors_fix: bool
    """ Do not flip polygons when their normals are not consistent with their newly computed custom vertex normals (default False)"""

    offset: mathutils.Vector
    """ Offset from object's center (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    target: Object | None
    """ Target object used to affect normals"""

    use_direction_parallel: bool
    """ Use same direction for all normals, from origin to target's center (Directional mode only) (default True)"""

    vertex_group: str
    """ Vertex group name for selecting/weighting the affected areas (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Object(ID, bpy_struct):
    """Object data-block defining an object in a scene"""

    active_material: Material | None
    """ Active material being displayed"""

    active_material_index: int | None
    """ Index of active material slot (in [0, inf], default 0)"""

    active_selection_set: int | None
    """ Index of the currently active selection set (in [-inf, inf], default 0)"""

    active_shape_key: ShapeKey | None
    """ Current shape key (readonly)"""

    active_shape_key_index: int | None
    """ Current shape key index (in [-32768, 32767], default 0)"""

    add_rest_position_attribute: bool
    """ Add a "rest_position" attribute that is a copy of the position attribute before shape keys and modifiers are evaluated (default False)"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    animation_visualization: AnimViz | None
    """ Animation data for this data-block (readonly, never None)"""

    bound_box: typing.Any
    """ Object's bounding box in object-space coordinates, all values are -1.0 when not available (multi-dimensional array of 8 * 3 items, in [-inf, inf], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), readonly)"""

    collision: CollisionSettings | None
    """ Settings for using the object as a collider in physics simulation (readonly)"""

    color: typing.Any
    """ Object color and alpha, used when the Object Color mode is enabled (array of 4 items, in [0, inf], default (1.0, 1.0, 1.0, 1.0))"""

    constraints: typing.Any
    """ Constraints affecting the transformation of the object (default None, readonly)"""

    cycles: typing.Any
    """ Cycles object settings (readonly)"""

    data: Armature | Camera | Curve | Curves | GreasePencil | Lattice | Light | LightProbe | Mesh | MetaBall | PointCloud | Speaker | SurfaceCurve | TextCurve | Volume | None
    delta_location: mathutils.Vector
    """ Extra translation added to the location of the object (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    delta_rotation_euler: mathutils.Euler
    """ Extra rotation added to the rotation of the object (when using Euler rotations) (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    delta_rotation_quaternion: mathutils.Quaternion
    """ Extra rotation added to the rotation of the object (when using Quaternion rotations) (array of 4 items, in [-inf, inf], default (1.0, 0.0, 0.0, 0.0))"""

    delta_scale: mathutils.Vector
    """ Extra scaling added to the scale of the object (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    dimensions: mathutils.Vector
    """ Absolute bounding box dimensions of the object.
Warning: Assigning to it or its members multiple consecutive times will not work correctly, as this needs up-to-date evaluated data(array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    display: ObjectDisplay | None
    """ Object display settings for 3D viewport (readonly, never None)"""

    display_bounds_type: typing.Literal["BOX", "SPHERE", "CYLINDER", "CONE", "CAPSULE"]
    """ Object boundary display type (default 'BOX')"""

    display_type: typing.Literal["BOUNDS", "WIRE", "SOLID", "TEXTURED"]
    """ How to display object in viewport (default 'TEXTURED')"""

    empty_display_size: float
    """ Size of display for empties in the viewport (in [0.0001, 1000], default 1.0)"""

    empty_display_type: Literal[bpy.stub_internal.rna_enums.ObjectEmptyDrawtypeItems]
    """ Viewport display style for empties (default 'PLAIN_AXES')"""

    empty_image_depth: typing.Literal["DEFAULT", "FRONT", "BACK"]
    """ Determine which other objects will occlude the image (default 'DEFAULT')"""

    empty_image_offset: typing.Any
    """ Origin offset distance (array of 2 items, in [-inf, inf], default (-0.5, -0.5))"""

    empty_image_side: typing.Literal["DOUBLE_SIDED", "FRONT", "BACK"]
    """ Show front/back side (default 'DOUBLE_SIDED')"""

    field: FieldSettings | None
    """ Settings for using the object as a field in physics simulation (readonly)"""

    hide_probe_plane: bool
    """ Globally disable in planar light probes (default False)"""

    hide_probe_sphere: bool
    """ Globally disable in spherical light probes (default False)"""

    hide_probe_volume: bool
    """ Globally disable in volume probes (default False)"""

    hide_render: bool
    """ Globally disable in renders (default False)"""

    hide_select: bool
    """ Disable selection in viewport (default False)"""

    hide_surface_pick: bool
    """ Disable surface influence during selection, snapping and depth-picking operators. Usually used to avoid semi-transparent objects to affect scene navigation (default False)"""

    hide_viewport: bool
    """ Globally disable in viewports (default False)"""

    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly, never None)"""

    instance_collection: Collection | None
    """ Instance an existing collection"""

    instance_faces_scale: float
    """ Scale the face instance objects (in [0.001, 10000], default 1.0)"""

    instance_type: typing.Literal["NONE", "VERTS", "FACES", "COLLECTION"]
    """ If not None, object instancing method to use (default 'NONE')"""

    is_from_instancer: bool
    """ Object comes from a instancer (default False, readonly)"""

    is_from_set: bool
    """ Object comes from a background set (default False, readonly)"""

    is_holdout: bool
    """ Render objects as a holdout or matte, creating a hole in the image with zero alpha, to fill out in compositing with real footage or another render (default False)"""

    is_instancer: bool
    """ (default False, readonly)"""

    is_shadow_catcher: bool
    """ Only render shadows and reflections on this object, for compositing renders into real footage. Objects with this setting are considered to already exist in the footage, objects without it are synthetic objects being composited into it. (default False)"""

    light_linking: ObjectLightLinking | None
    """ Light linking settings (readonly, never None)"""

    lightgroup: str
    """ Lightgroup that the object belongs to (default "", never None)"""

    lineart: ObjectLineArt | None
    """ Line Art settings for the object (readonly)"""

    location: mathutils.Vector
    """ Location of the object (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    lock_location: typing.Any
    """ Lock editing of location when transforming (array of 3 items, default (False, False, False))"""

    lock_rotation: typing.Any
    """ Lock editing of rotation when transforming (array of 3 items, default (False, False, False))"""

    lock_rotation_w: bool
    """ Lock editing of 'angle' component of four-component rotations when transforming (default False)"""

    lock_rotations_4d: bool
    """ Lock editing of four component rotations by components (instead of as Eulers) (default True)"""

    lock_scale: typing.Any
    """ Lock editing of scale when transforming (array of 3 items, default (False, False, False))"""

    material_slots: typing.Any
    """ Material slots in the object (default None, readonly)"""

    matrix_basis: mathutils.Matrix
    """ Matrix access to location, rotation and scale (including deltas), before constraints and parenting are applied (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_local: mathutils.Matrix
    """ Parent relative transformation matrix.
Warning: Only takes into account object parenting, so e.g. in case of bone parenting you get a matrix relative to the Armature object, not to the actual parent bone(multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_parent_inverse: mathutils.Matrix
    """ Inverse of object's parent matrix at time of parenting (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((1.0, 0.0, 0.0, 0.0), (0.0, 1.0, 0.0, 0.0), (0.0, 0.0, 1.0, 0.0), (0.0, 0.0, 0.0, 1.0)))"""

    matrix_world: mathutils.Matrix
    """ Worldspace transformation matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    mode: Literal[bpy.stub_internal.rna_enums.ObjectModeItems]
    """ Object interaction mode (default 'OBJECT', readonly)"""

    modifiers: typing.Any
    """ Modifiers affecting the geometric data of the object (default None, readonly)"""

    motion_path: MotionPath | None
    """ Motion Path for this element (readonly)"""

    parent: Object | None
    """ Parent object"""

    parent_bone: str
    """ Name of parent bone in case of a bone parenting relation (default "", never None)"""

    parent_type: typing.Literal[
        "OBJECT", "ARMATURE", "LATTICE", "VERTEX", "VERTEX_3", "BONE"
    ]
    """ Type of parent relation (default 'OBJECT')"""

    parent_vertices: typing.Any
    """ Indices of vertices in case of a vertex parenting relation (array of 3 items, in [0, inf], default (0, 0, 0))"""

    particle_systems: typing.Any
    """ Particle systems emitted from the object (default None, readonly)"""

    pass_index: int
    """ Index number for the "Object Index" render pass (in [0, 32767], default 0)"""

    pose: Pose | None
    """ Current pose for armatures (readonly)"""

    rigid_body: RigidBodyObject | None
    """ Settings for rigid body simulation (readonly)"""

    rigid_body_constraint: RigidBodyConstraint | None
    """ Constraint constraining rigid bodies (readonly)"""

    rotation_axis_angle: typing.Any
    """ Angle of Rotation for Axis-Angle rotation representation (array of 4 items, in [-inf, inf], default (0.0, 0.0, 1.0, 0.0))"""

    rotation_euler: mathutils.Euler
    """ Rotation in Eulers (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation_mode: Literal[bpy.stub_internal.rna_enums.ObjectRotationModeItems]
    """ The kind of rotation to apply, values from other rotation modes are not used (default 'XYZ')"""

    rotation_quaternion: mathutils.Quaternion
    """ Rotation in Quaternions (array of 4 items, in [-inf, inf], default (1.0, 0.0, 0.0, 0.0))"""

    scale: mathutils.Vector
    """ Scaling of the object (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    selection_sets: typing.Any
    """ List of groups of bones for easy selection (default None, readonly)"""

    shader_effects: typing.Any
    """ Effects affecting display of object (default None, readonly)"""

    shadow_terminator_geometry_offset: float
    """ Offset rays from the surface to reduce shadow terminator artifact on low poly geometry. Only affects triangles at grazing angles to light (in [0, inf], default 0.1)"""

    shadow_terminator_normal_offset: float
    """ Offset rays from the surface to reduce shadow terminator artifact on low poly geometry. Only affect triangles that are affected by the geometry offset (in [0, inf], default 0.0)"""

    shadow_terminator_shading_offset: float
    """ Push the shadow terminator towards the light to hide artifacts on low poly geometry (in [0, inf], default 0.0)"""

    show_all_edges: bool
    """ Display all edges for mesh objects (default False)"""

    show_axis: bool
    """ Display the object's origin and axes (default False)"""

    show_bounds: bool
    """ Display the object's bounds (default False)"""

    show_empty_image_only_axis_aligned: bool
    """ Only display the image when it is aligned with the view axis (default False)"""

    show_empty_image_orthographic: bool
    """ Display image in orthographic mode (default True)"""

    show_empty_image_perspective: bool
    """ Display image in perspective mode (default True)"""

    show_in_front: bool
    """ Make the object display in front of others (default False)"""

    show_instancer_for_render: bool
    """ Make instancer visible when rendering (default True)"""

    show_instancer_for_viewport: bool
    """ Make instancer visible in the viewport (default True)"""

    show_name: bool
    """ Display the object's name (default False)"""

    show_only_shape_key: bool
    """ Only show the active shape key at full value (default False)"""

    show_texture_space: bool
    """ Display the object's texture space (default False)"""

    show_transparent: bool
    """ Display material transparency in the object (default False)"""

    show_wire: bool
    """ Display the object's wireframe over solid shading (default False)"""

    soft_body: SoftBodySettings | None
    """ Settings for soft body simulation (readonly)"""

    track_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ Axis that points in the 'forward' direction (applies to Instance Vertices when Align to Vertex Normal is enabled) (default 'POS_X')"""

    type: Literal[bpy.stub_internal.rna_enums.ObjectTypeItems]
    """ Type of object (default 'EMPTY', readonly)"""

    up_axis: typing.Literal["X", "Y", "Z"]
    """ Axis that points in the upward direction (applies to Instance Vertices when Align to Vertex Normal is enabled) (default 'X')"""

    use_camera_lock_parent: bool
    """ View Lock 3D viewport camera transformation affects the object's parent instead (default False)"""

    use_dynamic_topology_sculpting: bool
    """ (default False, readonly)"""

    use_empty_image_alpha: bool
    """ Use alpha blending instead of alpha test (can produce sorting artifacts) (default False)"""

    use_grease_pencil_lights: bool
    """ Lights affect Grease Pencil object (default True)"""

    use_instance_faces_scale: bool
    """ Scale instance based on face size (default False)"""

    use_instance_vertices_rotation: bool
    """ Rotate instance according to vertex normal (default False)"""

    use_mesh_mirror_x: bool
    """ Enable mesh symmetry in the X axis (default False)"""

    use_mesh_mirror_y: bool
    """ Enable mesh symmetry in the Y axis (default False)"""

    use_mesh_mirror_z: bool
    """ Enable mesh symmetry in the Z axis (default False)"""

    use_parent_final_indices: bool
    """ Use the final evaluated indices rather than the original mesh indices (default False)"""

    use_shape_key_edit_mode: bool
    """ Display shape keys in edit mode (for meshes only) (default False)"""

    use_simulation_cache: bool
    """ Cache frames during simulation nodes playback (default True)"""

    vertex_groups: typing.Any
    """ Vertex groups of the object (default None, readonly)"""

    visible_camera: bool
    """ Object visibility to camera rays (default True)"""

    visible_diffuse: bool
    """ Object visibility to diffuse rays (default True)"""

    visible_glossy: bool
    """ Object visibility to glossy rays (default True)"""

    visible_shadow: bool
    """ Object visibility to shadow rays (default True)"""

    visible_transmission: bool
    """ Object visibility to transmission rays (default True)"""

    visible_volume_scatter: bool
    """ Object visibility to volume scattering rays (default True)"""

    children: tuple[Object, ...]
    """ All the children of this object.(readonly)"""

    children_recursive: list[Object]
    """ A list of all children from this object.(readonly)"""

    users_collection: tuple[Collection, ...]
    """ The collections this object is in.(readonly)"""

    users_scene: tuple[Scene, ...]
    """ The scenes this object is in.(readonly)"""

    def select_get(self, *, view_layer: ViewLayer | None = None) -> bool:
        """Test if the object is selected. The selection state is per view layer.

        :param view_layer: Use this instead of the active view layer (optional)
        :return: Object selected
        """

    def select_set(
        self, state: bool | None, *, view_layer: ViewLayer | None = None
    ) -> None:
        """Select or deselect the object. The selection state is per view layer.

        :param state: Selection state to define
        :param view_layer: Use this instead of the active view layer (optional)
        """

    def hide_get(self, *, view_layer: ViewLayer | None = None) -> bool:
        """Test if the object is hidden for viewport editing. This hiding state is per view layer.

        :param view_layer: Use this instead of the active view layer (optional)
        :return: Object hidden
        """

    def hide_set(
        self, state: bool | None, *, view_layer: ViewLayer | None = None
    ) -> None:
        """Hide the object for viewport editing. This hiding state is per view layer.

        :param state: Hide state to define
        :param view_layer: Use this instead of the active view layer (optional)
        """

    def visible_get(
        self,
        *,
        view_layer: ViewLayer | None = None,
        viewport: SpaceView3D | None = None,
    ) -> bool:
        """Test if the object is visible in the 3D viewport, taking into account all visibility settings

        :param view_layer: Use this instead of the active view layer (optional)
        :param viewport: Use this instead of the active 3D viewport (optional)
        :return: Object visible
        """

    def holdout_get(self, *, view_layer: ViewLayer | None = None) -> bool:
        """Test if object is masked in the view layer

        :param view_layer: Use this instead of the active view layer (optional)
        :return: Object holdout
        """

    def indirect_only_get(self, *, view_layer: ViewLayer | None = None) -> bool:
        """Test if object is set to contribute only indirectly (through shadows and reflections) in the view layer

        :param view_layer: Use this instead of the active view layer (optional)
        :return: Object indirect only
        """

    def local_view_get(self, viewport: SpaceView3D | None) -> bool:
        """Get the local view state for this object

        :param viewport: Viewport in local view (never None)
        :return: Object local view state
        """

    def local_view_set(self, viewport: SpaceView3D | None, state: bool | None) -> None:
        """Set the local view state for this object

        :param viewport: Viewport in local view (never None)
        :param state: Local view state to define
        """

    def visible_in_viewport_get(self, viewport: SpaceView3D | None) -> bool:
        """Check for local view and local collections for this viewport and object

        :param viewport: Viewport in local collections (never None)
        :return: Object viewport visibility
        """

    def convert_space(
        self,
        *,
        pose_bone: PoseBone | None = None,
        matrix: collections.abc.Sequence[collections.abc.Sequence[float]]
        | mathutils.Matrix
        | None = (
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
            (0.0, 0.0, 0.0, 0.0),
        ),
        from_space: typing.Literal["WORLD", "POSE", "LOCAL_WITH_PARENT", "LOCAL"]
        | None = "WORLD",
        to_space: typing.Literal["WORLD", "POSE", "LOCAL_WITH_PARENT", "LOCAL"]
        | None = "WORLD",
    ) -> mathutils.Matrix:
        """Convert (transform) the given matrix from one space to another

                :param pose_bone: Bone to use to define spaces (may be None, in which case only the two WORLD and LOCAL spaces are usable) (optional)
                :param matrix: The matrix to transform (multi-dimensional array of 4 * 4 items, in [-inf, inf], optional)
                :param from_space: The space in which matrix is currently (optional)

        WORLD
        World Space -- The most global space in Blender.

        POSE
        Pose Space -- The pose space of a bone (its armatures object space).

        LOCAL_WITH_PARENT
        Local With Parent -- The rest pose local space of a bone (this matrix includes parent transforms).

        LOCAL
        Local Space -- The local space of an object/bone.
                :param to_space: The space to which you want to transform matrix (optional)

        WORLD
        World Space -- The most global space in Blender.

        POSE
        Pose Space -- The pose space of a bone (its armatures object space).

        LOCAL_WITH_PARENT
        Local With Parent -- The rest pose local space of a bone (this matrix includes parent transforms).

        LOCAL
        Local Space -- The local space of an object/bone.
                :return: The transformed matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    def calc_matrix_camera(
        self,
        depsgraph: Depsgraph | None,
        *,
        x: int | None = 1,
        y: int | None = 1,
        scale_x: float | None = 1.0,
        scale_y: float | None = 1.0,
    ) -> mathutils.Matrix:
        """Generate the camera projection matrix of this object (mostly useful for Camera and Light types)

        :param depsgraph: Depsgraph to get evaluated data from
        :param x: Width of the render area (in [0, inf], optional)
        :param y: Height of the render area (in [0, inf], optional)
        :param scale_x: Width scaling factor (in [1e-06, inf], optional)
        :param scale_y: Height scaling factor (in [1e-06, inf], optional)
        :return: The camera projection matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    def camera_fit_coords(
        self,
        depsgraph: Depsgraph | None,
        coordinates: collections.abc.Sequence[float] | None,
    ) -> tuple[mathutils.Vector, float]:
        """Compute the coordinate (and scale for ortho cameras) given object should be to see all given coordinates

                :param depsgraph: Depsgraph to get evaluated data from
                :param coordinates: Coordinates to fit in (array of 1 items, in [-inf, inf], never None)
                :return: co_return, The location to aim to be able to see all given points, `mathutils.Vector`

        scale_return, The ortho scale to aim to be able to see all given points (if relevant), float
        """

    def crazyspace_eval(self, depsgraph: Depsgraph | None, scene: Scene | None) -> None:
        """Compute orientation mapping between vertices of an original object and object with shape keys and deforming modifiers applied.The evaluation is to be freed with the crazyspace_eval_free function

        :param depsgraph: Dependency Graph, Evaluated dependency graph
        :param scene: Scene, Scene of the object
        """

    def crazyspace_displacement_to_deformed(
        self,
        *,
        vertex_index: int | None = 0,
        displacement: collections.abc.Sequence[float] | mathutils.Vector | None = (
            0.0,
            0.0,
            0.0,
        ),
    ) -> mathutils.Vector:
        """Convert displacement vector from non-deformed object space to deformed object space

        :param vertex_index: vertex_index, (in [-inf, inf], optional)
        :param displacement: displacement, (array of 3 items, in [-inf, inf], optional)
        :return: displacement_deformed, (array of 3 items, in [-inf, inf])
        """

    def crazyspace_displacement_to_original(
        self,
        *,
        vertex_index: int | None = 0,
        displacement: collections.abc.Sequence[float] | mathutils.Vector | None = (
            0.0,
            0.0,
            0.0,
        ),
    ) -> mathutils.Vector:
        """Free evaluated state of crazyspace

        :param vertex_index: vertex_index, (in [-inf, inf], optional)
        :param displacement: displacement, (array of 3 items, in [-inf, inf], optional)
        :return: displacement_original, (array of 3 items, in [-inf, inf])
        """

    def crazyspace_eval_clear(self) -> None:
        """crazyspace_eval_clear"""

    def to_mesh(
        self,
        *,
        preserve_all_data_layers: bool | None = False,
        depsgraph: Depsgraph | None = None,
    ) -> Mesh:
        """Create a Mesh data-block from the current state of the object. The object owns the data-block. To force free it use to_mesh_clear(). The result is temporary and cannot be used by objects from the main database.

        :param preserve_all_data_layers: Preserve all data layers in the mesh, like UV maps and vertex groups. By default Blender only computes the subset of data layers needed for viewport display and rendering, for better performance. (optional)
        :param depsgraph: Dependency Graph, Evaluated dependency graph which is required when preserve_all_data_layers is true (optional)
        :return: Mesh created from object
        """

    def to_mesh_clear(self) -> None:
        """Clears mesh data-block created by to_mesh()"""

    def to_curve(
        self, depsgraph: Depsgraph | None, *, apply_modifiers: bool | None = False
    ) -> Curve:
        """Create a Curve data-block from the current state of the object. This only works for curve and text objects. The object owns the data-block. To force free it, use to_curve_clear(). The result is temporary and cannot be used by objects from the main database.

        :param depsgraph: Dependency Graph, Evaluated dependency graph
        :param apply_modifiers: Apply the deform modifiers on the control points of the curve. This is only supported for curve objects. (optional)
        :return: Curve created from object
        """

    def to_curve_clear(self) -> None:
        """Clears curve data-block created by to_curve()"""

    def find_armature(self) -> typing_extensions.Self:
        """Find armature influencing this object as a parent or via a modifier

        :return: Armature object influencing this object or nullptr
        """

    def shape_key_add(
        self, *, name: str | None = "Key", from_mix: bool | None = True
    ) -> ShapeKey:
        """Add shape key to this object

        :param name: Unique name for the new key-block (optional, never None)
        :param from_mix: Create new shape from existing mix of shapes (optional)
        :return: New shape key-block
        """

    def shape_key_remove(self, key: ShapeKey | None) -> None:
        """Remove a Shape Key from this object

        :param key: Key-block to be removed (never None)
        """

    def shape_key_clear(self) -> None:
        """Remove all Shape Keys from this object"""

    def shape_keys_selected(self) -> None:
        """Return selected shape keys

        :return: keyblocks
        """

    def ray_cast(
        self,
        origin: collections.abc.Sequence[float] | mathutils.Vector | None,
        direction: collections.abc.Sequence[float] | mathutils.Vector | None,
        *,
        distance: float | None = 1.70141e38,
        depsgraph: Depsgraph | None = None,
    ) -> tuple[bool, mathutils.Vector, mathutils.Vector, int]:
        """Cast a ray onto evaluated geometry, in object space (using contexts or provided depsgraph to get evaluated mesh if needed)

                :param origin: Origin of the ray, in object space (array of 3 items, in [-inf, inf])
                :param direction: Direction of the ray, in object space (array of 3 items, in [-inf, inf])
                :param distance: Maximum distance (in [0, inf], optional)
                :param depsgraph: Depsgraph to use to get evaluated data, when called from original object (only needed if current Contexts depsgraph is not suitable) (optional)
                :return: result, Whether the ray successfully hit the geometry, bool

        location, The hit location of this ray cast, `mathutils.Vector`

        normal, The face normal at the ray cast hit location, `mathutils.Vector`

        index, The face index, -1 when original data isnt available, int
        """

    def closest_point_on_mesh(
        self,
        origin: collections.abc.Sequence[float] | mathutils.Vector | None,
        *,
        distance: float | None = 1.84467e19,
        depsgraph: Depsgraph | None = None,
    ) -> tuple[bool, mathutils.Vector, mathutils.Vector, int]:
        """Find the nearest point on evaluated geometry, in object space (using contexts or provided depsgraph to get evaluated mesh if needed)

                :param origin: Point to find closest geometry from (in object space) (array of 3 items, in [-inf, inf])
                :param distance: Maximum distance (in [0, inf], optional)
                :param depsgraph: Depsgraph to use to get evaluated data, when called from original object (only needed if current Contexts depsgraph is not suitable) (optional)
                :return: result, Whether closest point on geometry was found, bool

        location, The location on the object closest to the point, `mathutils.Vector`

        normal, The face normal at the closest point, `mathutils.Vector`

        index, The face index, -1 when original data isnt available, int
        """

    def is_modified(
        self, scene: Scene | None, settings: typing.Literal["PREVIEW", "RENDER"] | None
    ) -> bool:
        """Determine if this object is modified from the base mesh data

                :param scene: Scene in which to check the object (never None)
                :param settings: Modifier settings to apply

        PREVIEW
        Preview -- Apply modifier preview settings.

        RENDER
        Render -- Apply modifier render settings.
                :return: Whether the object is modified
        """

    def is_deform_modified(
        self, scene: Scene | None, settings: typing.Literal["PREVIEW", "RENDER"] | None
    ) -> bool:
        """Determine if this object is modified by a deformation from the base mesh data

                :param scene: Scene in which to check the object (never None)
                :param settings: Modifier settings to apply

        PREVIEW
        Preview -- Apply modifier preview settings.

        RENDER
        Render -- Apply modifier render settings.
                :return: Whether the object is deform-modified
        """

    def update_from_editmode(self) -> bool:
        """Load the objects edit-mode data into the object data

        :return: Success
        """

    def cache_release(self) -> None:
        """Release memory used by caches associated with this object. Intended to be used by render engines only."""

    def evaluated_geometry(self) -> None:
        """Get the evaluated geometry set of this evaluated object. This only works for
        objects that contain geometry data like meshes and curves but not e.g. cameras.

                :return: The evaluated geometry.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectBase(bpy_struct):
    """An object instance in a View Layer (currently never exposed in Python API)"""

    hide_viewport: bool
    """ Temporarily hide in viewport (default False)"""

    object: Object | None
    """ Object this base links to (readonly)"""

    select: bool
    """ Object base selection state (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectDisplay(bpy_struct):
    """Object display settings for 3D viewport"""

    show_shadows: bool
    """ Object cast shadows in the 3D viewport (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectLightLinking(bpy_struct):
    blocker_collection: Collection | None
    """ Collection which defines objects which block light from this emitter"""

    receiver_collection: Collection | None
    """ Collection which defines light linking relation of this emitter"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectLineArt(bpy_struct):
    """Object Line Art settings"""

    crease_threshold: float
    """ Angles smaller than this will be treated as creases (in [0, 3.14159], default 2.44346)"""

    intersection_priority: int
    """ The intersection line will be included into the object with the higher intersection priority value (in [0, 255], default 0)"""

    usage: typing.Literal[
        "INHERIT",
        "INCLUDE",
        "OCCLUSION_ONLY",
        "EXCLUDE",
        "INTERSECTION_ONLY",
        "NO_INTERSECTION",
        "FORCE_INTERSECTION",
    ]
    """ How to use this object in Line Art calculation (default 'INHERIT')"""

    use_crease_override: bool
    """ Use this object's crease setting to overwrite scene global (default False)"""

    use_intersection_priority_override: bool
    """ Use this object's intersection priority to override collection setting (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ObjectSolverConstraint(Constraint, bpy_struct):
    """Lock motion to the reconstructed object movement"""

    camera: Object | None
    """ Camera to which motion is parented (if empty active scene camera is used)"""

    clip: MovieClip | None
    """ Movie Clip to get tracking data from"""

    object: str
    """ Movie tracking object to follow (default "", never None)"""

    set_inverse_pending: bool
    """ Set to true to request recalculation of the inverse matrix (default False)"""

    use_active_clip: bool
    """ Use active clip defined in scene (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class OceanModifier(Modifier, bpy_struct):
    """Simulate an ocean surface"""

    bake_foam_fade: float
    """ How much foam accumulates over time (baked ocean only) (in [0, inf], default 0.98)"""

    choppiness: float
    """ Choppiness of the wave's crest (adds some horizontal component to the displacement) (in [0, inf], default 1.0)"""

    damping: float
    """ Damp reflected waves going in opposite direction to the wind (in [0, 1], default 0.5)"""

    depth: float
    """ Depth of the solid ground below the water surface (in [-inf, inf], default 200.0)"""

    fetch_jonswap: float
    """ This is the distance from a lee shore, called the fetch, or the distance over which the wind blows with constant velocity. Used by 'JONSWAP' and 'TMA' models. (in [0, inf], default 120.0)"""

    filepath: str
    """ Path to a folder to store external baked images (default "", never None, blend relative // prefix supported)"""

    foam_coverage: float
    """ Amount of generated foam (in [-inf, inf], default 0.0)"""

    foam_layer_name: str
    """ Name of the vertex color layer used for foam (default "", never None)"""

    frame_end: int
    """ End frame of the ocean baking (in [-inf, inf], default 250)"""

    frame_start: int
    """ Start frame of the ocean baking (in [-inf, inf], default 1)"""

    geometry_mode: typing.Literal["GENERATE", "DISPLACE"]
    """ Method of modifying geometry (default 'GENERATE')"""

    invert_spray: bool
    """ Invert the spray direction map (default False)"""

    is_cached: bool
    """ Whether the ocean is using cached data or simulating (default False, readonly)"""

    random_seed: int
    """ Seed of the random generator (in [0, inf], default 0)"""

    repeat_x: int
    """ Repetitions of the generated surface in X (in [1, 1024], default 1)"""

    repeat_y: int
    """ Repetitions of the generated surface in Y (in [1, 1024], default 1)"""

    resolution: int
    """ Resolution of the generated surface for rendering and baking (in [1, 1024], default 7)"""

    sharpen_peak_jonswap: float
    """ Peak sharpening for 'JONSWAP' and 'TMA' models (in [0, 1], default 0.0)"""

    size: float
    """ Surface scale factor (does not affect the height of the waves) (in [0, inf], default 1.0)"""

    spatial_size: int
    """ Size of the simulation domain (in meters), and of the generated geometry (in BU) (in [-inf, inf], default 50)"""

    spectrum: typing.Literal[
        "PHILLIPS", "PIERSON_MOSKOWITZ", "JONSWAP", "TEXEL_MARSEN_ARSLOE"
    ]
    """ Spectrum to use (default 'PHILLIPS')"""

    spray_layer_name: str
    """ Name of the vertex color layer used for the spray direction map (default "", never None)"""

    time: float
    """ Current time of the simulation (in [0, inf], default 1.0)"""

    use_foam: bool
    """ Generate foam mask as a vertex color channel (default False)"""

    use_normals: bool
    """ Output normals for bump mapping - disabling can speed up performance if it's not needed (default False)"""

    use_spray: bool
    """ Generate map of spray direction as a vertex color channel (default False)"""

    viewport_resolution: int
    """ Viewport resolution of the generated surface (in [1, 1024], default 7)"""

    wave_alignment: float
    """ How much the waves are aligned to each other (in [0, 1], default 0.0)"""

    wave_direction: float
    """ Main direction of the waves when they are (partially) aligned (in [-inf, inf], default 0.0)"""

    wave_scale: float
    """ Scale of the displacement effect (in [0, inf], default 1.0)"""

    wave_scale_min: float
    """ Shortest allowed wavelength (in [0, inf], default 0.01)"""

    wind_velocity: float
    """ Wind speed (in [-inf, inf], default 30.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Operator(bpy_struct):
    """Storage of an operator being executed, or registered after execution"""

    bl_cursor_pending: Literal[bpy.stub_internal.rna_enums.WindowCursorItems]
    """ Cursor to use when waiting for the user to select a location to activate the operator (when bl_options has DEPENDS_ON_CURSOR set) (default 'DEFAULT')"""

    bl_description: str
    """ (default "", never None)"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    bl_options: set[Literal[bpy.stub_internal.rna_enums.OperatorTypeFlagItems]]
    """ Options for this operator type (default set())"""

    bl_translation_context: str
    """ (default "Operator", never None)"""

    bl_undo_group: str
    """ (default "", never None)"""

    has_reports: bool
    """ Operator has a set of reports (warnings and errors) from last execution (default False, readonly)"""

    layout: UILayout | None
    """ (readonly)"""

    macros: typing.Any
    """ (default None, readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    options: OperatorOptions | None
    """ Runtime options (readonly, never None)"""

    properties: OperatorProperties | None
    """ (readonly, never None)"""

    bl_property: str
    """ The name of a property to use as this operators primary property.
Currently this is only used to select the default property when
expanding an operator into a menu."""

    is_registered: bool

    def report(
        self,
        type: set[Literal[bpy.stub_internal.rna_enums.WmReportItems]] | None,
        message: str | None,
    ) -> None:
        """report

        :param type: Type
        :param message: Report Message, (never None)
        """

    def is_repeat(self) -> bool:
        """is_repeat

        :return: result
        """

    @classmethod
    def poll(cls, context: Context) -> bool:
        """Test if the operator can be called or not

        :param context: (never None)
        :return:
        """

    def execute(
        self, context: Context
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Execute the operator

        :param context: (never None)
        :return: result
        """

    def check(self, context: Context) -> bool:
        """Check the operator settings, return True to signal a change to redraw

        :param context: (never None)
        :return: result
        """

    def invoke(
        self, context: Context, event: Event | None
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Invoke the operator

        :param context: (never None)
        :param event: (never None)
        :return: result
        """

    def modal(
        self, context: Context, event: Event | None
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Modal operator function

        :param context: (never None)
        :param event: (never None)
        :return: result
        """

    def draw(self, context: Context) -> None:
        """Draw function for the operator

        :param context: (never None)
        """

    def cancel(self, context: Context) -> None:
        """Called when the operator is canceled

        :param context: (never None)
        """

    @classmethod
    def description(
        cls, context: Context, properties: OperatorProperties | None
    ) -> str:
        """Compute a description string that depends on parameters

        :param context: (never None)
        :param properties: (never None)
        :return: result
        """

    def as_keywords(self, *, ignore=()) -> dict[str, typing.Any]:
        """

        :param ignore:
        :return: A copy of the properties as a dictionary.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def poll_message_set(
        cls,
        message: collections.abc.Callable[..., str | None] | str | None,
        *args: typing.Any | None,
    ) -> None:
        """Set the message to show in the tool-tip when poll fails.When message is callable, additional user defined positional arguments are passed to the message function.

        :param message: The message or a function that returns the message.
        :param args: A sequence of arguments to pass to message, if its a callable, otherwise argument is not available.
        """

class OperatorFileListElement(PropertyGroup, bpy_struct):
    name: str
    """ Name of a file or directory within a file list (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class OperatorMacro(bpy_struct):
    """Storage of a sub operator in a macro after it has been added"""

    properties: OperatorProperties | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class OperatorMousePath(PropertyGroup, bpy_struct):
    """Mouse path values for operators that record such paths"""

    loc: mathutils.Vector
    """ Mouse location (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    time: float
    """ Time of mouse location (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class OperatorOptions(bpy_struct):
    """Runtime options"""

    is_grab_cursor: bool
    """ True when the cursor is grabbed (default False, readonly)"""

    is_invoke: bool
    """ True when invoked (even if only the execute callbacks available) (default False, readonly)"""

    is_repeat: bool
    """ True when run from the 'Adjust Last Operation' panel (default False, readonly)"""

    is_repeat_last: bool
    """ True when run from the operator 'Repeat Last' (default False, readonly)"""

    use_cursor_region: bool
    """ Enable to use the region under the cursor for modal execution (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class OperatorProperties(bpy_struct):
    """Input properties of an operator"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def __getattr__(self, key: str) -> typing.Any:
        """

        :param key:
        :return:
        """

    def __setattr__(self, key: str, value: typing.Any) -> None:
        """

        :param key:
        :param value:
        :return:
        """

class OperatorStrokeElement(PropertyGroup, bpy_struct):
    is_start: bool
    """ (default False)"""

    location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    mouse: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    mouse_event: mathutils.Vector
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    pressure: float
    """ Tablet pressure (in [0, 1], default 0.0)"""

    size: float
    """ Brush size in screen space (in [0, inf], default 0.0)"""

    time: float
    """ (in [0, inf], default 0.0)"""

    x_tilt: float
    """ Pen tilt from left (-1.0) to right (+1.0) (in [-1, 1], default 0.0)"""

    y_tilt: float
    """ Pen tilt from backward (-1.0) to forward (+1.0) (in [-1, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PARTICLE_UL_particle_systems(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
        _flt_flag,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        :param _flt_flag:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PHYSICS_UL_dynapaint_surfaces(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class POINTCLOUD_UL_attributes(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        attribute,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param attribute:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class POSE_UL_selection_set(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PackedFile(bpy_struct):
    """External file packed into the .blend file"""

    data: bytes
    """ Raw data (bytes, exact content of the embedded file) (default b"", readonly, never None)"""

    size: int
    """ Size of packed file in bytes (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Paint(bpy_struct):
    brush: Brush | None
    """ Active brush (readonly)"""

    brush_asset_reference: AssetWeakReference | None
    """ A weak reference to the matching brush asset, used e.g. to restore the last used brush on file load (readonly)"""

    cavity_curve: CurveMapping | None
    """ Editable cavity curve (readonly, never None)"""

    eraser_brush: Brush | None
    """ Default eraser brush for quickly alternating with the main brush"""

    eraser_brush_asset_reference: AssetWeakReference | None
    """ A weak reference to the matching brush asset, used e.g. to restore the last used brush on file load (readonly)"""

    palette: Palette | None
    """ Active Palette"""

    show_brush: bool
    """ (default True)"""

    show_brush_on_surface: bool
    """ (default False)"""

    show_bvh_nodes: bool
    """ Show the underlying BVH nodes as differently colored faces (default False)"""

    show_jitter_curve: bool
    """ (default False)"""

    show_low_resolution: bool
    """ For multires, show low resolution while navigating the view (default False)"""

    show_size_curve: bool
    """ (default False)"""

    show_strength_curve: bool
    """ (default False)"""

    tile_offset: mathutils.Vector
    """ Stride at which tiled strokes are copied (array of 3 items, in [0.01, inf], default (1.0, 1.0, 1.0))"""

    tile_x: bool
    """ Tile along X axis (default False)"""

    tile_y: bool
    """ Tile along Y axis (default False)"""

    tile_z: bool
    """ Tile along Z axis (default False)"""

    unified_paint_settings: UnifiedPaintSettings | None
    """ (readonly, never None)"""

    use_cavity: bool
    """ Mask painting according to mesh geometry cavity (default False)"""

    use_sculpt_delay_updates: bool
    """ Update the geometry when it enters the view, providing faster view navigation (default False)"""

    use_symmetry_feather: bool
    """ Reduce the strength of the brush where it overlaps symmetrical daubs (default True)"""

    use_symmetry_x: bool
    """ Mirror brush across the X axis (default False)"""

    use_symmetry_y: bool
    """ Mirror brush across the Y axis (default False)"""

    use_symmetry_z: bool
    """ Mirror brush across the Z axis (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PaintCurve(ID, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PaintModeSettings(bpy_struct):
    """Properties of paint mode"""

    canvas_image: Image | None
    """ Image used as painting target"""

    canvas_source: typing.Literal["COLOR_ATTRIBUTE", "MATERIAL", "IMAGE"]
    """ Source to select canvas from (default 'MATERIAL')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Palette(ID, bpy_struct):
    colors: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PaletteColor(bpy_struct):
    color: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    strength: float
    """ (in [0, 1], default 0.0)"""

    weight: float
    """ (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Panel(bpy_struct):
    """Panel containing UI elements"""

    bl_category: str
    """ The category (tab) in which the panel will be displayed, when applicable (default "", never None)"""

    bl_context: str
    """ The context in which the panel belongs to. (TODO: explain the possible combinations bl_context/bl_region_type/bl_space_type) (default "", never None)"""

    bl_description: str
    """ The panel tooltip (default "")"""

    bl_idname: str
    """ If this is set, the panel gets a custom ID, otherwise it takes the name of the class used to define the panel. For example, if the class name is "OBJECT_PT_hello", and bl_idname is not set by the script, then bl_idname = "OBJECT_PT_hello". (default "", never None)"""

    bl_label: str
    """ The panel label, shows up in the panel header at the right of the triangle used to collapse the panel (default "", never None)"""

    bl_options: set[
        typing.Literal[
            "DEFAULT_CLOSED", "HIDE_HEADER", "INSTANCED", "HEADER_LAYOUT_EXPAND"
        ]
    ]
    """ Options for this panel type (default set())"""

    bl_order: int
    """ Panels with lower numbers are default ordered before panels with higher numbers (in [0, inf], default 0)"""

    bl_owner_id: str
    """ The ID owning the data displayed in the panel, if any (default "", never None)"""

    bl_parent_id: str
    """ If this is set, the panel becomes a sub-panel (default "", never None)"""

    bl_region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
    """ The region where the panel is going to be used in (default 'WINDOW')"""

    bl_space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ The space where the panel is going to be used in (default 'EMPTY')"""

    bl_translation_context: str
    """ Specific translation context, only define when the label needs to be disambiguated from others using the exact same label (default "*", never None)"""

    bl_ui_units_x: int
    """ When set, defines popup panel width (in [0, inf], default 0)"""

    custom_data: Constraint | None
    """ Panel data (readonly)"""

    is_popover: bool
    """ (default False, readonly)"""

    layout: UILayout | None
    """ Defines the structure of the panel in the UI (readonly)"""

    text: str
    """ Override for the panel label in the UI (default "", never None)"""

    use_pin: bool
    """ Show the panel on all tabs (default False)"""

    is_registered: bool

    @classmethod
    def poll(cls, context: Context) -> bool:
        """If this method returns a non-null output, then the panel can be drawn

        :param context: (never None)
        :return:
        """

    def draw(self, context: Context) -> None:
        """Draw UI elements into the panel UI layout

        :param context: (never None)
        """

    def draw_header(self, context: Context) -> None:
        """Draw UI elements into the panels header UI layout

        :param context: (never None)
        """

    def draw_header_preset(self, context: Context) -> None:
        """Draw UI elements for presets in the panels header

        :param context: (never None)
        """

    @classmethod
    def append(cls, draw_func) -> None:
        """Append a draw function to this menu,
        takes the same arguments as the menus draw function

                :param draw_func:
        """

    @classmethod
    def is_extended(cls) -> None: ...
    @classmethod
    def prepend(cls, draw_func) -> None:
        """Prepend a draw function to this menu, takes the same arguments as
        the menus draw function

                :param draw_func:
        """

    @classmethod
    def remove(cls, draw_func) -> None:
        """Remove a draw function that has been added to this menu.

        :param draw_func:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Particle(bpy_struct):
    """Particle in a particle system"""

    alive_state: typing.Literal["DEAD", "UNBORN", "ALIVE", "DYING"]
    """ (default 'DEAD')"""

    angular_velocity: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    birth_time: float
    """ (in [-inf, inf], default 0.0)"""

    die_time: float
    """ (in [-inf, inf], default 0.0)"""

    hair_keys: typing.Any
    """ (default None, readonly)"""

    is_exist: bool
    """ (default True, readonly)"""

    is_visible: bool
    """ (default True, readonly)"""

    lifetime: float
    """ (in [-inf, inf], default 0.0)"""

    location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    particle_keys: typing.Any
    """ (default None, readonly)"""

    prev_angular_velocity: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    prev_location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    prev_rotation: mathutils.Quaternion
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    prev_velocity: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation: mathutils.Quaternion
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    size: float
    """ (in [-inf, inf], default 0.0)"""

    velocity: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    def uv_on_emitter(
        self, modifier: ParticleSystemModifier | None
    ) -> mathutils.Vector:
        """Obtain UV coordinates for a particle on an evaluated mesh.

        :param modifier: Particle modifier from an evaluated object (never None)
        :return: uv, (array of 2 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleBrush(bpy_struct):
    """Particle editing brush"""

    count: int
    """ Particle count (in [1, 1000], default 10)"""

    curve: CurveMapping | None
    """ (readonly)"""

    length_mode: typing.Literal["GROW", "SHRINK"]
    """ (default 'GROW')"""

    puff_mode: typing.Literal["ADD", "SUB"]
    """ (default 'ADD')"""

    size: int
    """ Radius of the brush in pixels (in [1, 32767], default 50)"""

    steps: int
    """ Brush steps (in [1, 32767], default 10)"""

    strength: float
    """ Brush strength (in [0.001, 1], default 0.5)"""

    use_puff_volume: bool
    """ Apply puff to unselected end-points (helps maintain hair volume when puffing root) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleDupliWeight(bpy_struct):
    """Weight of a particle instance object in a collection"""

    count: int
    """ The number of times this object is repeated with respect to other objects (in [0, 32767], default 0)"""

    name: str
    """ Particle instance object name (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleEdit(bpy_struct):
    """Properties of particle editing mode"""

    brush: ParticleBrush | None
    """ (readonly)"""

    default_key_count: int
    """ How many keys to make new particles with (in [2, 32767], default 5)"""

    display_step: int
    """ How many steps to display the path with (in [1, 10], default 2)"""

    emitter_distance: float
    """ Distance to keep particles away from the emitter (in [-inf, inf], default 0.25)"""

    fade_frames: int
    """ How many frames to fade (in [1, 100], default 2)"""

    is_editable: bool
    """ A valid edit mode exists (default False, readonly)"""

    is_hair: bool
    """ Editing hair (default False, readonly)"""

    object: Object | None
    """ The edited object (readonly)"""

    select_mode: typing.Literal["PATH", "POINT", "TIP"]
    """ Particle select and display mode (default 'PATH')"""

    shape_object: Object | None
    """ Outer shape to use for tools"""

    show_particles: bool
    """ Display actual particles (default False)"""

    tool: typing.Literal["COMB", "SMOOTH", "ADD", "LENGTH", "PUFF", "CUT", "WEIGHT"]
    """ (default 'COMB')"""

    type: typing.Literal["PARTICLES", "SOFT_BODY", "CLOTH"]
    """ (default 'PARTICLES')"""

    use_auto_velocity: bool
    """ Calculate point velocities automatically (default True)"""

    use_default_interpolate: bool
    """ Interpolate new particles from the existing ones (default False)"""

    use_emitter_deflect: bool
    """ Keep paths from intersecting the emitter (default True)"""

    use_fade_time: bool
    """ Fade paths and keys further away from current frame (default False)"""

    use_preserve_length: bool
    """ Keep path lengths constant (default True)"""

    use_preserve_root: bool
    """ Keep root keys unmodified (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleHairKey(bpy_struct):
    """Particle key for hair particle system"""

    co: mathutils.Vector
    """ Location of the hair key in object space (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    co_local: mathutils.Vector
    """ Location of the hair key in its local coordinate system, relative to the emitting face (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    time: float
    """ Relative time of key over hair length (in [0, inf], default 0.0)"""

    weight: float
    """ Weight for cloth simulation (in [0, 1], default 0.0)"""

    def co_object(
        self,
        object: Object | None,
        modifier: ParticleSystemModifier | None,
        particle: Particle | None,
    ) -> mathutils.Vector:
        """Obtain hairkey location with particle and modifier data

        :param object: Object (never None)
        :param modifier: Particle modifier (never None)
        :param particle: hair particle (never None)
        :return: Co, Exported hairkey location (array of 3 items, in [-inf, inf])
        """

    def co_object_set(
        self,
        object: Object | None,
        modifier: ParticleSystemModifier | None,
        particle: Particle | None,
        co: collections.abc.Sequence[float] | mathutils.Vector | None,
    ) -> None:
        """Set hairkey location with particle and modifier data

        :param object: Object (never None)
        :param modifier: Particle modifier (never None)
        :param particle: hair particle (never None)
        :param co: Co, Specified hairkey location (array of 3 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleInstanceModifier(Modifier, bpy_struct):
    """Particle system instancing modifier"""

    axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Pole axis for rotation (default 'Z')"""

    index_layer_name: str
    """ Custom data layer name for the index (default "", never None)"""

    object: Object | None
    """ Object that has the particle system"""

    particle_amount: float
    """ Amount of particles to use for instancing (in [0, 1], default 1.0)"""

    particle_offset: float
    """ Relative offset of particles to use for instancing, to avoid overlap of multiple instances (in [0, 1], default 0.0)"""

    particle_system: ParticleSystem | None
    particle_system_index: int
    """ (in [1, 32767], default 1)"""

    position: float
    """ Position along path (in [0, 1], default 1.0)"""

    random_position: float
    """ Randomize position along path (in [0, 1], default 0.0)"""

    random_rotation: float
    """ Randomize rotation around path (in [0, 1], default 0.0)"""

    rotation: float
    """ Rotation around path (in [0, 1], default 0.0)"""

    show_alive: bool
    """ Show instances when particles are alive (default True)"""

    show_dead: bool
    """ Show instances when particles are dead (default True)"""

    show_unborn: bool
    """ Show instances when particles are unborn (default True)"""

    space: typing.Literal["LOCAL", "WORLD"]
    """ Space to use for copying mesh data (default 'WORLD')"""

    use_children: bool
    """ Create instances from child particles (default False)"""

    use_normal: bool
    """ Create instances from normal particles (default True)"""

    use_path: bool
    """ Create instances along particle paths (default False)"""

    use_preserve_shape: bool
    """ Don't stretch the object (default False)"""

    use_size: bool
    """ Use particle size to scale the instances (default False)"""

    value_layer_name: str
    """ Custom data layer name for the randomized value (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleKey(bpy_struct):
    """Key location for a particle over time"""

    angular_velocity: mathutils.Vector
    """ Key angular velocity (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    location: mathutils.Vector
    """ Key location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation: mathutils.Quaternion
    """ Key rotation quaternion (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    time: float
    """ Time of key over the simulation (in [0, inf], default 0.0)"""

    velocity: mathutils.Vector
    """ Key velocity (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSettings(ID, bpy_struct):
    """Particle settings, reusable by multiple particle systems"""

    active_instanceweight: ParticleDupliWeight | None
    """ (readonly)"""

    active_instanceweight_index: int | None
    """ (in [0, inf], default 0)"""

    active_texture: Texture | None
    """ Active texture slot being displayed"""

    active_texture_index: int | None
    """ Index of active texture slot (in [0, 17], default 0)"""

    adaptive_angle: int
    """ How many degrees path has to curve to make another render segment (in [0, 45], default 5)"""

    adaptive_pixel: int
    """ How many pixels path has to cover to make another render segment (in [0, 50], default 3)"""

    angular_velocity_factor: float
    """ Angular velocity amount (in radians per second) (in [-200, 200], default 0.0)"""

    angular_velocity_mode: typing.Literal[
        "NONE",
        "VELOCITY",
        "HORIZONTAL",
        "VERTICAL",
        "GLOBAL_X",
        "GLOBAL_Y",
        "GLOBAL_Z",
        "RAND",
    ]
    """ What axis is used to change particle rotation with time (default 'VELOCITY')"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    apply_effector_to_children: bool
    """ Apply effectors to children (default False)"""

    apply_guide_to_children: bool
    """ (default False)"""

    bending_random: float
    """ Random stiffness of hairs (in [0, 1], default 0.0)"""

    boids: BoidSettings | None
    """ (readonly)"""

    branch_threshold: float
    """ Threshold of branching (in [0, 1], default 0.0)"""

    brownian_factor: float
    """ Amount of random, erratic particle movement (in [0, 200], default 0.0)"""

    child_length: float
    """ Length of child paths (in [0, 1], default 1.0)"""

    child_length_threshold: float
    """ Amount of particles left untouched by child path length (in [0, 1], default 0.0)"""

    child_parting_factor: float
    """ Create parting in the children based on parent strands (in [0, 1], default 0.0)"""

    child_parting_max: float
    """ Maximum root to tip angle (tip distance/root distance for long hair) (in [0, 180], default 0.0)"""

    child_parting_min: float
    """ Minimum root to tip angle (tip distance/root distance for long hair) (in [0, 180], default 0.0)"""

    child_percent: int
    """ Number of children per parent (in [0, 100000], default 10)"""

    child_radius: float
    """ Radius of children around parent (in [0, 100000], default 0.2)"""

    child_roundness: float
    """ Roundness of children around parent (in [0, 1], default 0.0)"""

    child_size: float
    """ A multiplier for the child particle size (in [0.001, 100000], default 1.0)"""

    child_size_random: float
    """ Random variation to the size of the child particles (in [0, 1], default 0.0)"""

    child_type: typing.Literal["NONE", "SIMPLE", "INTERPOLATED"]
    """ Create child particles (default 'NONE')"""

    clump_curve: CurveMapping | None
    """ Curve defining clump tapering (readonly)"""

    clump_factor: float
    """ Amount of clumping (in [-1, 1], default 0.0)"""

    clump_noise_size: float
    """ Size of clump noise (in [1e-05, 100000], default 1.0)"""

    clump_shape: float
    """ Shape of clumping (in [-0.999, 0.999], default 0.0)"""

    collision_collection: Collection | None
    """ Limit colliders to this collection"""

    color_maximum: float
    """ Maximum length of the particle color vector (in [0.01, 100], default 1.0)"""

    count: int
    """ Total number of particles (in [0, inf], default 1000)"""

    courant_target: float
    """ The relative distance a particle can move before requiring more subframes (target Courant number); 0.01 to 0.3 is the recommended range (in [0.0001, 10], default 0.2)"""

    create_long_hair_children: bool
    """ Calculate children that suit long hair well (default False)"""

    damping: float
    """ Amount of damping (in [0, 1], default 0.0)"""

    display_color: typing.Literal["NONE", "MATERIAL", "VELOCITY", "ACCELERATION"]
    """ Display additional particle data as a color (default 'MATERIAL')"""

    display_method: typing.Literal["NONE", "RENDER", "DOT", "CIRC", "CROSS", "AXIS"]
    """ How particles are displayed in viewport (default 'RENDER')"""

    display_percentage: int
    """ Percentage of particles to display in 3D view (in [0, 100], default 100)"""

    display_size: float
    """ Size of particles on viewport (in [0, 1000], default 0.1)"""

    display_step: int
    """ How many steps paths are displayed with (power of 2) (in [0, 10], default 2)"""

    distribution: typing.Literal["JIT", "RAND", "GRID"]
    """ How to distribute particles on selected element (default 'JIT')"""

    drag_factor: float
    """ Amount of air drag (in [0, 1], default 0.0)"""

    effect_hair: float
    """ Hair stiffness for effectors (in [0, 1], default 0.0)"""

    effector_amount: int
    """ How many particles are effectors (0 is all particles) (in [0, 10000], default 0)"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    emit_from: typing.Literal["VERT", "FACE", "VOLUME"]
    """ Where to emit particles from (default 'FACE')"""

    factor_random: float
    """ Give the starting velocity a random variation (in [0, 200], default 0.0)"""

    fluid: SPHFluidSettings | None
    """ (readonly)"""

    force_field_1: FieldSettings | None
    """ (readonly)"""

    force_field_2: FieldSettings | None
    """ (readonly)"""

    frame_end: float
    """ Frame number to stop emitting particles (in [-1.04857e+06, 1.04857e+06], default 200.0)"""

    frame_start: float
    """ Frame number to start emitting particles (in [-1.04857e+06, 1.04857e+06], default 1.0)"""

    grid_random: float
    """ Add random offset to the grid locations (in [0, 1], default 0.0)"""

    grid_resolution: int
    """ The resolution of the particle grid (in [1, 250], default 10)"""

    hair_length: float
    """ Length of the hair (in [0, 1000], default 0.0)"""

    hair_step: int
    """ Number of hair segments (in [2, 32767], default 5)"""

    hexagonal_grid: bool
    """ Create the grid in a hexagonal pattern (default False)"""

    instance_collection: Collection | None
    """ Show objects in this collection in place of particles"""

    instance_object: Object | None
    """ Show this object in place of particles"""

    instance_weights: typing.Any
    """ Weights for all of the objects in the instance collection (default None, readonly)"""

    integrator: typing.Literal["EULER", "VERLET", "MIDPOINT", "RK4"]
    """ Algorithm used to calculate physics, from the fastest to the most stable and accurate: Midpoint, Euler, Verlet, RK4 (default 'MIDPOINT')"""

    invert_grid: bool
    """ Invert what is considered object and what is not (default False)"""

    is_fluid: bool
    """ Particles were created by a fluid simulation (default False, readonly)"""

    jitter_factor: float
    """ Amount of jitter applied to the sampling (in [0, 2], default 1.0)"""

    keyed_loops: int
    """ Number of times the keys are looped (in [1, 10000], default 1)"""

    keys_step: int
    """ (in [0, 32767], default 5)"""

    kink: typing.Literal["NO", "CURL", "RADIAL", "WAVE", "BRAID", "SPIRAL"]
    """ Type of periodic offset on the path (default 'NO')"""

    kink_amplitude: float
    """ The amplitude of the offset (in [-100000, 100000], default 0.2)"""

    kink_amplitude_clump: float
    """ How much clump affects kink amplitude (in [0, 1], default 1.0)"""

    kink_amplitude_random: float
    """ Random variation of the amplitude (in [0, 1], default 0.0)"""

    kink_axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Which axis to use for offset (default 'Z')"""

    kink_axis_random: float
    """ Random variation of the orientation (in [0, 1], default 0.0)"""

    kink_extra_steps: int
    """ Extra steps for resolution of special kink features (in [1, inf], default 4)"""

    kink_flat: float
    """ How flat the hairs are (in [0, 1], default 0.0)"""

    kink_frequency: float
    """ The frequency of the offset (1/total length) (in [-100000, 100000], default 2.0)"""

    kink_shape: float
    """ Adjust the offset to the beginning/end (in [-0.999, 0.999], default 0.0)"""

    length_random: float
    """ Give path length a random variation (in [0, 1], default 0.0)"""

    lifetime: float
    """ Life span of the particles (in [1, 1.04857e+06], default 50.0)"""

    lifetime_random: float
    """ Give the particle life a random variation (in [0, 1], default 0.0)"""

    line_length_head: float
    """ Length of the line's head (in [0, 100000], default 0.0)"""

    line_length_tail: float
    """ Length of the line's tail (in [0, 100000], default 0.0)"""

    lock_boids_to_surface: bool
    """ Constrain boids to a surface (default False)"""

    mass: float
    """ Mass of the particles (in [1e-08, 100000], default 1.0)"""

    material: int
    """ Index of material slot used for rendering particles (in [1, 32767], default 1)"""

    material_slot: typing.Literal["DEFAULT"]
    """ Material slot used for rendering particles (default 'DEFAULT')"""

    normal_factor: float
    """ Let the surface normal give the particle a starting velocity (in [-1000, 1000], default 1.0)"""

    object_align_factor: mathutils.Vector
    """ Let the emitter object orientation give the particle a starting velocity (array of 3 items, in [-200, 200], default (0.0, 0.0, 0.0))"""

    object_factor: float
    """ Let the object give the particle a starting velocity (in [-200, 200], default 0.0)"""

    particle_factor: float
    """ Let the target particle give the particle a starting velocity (in [-200, 200], default 0.0)"""

    particle_size: float
    """ The size of the particles (in [0.001, 100000], default 0.05)"""

    path_end: float
    """ End time of path (in [-inf, inf], default 1.0)"""

    path_start: float
    """ Starting time of path (in [-inf, inf], default 0.0)"""

    phase_factor: float
    """ Rotation around the chosen orientation axis (in [-1, 1], default 0.0)"""

    phase_factor_random: float
    """ Randomize rotation around the chosen orientation axis (in [0, 2], default 0.0)"""

    physics_type: typing.Literal["NO", "NEWTON", "KEYED", "BOIDS", "FLUID"]
    """ Particle physics type (default 'NEWTON')"""

    radius_scale: float
    """ Multiplier of diameter properties (in [0, inf], default 0.01)"""

    react_event: typing.Literal["DEATH", "COLLIDE", "NEAR"]
    """ The event of target particles to react on (default 'DEATH')"""

    reactor_factor: float
    """ Let the vector away from the target particle's location give the particle a starting velocity (in [-10, 10], default 0.0)"""

    render_step: int
    """ How many steps paths are rendered with (power of 2) (in [0, 20], default 3)"""

    render_type: typing.Literal["NONE", "HALO", "LINE", "PATH", "OBJECT", "COLLECTION"]
    """ How particles are rendered (default 'HALO')"""

    rendered_child_count: int
    """ Number of children per parent for rendering (in [0, 100000], default 100)"""

    root_radius: float
    """ Strand diameter width at the root (in [0, inf], default 1.0)"""

    rotation_factor_random: float
    """ Randomize particle orientation (in [0, 1], default 0.0)"""

    rotation_mode: typing.Literal[
        "NONE",
        "NOR",
        "NOR_TAN",
        "VEL",
        "GLOB_X",
        "GLOB_Y",
        "GLOB_Z",
        "OB_X",
        "OB_Y",
        "OB_Z",
    ]
    """ Particle orientation axis (does not affect Explode modifier's results) (default 'VEL')"""

    roughness_1: float
    """ Amount of location dependent roughness (in [0, 100000], default 0.0)"""

    roughness_1_size: float
    """ Size of location dependent roughness (in [0.01, 100000], default 1.0)"""

    roughness_2: float
    """ Amount of random roughness (in [0, 100000], default 0.0)"""

    roughness_2_size: float
    """ Size of random roughness (in [0.01, 100000], default 1.0)"""

    roughness_2_threshold: float
    """ Amount of particles left untouched by random roughness (in [0, 1], default 0.0)"""

    roughness_curve: CurveMapping | None
    """ Curve defining roughness (readonly)"""

    roughness_end_shape: float
    """ Shape of endpoint roughness (in [0, 10], default 1.0)"""

    roughness_endpoint: float
    """ Amount of endpoint roughness (in [0, 100000], default 0.0)"""

    shape: float
    """ Strand shape parameter (in [-1, 1], default 0.0)"""

    show_guide_hairs: bool
    """ Show guide hairs (default False)"""

    show_hair_grid: bool
    """ Show hair simulation grid (default False)"""

    show_health: bool
    """ Display boid health (default False)"""

    show_number: bool
    """ Show particle number (default False)"""

    show_size: bool
    """ Show particle size (default False)"""

    show_unborn: bool
    """ Show particles before they are emitted (default False)"""

    show_velocity: bool
    """ Show particle velocity (default False)"""

    size_random: float
    """ Give the particle size a random variation (in [0, 1], default 0.0)"""

    subframes: int
    """ Subframes to simulate for improved stability and finer granularity simulations (dt = timestep / (subframes + 1)) (in [0, 1000], default 0)"""

    tangent_factor: float
    """ Let the surface tangent give the particle a starting velocity (in [-1000, 1000], default 0.0)"""

    tangent_phase: float
    """ Rotate the surface tangent (in [-1, 1], default 0.0)"""

    texture_slots: typing.Any
    """ Texture slots defining the mapping and influence of textures (default None, readonly)"""

    time_tweak: float
    """ A multiplier for physics timestep (1.0 means one frame = 1/25 seconds) (in [0, 100], default 1.0)"""

    timestep: float
    """ The simulation timestep per frame (seconds per frame) (in [0.0001, 100], default 0.0)"""

    tip_radius: float
    """ Strand diameter width at the tip (in [0, inf], default 0.0)"""

    trail_count: int
    """ Number of trail particles (in [1, 100000], default 0)"""

    twist: float
    """ Number of turns around parent along the strand (in [-100000, 100000], default 0.0)"""

    twist_curve: CurveMapping | None
    """ Curve defining twist (readonly)"""

    type: typing.Literal["EMITTER", "HAIR"]
    """ Particle type (default 'EMITTER')"""

    use_absolute_path_time: bool
    """ Path timing is in absolute frames (default False)"""

    use_adaptive_subframes: bool
    """ Automatically set the number of subframes (default False)"""

    use_advanced_hair: bool
    """ Use full physics calculations for growing hair (default False)"""

    use_close_tip: bool
    """ Set tip radius to zero (default True)"""

    use_clump_curve: bool
    """ Use a curve to define clump tapering (default False)"""

    use_clump_noise: bool
    """ Create random clumps around the parent (default False)"""

    use_collection_count: bool
    """ Use object multiple times in the same collection (default False)"""

    use_collection_pick_random: bool
    """ Pick objects from collection randomly (default False)"""

    use_dead: bool
    """ Show particles after they have died (default False)"""

    use_die_on_collision: bool
    """ Particles die when they collide with a deflector object (default False)"""

    use_dynamic_rotation: bool
    """ Particle rotations are affected by collisions and effectors (default False)"""

    use_emit_random: bool
    """ Emit in random order of elements (default True)"""

    use_even_distribution: bool
    """ Use even distribution from faces based on face areas or edge lengths (default True)"""

    use_global_instance: bool
    """ Use object's global coordinates for duplication (default False)"""

    use_hair_bspline: bool
    """ Interpolate hair using B-Splines (default False)"""

    use_modifier_stack: bool
    """ Emit particles from mesh with modifiers applied (must use same subdivision surface level for viewport and render for correct results) (default False)"""

    use_multiply_size_mass: bool
    """ Multiply mass by particle size (default False)"""

    use_parent_particles: bool
    """ Render parent particles (default False)"""

    use_react_multiple: bool
    """ React multiple times (default False)"""

    use_react_start_end: bool
    """ Give birth to unreacted particles eventually (default False)"""

    use_regrow_hair: bool
    """ Regrow hair for each frame (default False)"""

    use_render_adaptive: bool
    """ Display steps of the particle path (default False)"""

    use_rotation_instance: bool
    """ Use object's rotation for duplication (global x-axis is aligned particle rotation axis) (default False)"""

    use_rotations: bool
    """ Calculate particle rotations (default False)"""

    use_roughness_curve: bool
    """ Use a curve to define roughness (default False)"""

    use_scale_instance: bool
    """ Use object's scale for duplication (default True)"""

    use_self_effect: bool
    """ Particle effectors affect themselves (default False)"""

    use_size_deflect: bool
    """ Use particle's size in deflection (default False)"""

    use_strand_primitive: bool
    """ Use the strand primitive for rendering (default False)"""

    use_twist_curve: bool
    """ Use a curve to define twist (default False)"""

    use_velocity_length: bool
    """ Multiply line length by particle speed (default False)"""

    use_whole_collection: bool
    """ Use whole collection at once (default False)"""

    userjit: int
    """ Emission locations per face (0 = automatic) (in [0, 1000], default 0)"""

    virtual_parents: float
    """ Relative amount of virtual parents (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSettingsTextureSlot(TextureSlot, bpy_struct):
    """Texture slot for textures in a Particle Settings data-block"""

    clump_factor: float
    """ Amount texture affects child clump (in [-inf, inf], default 1.0)"""

    damp_factor: float
    """ Amount texture affects particle damping (in [-inf, inf], default 1.0)"""

    density_factor: float
    """ Amount texture affects particle density (in [-inf, inf], default 1.0)"""

    field_factor: float
    """ Amount texture affects particle force fields (in [-inf, inf], default 1.0)"""

    gravity_factor: float
    """ Amount texture affects particle gravity (in [-inf, inf], default 1.0)"""

    kink_amp_factor: float
    """ Amount texture affects child kink amplitude (in [-inf, inf], default 1.0)"""

    kink_freq_factor: float
    """ Amount texture affects child kink frequency (in [-inf, inf], default 1.0)"""

    length_factor: float
    """ Amount texture affects child hair length (in [-inf, inf], default 1.0)"""

    life_factor: float
    """ Amount texture affects particle life time (in [-inf, inf], default 1.0)"""

    mapping: typing.Literal["FLAT", "CUBE", "TUBE", "SPHERE"]
    """ (default 'FLAT')"""

    mapping_x: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'X')"""

    mapping_y: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'Y')"""

    mapping_z: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'Z')"""

    object: Object | None
    """ Object to use for mapping with Object texture coordinates"""

    rough_factor: float
    """ Amount texture affects child roughness (in [-inf, inf], default 1.0)"""

    size_factor: float
    """ Amount texture affects physical particle size (in [-inf, inf], default 1.0)"""

    texture_coords: typing.Literal["GLOBAL", "OBJECT", "UV", "ORCO", "STRAND"]
    """ Texture coordinates used to map the texture onto the background (default 'UV')"""

    time_factor: float
    """ Amount texture affects particle emission time (in [-inf, inf], default 1.0)"""

    twist_factor: float
    """ Amount texture affects child twist (in [-inf, inf], default 1.0)"""

    use_map_clump: bool
    """ Affect the child clumping (default False)"""

    use_map_damp: bool
    """ Affect the particle velocity damping (default False)"""

    use_map_density: bool
    """ Affect the density of the particles (default False)"""

    use_map_field: bool
    """ Affect the particle force fields (default False)"""

    use_map_gravity: bool
    """ Affect the particle gravity (default False)"""

    use_map_kink_amp: bool
    """ Affect the child kink amplitude (default False)"""

    use_map_kink_freq: bool
    """ Affect the child kink frequency (default False)"""

    use_map_length: bool
    """ Affect the child hair length (default False)"""

    use_map_life: bool
    """ Affect the life time of the particles (default False)"""

    use_map_rough: bool
    """ Affect the child rough (default False)"""

    use_map_size: bool
    """ Affect the particle size (default False)"""

    use_map_time: bool
    """ Affect the emission time of the particles (default True)"""

    use_map_twist: bool
    """ Affect the child twist (default False)"""

    use_map_velocity: bool
    """ Affect the particle initial velocity (default False)"""

    uv_layer: str
    """ UV map to use for mapping with UV texture coordinates (default "", never None)"""

    velocity_factor: float
    """ Amount texture affects particle initial velocity (in [-inf, inf], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSystem(bpy_struct):
    """Particle system in an object"""

    active_particle_target: ParticleTarget | None
    """ (readonly)"""

    active_particle_target_index: int | None
    """ (in [0, inf], default 0)"""

    child_particles: typing.Any
    """ Child particles generated by the particle system (default None, readonly)"""

    child_seed: int
    """ Offset in the random number table for child particles, to get a different randomized result (in [0, inf], default 0)"""

    cloth: ClothModifier | None
    """ Cloth dynamics for hair (readonly, never None)"""

    dt_frac: float
    """ The current simulation time step size, as a fraction of a frame (in [0.00990099, 1], default 0.0, readonly)"""

    has_multiple_caches: bool
    """ Particle system has multiple point caches (default False, readonly)"""

    invert_vertex_group_clump: bool
    """ Negate the effect of the clump vertex group (default False)"""

    invert_vertex_group_density: bool
    """ Negate the effect of the density vertex group (default False)"""

    invert_vertex_group_field: bool
    """ Negate the effect of the field vertex group (default False)"""

    invert_vertex_group_kink: bool
    """ Negate the effect of the kink vertex group (default False)"""

    invert_vertex_group_length: bool
    """ Negate the effect of the length vertex group (default False)"""

    invert_vertex_group_rotation: bool
    """ Negate the effect of the rotation vertex group (default False)"""

    invert_vertex_group_roughness_1: bool
    """ Negate the effect of the roughness 1 vertex group (default False)"""

    invert_vertex_group_roughness_2: bool
    """ Negate the effect of the roughness 2 vertex group (default False)"""

    invert_vertex_group_roughness_end: bool
    """ Negate the effect of the roughness end vertex group (default False)"""

    invert_vertex_group_size: bool
    """ Negate the effect of the size vertex group (default False)"""

    invert_vertex_group_tangent: bool
    """ Negate the effect of the tangent vertex group (default False)"""

    invert_vertex_group_twist: bool
    """ Negate the effect of the twist vertex group (default False)"""

    invert_vertex_group_velocity: bool
    """ Negate the effect of the velocity vertex group (default False)"""

    is_editable: bool
    """ Particle system can be edited in particle mode (default False, readonly)"""

    is_edited: bool
    """ Particle system has been edited in particle mode (default False, readonly)"""

    is_global_hair: bool
    """ Hair keys are in global coordinate space (default False, readonly)"""

    name: str
    """ Particle system name (default "", never None)"""

    parent: Object | None
    """ Use this object's coordinate system instead of global coordinate system"""

    particles: typing.Any
    """ Particles generated by the particle system (default None, readonly)"""

    point_cache: PointCache | None
    """ (readonly, never None)"""

    reactor_target_object: Object | None
    """ For reactor systems, the object that has the target particle system (empty if same object)"""

    reactor_target_particle_system: int
    """ For reactor systems, index of particle system on the target object (in [1, 32767], default 0)"""

    seed: int
    """ Offset in the random number table, to get a different randomized result (in [0, inf], default 0)"""

    settings: ParticleSettings | None
    """ Particle system settings (never None)"""

    targets: typing.Any
    """ Target particle systems (default None, readonly)"""

    use_hair_dynamics: bool
    """ Enable hair dynamics using cloth simulation (default False)"""

    use_keyed_timing: bool
    """ Use key times (default False)"""

    vertex_group_clump: str
    """ Vertex group to control clump (default "", never None)"""

    vertex_group_density: str
    """ Vertex group to control density (default "", never None)"""

    vertex_group_field: str
    """ Vertex group to control field (default "", never None)"""

    vertex_group_kink: str
    """ Vertex group to control kink (default "", never None)"""

    vertex_group_length: str
    """ Vertex group to control length (default "", never None)"""

    vertex_group_rotation: str
    """ Vertex group to control rotation (default "", never None)"""

    vertex_group_roughness_1: str
    """ Vertex group to control roughness 1 (default "", never None)"""

    vertex_group_roughness_2: str
    """ Vertex group to control roughness 2 (default "", never None)"""

    vertex_group_roughness_end: str
    """ Vertex group to control roughness end (default "", never None)"""

    vertex_group_size: str
    """ Vertex group to control size (default "", never None)"""

    vertex_group_tangent: str
    """ Vertex group to control tangent (default "", never None)"""

    vertex_group_twist: str
    """ Vertex group to control twist (default "", never None)"""

    vertex_group_velocity: str
    """ Vertex group to control velocity (default "", never None)"""

    def co_hair(
        self,
        object: Object | None,
        *,
        particle_no: int | None = 0,
        step: int | None = 0,
    ) -> mathutils.Vector:
        """Obtain cache hair data

        :param object: Object (never None)
        :param particle_no: Particle no, (in [-inf, inf], optional)
        :param step: step no, (in [-inf, inf], optional)
        :return: Co, Exported hairkey location (array of 3 items, in [-inf, inf])
        """

    def uv_on_emitter(
        self,
        modifier: ParticleSystemModifier | None,
        particle: Particle | None,
        *,
        particle_no: int | None = 0,
        uv_no: int | None = 0,
    ) -> mathutils.Vector:
        """Obtain uv for all particles

        :param modifier: Particle modifier (never None)
        :param particle: Particle (never None)
        :param particle_no: Particle no, (in [-inf, inf], optional)
        :param uv_no: UV no, (in [-inf, inf], optional)
        :return: uv, (array of 2 items, in [-inf, inf])
        """

    def mcol_on_emitter(
        self,
        modifier: ParticleSystemModifier | None,
        particle: Particle | None,
        *,
        particle_no: int | None = 0,
        vcol_no: int | None = 0,
    ) -> mathutils.Color:
        """Obtain mcol for all particles

        :param modifier: Particle modifier (never None)
        :param particle: Particle (never None)
        :param particle_no: Particle no, (in [-inf, inf], optional)
        :param vcol_no: vcol no, (in [-inf, inf], optional)
        :return: mcol, (array of 3 items, in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleSystemModifier(Modifier, bpy_struct):
    """Particle system simulation modifier"""

    particle_system: ParticleSystem | None
    """ Particle System that this modifier controls (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ParticleTarget(bpy_struct):
    """Target particle system"""

    alliance: typing.Literal["FRIEND", "NEUTRAL", "ENEMY"]
    """ (default 'NEUTRAL')"""

    duration: float
    """ (in [0, 1.04857e+06], default 0.0)"""

    is_valid: bool
    """ Keyed particles target is valid (default False)"""

    name: str
    """ Particle target name (default "", readonly, never None)"""

    object: Object | None
    """ The object that has the target particle system (empty if same object)"""

    system: int
    """ The index of particle system on the target object (in [1, inf], default 0)"""

    time: float
    """ (in [0, 1.04857e+06], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PathCompare(bpy_struct):
    """Match paths against this value"""

    path: str
    """ (default "", never None)"""

    use_glob: bool
    """ Enable wildcard globbing (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PitchModifier(StripModifier, bpy_struct):
    """Shift Audio Pitch"""

    cents: int
    """ A cent is one one-hundredth of a semi-tone. (in [-100, 100], default 0)"""

    mode: typing.Literal["SEMITONES", "RATIO"]
    """ Mode of the pitch shift (default 'SEMITONES')"""

    preserve_formant: bool
    """ Whether to preserve the vocal formants when shifting the pitch. (default False)"""

    quality: typing.Literal["HIGH", "FAST", "CONSISTENT"]
    """ Quality of the pitch shifting (default 'HIGH')"""

    ratio: float
    """ Factor by which the audio pitch is scaled. (in [0.5, 2], default 0.0)"""

    semitones: int
    """ Number of semitones to shift the pitch. (in [-12, 12], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PivotConstraint(Constraint, bpy_struct):
    """Rotate around a different point"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    offset: mathutils.Vector
    """ Offset of pivot from target (when set), or from owner's location (when Fixed Position is off), or the absolute pivot point (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation_range: typing.Literal["ALWAYS_ACTIVE", "NX", "NY", "NZ", "X", "Y", "Z"]
    """ Rotation range on which pivoting should occur (default 'NX')"""

    subtarget: str
    """ (default "", never None)"""

    target: Object | None
    """ Target Object, defining the position of the pivot when defined"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    use_relative_location: bool
    """ Offset will be an absolute point in space instead of relative to the target (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Point(bpy_struct):
    """Point in a point cloud"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    index: int
    """ Index of this point (in [0, inf], default 0, readonly)"""

    radius: float
    """ (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointCache(bpy_struct):
    """Active point cache for physics simulations"""

    filepath: str
    """ Cache file path (default "", never None, blend relative // prefix supported)"""

    frame_end: int
    """ Frame on which the simulation stops (in [1, 1048574], default 0)"""

    frame_start: int
    """ Frame on which the simulation starts (in [-1048574, 1048574], default 0)"""

    frame_step: int
    """ Number of frames between cached frames (in [1, 20], default 0)"""

    index: int
    """ Index number of cache files (in [-1, 100], default 0)"""

    info: str
    """ Info on current cache status (default "", readonly, never None)"""

    is_baked: bool
    """ The cache is baked (default False, readonly)"""

    is_baking: bool
    """ The cache is being baked (default False, readonly)"""

    is_frame_skip: bool
    """ Some frames were skipped while baking/saving that cache (default False, readonly)"""

    is_outdated: bool
    """ (default False, readonly)"""

    name: str
    """ Cache name (default "", never None)"""

    point_caches: typing.Any
    """ (default None, readonly)"""

    use_disk_cache: bool
    """ Save cache files to disk (.blend file must be saved first) (default False)"""

    use_external: bool
    """ Read cache from an external location (default False)"""

    use_library_path: bool
    """ Use this file's path for the disk cache when library linked into another file (for local bakes per scene file, disable this option) (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointCacheItem(bpy_struct):
    """Point cache for physics simulations"""

    filepath: str
    """ Cache file path (default "", never None, blend relative // prefix supported)"""

    frame_end: int
    """ Frame on which the simulation stops (in [1, 1048574], default 0)"""

    frame_start: int
    """ Frame on which the simulation starts (in [-1048574, 1048574], default 0)"""

    frame_step: int
    """ Number of frames between cached frames (in [1, 20], default 0)"""

    index: int
    """ Index number of cache files (in [-1, 100], default 0)"""

    info: str
    """ Info on current cache status (default "", readonly, never None)"""

    is_baked: bool
    """ The cache is baked (default False, readonly)"""

    is_baking: bool
    """ The cache is being baked (default False, readonly)"""

    is_frame_skip: bool
    """ Some frames were skipped while baking/saving that cache (default False, readonly)"""

    is_outdated: bool
    """ (default False, readonly)"""

    name: str
    """ Cache name (default "", never None)"""

    use_disk_cache: bool
    """ Save cache files to disk (.blend file must be saved first) (default False)"""

    use_external: bool
    """ Read cache from an external location (default False)"""

    use_library_path: bool
    """ Use this file's path for the disk cache when library linked into another file (for local bakes per scene file, disable this option) (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointCloud(ID, bpy_struct):
    """Point cloud data-block"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    attributes: typing.Any
    """ Geometry attributes (default None, readonly)"""

    color_attributes: typing.Any
    """ Geometry color attributes (default None, readonly)"""

    materials: typing.Any
    """ (default None, readonly)"""

    points: typing.Any
    """ (default None, readonly)"""

    def resize(self, size: int | None) -> None:
        """resize

        :param size: Size, New number of points (in [0, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointLight(Light, ID, bpy_struct):
    """Omnidirectional point Light"""

    energy: float
    """ Light energy emitted over the entire area of the light in all directions, in units of radiant power (W) (in [-inf, inf], default 10.0)"""

    shadow_buffer_clip_start: float
    """ Shadow map clip start, below which objects will not generate shadows (in [1e-06, inf], default 0.05)"""

    shadow_filter_radius: float
    """ Blur shadow aliasing using Percentage Closer Filtering (in [0, inf], default 1.0)"""

    shadow_jitter_overblur: float
    """ Apply shadow tracing to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 10.0)"""

    shadow_maximum_resolution: float
    """ Minimum size of a shadow map pixel. Higher values use less memory at the cost of shadow quality. (in [0, inf], default 0.001)"""

    shadow_soft_size: float
    """ Light size for ray shadow sampling (Raytraced shadows) (in [0, inf], default 0.0)"""

    use_absolute_resolution: bool
    """ Limit the resolution at 1 unit from the light origin instead of relative to the shadowed pixel (default False)"""

    use_shadow_jitter: bool
    """ Enable jittered soft shadows to increase shadow precision (disabled in viewport unless enabled in the render settings). Has a high performance impact. (default False)"""

    use_soft_falloff: bool
    """ Apply falloff to avoid sharp edges when the light geometry intersects with other objects (default True)"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this light. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PointerProperty(Property, bpy_struct):
    """RNA pointer property to point to another RNA struct"""

    fixed_type: Struct | None
    """ Fixed pointer type, empty if variable type (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Pose(bpy_struct):
    """A collection of pose channels, including settings for animating bones"""

    animation_visualization: AnimViz | None
    """ Animation data for this data-block (readonly, never None)"""

    bones: typing.Any
    """ Individual pose bones for the armature (default None, readonly)"""

    ik_param: IKParam | None
    """ Parameters for IK solver (readonly)"""

    ik_solver: typing.Literal["LEGACY", "ITASC"]
    """ Selection of IK solver for IK chain (default 'LEGACY')"""

    use_auto_ik: bool
    """ Add temporary IK constraints while grabbing bones in Pose Mode (default False)"""

    use_mirror_relative: bool
    """ Apply relative transformations in X-mirror mode (not supported with Auto IK) (default False)"""

    use_mirror_x: bool
    """ Apply changes to matching bone on opposite side of X-Axis (default False)"""

    @classmethod
    def apply_pose_from_action(
        cls, action: Action | None, *, evaluation_time: float | None = 0.0
    ) -> None:
        """Apply the given action to this pose by evaluating it at a specific time. Only updates the pose of selected bones, or all bones if none are selected.

        :param action: Action, The Action containing the pose
        :param evaluation_time: Evaluation Time, Time at which the given action is evaluated to obtain the pose (in [-inf, inf], optional)
        """

    @classmethod
    def blend_pose_from_action(
        cls,
        action: Action | None,
        *,
        blend_factor: float | None = 1.0,
        evaluation_time: float | None = 0.0,
    ) -> None:
        """Blend the given action into this pose by evaluating it at a specific time. Only updates the pose of selected bones, or all bones if none are selected.

        :param action: Action, The Action containing the pose
        :param blend_factor: Blend Factor, How much the given Action affects the final pose (in [0, 1], optional)
        :param evaluation_time: Evaluation Time, Time at which the given action is evaluated to obtain the pose (in [-inf, inf], optional)
        """

    @classmethod
    def backup_create(cls, action: Action | None) -> None:
        """Create a backup of the current pose. Only those bones that are animated in the Action are backed up. The object owns the backup, and each object can have only one backup at a time. When you no longer need it, it must be freed use backup_clear().

        :param action: Action, An Action with animation data for the bones. Only the animated bones will be included in the backup.
        """

    @classmethod
    def backup_restore(cls) -> bool:
        """Restore the previously made pose backup. This can be called multiple times. See Pose.backup_create() for more info.

        :return: True when the backup was restored, False if there was no backup to restore
        """

    @classmethod
    def backup_clear(cls) -> None:
        """Free a previously made pose backup. See Pose.backup_create() for more info."""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PoseBone(bpy_struct):
    """Channel defining pose data for a bone in a Pose"""

    bbone_curveinx: float
    """ X-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveinz: float
    """ Z-axis handle offset for start of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutx: float
    """ X-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_curveoutz: float
    """ Z-axis handle offset for end of the B-Bone's curve, adjusts curvature (in [-inf, inf], default 0.0)"""

    bbone_custom_handle_end: typing_extensions.Self | None
    """ Bone that serves as the end handle for the B-Bone curve (readonly)"""

    bbone_custom_handle_start: typing_extensions.Self | None
    """ Bone that serves as the start handle for the B-Bone curve (readonly)"""

    bbone_easein: float
    """ Length of first Bézier Handle (for B-Bones only) (in [-inf, inf], default 0.0)"""

    bbone_easeout: float
    """ Length of second Bézier Handle (for B-Bones only) (in [-inf, inf], default 0.0)"""

    bbone_rollin: float
    """ Roll offset for the start of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_rollout: float
    """ Roll offset for the end of the B-Bone, adjusts twist (in [-inf, inf], default 0.0)"""

    bbone_scalein: mathutils.Vector
    """ Scale factors for the start of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    bbone_scaleout: mathutils.Vector
    """ Scale factors for the end of the B-Bone, adjusts thickness (for tapering effects) (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    bone: Bone | None
    """ Bone associated with this PoseBone (readonly, never None)"""

    child: typing_extensions.Self | None
    """ Child of this pose bone (readonly)"""

    color: BoneColor | None
    """ (readonly)"""

    constraints: typing.Any
    """ Constraints that act on this pose channel (default None, readonly)"""

    custom_shape: Object | None
    """ Object that defines custom display shape for this bone"""

    custom_shape_rotation_euler: mathutils.Euler
    """ Adjust the rotation of the custom shape (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    custom_shape_scale_xyz: mathutils.Vector
    """ Adjust the size of the custom shape (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    custom_shape_transform: typing_extensions.Self | None
    """ Bone that defines the display transform of this custom shape"""

    custom_shape_translation: mathutils.Vector
    """ Adjust the location of the custom shape (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    custom_shape_wire_width: float
    """ Adjust the line thickness of custom shapes (in [1, 16], default 0.0)"""

    head: mathutils.Vector
    """ Location of head of the channel's bone (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    hide: bool
    """ Bone is not visible except for Edit Mode (default False)"""

    ik_linear_weight: float
    """ Weight of scale constraint for IK (in [0, 1], default 0.0)"""

    ik_max_x: float
    """ Maximum angles for IK Limit (in [0, 3.14159], default 0.0)"""

    ik_max_y: float
    """ Maximum angles for IK Limit (in [0, 3.14159], default 0.0)"""

    ik_max_z: float
    """ Maximum angles for IK Limit (in [0, 3.14159], default 0.0)"""

    ik_min_x: float
    """ Minimum angles for IK Limit (in [-3.14159, 0], default 0.0)"""

    ik_min_y: float
    """ Minimum angles for IK Limit (in [-3.14159, 0], default 0.0)"""

    ik_min_z: float
    """ Minimum angles for IK Limit (in [-3.14159, 0], default 0.0)"""

    ik_rotation_weight: float
    """ Weight of rotation constraint for IK (in [0, 1], default 0.0)"""

    ik_stiffness_x: float
    """ IK stiffness around the X axis (in [0, 0.99], default 0.0)"""

    ik_stiffness_y: float
    """ IK stiffness around the Y axis (in [0, 0.99], default 0.0)"""

    ik_stiffness_z: float
    """ IK stiffness around the Z axis (in [0, 0.99], default 0.0)"""

    ik_stretch: float
    """ Allow scaling of the bone for IK (in [0, 1], default 0.0)"""

    is_in_ik_chain: bool
    """ Is part of an IK chain (default False, readonly)"""

    length: float
    """ Length of the bone (in [-inf, inf], default 0.0, readonly)"""

    location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    lock_ik_x: bool
    """ Disallow movement around the X axis (default False)"""

    lock_ik_y: bool
    """ Disallow movement around the Y axis (default False)"""

    lock_ik_z: bool
    """ Disallow movement around the Z axis (default False)"""

    lock_location: typing.Any
    """ Lock editing of location when transforming (array of 3 items, default (False, False, False))"""

    lock_rotation: typing.Any
    """ Lock editing of rotation when transforming (array of 3 items, default (False, False, False))"""

    lock_rotation_w: bool
    """ Lock editing of 'angle' component of four-component rotations when transforming (default False)"""

    lock_rotations_4d: bool
    """ Lock editing of four component rotations by components (instead of as Eulers) (default False)"""

    lock_scale: typing.Any
    """ Lock editing of scale when transforming (array of 3 items, default (False, False, False))"""

    matrix: mathutils.Matrix
    """ Final 4×4 matrix after constraints and drivers are applied, in the armature object space (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_basis: mathutils.Matrix
    """ Alternative access to location/scale/rotation relative to the parent and own rest bone (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    matrix_channel: mathutils.Matrix
    """ 4×4 matrix of the bone's location/rotation/scale channels (including animation and drivers) and the effect of bone constraints (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    motion_path: MotionPath | None
    """ Motion Path for this element (readonly)"""

    name: str
    """ (default "", never None)"""

    parent: PoseBone | None
    """ Parent of this pose bone (readonly)"""

    rotation_axis_angle: typing.Any
    """ Angle of Rotation for Axis-Angle rotation representation (array of 4 items, in [-inf, inf], default (0.0, 0.0, 1.0, 0.0))"""

    rotation_euler: mathutils.Euler
    """ Rotation in Eulers (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation_mode: Literal[bpy.stub_internal.rna_enums.ObjectRotationModeItems]
    """ The kind of rotation to apply, values from other rotation modes are not used (default 'QUATERNION')"""

    rotation_quaternion: mathutils.Quaternion
    """ Rotation in Quaternions (array of 4 items, in [-inf, inf], default (1.0, 0.0, 0.0, 0.0))"""

    scale: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    select: bool
    """ Bone is selected in Pose Mode (default False)"""

    tail: mathutils.Vector
    """ Location of tail of the channel's bone (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    use_custom_shape_bone_size: bool
    """ Scale the custom object by the bone length (default True)"""

    use_ik_limit_x: bool
    """ Limit movement around the X axis (default False)"""

    use_ik_limit_y: bool
    """ Limit movement around the Y axis (default False)"""

    use_ik_limit_z: bool
    """ Limit movement around the Z axis (default False)"""

    use_ik_linear_control: bool
    """ Apply channel size as IK constraint if stretching is enabled (default False)"""

    use_ik_rotation_control: bool
    """ Apply channel rotation as IK constraint (default False)"""

    use_transform_around_custom_shape: bool
    """ Transform the bone as if it was a child of the Custom Shape Transform bone. This can be useful when combining shape-key and armature deformations. (default False)"""

    use_transform_at_custom_shape: bool
    """ The location and orientation of the Custom Shape Transform bone will be used for transform gizmos and for other transform operators in the 3D Viewport. When disabled, the 3D Viewport will still use the actual bone transform for these, even when the custom bone shape transform is overridden. (default False)"""

    basename: typing.Any
    """ The name of this bone before any . character.(readonly)"""

    center: typing.Any
    """ The midpoint between the head and the tail.(readonly)"""

    children: typing.Any
    """ (readonly)"""

    children_recursive: typing.Any
    """ A list of all children from this bone.(readonly)"""

    children_recursive_basename: typing.Any
    """ Returns a chain of children with the same base name as this bone.
Only direct chains are supported, forks caused by multiple children
with matching base names will terminate the function
and not be returned.(readonly)"""

    parent_recursive: typing.Any
    """ A list of parents, starting with the immediate parent.(readonly)"""

    vector: typing.Any
    """ The direction this bone is pointing.
Utility function for (tail - head)(readonly)"""

    x_axis: typing.Any
    """ Vector pointing down the x-axis of the bone.(readonly)"""

    y_axis: typing.Any
    """ Vector pointing down the y-axis of the bone.(readonly)"""

    z_axis: typing.Any
    """ Vector pointing down the z-axis of the bone.(readonly)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def evaluate_envelope(
        self, point: collections.abc.Sequence[float] | mathutils.Vector | None
    ) -> float:
        """Calculate bone envelope at given point

        :param point: Point, Position in 3d space to evaluate (array of 3 items, in [-inf, inf])
        :return: Factor, Envelope factor (in [-inf, inf])
        """

    def bbone_segment_index(
        self, point: collections.abc.Sequence[float] | mathutils.Vector | None
    ) -> tuple[int, float]:
        """Retrieve the index and blend factor of the B-Bone segments based on vertex position

                :param point: Point, Vertex position in armature pose space (array of 3 items, in [-inf, inf])
                :return: index, The index of the first segment joint affecting the point, int

        blend_next, The blend factor between the given and the following joint, float
        """

    def bbone_segment_matrix(
        self, index: int | None, *, rest: bool | None = False
    ) -> mathutils.Matrix:
        """Retrieve the matrix of the joint between B-Bone segments if availableThis example shows how to use B-Bone segment matrices to emulate deformation
        produced by the Armature modifier or constraint when assigned to the given bone
        (without Preserve Volume). The coordinates are processed in armature Pose space:

                :param index: Index of the segment endpoint (in [0, inf])
                :param rest: Return the rest pose matrix (optional)
                :return: The resulting matrix in bone local space (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    def compute_bbone_handles(
        self,
        *,
        rest: bool | None = False,
        ease: bool | None = False,
        offsets: bool | None = False,
    ) -> tuple[mathutils.Vector, float, mathutils.Vector, float]:
        """Retrieve the vectors and rolls coming from B-Bone custom handles

                :param rest: Return the rest pose state (optional)
                :param ease: Apply scale from ease values (optional)
                :param offsets: Apply roll and curve offsets from bone properties (optional)
                :return: handle1, The direction vector of the start handle in bone local space, `mathutils.Vector`

        roll1, Roll of the start handle, float

        handle2, The direction vector of the end handle in bone local space, `mathutils.Vector`

        roll2, Roll of the end handle, float
        """

    def parent_index(self, parent_test) -> None:
        """The same as bone in other_bone.parent_recursive
        but saved generating a list.

                :param parent_test:
        """

    def translate(self, vec) -> None:
        """Utility function to add vec to the head and tail of this bone.

        :param vec:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Preferences(bpy_struct):
    """Global preferences"""

    active_section: Literal[bpy.stub_internal.rna_enums.PreferenceSectionItems] | None
    """ Preferences (default 'INTERFACE')"""

    addons: typing.Any
    """ (default None, readonly)"""

    app_template: str
    """ (default "", never None)"""

    apps: PreferencesApps | None
    """ Preferences that work only for apps (readonly, never None)"""

    autoexec_paths: typing.Any
    """ (default None, readonly)"""

    edit: PreferencesEdit | None
    """ Settings for interacting with Blender data (readonly, never None)"""

    experimental: PreferencesExperimental | None
    """ Settings for features that are still early in their development stage (readonly, never None)"""

    extensions: PreferencesExtensions | None
    """ Settings for extensions (readonly, never None)"""

    filepaths: PreferencesFilePaths | None
    """ Default paths for external files (readonly, never None)"""

    inputs: PreferencesInput | None
    """ Settings for input devices (readonly, never None)"""

    is_dirty: bool
    """ Preferences have changed (default False)"""

    keymap: PreferencesKeymap | None
    """ Shortcut setup for keyboards and other input devices (readonly, never None)"""

    show_hidden_ids: bool
    """ Show data-blocks with dot-prefixed names in search menus (default False)"""

    studio_lights: typing.Any
    """ (default None, readonly)"""

    system: PreferencesSystem | None
    """ Graphics driver and operating system settings (readonly, never None)"""

    themes: typing.Any
    """ (default None, readonly)"""

    ui_styles: typing.Any
    """ (default None, readonly)"""

    use_preferences_save: bool
    """ Save preferences on exit when modified (unless factory settings have been loaded) (default True)"""

    use_recent_searches: bool
    """ Sort the recently searched items at the top (default True)"""

    version: typing.Any
    """ Version of Blender the userpref.blend was saved with (array of 3 items, in [0, inf], default (0, 0, 0), readonly)"""

    view: PreferencesView | None
    """ Preferences related to viewing data (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesApps(bpy_struct):
    """Preferences that work only for apps"""

    show_corner_split: bool
    """ Split and join editors by dragging from corners (default True)"""

    show_edge_resize: bool
    """ Resize editors by dragging from the edges (default True)"""

    show_regions_visibility_toggle: bool
    """ Header and side bars visibility toggles (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesEdit(bpy_struct):
    """Settings for interacting with Blender data"""

    auto_keying_mode: typing.Literal["ADD_REPLACE_KEYS", "REPLACE_KEYS"]
    """ Mode of automatic keyframe insertion for Objects and Bones (default setting used for new Scenes) (default 'ADD_REPLACE_KEYS')"""

    collection_instance_empty_size: float
    """ Display size of the empty when new collection instances are created (in [0.001, inf], default 1.0)"""

    connect_strips_by_default: bool
    """ Connect newly added movie strips by default if they have multiple channels (default True)"""

    fcurve_new_auto_smoothing: Literal[
        bpy.stub_internal.rna_enums.FcurveAutoSmoothingItems
    ]
    """ Auto Handle Smoothing mode used for newly added F-Curves (default 'CONT_ACCEL')"""

    fcurve_unselected_alpha: float
    """ The opacity of unselected F-Curves against the background of the Graph Editor (in [0.001, 1], default 0.25)"""

    grease_pencil_default_color: typing.Any
    """ Color of new annotation layers (array of 4 items, in [0, inf], default (0.38, 0.61, 0.78, 0.9))"""

    grease_pencil_eraser_radius: int
    """ Radius of eraser 'brush' (in [1, 500], default 25)"""

    grease_pencil_euclidean_distance: int
    """ Distance moved by mouse when drawing stroke to include (in [0, 100], default 2)"""

    grease_pencil_manhattan_distance: int
    """ Pixels moved by mouse per axis when drawing stroke (in [0, 100], default 1)"""

    key_insert_channels: set[
        typing.Literal["LOCATION", "ROTATION", "SCALE", "ROTATE_MODE", "CUSTOM_PROPS"]
    ]
    """ Which channels to insert keys at when no keying set is active (default {'CUSTOM_PROPS', 'LOCATION', 'ROTATION', 'SCALE'})"""

    keyframe_new_handle_type: Literal[
        bpy.stub_internal.rna_enums.KeyframeHandleTypeItems
    ]
    """ Handle type for handles of new keyframes (default 'AUTO_CLAMPED')"""

    keyframe_new_interpolation_type: Literal[
        bpy.stub_internal.rna_enums.BeztripleInterpolationModeItems
    ]
    """ Interpolation mode used for first keyframe on newly added F-Curves (subsequent keyframes take interpolation from preceding keyframe) (default 'BEZIER')"""

    material_link: typing.Literal["OBDATA", "OBJECT"]
    """ Toggle whether the material is linked to object data or the object block (default 'OBDATA')"""

    node_margin: int
    """ Minimum distance between nodes for Auto-offsetting nodes (in [0, 255], default 40)"""

    node_preview_resolution: int
    """ Resolution used for Shader node previews (should be changed for performance convenience) (in [50, 250], default 120)"""

    node_use_insert_offset: bool
    """ Automatically offset the following or previous nodes in a chain when inserting a new node (default True)"""

    object_align: typing.Literal["WORLD", "VIEW", "CURSOR"]
    """ The default alignment for objects added from a 3D viewport menu (default 'WORLD')"""

    sculpt_paint_overlay_color: mathutils.Color
    """ Color of texture overlay (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    show_only_selected_curve_keyframes: bool
    """ Only keyframes of selected F-Curves are visible and editable (default False)"""

    undo_memory_limit: int
    """ Maximum memory usage in megabytes (0 means unlimited) (in [0, inf], default 0)"""

    undo_steps: int
    """ Number of undo steps available (smaller values conserve memory) (in [0, 256], default 32)"""

    use_anim_channel_group_colors: bool
    """ Use animation channel group colors; generally this is used to show bone group colors (default False)"""

    use_auto_keyframe_insert_needed: bool
    """ Auto-Keying will skip inserting keys that don't affect the animation (default True)"""

    use_auto_keying: bool
    """ Automatic keyframe insertion for Objects and Bones (default setting used for new Scenes) (default False)"""

    use_auto_keying_warning: bool
    """ Show warning indicators when transforming objects and bones if auto keying is enabled (default True)"""

    use_cursor_lock_adjust: bool
    """ Place the cursor without 'jumping' to the new location (when lock-to-cursor is used) (default True)"""

    use_duplicate_action: bool
    """ Causes actions to be duplicated with the data-blocks (default True)"""

    use_duplicate_armature: bool
    """ Causes armature data to be duplicated with the object (default True)"""

    use_duplicate_camera: bool
    """ Causes camera data to be duplicated with the object (default True)"""

    use_duplicate_curve: bool
    """ Causes curve data to be duplicated with the object (default True)"""

    use_duplicate_curves: bool
    """ Causes curves data to be duplicated with the object (default True)"""

    use_duplicate_grease_pencil: bool
    """ Causes Grease Pencil data to be duplicated with the object (default True)"""

    use_duplicate_lattice: bool
    """ Causes lattice data to be duplicated with the object (default True)"""

    use_duplicate_light: bool
    """ Causes light data to be duplicated with the object (default True)"""

    use_duplicate_lightprobe: bool
    """ Causes light probe data to be duplicated with the object (default True)"""

    use_duplicate_material: bool
    """ Causes material data to be duplicated with the object (default False)"""

    use_duplicate_mesh: bool
    """ Causes mesh data to be duplicated with the object (default True)"""

    use_duplicate_metaball: bool
    """ Causes metaball data to be duplicated with the object (default True)"""

    use_duplicate_node_tree: bool
    """ Make copies of node groups when duplicating nodes in the node editor (default False)"""

    use_duplicate_particle: bool
    """ Causes particle systems to be duplicated with the object (default False)"""

    use_duplicate_pointcloud: bool
    """ Causes point cloud data to be duplicated with the object (default True)"""

    use_duplicate_speaker: bool
    """ Causes speaker data to be duplicated with the object (default True)"""

    use_duplicate_surface: bool
    """ Causes surface data to be duplicated with the object (default True)"""

    use_duplicate_text: bool
    """ Causes text data to be duplicated with the object (default True)"""

    use_duplicate_volume: bool
    """ Causes volume data to be duplicated with the object (default False)"""

    use_enter_edit_mode: bool
    """ Enter edit mode automatically after adding a new object (default False)"""

    use_fcurve_high_quality_drawing: bool
    """ Draw F-Curves using Anti-Aliasing (disable for better performance) (default True)"""

    use_global_undo: bool
    """ Global undo works by keeping a full copy of the file itself in memory, so takes extra memory (default True)"""

    use_insertkey_xyz_to_rgb: bool
    """ Color for newly added transformation F-Curves (Location, Rotation, Scale) and also Color is based on the transform axis (default True)"""

    use_keyframe_insert_available: bool
    """ Insert Keyframes only for properties that are already animated (default False)"""

    use_keyframe_insert_needed: bool
    """ When keying manually, skip inserting keys that don't affect the animation (default False)"""

    use_mouse_depth_cursor: bool
    """ Use the surface depth for cursor placement (default True)"""

    use_negative_frames: bool
    """ Current frame number can be manually set to a negative value (default False)"""

    use_text_edit_auto_close: bool
    """ Automatically close relevant character pairs when typing in the text editor (default False)"""

    use_visual_keying: bool
    """ Use Visual keying automatically for constrained objects (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesExperimental(bpy_struct):
    """Experimental features"""

    no_data_block_packing: bool
    """ Fall-back to appending instead of packing data-blocks (default False)"""

    override_auto_resync: bool
    """ Disable library overrides automatic resync detection and process on file load (can be useful to help fixing broken files). Also see the "--disable-liboverride-auto-resync" command line option (default False)"""

    show_asset_debug_info: bool
    """ Enable some extra fields in the Asset Browser to aid in debugging (default False)"""

    use_all_linked_data_direct: bool
    """ Forces all linked data to be considered as directly linked. Workaround for current issues/limitations in BAT (Blender studio pipeline tool) (default False)"""

    use_asset_indexing: bool
    """ Disable the asset indexer, to force every asset library refresh to completely reread assets from disk (default False)"""

    use_cycles_debug: bool
    """ Enable Cycles debugging options for developers (default False)"""

    use_eevee_debug: bool
    """ Enable EEVEE debugging options for developers (default False)"""

    use_extended_asset_browser: bool
    """ Enable Asset Browser editor and operators to manage regular data-blocks as assets, not just poses (default False)"""

    use_extensions_debug: bool
    """ Extra debugging information & developer support utilities for extensions (default False)"""

    use_geometry_bundle: bool
    """ Support storing custom bundles in a geometry in Geometry Nodes (default False)"""

    use_geometry_nodes_lists: bool
    """ Enable new list types and nodes (default False)"""

    use_new_curves_tools: bool
    """ Enable additional features for the new curves data block (default False)"""

    use_paint_debug: bool
    """ Enable paint & sculpt debugging options for developers (default False)"""

    use_recompute_usercount_on_save_debug: bool
    """ Recompute all ID user-counts before saving to a blend-file. Allows to work around invalid user-count handling in code that may lead to loss of data due to wrongly detected unused data-blocks (default False)"""

    use_remote_asset_libraries: bool
    """ Enable asset libraries served over HTTP/HTTPS (default False)"""

    use_sculpt_texture_paint: bool
    """ Use texture painting in Sculpt Mode (default False)"""

    use_shader_node_previews: bool
    """ Enables previews in the shader node editor (default False)"""

    use_undo_legacy: bool
    """ Use legacy undo (slower than the new default one, but may be more stable in some cases) (default False)"""

    use_viewport_debug: bool
    """ Enable viewport debugging options for developers in the overlays pop-over (default False)"""

    write_legacy_blend_file_format: bool
    """ Use file format used before Blender 5.0. This format is more limited but it may have better compatibility with tools that don't support the new format yet (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesExtensions(bpy_struct):
    """Settings for extensions"""

    active_repo: int | None
    """ Index of the extensions repository being edited in the Preferences UI (in [-32768, 32767], default 0)"""

    repos: typing.Any
    """ (default None, readonly)"""

    use_online_access_handled: bool
    """ The user has been shown the "Online Access" prompt and made a choice (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesFilePaths(bpy_struct):
    """Default paths for external files"""

    active_asset_library: int | None
    """ Index of the asset library being edited in the Preferences UI (in [-32768, 32767], default 0)"""

    animation_player: str
    """ Path to a custom animation/frame sequence player (default "", never None)"""

    animation_player_preset: typing.Literal[
        "INTERNAL", "DJV", "FRAMECYCLER", "RV", "MPLAYER", "CUSTOM"
    ]
    """ Preset configs for external animation players (default 'INTERNAL')"""

    asset_libraries: typing.Any
    """ (default None, readonly)"""

    auto_save_time: int
    """ The time (in minutes) to wait between automatic temporary saves (in [1, 60], default 2)"""

    file_preview_type: typing.Literal["NONE", "AUTO", "SCREENSHOT", "CAMERA"]
    """ What type of blend preview to create (default 'AUTO')"""

    font_directory: str
    """ The default directory to search for loading fonts (default "", never None, blend relative // prefix supported)"""

    i18n_branches_directory: str
    """ The path to the '/branches' directory of your local svn-translation copy, to allow translating from the UI (default "", never None)"""

    image_editor: str
    """ Path to an image editor (default "", never None)"""

    recent_files: int
    """ Maximum number of recently opened files to remember (in [0, 1000], default 200)"""

    render_cache_directory: str
    """ Where to cache raw render results (default "", never None, blend relative // prefix supported)"""

    render_output_directory: str
    """ The default directory for rendering output, for new scenes (default "", never None, blend relative // prefix supported)"""

    save_version: int
    """ The number of old versions to maintain in the current directory, when manually saving (in [0, 32], default 1)"""

    script_directories: typing.Any
    """ (default None, readonly)"""

    show_hidden_files_datablocks: bool
    """ Show files and data-blocks that are normally hidden (default True)"""

    show_recent_locations: bool
    """ Show Recent locations list in the File Browser (default True)"""

    show_system_bookmarks: bool
    """ Show System locations list in the File Browser (default True)"""

    sound_directory: str
    """ The default directory to search for sounds (default "", never None, blend relative // prefix supported)"""

    temporary_directory: str
    """ The directory for storing temporary save files. The path must reference an existing directory or it will be ignored (default "", never None)"""

    text_editor: str
    """ Command to launch the text editor, either a full path or a command in $PATH.
Use the internal editor when left blank(default "", never None)"""

    text_editor_args: str
    """ Defines the specific format of the arguments with which the text editor opens files. The supported expansions are as follows:$filepath The absolute path of the file.
$line The line to open at (Optional).
$column The column to open from the beginning of the line (Optional).
$line0 & column0 start at zero.
Example: -f $filepath -l $line -c $column(default "", never None)"""

    texture_directory: str
    """ The default directory to search for textures (default "", never None, blend relative // prefix supported)"""

    use_auto_save_temporary_files: bool
    """ Automatic saving of temporary files in temp directory, uses process ID.
Warning: Sculpt and edit mode data won't be saved(default True)"""

    use_extension_online_access_handled: bool
    """ The user has been shown the "Online Access" prompt and made a choice (default False)"""

    use_file_compression: bool
    """ Enable file compression when saving .blend files (default True)"""

    use_filter_files: bool
    """ Enable filtering of files in the File Browser (default True)"""

    use_load_ui: bool
    """ Load user interface setup when loading .blend files (default True)"""

    use_relative_paths: bool
    """ Default relative path option for the file selector, when no path is defined yet (default True)"""

    use_scripts_auto_execute: bool
    """ Allow any .blend file to run scripts automatically (unsafe with blend files from an untrusted source) (default False)"""

    use_tabs_as_spaces: bool
    """ Automatically convert all new tabs into spaces for new and loaded text files (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesInput(bpy_struct):
    """Settings for input devices"""

    drag_threshold: int
    """ Number of pixels to drag before a drag event is triggered for keyboard and other non mouse/tablet input (otherwise click events are detected) (in [1, 255], default 30)"""

    drag_threshold_mouse: int
    """ Number of pixels to drag before a drag event is triggered for mouse/trackpad input (otherwise click events are detected) (in [1, 255], default 3)"""

    drag_threshold_tablet: int
    """ Number of pixels to drag before a drag event is triggered for tablet input (otherwise click events are detected) (in [1, 255], default 10)"""

    invert_mouse_zoom: bool
    """ Invert the axis of mouse movement for zooming (default False)"""

    invert_zoom_wheel: bool
    """ Swap the Mouse Wheel zoom direction (default False)"""

    mouse_double_click_time: int
    """ Time/delay (in ms) for a double click (in [1, 1000], default 350)"""

    mouse_emulate_3_button_modifier: typing.Literal["ALT", "OSKEY"]
    """ Hold this modifier to emulate the middle mouse button (default 'ALT')"""

    move_threshold: int
    """ Number of pixels to before the cursor is considered to have moved (used for cycling selected items on successive clicks) (in [0, 255], default 2)"""

    navigation_mode: Literal[bpy.stub_internal.rna_enums.NavigationModeItems]
    """ Which method to use for viewport navigation (default 'WALK')"""

    ndof_deadzone: float
    """ Threshold of initial movement needed from the device's rest position (in [0, 1], default 0.0)"""

    ndof_fly_helicopter: bool
    """ Device up/down directly controls the Z position of the 3D viewport (default False)"""

    ndof_fly_speed_auto: bool
    """ Automatically adjusts fly navigation speed based on the distance of objects near the center of the viewport, making it easier to navigate complex scenes. Speed is recalculated each time movement starts. (default False)"""

    ndof_lock_camera_pan_zoom: bool
    """ Pan/zoom the camera view instead of leaving the camera view when orbiting (default True)"""

    ndof_lock_horizon: bool
    """ Lock Horizon forces the horizon to be kept leveled as it currently is (default True)"""

    ndof_navigation_mode: typing.Literal["OBJECT", "FLY", "DRONE"]
    """ 3D Mouse Navigation Mode (default 'OBJECT')"""

    ndof_orbit_center_auto: bool
    """ Auto sets the orbit center dynamically. When the complete model is in view, the center of volume of the whole model is used as the rotation point. When you move closer, the orbit center will be set on an object close to your center of the view. (default True)"""

    ndof_orbit_center_selected: bool
    """ Selected Item forces the orbit center to only take the currently selected objects into account. (default False)"""

    ndof_panx_invert_axis: bool
    """ (default False)"""

    ndof_pany_invert_axis: bool
    """ (default False)"""

    ndof_panz_invert_axis: bool
    """ (default False)"""

    ndof_rotation_sensitivity: float
    """ Overall sensitivity of the 3D Mouse for rotation (in [0.01, 40], default 4.0)"""

    ndof_rotx_invert_axis: bool
    """ (default False)"""

    ndof_roty_invert_axis: bool
    """ (default False)"""

    ndof_rotz_invert_axis: bool
    """ (default False)"""

    ndof_show_guide_orbit_axis: bool
    """ Display the center and axis during rotation (default False)"""

    ndof_show_guide_orbit_center: bool
    """ Display the orbit center during rotation (default True)"""

    ndof_translation_sensitivity: float
    """ Overall sensitivity of the 3D Mouse for translation (in [0.01, 40], default 4.0)"""

    ndof_zoom_direction: typing.Literal["NDOF_ZOOM_FORWARD", "NDOF_ZOOM_UP"]
    """ Which axis of the 3D Mouse cap zooms the view (default 'NDOF_ZOOM_FORWARD')"""

    pressure_softness: float
    """ Adjusts softness of the low pressure response onset using a gamma curve (in [-inf, inf], default 0.0)"""

    pressure_threshold_max: float
    """ Raw input pressure value that is interpreted as 100% by Blender (in [0, 1], default 1.0)"""

    show_tablet_debug_values: bool
    """ Show pressure values when using a paint operator (default False)"""

    tablet_api: typing.Literal["AUTOMATIC", "WINDOWS_INK", "WINTAB"]
    """ Select the tablet API to use for pressure sensitivity (may require restarting Blender for changes to take effect) (default 'AUTOMATIC')"""

    touchpad_scroll_direction: typing.Literal["TRADITIONAL", "NATURAL"]
    """ Scroll direction (Wayland only) (default 'TRADITIONAL')"""

    use_auto_perspective: bool
    """ Automatically switch between orthographic and perspective when changing from top/front/side views (default True)"""

    use_drag_immediately: bool
    """ Moving things with a mouse drag confirms when releasing the button (default True)"""

    use_emulate_numpad: bool
    """ Main 1 to 0 keys act as the numpad ones (useful for laptops) (default False)"""

    use_mouse_continuous: bool
    """ Let the mouse wrap around the view boundaries so mouse movements are not limited by the screen size (used by transform, dragging of UI controls, etc.) (default True)"""

    use_mouse_depth_navigate: bool
    """ Use the depth under the mouse to improve view pan/rotate/zoom functionality (default False)"""

    use_mouse_emulate_3_button: bool
    """ Emulate Middle Mouse with Alt+Left Mouse (default False)"""

    use_multitouch_gestures: bool
    """ Use multi-touch gestures for navigation with touchpad, instead of scroll wheel emulation (default True)"""

    use_numeric_input_advanced: bool
    """ When entering numbers while transforming, default to advanced mode for full math expression evaluation (default False)"""

    use_rotate_around_active: bool
    """ Use the selection (or the last stroke center in Paint modes) as the pivot point for orbiting (default False)"""

    use_zoom_to_mouse: bool
    """ Zoom in towards the mouse pointer's position in the 3D view, rather than the 2D window center (default False)"""

    view_rotate_method: typing.Literal["TURNTABLE", "TRACKBALL"]
    """ Orbit method in the viewport (default 'TURNTABLE')"""

    view_rotate_sensitivity_trackball: float
    """ Scale trackball orbit sensitivity (in [0.1, 10], default 1.0)"""

    view_rotate_sensitivity_turntable: float
    """ Rotation amount per pixel to control how fast the viewport orbits (in [1.74533e-05, 0.261799], default 0.00698132)"""

    view_zoom_axis: typing.Literal["VERTICAL", "HORIZONTAL"]
    """ Axis of mouse movement to zoom in or out on (default 'VERTICAL')"""

    view_zoom_method: typing.Literal["CONTINUE", "DOLLY", "SCALE"]
    """ Which style to use for viewport scaling (default 'DOLLY')"""

    walk_navigation: WalkNavigation | None
    """ Settings for walk navigation mode (readonly, never None)"""

    xr_navigation: XrNavigation | None
    """ Settings for navigation in XR (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesKeymap(bpy_struct):
    """Shortcut setup for keyboards and other input devices"""

    active_keyconfig: str | None
    """ The name of the active key configuration (default "", never None)"""

    show_ui_keyconfig: bool
    """ (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesSystem(bpy_struct):
    """Graphics driver and operating system settings"""

    anisotropic_filter: typing.Literal[
        "FILTER_0", "FILTER_2", "FILTER_4", "FILTER_8", "FILTER_16"
    ]
    """ Quality of anisotropic filtering (default 'FILTER_2')"""

    audio_channels: typing.Literal[
        "MONO", "STEREO", "SURROUND4", "SURROUND51", "SURROUND71"
    ]
    """ Audio channel count (default 'STEREO')"""

    audio_device: typing.Literal["None"]
    """ Audio output device (default 'None')"""

    audio_mixing_buffer: typing.Literal[
        "SAMPLES_256",
        "SAMPLES_512",
        "SAMPLES_1024",
        "SAMPLES_2048",
        "SAMPLES_4096",
        "SAMPLES_8192",
        "SAMPLES_16384",
        "SAMPLES_32768",
    ]
    """ Number of samples used by the audio mixing buffer (default 'SAMPLES_2048')"""

    audio_sample_format: typing.Literal["U8", "S16", "S24", "S32", "FLOAT", "DOUBLE"]
    """ Audio sample format (default 'FLOAT')"""

    audio_sample_rate: typing.Literal[
        "RATE_44100", "RATE_48000", "RATE_96000", "RATE_192000"
    ]
    """ Audio sample rate (default 'RATE_48000')"""

    dpi: int
    """ (in [-inf, inf], default 0, readonly)"""

    gl_clip_alpha: float
    """ Clip alpha below this threshold in the 3D textured view (in [0, 1], default 0.004)"""

    gl_texture_limit: typing.Literal[
        "CLAMP_OFF",
        "CLAMP_8192",
        "CLAMP_4096",
        "CLAMP_2048",
        "CLAMP_1024",
        "CLAMP_512",
        "CLAMP_256",
        "CLAMP_128",
    ]
    """ Limit the texture size to save graphics memory (default 'CLAMP_OFF')"""

    gpu_backend: typing.Literal["OPENGL", "METAL", "VULKAN"]
    """ GPU backend to use (requires restarting Blender for changes to take effect) (default 'OPENGL')"""

    gpu_preferred_device: typing.Literal["AUTO"]
    """ Preferred device to select during detection (requires restarting Blender for changes to take effect) (default 'AUTO')"""

    gpu_shader_workers: int
    """ Number of shader compilation threads or subprocesses, clamped at the max threads supported by the CPU (requires restarting Blender for changes to take effect). A higher number increases the RAM usage while reducing compilation time. A value of 0 will use automatic configuration. (OpenGL only) (in [0, 32], default 0)"""

    image_draw_method: typing.Literal["AUTO", "2DTEXTURE", "GLSL"]
    """ Method used for displaying images on the screen (default 'AUTO')"""

    is_microsoft_store_install: bool
    """ Whether this blender installation is a sandboxed Microsoft Store version (default False, readonly)"""

    legacy_compute_device_type: int
    """ For backwards compatibility only (in [-inf, inf], default 0, readonly)"""

    light_ambient: mathutils.Color
    """ Color of the ambient light that uniformly lit the scene (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    memory_cache_limit: int
    """ Memory cache limit (in megabytes) (in [0, inf], default 4096)"""

    network_connection_limit: int
    """ Limit the number of simultaneous internet connections online operations may make at once. Zero disables the limit. (in [0, 255], default 0)"""

    network_timeout: int
    """ The time in seconds to wait for online operations before a connection may fail with a time-out error. Zero uses the systems default. (in [0, 255], default 0)"""

    pixel_size: float
    """ (in [-inf, inf], default 1.0, readonly)"""

    register_all_users: bool
    """ Make this Blender version open blend files for all users. Requires elevated privileges. (default False)"""

    scrollback: int
    """ Maximum number of lines to store for the console buffer (in [32, 32768], default 256)"""

    sequencer_proxy_setup: typing.Literal["MANUAL", "AUTOMATIC"]
    """ When and how proxies are created (default 'AUTOMATIC')"""

    shader_compilation_method: typing.Literal["THREAD", "SUBPROCESS"]
    """ Compilation method used for compiling shaders in parallel. Subprocess requires a lot more RAM for each worker but might compile shaders faster on some systems. Requires restarting Blender for changes to take effect. (OpenGL only) (default 'THREAD')"""

    solid_lights: typing.Any
    """ Lights used to display objects in solid shading mode (default None, readonly)"""

    texture_collection_rate: int
    """ Number of seconds between each run of the GL texture garbage collector (in [1, 3600], default 60)"""

    texture_time_out: int
    """ Time since last access of a GL texture in seconds after which it is freed (set to 0 to keep textures allocated) (in [0, 3600], default 120)"""

    ui_line_width: float
    """ Suggested line thickness and point size in pixels, for add-ons displaying custom user interface elements, based on operating system settings and Blender UI scale (in [-inf, inf], default 1.0, readonly)"""

    ui_scale: float
    """ Size multiplier to use when displaying custom user interface elements, so that they are scaled correctly on screens with different DPI. This value is based on operating system DPI settings and Blender display scale. (in [-inf, inf], default 0.0, readonly)"""

    use_edit_mode_smooth_wire: bool
    """ Enable edit mode edge smoothing, reducing aliasing (requires restart) (default True)"""

    use_gpu_subdivision: bool
    """ Enable GPU acceleration for evaluating the last subdivision surface modifiers in the stack (default True)"""

    use_online_access: bool
    """ Allow Blender to access the internet. Add-ons that follow this setting will only connect to the internet if enabled. However, Blender cannot prevent third-party add-ons from violating this rule. (default False)"""

    use_overlay_smooth_wire: bool
    """ Enable overlay smooth wires, reducing aliasing (default True)"""

    use_region_overlap: bool
    """ Display tool/property regions over the main region (default True)"""

    use_studio_light_edit: bool
    """ View the result of the studio light editor in the viewport (default False)"""

    vbo_collection_rate: int
    """ Number of seconds between each run of the GL vertex buffer object garbage collector (in [1, 3600], default 60)"""

    vbo_time_out: int
    """ Time since last access of a GL vertex buffer object in seconds after which it is freed (set to 0 to keep VBO allocated) (in [0, 3600], default 120)"""

    viewport_aa: typing.Literal["OFF", "FXAA", "5", "8", "11", "16", "32"]
    """ Method of anti-aliasing in 3d viewport (default '8')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PreferencesView(bpy_struct):
    """Preferences related to viewing data"""

    border_width: int
    """ Size of the padding around each editor. (in [1, 10], default 2)"""

    color_picker_type: typing.Literal[
        "CIRCLE_HSV", "CIRCLE_HSL", "SQUARE_SV", "SQUARE_HS", "SQUARE_HV"
    ]
    """ Different styles of displaying the color picker widget (default 'CIRCLE_HSV')"""

    factor_display_type: typing.Literal["FACTOR", "PERCENTAGE"]
    """ How factor values are displayed (default 'FACTOR')"""

    filebrowser_display_type: typing.Literal["SCREEN", "WINDOW"]
    """ Default location where the File Editor will be displayed in (default 'WINDOW')"""

    font_path_ui: str
    """ Path to interface font (default "", never None)"""

    font_path_ui_mono: str
    """ Path to interface monospaced Font (default "", never None)"""

    gizmo_size: int
    """ Diameter of the gizmo (in [10, 200], default 75)"""

    gizmo_size_navigate_v3d: int
    """ The Navigate Gizmo size (in [30, 200], default 80)"""

    header_align: typing.Literal["NONE", "TOP", "BOTTOM"]
    """ Default header position for new space-types (default 'BOTTOM')"""

    language: typing.Literal[
        "DEFAULT",
        "ab",
        "ar_EG",
        "eu_EU",
        "be",
        "bg_BG",
        "ca_AD",
        "zh_HANS",
        "zh_HANT",
        "cs_CZ",
        "da",
        "nl_NL",
        "en_GB",
        "en_US",
        "eo",
        "fi_FI",
        "fr_FR",
        "ka",
        "de_DE",
        "el_GR",
        "he_IL",
        "hi_IN",
        "hu_HU",
        "id_ID",
        "it_IT",
        "ja_JP",
        "ko_KR",
        "ky_KG",
        "lt",
        "ml",
        "nb",
        "fa_IR",
        "pl_PL",
        "pt_BR",
        "pt_PT",
        "ro_RO",
        "ru_RU",
        "sr_RS",
        "sr_RS@latin",
        "sk_SK",
        "sl",
        "es",
        "sw",
        "sv_SE",
        "ta",
        "th_TH",
        "tr_TR",
        "uk_UA",
        "ur",
        "vi_VN",
    ]
    """ Language used for translation (default 'DEFAULT')"""

    lookdev_sphere_size: int
    """ Diameter of the HDRI reference spheres (in [50, 400], default 150)"""

    menu_close_leave: bool
    """ Close menus when the mouse is moved out of the region. (default False)"""

    mini_axis_brightness: int
    """ Brightness of the icon (in [0, 10], default 8)"""

    mini_axis_size: int
    """ The axes icon's size (in [10, 64], default 25)"""

    mini_axis_type: typing.Literal["NONE", "MINIMAL", "GIZMO"]
    """ Show small rotating 3D axes in the top right corner of the 3D viewport (default 'GIZMO')"""

    open_sublevel_delay: int
    """ Time delay in 1/10 seconds before automatically opening sub level menus (in [1, 40], default 2)"""

    open_toplevel_delay: int
    """ Time delay in 1/10 seconds before automatically opening top level menus (in [1, 40], default 5)"""

    pie_animation_timeout: int
    """ Time needed to fully animate the pie to unfolded state (in 1/100ths of sec) (in [0, 1000], default 6)"""

    pie_initial_timeout: int
    """ Pie menus will use the initial mouse position as center for this amount of time (in 1/100ths of sec) (in [0, 1000], default 0)"""

    pie_menu_confirm: int
    """ Distance threshold after which selection is made (zero to disable) (in [0, 1000], default 0)"""

    pie_menu_radius: int
    """ Pie menu size in pixels (in [0, 1000], default 100)"""

    pie_menu_threshold: int
    """ Distance from center needed before a selection can be made (in [0, 1000], default 12)"""

    pie_tap_timeout: int
    """ Pie menu button held longer than this will dismiss menu on release (in 1/100ths of sec) (in [0, 1000], default 20)"""

    playback_fps_samples: int
    """ The number of frames to use for calculating FPS average. Zero to calculate this automatically, where the number of samples matches the target FPS. (in [0, 5000], default 8)"""

    preferences_display_type: typing.Literal["SCREEN", "WINDOW"]
    """ Default location where the Preferences will be displayed in (default 'WINDOW')"""

    render_display_type: typing.Literal["NONE", "SCREEN", "AREA", "WINDOW"]
    """ Default location where rendered images will be displayed in (default 'WINDOW')"""

    rotation_angle: float
    """ Rotation step for numerical pad keys (2 4 6 8) (in [0, 90], default 15.0)"""

    show_addons_enabled_only: bool
    """ Only show enabled add-ons. Un-check to see all installed add-ons. (default False)"""

    show_area_handle: bool
    """ Show visible area maintenance corner handles (default False)"""

    show_column_layout: bool
    """ Use a column layout for toolbox (default True)"""

    show_developer_ui: bool
    """ Display advanced settings and tools for developers (default False)"""

    show_extensions_updates: bool
    """ Show Extensions Update Count (default True)"""

    show_gizmo: bool
    """ Use transform gizmos by default (default True)"""

    show_navigate_ui: bool
    """ Show navigation controls in 2D and 3D views which do not have scroll bars (default True)"""

    show_number_arrows: bool
    """ Display arrows in numeric input fields for increasing or decreasing values (default False)"""

    show_object_info: bool
    """ Include the name of the active object and the current frame number in the text info overlay (default True)"""

    show_online_assets: bool
    """ When internet access is enabled, load and display online assets in asset shelves (default True)"""

    show_playback_fps: bool
    """ Include the number of frames displayed per second in the text info overlay while animation is played back (default True)"""

    show_splash: bool
    """ Display splash screen on startup (default True)"""

    show_statusbar_memory: bool
    """ Show Blender memory usage (default False)"""

    show_statusbar_scene_duration: bool
    """ Show scene duration (default False)"""

    show_statusbar_stats: bool
    """ Show scene statistics (default False)"""

    show_statusbar_version: bool
    """ Show Blender version string (default True)"""

    show_statusbar_vram: bool
    """ Show GPU video memory usage (default False)"""

    show_tooltips: bool
    """ Display tooltips (when disabled, hold Alt then hover to force display) (default True)"""

    show_tooltips_python: bool
    """ Show Python references in tooltips (default False)"""

    show_view_name: bool
    """ Include the name of the view orientation in the text info overlay (default True)"""

    smooth_view: int
    """ Time to animate the view in milliseconds, zero to disable (in [0, 1000], default 200)"""

    text_hinting: typing.Literal["AUTO", "NONE", "SLIGHT", "FULL"]
    """ Method for making user interface text render sharp (default 'AUTO')"""

    timecode_style: typing.Literal[
        "MINIMAL", "SMPTE", "SMPTE_COMPACT", "MILLISECONDS", "SECONDS_ONLY"
    ]
    """ Format of timecode displayed when not displaying timing in terms of frames (default 'MINIMAL')"""

    ui_line_width: typing.Literal["THIN", "AUTO", "THICK"]
    """ Changes the thickness of widget outlines, lines and dots in the interface (default 'AUTO')"""

    ui_scale: float
    """ Changes the size of the fonts and widgets in the interface (in [0.5, 6], default 1.0)"""

    use_filter_brushes_by_tool: bool
    """ Only show brushes applicable for the currently active tool in the asset shelf. Stored in the Preferences, which may have to be saved manually if Auto-Save Preferences is disabled (default False)"""

    use_fresnel_edit: bool
    """ Enable a fresnel effect on edit mesh overlays.
It improves shape readability of very dense meshes, but increases eye fatigue when modeling lower poly(default False)"""

    use_mouse_over_open: bool
    """ Open menu buttons and pull-downs automatically when the mouse is hovering (default False)"""

    use_reduce_motion: bool
    """ Avoid animations and other motion effects in the interface (default False)"""

    use_save_prompt: bool
    """ Ask for confirmation when quitting with unsaved changes (default True)"""

    use_text_antialiasing: bool
    """ Smooth jagged edges of user interface text (default True)"""

    use_text_render_subpixelaa: bool
    """ Render text for optimal horizontal placement (default False)"""

    use_translate_interface: bool
    """ Translate all labels in menus, buttons and panels (note that this might make it hard to follow tutorials or the manual) (default True)"""

    use_translate_new_dataname: bool
    """ Translate the names of new data-blocks (objects, materials...) (default True)"""

    use_translate_reports: bool
    """ Translate additional information, such as error messages (default True)"""

    use_translate_tooltips: bool
    """ Translate the descriptions when hovering UI elements (recommended) (default True)"""

    use_weight_color_range: bool
    """ Enable color range used for weight visualization in weight painting mode (default False)"""

    view2d_grid_spacing_min: int
    """ Minimum number of pixels between each gridline in 2D Viewports (in [1, 500], default 45)"""

    view_frame_keyframes: int
    """ Keyframes around cursor that we zoom around (in [1, 500], default 0)"""

    view_frame_seconds: float
    """ Seconds around cursor that we zoom around (in [0, 10000], default 0.0)"""

    view_frame_type: typing.Literal["KEEP_RANGE", "SECONDS", "KEYFRAMES"]
    """ How zooming to frame focuses around current frame (default 'KEEP_RANGE')"""

    weight_color_range: ColorRamp | None
    """ Color range used for weight visualization in weight painting mode (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PrimitiveBoolean(bpy_struct):
    """RNA wrapped boolean"""

    value: bool
    """ (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PrimitiveFloat(bpy_struct):
    """RNA wrapped float"""

    value: float
    """ (in [-inf, inf], default 0.0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PrimitiveInt(bpy_struct):
    """RNA wrapped int"""

    value: int
    """ (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PrimitiveString(bpy_struct):
    """RNA wrapped string"""

    value: bytes
    """ (default b"", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Property(bpy_struct):
    """RNA property definition"""

    deprecated_note: str
    """ A note regarding deprecation (default "", readonly, never None)"""

    deprecated_removal_version: typing.Any
    """ The Blender version this is expected to be removed (array of 3 items, in [-inf, inf], default (0, 0, 0), readonly)"""

    deprecated_version: typing.Any
    """ The Blender version this was deprecated (array of 3 items, in [-inf, inf], default (0, 0, 0), readonly)"""

    description: str
    """ Description of the property for tooltips (default "", readonly, never None)"""

    icon: Literal[bpy.stub_internal.rna_enums.IconItems]
    """ Icon of the item (default 'NONE', readonly)"""

    identifier: str
    """ Unique name used in the code and scripting (default "", readonly, never None)"""

    is_animatable: bool
    """ Property is animatable through RNA (default False, readonly)"""

    is_argument_optional: bool
    """ True when the property is optional in a Python function implementing an RNA function (default False, readonly)"""

    is_deprecated: bool
    """ The property is deprecated (default False, readonly)"""

    is_enum_flag: bool
    """ True when multiple enums (default False, readonly)"""

    is_hidden: bool
    """ True when the property is hidden (default False, readonly)"""

    is_library_editable: bool
    """ Property is editable from linked instances (changes not saved) (default False, readonly)"""

    is_never_none: bool
    """ True when this value cannot be set to None (default False, readonly)"""

    is_output: bool
    """ True when this property is an output value from an RNA function (default False, readonly)"""

    is_overridable: bool
    """ Property is overridable through RNA (default False, readonly)"""

    is_path_output: bool
    """ Property is a filename, filepath or directory output (default False, readonly)"""

    is_path_supports_blend_relative: bool
    """ Property is a path which supports the "//" prefix, signifying the location as relative to the ".blend" file's directory (default False, readonly)"""

    is_path_supports_templates: bool
    """ Property is a path which supports the "{variable_name}" variable expression syntax, which substitutes the value of the referenced variable in place of the expression (default False, readonly)"""

    is_readonly: bool
    """ Property is editable through RNA (default False, readonly)"""

    is_registered: bool
    """ Property is registered as part of type registration (default False, readonly)"""

    is_registered_optional: bool
    """ Property is optionally registered as part of type registration (default False, readonly)"""

    is_required: bool
    """ False when this property is an optional argument in an RNA function (default False, readonly)"""

    is_runtime: bool
    """ Property has been dynamically created at runtime (default False, readonly)"""

    is_skip_preset: bool
    """ True when the property is not saved in presets (default False, readonly)"""

    is_skip_save: bool
    """ True when the property uses ghost values (default False, readonly)"""

    name: str
    """ Human readable name (default "", readonly, never None)"""

    srna: Struct | None
    """ Struct definition used for properties assigned to this item (readonly)"""

    subtype: Literal[bpy.stub_internal.rna_enums.PropertySubtypeItems]
    """ Semantic interpretation of the property (default 'NONE', readonly)"""

    tags: set[str]
    """ Subset of tags (defined in parent struct) that are set for this property (default set(), readonly)"""

    translation_context: str
    """ Translation context of the property's name (default "", readonly, never None)"""

    type: Literal[bpy.stub_internal.rna_enums.PropertyTypeItems]
    """ Data type of the property (default 'BOOLEAN', readonly)"""

    unit: Literal[bpy.stub_internal.rna_enums.PropertyUnitItems]
    """ Type of units for this property (default 'NONE', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PropertyGroup(bpy_struct):
    """Group of ID properties"""

    name: str
    """ Unique name used in the code and scripting, can be re-defined in Python sub-classes if needed (default "", never None)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> typing_extensions.Self:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class PropertyGroupItem(bpy_struct):
    """Property that stores arbitrary, user defined properties"""

    bool: bool
    """ (default False)"""

    bool_array: typing.Any
    """ (array of 1 items, default (False,))"""

    collection: typing.Any
    """ (default None, readonly)"""

    double: float
    """ (in [-inf, inf], default 0.0)"""

    double_array: typing.Any
    """ (array of 1 items, in [-inf, inf], default (0.0,))"""

    enum: typing.Literal["DEFAULT"]
    """ (default 'DEFAULT')"""

    float: float
    """ (in [-inf, inf], default 0.0)"""

    float_array: typing.Any
    """ (array of 1 items, in [-inf, inf], default (0.0,))"""

    group: PropertyGroup | None
    """ (readonly)"""

    id: ID | None
    idp_array: typing.Any
    """ (default None, readonly)"""

    int: int
    """ (in [-inf, inf], default 0)"""

    int_array: typing.Any
    """ (array of 1 items, in [-inf, inf], default (0,))"""

    string: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class QuaternionAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores rotation"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class QuaternionAttributeValue(bpy_struct):
    """Rotation value in geometry attribute"""

    value: typing.Any
    """ Quaternion (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RENDER_UL_renderviews(UIList, bpy_struct):
    def draw_item(
        self, _context, layout, _data, item, icon, _active_data, _active_propname, index
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RaytraceEEVEE(bpy_struct):
    """Quality options for the raytracing pipeline"""

    denoise_bilateral: bool
    """ Blur the resolved radiance using a bilateral filter (default True)"""

    denoise_spatial: bool
    """ Reuse neighbor pixels' rays (default True)"""

    denoise_temporal: bool
    """ Accumulate samples by reprojecting last tracing results (default True)"""

    resolution_scale: typing.Literal["1", "2", "4", "8", "16"]
    """ Determines the number of rays per pixel. Higher resolution uses more memory. (default '2')"""

    screen_trace_quality: float
    """ Precision of the screen space ray-tracing (in [0, 1], default 0.25)"""

    screen_trace_thickness: float
    """ Surface thickness used to detect intersection when using screen-tracing (in [1e-06, inf], default 0.2)"""

    trace_max_roughness: float
    """ Maximum roughness to use the tracing pipeline for. Higher roughness surfaces will use fast GI approximation. A value of 1 will disable fast GI approximation. (in [0, 1], default 0.5)"""

    use_denoise: bool
    """ Enable noise reduction techniques for raytraced effects (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ReadOnlyInteger(bpy_struct):
    value: int
    """ (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Region(bpy_struct):
    """Region in a subdivided screen area"""

    active_panel_category: Literal[
        bpy.stub_internal.rna_enums.RegionPanelCategoryItems
    ] | None
    """ The current active panel category, may be Null if the region does not support this feature (NOTE: these categories are generated at runtime, so list may be empty at initialization, before any drawing took place) (default 'UNSUPPORTED')"""

    alignment: typing.Literal[
        "NONE",
        "TOP",
        "BOTTOM",
        "LEFT",
        "RIGHT",
        "HORIZONTAL_SPLIT",
        "VERTICAL_SPLIT",
        "FLOAT",
        "QUAD_SPLIT",
    ]
    """ Alignment of the region within the area (default 'NONE', readonly)"""

    data: typing.Any | None
    """ Region specific data (the type depends on the region type) (readonly)"""

    height: int
    """ Region height (in [0, 32767], default 0, readonly)"""

    type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems]
    """ Type of this region (default 'WINDOW', readonly)"""

    view2d: View2D | None
    """ 2D view of the region (readonly, never None)"""

    width: int
    """ Region width (in [0, 32767], default 0, readonly)"""

    x: int
    """ The window relative vertical location of the region (in [-inf, inf], default 0, readonly)"""

    y: int
    """ The window relative horizontal location of the region (in [-inf, inf], default 0, readonly)"""

    def tag_redraw(self) -> None:
        """tag_redraw"""

    def tag_refresh_ui(self) -> None:
        """tag_refresh_ui"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RegionView3D(bpy_struct):
    """3D View region data"""

    clip_planes: typing.Any
    """ (multi-dimensional array of 6 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    is_orthographic_side_view: bool
    """ Whether the current view is aligned to an axis (does not check whether the view is orthographic, use "is_perspective" for that). Setting this will rotate the view to the closest axis (default False)"""

    is_perspective: bool
    """ (default False)"""

    lock_rotation: bool
    """ Lock view rotation of side views to Top/Front/Right (default False)"""

    perspective_matrix: mathutils.Matrix
    """ Current perspective matrix (window_matrix * view_matrix) (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    show_sync_view: bool
    """ Sync view position between side views (default False)"""

    use_box_clip: bool
    """ Clip view contents based on what is visible in other side views (default False)"""

    use_clip_planes: bool
    """ (default False)"""

    view_camera_offset: typing.Any
    """ View shift in camera view (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    view_camera_zoom: float
    """ Zoom factor in camera view (in [-30, 600], default 0.0)"""

    view_distance: float
    """ Distance to the view location (in [0, inf], default 0.0)"""

    view_location: mathutils.Vector
    """ View pivot location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    view_matrix: mathutils.Matrix
    """ Current view matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    view_perspective: typing.Literal["PERSP", "ORTHO", "CAMERA"]
    """ View Perspective (default 'ORTHO')"""

    view_rotation: mathutils.Quaternion
    """ Rotation in quaternions (keep normalized) (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    window_matrix: mathutils.Matrix
    """ Current window matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    def update(self) -> None:
        """Recalculate the view matrices"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RemeshModifier(Modifier, bpy_struct):
    """Generate a new surface with regular topology that follows the shape of the input mesh"""

    adaptivity: float
    """ Reduces the final face count by simplifying geometry where detail is not needed, generating triangles. A value greater than 0 disables Fix Poles. (in [-inf, inf], default 0.0)"""

    mode: typing.Literal["BLOCKS", "SMOOTH", "SHARP", "VOXEL"]
    """ (default 'VOXEL')"""

    octree_depth: int
    """ Resolution of the octree; higher values give finer details (in [1, 24], default 4)"""

    scale: float
    """ The ratio of the largest dimension of the model over the size of the grid (in [0, 0.99], default 0.9)"""

    sharpness: float
    """ Tolerance for outliers; lower values filter noise while higher values will reproduce edges closer to the input (in [-inf, inf], default 1.0)"""

    threshold: float
    """ If removing disconnected pieces, minimum size of components to preserve as a ratio of the number of polygons in the largest component (in [0, 1], default 1.0)"""

    use_remove_disconnected: bool
    """ (default True)"""

    use_smooth_shade: bool
    """ Output faces with smooth shading rather than flat shaded (default False)"""

    voxel_size: float
    """ Size of the voxel in object space used for volume evaluation. Lower values preserve finer details. (in [0, inf], default 0.1)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderEngine(bpy_struct):
    """Render engine"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    bl_use_custom_freestyle: bool
    """ Handles freestyle rendering on its own, instead of delegating it to EEVEE (default False)"""

    bl_use_eevee_viewport: bool
    """ Uses EEVEE for viewport shading in Material Preview shading mode (default False)"""

    bl_use_gpu_context: bool
    """ Enable OpenGL context for the render method, for engines that render using OpenGL (default False)"""

    bl_use_image_save: bool
    """ Save images/movie to disk while rendering an animation. Disabling image saving is only supported when bl_use_postprocess is also disabled. (default True)"""

    bl_use_materialx: bool
    """ Use MaterialX for exporting materials to Hydra (default False)"""

    bl_use_postprocess: bool
    """ Apply compositing on render results (default False)"""

    bl_use_preview: bool
    """ Render engine supports being used for rendering previews of materials, lights and worlds (default False)"""

    bl_use_shading_nodes_custom: bool
    """ Don't expose Cycles and EEVEE shading nodes in the node editor user interface, so separate nodes can be used instead (default True)"""

    bl_use_spherical_stereo: bool
    """ Support spherical stereo camera models (default False)"""

    bl_use_stereo_viewport: bool
    """ Support rendering stereo 3D viewport (default False)"""

    camera_override: Object | None
    """ (readonly)"""

    is_animation: bool
    """ (default False)"""

    is_preview: bool
    """ (default False)"""

    layer_override: typing.Any
    """ (array of 20 items, default (False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False))"""

    render: RenderSettings | None
    """ (readonly)"""

    resolution_x: int
    """ (in [-inf, inf], default 0, readonly)"""

    resolution_y: int
    """ (in [-inf, inf], default 0, readonly)"""

    temporary_directory: str
    """ (default "", readonly, never None)"""

    use_highlight_tiles: bool
    """ (default False)"""

    def update(
        self, *, data: BlendData | None = None, depsgraph: Depsgraph | None = None
    ) -> None:
        """Export scene data for render

        :param data: (optional)
        :param depsgraph: (optional)
        """

    def render(self, depsgraph: Depsgraph | None) -> None:
        """Render scene into an image

        :param depsgraph:
        """

    def render_frame_finish(self) -> None:
        """Perform finishing operations after all view layers in a frame were rendered"""

    def draw(self, context: Context, depsgraph: Depsgraph | None) -> None:
        """Draw render image

        :param context:
        :param depsgraph:
        """

    def bake(
        self,
        depsgraph: Depsgraph | None,
        object: Object | None,
        pass_type: Literal[bpy.stub_internal.rna_enums.BakePassTypeItems] | None,
        pass_filter: int | None,
        width: int | None,
        height: int | None,
    ) -> None:
        """Bake passes

        :param depsgraph:
        :param object:
        :param pass_type: Pass, Pass to bake
        :param pass_filter: Pass Filter, Filter to combined, diffuse, glossy and transmission passes (in [0, inf])
        :param width: Width, Image width (in [0, inf])
        :param height: Height, Image height (in [0, inf])
        """

    def view_update(self, context: Context, depsgraph: Depsgraph | None) -> None:
        """Update on data changes for viewport render

        :param context:
        :param depsgraph:
        """

    def view_draw(self, context: Context, depsgraph: Depsgraph | None) -> None:
        """Draw viewport render

        :param context:
        :param depsgraph:
        """

    def update_script_node(self, *, node: Node | None = None) -> None:
        """Compile shader script node

        :param node: (optional)
        """

    def update_render_passes(
        self, *, scene: Scene | None = None, renderlayer: ViewLayer | None = None
    ) -> None:
        """Update the render passes that will be generated

        :param scene: (optional)
        :param renderlayer: (optional)
        """

    def update_custom_camera(self, *, cam: Camera | None = None) -> None:
        """Compile custom camera

        :param cam: (optional)
        """

    def tag_redraw(self) -> None:
        """Request redraw for viewport rendering"""

    def tag_update(self) -> None:
        """Request update call for viewport rendering"""

    def begin_result(
        self,
        x: int | None,
        y: int | None,
        w: int | None,
        h: int | None,
        *,
        layer: str | None = "",
        view: str | None = "",
    ) -> RenderResult:
        """Create render result to write linear floating-point render layers and passes

        :param x: X, (in [0, inf])
        :param y: Y, (in [0, inf])
        :param w: Width, (in [0, inf])
        :param h: Height, (in [0, inf])
        :param layer: Layer, Single layer to get render result for (optional, never None)
        :param view: View, Single view to get render result for (optional, never None)
        :return: Result
        """

    def update_result(self, result: RenderResult | None) -> None:
        """Signal that pixels have been updated and can be redrawn in the user interface

        :param result: Result
        """

    def end_result(
        self,
        result: RenderResult | None,
        *,
        cancel: bool | None = False,
        highlight: bool | None = False,
        do_merge_results: bool | None = False,
    ) -> None:
        """All pixels in the render result have been set and are final

        :param result: Result
        :param cancel: Cancel, Dont mark tile as done, dont merge results unless forced (optional)
        :param highlight: Highlight, Dont mark tile as done yet (optional)
        :param do_merge_results: Merge Results, Merge results even if cancel=true (optional)
        """

    def add_pass(
        self,
        name: str | None,
        channels: int | None,
        chan_id: str | None,
        *,
        layer: str | None = "",
    ) -> None:
        """Add a pass to the render layer

        :param name: Name, Name of the Pass, without view or channel tag (never None)
        :param channels: Channels, (in [0, inf])
        :param chan_id: Channel IDs, Channel names, one character per channel (never None)
        :param layer: Layer, Single layer to add render pass to (optional, never None)
        """

    def get_result(self) -> RenderResult:
        """Get final result for non-pixel operations

        :return: Result
        """

    def test_break(self) -> bool:
        """Test if the render operation should been canceled, this is a fast call that should be used regularly for responsiveness

        :return: Break
        """

    def pass_by_index_get(self, layer: str | None, index: int | None) -> RenderPass:
        """pass_by_index_get

        :param layer: Layer, Name of render layer to get pass for (never None)
        :param index: Index, Index of pass to get (in [0, inf])
        :return: Index, Index of pass to get
        """

    def active_view_get(self) -> str:
        """active_view_get

        :return: View, Single view active (never None)
        """

    def active_view_set(self, view: str | None) -> None:
        """active_view_set

        :param view: View, Single view to set as active (never None)
        """

    def camera_shift_x(
        self, camera: Object | None, *, use_spherical_stereo: bool | None = False
    ) -> float:
        """camera_shift_x

        :param camera:
        :param use_spherical_stereo: Spherical Stereo, (optional)
        :return: Shift X, (in [0, inf])
        """

    def camera_model_matrix(
        self, camera: Object | None, *, use_spherical_stereo: bool | None = False
    ) -> mathutils.Matrix:
        """camera_model_matrix

        :param camera:
        :param use_spherical_stereo: Spherical Stereo, (optional)
        :return: Model Matrix, Normalized camera model matrix (multi-dimensional array of 4 * 4 items, in [-inf, inf])
        """

    def use_spherical_stereo(self, camera: Object | None) -> bool:
        """use_spherical_stereo

        :param camera:
        :return: Spherical Stereo
        """

    def update_stats(self, stats: str | None, info: str | None) -> None:
        """Update and signal to redraw render status text

        :param stats: Stats, (never None)
        :param info: Info, (never None)
        """

    def frame_set(self, frame: int | None, subframe: float | None) -> None:
        """Evaluate scene at a different frame (for motion blur)

        :param frame: Frame, (in [-inf, inf])
        :param subframe: Subframe, (in [0, 1])
        """

    def update_progress(self, progress: float | None) -> None:
        """Update progress percentage of render

        :param progress: Percentage of render thats done (in [0, 1])
        """

    def update_memory_stats(
        self, *, memory_used: float | None = 0.0, memory_peak: float | None = 0.0
    ) -> None:
        """Update memory usage statistics

        :param memory_used: Current memory usage in megabytes (in [0, inf], optional)
        :param memory_peak: Peak memory usage in megabytes (in [0, inf], optional)
        """

    def report(
        self,
        type: set[Literal[bpy.stub_internal.rna_enums.WmReportItems]] | None,
        message: str | None,
    ) -> None:
        """Report info, warning or error messages

        :param type: Type
        :param message: Report Message, (never None)
        """

    def error_set(self, message: str | None) -> None:
        """Set error message displaying after the render is finished

        :param message: Report Message, (never None)
        """

    def bind_display_space_shader(self, scene: Scene | None) -> None:
        """Bind GLSL fragment shader that converts linear colors to display space colors using scene color management settings

        :param scene:
        """

    def unbind_display_space_shader(self) -> None:
        """Unbind GLSL display space shader, must always be called after binding the shader"""

    def support_display_space_shader(self, scene: Scene | None) -> bool:
        """Test if GLSL display space shader is supported for the combination of graphics card and scene settings

        :param scene:
        :return: Supported
        """

    def get_preview_pixel_size(self, scene: Scene | None) -> int:
        """Get the pixel size that should be used for preview rendering

        :param scene:
        :return: Pixel Size, (in [1, 8])
        """

    def free_blender_memory(self) -> None:
        """Free Blender side memory of render engine"""

    def tile_highlight_set(
        self,
        x: int | None,
        y: int | None,
        width: int | None,
        height: int | None,
        highlight: bool | None,
    ) -> None:
        """Set highlighted state of the given tile

        :param x: X, (in [0, inf])
        :param y: Y, (in [0, inf])
        :param width: Width, (in [0, inf])
        :param height: Height, (in [0, inf])
        :param highlight: Highlight
        """

    def tile_highlight_clear_all(self) -> None:
        """The temp directory used by Blender"""

    def register_pass(
        self,
        scene: Scene | None,
        view_layer: ViewLayer | None,
        name: str | None,
        channels: int | None,
        chanid: str | None,
        type: typing.Literal["VALUE", "VECTOR", "COLOR"] | None,
    ) -> None:
        """Register a render pass that will be part of the render with the current settings

        :param scene:
        :param view_layer:
        :param name: Name, (never None)
        :param channels: Channels, (in [1, 8])
        :param chanid: Channel IDs, (never None)
        :param type: Type
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderLayer(bpy_struct):
    name: str
    """ View layer name (default "", readonly, never None)"""

    passes: typing.Any
    """ (default None, readonly)"""

    use_ao: bool
    """ Render Ambient Occlusion in this Layer (default False, readonly)"""

    use_grease_pencil: bool
    """ Render Grease Pencil on this layer (default False, readonly)"""

    use_motion_blur: bool
    """ Render motion blur in this Layer, if enabled in the scene (default False, readonly)"""

    use_pass_ambient_occlusion: bool
    """ Deliver Ambient Occlusion pass (default False, readonly)"""

    use_pass_combined: bool
    """ Deliver full combined RGBA buffer (default False, readonly)"""

    use_pass_diffuse_color: bool
    """ Deliver diffuse color pass (default False, readonly)"""

    use_pass_diffuse_direct: bool
    """ Deliver diffuse direct pass (default False, readonly)"""

    use_pass_diffuse_indirect: bool
    """ Deliver diffuse indirect pass (default False, readonly)"""

    use_pass_emit: bool
    """ Deliver emission pass (default False, readonly)"""

    use_pass_environment: bool
    """ Deliver environment lighting pass (default False, readonly)"""

    use_pass_glossy_color: bool
    """ Deliver glossy color pass (default False, readonly)"""

    use_pass_glossy_direct: bool
    """ Deliver glossy direct pass (default False, readonly)"""

    use_pass_glossy_indirect: bool
    """ Deliver glossy indirect pass (default False, readonly)"""

    use_pass_material_index: bool
    """ Deliver material index pass (default False, readonly)"""

    use_pass_mist: bool
    """ Deliver mist factor pass (0.0 to 1.0) (default False, readonly)"""

    use_pass_normal: bool
    """ Deliver normal pass (default False, readonly)"""

    use_pass_object_index: bool
    """ Deliver object index pass (default False, readonly)"""

    use_pass_position: bool
    """ Deliver position pass (default False, readonly)"""

    use_pass_shadow: bool
    """ Deliver shadow pass (default False, readonly)"""

    use_pass_subsurface_color: bool
    """ Deliver subsurface color pass (default False, readonly)"""

    use_pass_subsurface_direct: bool
    """ Deliver subsurface direct pass (default False, readonly)"""

    use_pass_subsurface_indirect: bool
    """ Deliver subsurface indirect pass (default False, readonly)"""

    use_pass_transmission_color: bool
    """ Deliver transmission color pass (default False, readonly)"""

    use_pass_transmission_direct: bool
    """ Deliver transmission direct pass (default False, readonly)"""

    use_pass_transmission_indirect: bool
    """ Deliver transmission indirect pass (default False, readonly)"""

    use_pass_uv: bool
    """ Deliver texture UV pass (default False, readonly)"""

    use_pass_vector: bool
    """ Deliver speed vector pass (default False, readonly)"""

    use_pass_z: bool
    """ Deliver depth values pass (default False, readonly)"""

    use_sky: bool
    """ Render Sky in this Layer (default False, readonly)"""

    use_solid: bool
    """ Render Solid faces in this Layer (default False, readonly)"""

    use_strand: bool
    """ Render Strands in this Layer (default False, readonly)"""

    use_volumes: bool
    """ Render volumes in this Layer (default False, readonly)"""

    def load_from_file(
        self, filepath: str | None, *, x: int | None = 0, y: int | None = 0
    ) -> None:
        """Copies the pixels of this renderlayer from an image file

        :param filepath: File Path, File path to load into this render tile, must be no smaller than the renderlayer (never None)
        :param x: Offset X, Offset the position to copy from if the image is larger than the render layer (in [0, inf], optional)
        :param y: Offset Y, Offset the position to copy from if the image is larger than the render layer (in [0, inf], optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderPass(bpy_struct):
    channel_id: str
    """ (default "", readonly, never None)"""

    channels: int
    """ (in [-inf, inf], default 0, readonly)"""

    fullname: str
    """ (default "", readonly, never None)"""

    name: str
    """ (default "", readonly, never None)"""

    rect: float
    """ (in [-inf, inf], default 0.0)"""

    view_id: int
    """ (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderResult(bpy_struct):
    """Result of rendering, including all layers and passes"""

    layers: typing.Any
    """ (default None, readonly)"""

    resolution_x: int
    """ (in [-inf, inf], default 0, readonly)"""

    resolution_y: int
    """ (in [-inf, inf], default 0, readonly)"""

    views: typing.Any
    """ (default None, readonly)"""

    def load_from_file(self, filepath: str | None) -> None:
        """Copies the pixels of this render result from an image file

        :param filepath: File Name, Filename to load into this render tile, must be no smaller than the render result (never None)
        """

    def stamp_data_add_field(self, field: str | None, value: str | None) -> None:
        """Add engine-specific stamp data to the result

        :param field: Field, Name of the stamp field to add (never None)
        :param value: Value, Value of the stamp data (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderSettings(bpy_struct):
    """Rendering settings for a Scene data-block"""

    bake: BakeSettings | None
    """ (readonly, never None)"""

    border_max_x: float
    """ Maximum X value for the render region (in [0, 1], default 1.0)"""

    border_max_y: float
    """ Maximum Y value for the render region (in [0, 1], default 1.0)"""

    border_min_x: float
    """ Minimum X value for the render region (in [0, 1], default 0.0)"""

    border_min_y: float
    """ Minimum Y value for the render region (in [0, 1], default 0.0)"""

    compositor_denoise_device: typing.Literal["AUTO", "CPU", "GPU"]
    """ The device to use to process the denoise nodes in the compositor (default 'AUTO')"""

    compositor_denoise_final_quality: typing.Literal["HIGH", "BALANCED", "FAST"]
    """ The quality used by denoise nodes during the compositing of final renders if the nodes' quality option is set to Follow Scene (default 'HIGH')"""

    compositor_denoise_preview_quality: typing.Literal["HIGH", "BALANCED", "FAST"]
    """ The quality used by denoise nodes during viewport and interactive compositing if the nodes' quality option is set to Follow Scene (default 'BALANCED')"""

    compositor_device: typing.Literal["CPU", "GPU"]
    """ Set how compositing is executed (default 'CPU')"""

    compositor_precision: typing.Literal["AUTO", "FULL"]
    """ The precision of compositor intermediate result (default 'AUTO')"""

    dither_intensity: float
    """ Amount of dithering noise added to the rendered image to break up banding (in [0, inf], default 1.0)"""

    engine: typing.Literal["BLENDER_EEVEE"]
    """ Engine to use for rendering (default 'BLENDER_EEVEE')"""

    ffmpeg: FFmpegSettings | None
    """ FFmpeg related settings for the scene (readonly)"""

    file_extension: str
    """ The file extension used for saving renders (default "", readonly, never None)"""

    filepath: str
    """ Directory/name to save animations, # characters define the position and padding of frame numbers (default "", never None, blend relative // prefix supported, Supports template expressions)"""

    film_transparent: bool
    """ World background is transparent, for compositing the render over another background (default False)"""

    filter_size: float
    """ Width over which the reconstruction filter combines samples (in [0, 500], default 1.5)"""

    fps: int
    """ Framerate, expressed in frames per second (in [1, 32767], default 24)"""

    fps_base: float
    """ Framerate base (in [1e-05, 1e+06], default 1.0)"""

    frame_map_new: int
    """ How many frames the Map Old will last (in [1, 900], default 100)"""

    frame_map_old: int
    """ Old mapping value in frames (in [1, 900], default 100)"""

    hair_subdiv: int
    """ Additional subdivision along the curves (in [0, 3], default 0)"""

    hair_type: typing.Literal["STRAND", "STRIP", "CYLINDER"]
    """ Curves shape type (default 'STRAND')"""

    has_multiple_engines: bool
    """ More than one rendering engine is available (default False, readonly)"""

    image_settings: ImageFormatSettings | None
    """ (readonly, never None)"""

    is_movie_format: bool
    """ When true the format is a movie (default False, readonly)"""

    line_thickness: float
    """ Line thickness in pixels (in [0, 10000], default 1.0)"""

    line_thickness_mode: typing.Literal["ABSOLUTE", "RELATIVE"]
    """ Line thickness mode for Freestyle line drawing (default 'ABSOLUTE')"""

    metadata_input: typing.Literal["SCENE", "STRIPS"]
    """ Where to take the metadata from (default 'SCENE')"""

    motion_blur_position: typing.Literal["START", "CENTER", "END"]
    """ Offset for the shutter's time interval, allows to change the motion blur trails (default 'CENTER')"""

    motion_blur_shutter: float
    """ Time taken in frames between shutter open and close (in [0, inf], default 0.5)"""

    motion_blur_shutter_curve: CurveMapping | None
    """ Curve defining the shutter's openness over time (readonly)"""

    pixel_aspect_x: float
    """ Horizontal aspect ratio - for anamorphic or non-square pixel output (in [1, 200], default 1.0)"""

    pixel_aspect_y: float
    """ Vertical aspect ratio - for anamorphic or non-square pixel output (in [1, 200], default 1.0)"""

    ppm_base: float
    """ The base unit for pixels per meter. (in [1e-05, 1e+06], default 0.0254)"""

    ppm_factor: float
    """ The pixel density meta-data written to supported image formats. This value is multiplied by the PPM-base which defines the unit (typically inches or meters) (in [1e-05, 1e+06], default 72.0)"""

    preview_pixel_size: typing.Literal["AUTO", "1", "2", "4", "8"]
    """ Pixel size for viewport rendering (default 'AUTO')"""

    resolution_percentage: int
    """ Percentage scale for render resolution (in [1, 32767], default 100)"""

    resolution_x: int
    """ Number of horizontal pixels in the rendered image (in [4, 65536], default 1920)"""

    resolution_y: int
    """ Number of vertical pixels in the rendered image (in [4, 65536], default 1080)"""

    save_output: bool
    """ Write frames to disk for animation renders (default True)"""

    sequencer_gl_preview: Literal[bpy.stub_internal.rna_enums.ShadingTypeItems]
    """ Display method used in the sequencer view (default 'SOLID')"""

    simplify_child_particles: float
    """ Global child particles percentage (in [0, 1], default 1.0)"""

    simplify_child_particles_render: float
    """ Global child particles percentage during rendering (in [0, 1], default 0.0)"""

    simplify_gpencil: bool
    """ Simplify Grease Pencil drawing (default False)"""

    simplify_gpencil_antialiasing: bool
    """ Use Antialiasing to smooth stroke edges (default True)"""

    simplify_gpencil_modifier: bool
    """ Display modifiers (default True)"""

    simplify_gpencil_onplay: bool
    """ Simplify Grease Pencil only during animation playback (default False)"""

    simplify_gpencil_shader_fx: bool
    """ Display Shader Effects (default True)"""

    simplify_gpencil_tint: bool
    """ Display layer tint (default True)"""

    simplify_gpencil_view_fill: bool
    """ Display fill strokes in the viewport (default True)"""

    simplify_subdivision: int
    """ Global maximum subdivision level (in [0, 32767], default 6)"""

    simplify_subdivision_render: int
    """ Global maximum subdivision level during rendering (in [0, 32767], default 0)"""

    simplify_volumes: float
    """ Resolution percentage of volume objects in viewport (in [0, 1], default 1.0)"""

    stamp_background: typing.Any
    """ Color to use behind stamp text (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.25))"""

    stamp_font_size: int
    """ Size of the font used when rendering stamp text (in [8, 64], default 12)"""

    stamp_foreground: typing.Any
    """ Color to use for stamp text (array of 4 items, in [0, 1], default (0.8, 0.8, 0.8, 1.0))"""

    stamp_note_text: str
    """ Custom text to appear in the stamp note (default "", never None)"""

    stereo_views: typing.Any
    """ (default None, readonly)"""

    threads: int
    """ Maximum number of CPU cores to use simultaneously while rendering (for multi-core/CPU systems) (in [1, 1024], default 1)"""

    threads_mode: typing.Literal["AUTO", "FIXED"]
    """ Determine the amount of render threads used (default 'AUTO')"""

    use_border: bool
    """ Render a user-defined render region, within the frame size (default False)"""

    use_compositing: bool
    """ Process the render result through the compositing pipeline, if a compositing node group is assigned to the scene (default True)"""

    use_crop_to_border: bool
    """ Crop the rendered frame to the defined render region size (default False)"""

    use_file_extension: bool
    """ Add the file format extensions to the rendered file name (eg: filename + .jpg) (default True)"""

    use_freestyle: bool
    """ Draw stylized strokes using Freestyle (default False)"""

    use_high_quality_normals: bool
    """ Use high quality tangent space at the cost of lower performance (default False)"""

    use_lock_interface: bool
    """ Lock interface during rendering in favor of giving more memory to the renderer (default False)"""

    use_motion_blur: bool
    """ Use multi-sampled 3D scene motion blur (default False)"""

    use_multiview: bool
    """ Use multiple views in the scene (default False)"""

    use_overwrite: bool
    """ Overwrite existing files while rendering (default True)"""

    use_persistent_data: bool
    """ Keep render data around for faster re-renders and animation renders, at the cost of increased memory usage (default False)"""

    use_placeholder: bool
    """ Create empty placeholder files while rendering frames (similar to Unix 'touch') (default False)"""

    use_render_cache: bool
    """ Save render cache to EXR files (useful for heavy compositing, Note: affects indirectly rendered scenes) (default False)"""

    use_sequencer: bool
    """ Process the render (and composited) result through the video sequence editor pipeline, if sequencer strips exist (default True)"""

    use_sequencer_override_scene_strip: bool
    """ Use workbench render settings from the sequencer scene, instead of each individual scene used in the strip (default False)"""

    use_simplify: bool
    """ Enable simplification of scene for quicker preview renders (default False)"""

    use_simplify_normals: bool
    """ Skip computing custom normals and face corner normals for displaying meshes in the viewport (default False)"""

    use_single_layer: bool
    """ Only render the active layer. Only affects rendering from the interface, ignored for rendering from command line. (default False)"""

    use_spherical_stereo: bool
    """ Active render engine supports spherical stereo rendering (default False, readonly)"""

    use_stamp: bool
    """ Render the stamp info text in the rendered image (default False)"""

    use_stamp_camera: bool
    """ Include the name of the active camera in image metadata (default True)"""

    use_stamp_date: bool
    """ Include the current date in image/video metadata (default True)"""

    use_stamp_filename: bool
    """ Include the .blend filename in image/video metadata (default True)"""

    use_stamp_frame: bool
    """ Include the frame number in image metadata (default True)"""

    use_stamp_frame_range: bool
    """ Include the rendered frame range in image/video metadata (default False)"""

    use_stamp_hostname: bool
    """ Include the hostname of the machine that rendered the frame (default False)"""

    use_stamp_labels: bool
    """ Display stamp labels ("Camera" in front of camera name, etc.) (default True)"""

    use_stamp_lens: bool
    """ Include the active camera's lens in image metadata (default False)"""

    use_stamp_marker: bool
    """ Include the name of the last marker in image metadata (default False)"""

    use_stamp_memory: bool
    """ Include the peak memory usage in image metadata (default True)"""

    use_stamp_note: bool
    """ Include a custom note in image/video metadata (default False)"""

    use_stamp_render_time: bool
    """ Include the render time in image metadata (default True)"""

    use_stamp_scene: bool
    """ Include the name of the active scene in image/video metadata (default True)"""

    use_stamp_sequencer_strip: bool
    """ Include the name of the foreground sequence strip in image metadata (default False)"""

    use_stamp_time: bool
    """ Include the rendered frame timecode as HH:MM:SS.FF in image metadata (default True)"""

    views: typing.Any
    """ (default None, readonly)"""

    views_format: typing.Literal["STEREO_3D", "MULTIVIEW"]
    """ (default 'STEREO_3D')"""

    def frame_path(
        self,
        *,
        frame: int | None = -2147483648,
        preview: bool | None = False,
        view: str | None = "",
    ) -> str:
        """Return the absolute path to the filename to be written for a given frame

        :param frame: Frame number to use, if unset the current frame will be used (in [-inf, inf], optional)
        :param preview: Preview, Use preview range (optional)
        :param view: View, The name of the view to use to replace the "%" chars (optional, never None)
        :return: File Path, The resulting filepath from the scenes render settings (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderSlot(bpy_struct):
    """Parameters defining the render slot"""

    name: str
    """ Render slot name (default "", never None)"""

    def clear(self, iuser: ImageUser | None) -> None:
        """Clear the render slot

        :param iuser: ImageUser
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RenderView(bpy_struct):
    name: str
    """ (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RepeatItem(bpy_struct):
    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RepeatZoneViewerPathElem(ViewerPathElem, bpy_struct):
    repeat_output_node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RetimingKey(bpy_struct):
    """Key mapped to particular frame that can be moved to change playback speed"""

    timeline_frame: int
    """ Position of retiming key in timeline (in [-inf, inf], default 0)"""

    def remove(self) -> None:
        """Remove retiming key"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RigidBodyConstraint(bpy_struct):
    """Constraint influencing Objects inside Rigid Body Simulation"""

    breaking_threshold: float
    """ Impulse threshold that must be reached for the constraint to break (in [0, inf], default 10.0)"""

    disable_collisions: bool
    """ Disable collisions between constrained rigid bodies (default False)"""

    enabled: bool
    """ Enable this constraint (default False)"""

    limit_ang_x_lower: float
    """ Lower limit of X axis rotation (in [-6.28319, 6.28319], default -0.785398)"""

    limit_ang_x_upper: float
    """ Upper limit of X axis rotation (in [-6.28319, 6.28319], default 0.785398)"""

    limit_ang_y_lower: float
    """ Lower limit of Y axis rotation (in [-6.28319, 6.28319], default -0.785398)"""

    limit_ang_y_upper: float
    """ Upper limit of Y axis rotation (in [-6.28319, 6.28319], default 0.785398)"""

    limit_ang_z_lower: float
    """ Lower limit of Z axis rotation (in [-6.28319, 6.28319], default -0.785398)"""

    limit_ang_z_upper: float
    """ Upper limit of Z axis rotation (in [-6.28319, 6.28319], default 0.785398)"""

    limit_lin_x_lower: float
    """ Lower limit of X axis translation (in [-inf, inf], default -1.0)"""

    limit_lin_x_upper: float
    """ Upper limit of X axis translation (in [-inf, inf], default 1.0)"""

    limit_lin_y_lower: float
    """ Lower limit of Y axis translation (in [-inf, inf], default -1.0)"""

    limit_lin_y_upper: float
    """ Upper limit of Y axis translation (in [-inf, inf], default 1.0)"""

    limit_lin_z_lower: float
    """ Lower limit of Z axis translation (in [-inf, inf], default -1.0)"""

    limit_lin_z_upper: float
    """ Upper limit of Z axis translation (in [-inf, inf], default 1.0)"""

    motor_ang_max_impulse: float
    """ Maximum angular motor impulse (in [0, inf], default 1.0)"""

    motor_ang_target_velocity: float
    """ Target angular motor velocity (in [-inf, inf], default 1.0)"""

    motor_lin_max_impulse: float
    """ Maximum linear motor impulse (in [0, inf], default 1.0)"""

    motor_lin_target_velocity: float
    """ Target linear motor velocity (in [-inf, inf], default 1.0)"""

    object1: Object | None
    """ First Rigid Body Object to be constrained"""

    object2: Object | None
    """ Second Rigid Body Object to be constrained"""

    solver_iterations: int
    """ Number of constraint solver iterations made per simulation step (higher values are more accurate but slower) (in [1, 1000], default 10)"""

    spring_damping_ang_x: float
    """ Damping on the X rotational axis (in [0, inf], default 0.5)"""

    spring_damping_ang_y: float
    """ Damping on the Y rotational axis (in [0, inf], default 0.5)"""

    spring_damping_ang_z: float
    """ Damping on the Z rotational axis (in [0, inf], default 0.5)"""

    spring_damping_x: float
    """ Damping on the X axis (in [0, inf], default 0.5)"""

    spring_damping_y: float
    """ Damping on the Y axis (in [0, inf], default 0.5)"""

    spring_damping_z: float
    """ Damping on the Z axis (in [0, inf], default 0.5)"""

    spring_stiffness_ang_x: float
    """ Stiffness on the X rotational axis (in [0, inf], default 10.0)"""

    spring_stiffness_ang_y: float
    """ Stiffness on the Y rotational axis (in [0, inf], default 10.0)"""

    spring_stiffness_ang_z: float
    """ Stiffness on the Z rotational axis (in [0, inf], default 10.0)"""

    spring_stiffness_x: float
    """ Stiffness on the X axis (in [0, inf], default 10.0)"""

    spring_stiffness_y: float
    """ Stiffness on the Y axis (in [0, inf], default 10.0)"""

    spring_stiffness_z: float
    """ Stiffness on the Z axis (in [0, inf], default 10.0)"""

    spring_type: typing.Literal["SPRING1", "SPRING2"]
    """ Which implementation of spring to use (default 'SPRING1')"""

    type: Literal[bpy.stub_internal.rna_enums.RigidbodyConstraintTypeItems]
    """ Type of Rigid Body Constraint (default 'POINT')"""

    use_breaking: bool
    """ Constraint can be broken if it receives an impulse above the threshold (default False)"""

    use_limit_ang_x: bool
    """ Limit rotation around X axis (default False)"""

    use_limit_ang_y: bool
    """ Limit rotation around Y axis (default False)"""

    use_limit_ang_z: bool
    """ Limit rotation around Z axis (default False)"""

    use_limit_lin_x: bool
    """ Limit translation on X axis (default False)"""

    use_limit_lin_y: bool
    """ Limit translation on Y axis (default False)"""

    use_limit_lin_z: bool
    """ Limit translation on Z axis (default False)"""

    use_motor_ang: bool
    """ Enable angular motor (default False)"""

    use_motor_lin: bool
    """ Enable linear motor (default False)"""

    use_override_solver_iterations: bool
    """ Override the number of solver iterations for this constraint (default False)"""

    use_spring_ang_x: bool
    """ Enable spring on X rotational axis (default False)"""

    use_spring_ang_y: bool
    """ Enable spring on Y rotational axis (default False)"""

    use_spring_ang_z: bool
    """ Enable spring on Z rotational axis (default False)"""

    use_spring_x: bool
    """ Enable spring on X axis (default False)"""

    use_spring_y: bool
    """ Enable spring on Y axis (default False)"""

    use_spring_z: bool
    """ Enable spring on Z axis (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RigidBodyObject(bpy_struct):
    """Settings for object participating in Rigid Body Simulation"""

    angular_damping: float
    """ Amount of angular velocity that is lost over time (in [0, 1], default 0.1)"""

    collision_collections: typing.Any
    """ Collision collections rigid body belongs to (array of 20 items, default (False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False, False))"""

    collision_margin: float
    """ Threshold of distance near surface where collisions are still considered (best results when non-zero) (in [0, 1], default 0.04)"""

    collision_shape: Literal[bpy.stub_internal.rna_enums.RigidbodyObjectShapeItems]
    """ Collision Shape of object in Rigid Body Simulations (default 'BOX')"""

    deactivate_angular_velocity: float
    """ Angular Velocity below which simulation stops simulating object (in [0, inf], default 0.5)"""

    deactivate_linear_velocity: float
    """ Linear Velocity below which simulation stops simulating object (in [0, inf], default 0.4)"""

    enabled: bool
    """ Rigid Body actively participates to the simulation (default True)"""

    friction: float
    """ Resistance of object to movement (in [0, inf], default 0.5)"""

    kinematic: bool
    """ Allow rigid body to be controlled by the animation system (default False)"""

    linear_damping: float
    """ Amount of linear velocity that is lost over time (in [0, 1], default 0.04)"""

    mass: float
    """ How much the object 'weighs' irrespective of gravity (in [0.001, inf], default 1.0)"""

    mesh_source: typing.Literal["BASE", "DEFORM", "FINAL"]
    """ Source of the mesh used to create collision shape (default 'BASE')"""

    restitution: float
    """ Tendency of object to bounce after colliding with another (0 = stays still, 1 = perfectly elastic) (in [0, inf], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.RigidbodyObjectTypeItems]
    """ Role of object in Rigid Body Simulations (default 'ACTIVE')"""

    use_deactivation: bool
    """ Enable deactivation of resting rigid bodies (increases performance and stability but can cause glitches) (default True)"""

    use_deform: bool
    """ Rigid body deforms during simulation (default False)"""

    use_margin: bool
    """ Use custom collision margin (some shapes will have a visible gap around them) (default False)"""

    use_start_deactivated: bool
    """ Deactivate rigid body at the start of the simulation (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class RigidBodyWorld(bpy_struct):
    """Self-contained rigid body simulation environment and settings"""

    collection: Collection | None
    """ Collection containing objects participating in this simulation"""

    constraints: Collection | None
    """ Collection containing rigid body constraint objects"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    enabled: bool
    """ Simulation will be evaluated (default True)"""

    point_cache: PointCache | None
    """ (readonly, never None)"""

    solver_iterations: int
    """ Number of constraint solver iterations made per simulation step (higher values are more accurate but slower) (in [1, 1000], default 10)"""

    substeps_per_frame: int
    """ Number of simulation steps taken per frame (higher values are more accurate but slower) (in [1, 32767], default 10)"""

    time_scale: float
    """ Change the speed of the simulation (in [0, 100], default 1.0)"""

    use_split_impulse: bool
    """ Reduce extra velocity that can build up when objects collide (lowers simulation stability a little so use only when necessary) (default False)"""

    def convex_sweep_test(
        self,
        object: Object | None,
        start: collections.abc.Sequence[float] | mathutils.Vector | None,
        end: collections.abc.Sequence[float] | mathutils.Vector | None,
    ) -> tuple[mathutils.Vector, mathutils.Vector, mathutils.Vector, int]:
        """Sweep test convex rigidbody against the current rigidbody world

                :param object: Rigidbody object with a convex collision shape (never None)
                :param start: (array of 3 items, in [-inf, inf])
                :param end: (array of 3 items, in [-inf, inf])
                :return: object_location, The hit location of this sweep test, `mathutils.Vector`

        hitpoint, The hit location of this sweep test, `mathutils.Vector`

        normal, The face normal at the sweep test hit location, `mathutils.Vector`

        has_hit, If the function has found collision point, value is 1, otherwise 0, int
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SCENE_UL_gltf2_filter_action(UIList, bpy_struct):
    def draw_item(
        self, context, layout, data, item, icon, active_data, active_propname, index
    ) -> None:
        """

        :param context:
        :param layout:
        :param data:
        :param item:
        :param icon:
        :param active_data:
        :param active_propname:
        :param index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SCENE_UL_keying_set_paths(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SEQUENCER_FH_image_strip(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SEQUENCER_FH_movie_strip(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SEQUENCER_FH_sound_strip(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SPHFluidSettings(bpy_struct):
    """Settings for particle fluids physics"""

    buoyancy: float
    """ Artificial buoyancy force in negative gravity direction based on pressure differences inside the fluid (in [0, 10], default 0.0)"""

    fluid_radius: float
    """ Fluid interaction radius (in [0, 20], default 0.0)"""

    linear_viscosity: float
    """ Linear viscosity (in [0, 100], default 0.0)"""

    plasticity: float
    """ How much the spring rest length can change after the elastic limit is crossed (in [0, 100], default 0.0)"""

    repulsion: float
    """ How strongly the fluid tries to keep from clustering (factor of stiffness) (in [0, 100], default 0.0)"""

    rest_density: float
    """ Fluid rest density (in [0, 10000], default 0.0)"""

    rest_length: float
    """ Spring rest length (factor of particle radius) (in [0, 2], default 0.0)"""

    solver: typing.Literal["DDR", "CLASSICAL"]
    """ The code used to calculate internal forces on particles (default 'DDR')"""

    spring_force: float
    """ Spring force (in [0, 100], default 0.0)"""

    spring_frames: int
    """ Create springs for this number of frames since particles birth (0 is always) (in [0, 100], default 0)"""

    stiff_viscosity: float
    """ Creates viscosity for expanding fluid (in [0, 100], default 0.0)"""

    stiffness: float
    """ How incompressible the fluid is (speed of sound) (in [0, 1000], default 0.0)"""

    use_factor_density: bool
    """ Density is calculated as a factor of default density (depends on particle size) (default False)"""

    use_factor_radius: bool
    """ Interaction radius is a factor of 4 * particle size (default False)"""

    use_factor_repulsion: bool
    """ Repulsion is a factor of stiffness (default False)"""

    use_factor_rest_length: bool
    """ Spring rest length is a factor of 2 * particle size (default False)"""

    use_factor_stiff_viscosity: bool
    """ Stiff viscosity is a factor of normal viscosity (default False)"""

    use_initial_rest_length: bool
    """ Use the initial length as spring rest length instead of 2 * particle size (default False)"""

    use_viscoelastic_springs: bool
    """ Use viscoelastic springs instead of Hooke's springs (default False)"""

    yield_ratio: float
    """ How much the spring has to be stretched/compressed in order to change its rest length (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Scene(ID, bpy_struct):
    """Scene data-block, consisting in objects and defining time and render related settings"""

    active_clip: MovieClip | None
    """ Active Movie Clip that can be used by motion tracking constraints or as a camera's background image"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    annotation: Annotation | None
    """ Data-block used for annotations in the 3D view"""

    audio_distance_model: typing.Literal[
        "NONE",
        "INVERSE",
        "INVERSE_CLAMPED",
        "LINEAR",
        "LINEAR_CLAMPED",
        "EXPONENT",
        "EXPONENT_CLAMPED",
    ]
    """ Distance model for distance attenuation calculation (default 'INVERSE_CLAMPED')"""

    audio_doppler_factor: float
    """ Pitch factor for Doppler effect calculation (in [0, inf], default 1.0)"""

    audio_doppler_speed: float
    """ Speed of sound for Doppler effect calculation (in [0.01, inf], default 343.3)"""

    audio_volume: float
    """ Audio volume (in [0, 100], default 1.0)"""

    background_set: typing_extensions.Self | None
    """ Background set scene"""

    camera: Object | None
    """ Active camera, used for rendering the scene"""

    collection: Collection | None
    """ Scene root collection that owns all the objects and other collections instantiated in the scene (readonly, never None)"""

    compositing_node_group: NodeTree | None
    """ Compositor Nodes"""

    cursor: View3DCursor | None
    """ (readonly, never None)"""

    cycles: typing.Any
    """ Cycles render settings (readonly)"""

    cycles_curves: typing.Any
    """ Cycles curves rendering settings (readonly)"""

    display: SceneDisplay | None
    """ Scene display settings for 3D viewport (readonly)"""

    display_settings: ColorManagedDisplaySettings | None
    """ Settings of device saved image would be displayed on (readonly)"""

    eevee: SceneEEVEE | None
    """ EEVEE settings for the scene (readonly)"""

    frame_current: int
    """ Current frame, to update animation data from Python frame_set() instead (in [-1048574, 1048574], default 1)"""

    frame_current_final: float
    """ Current frame with subframe and time remapping applied (in [-1.04857e+06, 1.04857e+06], default 0.0, readonly)"""

    frame_end: int
    """ Final frame of the playback/rendering range (in [0, 1048574], default 250)"""

    frame_float: float
    """ (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    frame_preview_end: int
    """ Alternative end frame for UI playback (in [-inf, inf], default 0)"""

    frame_preview_start: int
    """ Alternative start frame for UI playback (in [-inf, inf], default 0)"""

    frame_start: int
    """ First frame of the playback/rendering range (in [0, 1048574], default 1)"""

    frame_step: int
    """ Number of frames to skip forward while rendering/playing back each frame (in [0, 1048574], default 1)"""

    frame_subframe: float
    """ (in [0, 1], default 0.0)"""

    gravity: mathutils.Vector
    """ Constant acceleration in a given direction (array of 3 items, in [-inf, inf], default (0.0, 0.0, -9.81))"""

    grease_pencil_settings: SceneGpencil | None
    """ Grease Pencil settings for the scene (readonly)"""

    hydra: SceneHydra | None
    """ Hydra settings for the scene (readonly)"""

    is_nla_tweakmode: bool
    """ Whether there is any action referenced by NLA being edited (strictly read-only) (default False, readonly)"""

    keying_sets: typing.Any
    """ Absolute Keying Sets for this Scene (default None, readonly)"""

    keying_sets_all: typing.Any
    """ All Keying Sets available for use (Builtins and Absolute Keying Sets for this Scene) (default None, readonly)"""

    lock_frame_selection_to_range: bool
    """ Don't allow frame to be selected with mouse outside of frame range (default False)"""

    objects: typing.Any
    """ (default None, readonly)"""

    render: RenderSettings | None
    """ (readonly, never None)"""

    rigidbody_world: RigidBodyWorld | None
    """ (readonly)"""

    safe_areas: DisplaySafeAreas | None
    """ (readonly, never None)"""

    sequence_editor: SequenceEditor | None
    """ (readonly)"""

    sequencer_colorspace_settings: ColorManagedSequencerColorspaceSettings | None
    """ Settings of color space sequencer is working in (readonly)"""

    show_keys_from_selected_only: bool
    """ Only include channels relating to selected objects and data (default True)"""

    show_subframe: bool
    """ Display and allow setting fractional frame values for the current frame (default False)"""

    simulation_frame_end: int
    """ Frame at which simulations end (in [-inf, inf], default 250)"""

    simulation_frame_start: int
    """ Frame at which simulations start (in [-inf, inf], default 1)"""

    sync_mode: typing.Literal["NONE", "FRAME_DROP", "AUDIO_SYNC"]
    """ How to sync playback (default 'AUDIO_SYNC')"""

    time_jump_delta: float
    """ Number of frames or seconds to jump forward or backward (in [0.1, inf], default 1.0)"""

    time_jump_unit: typing.Literal["FRAME", "SECOND"]
    """ Which unit to use for time jumps in the timeline (default 'SECOND')"""

    timeline_markers: typing.Any
    """ Markers used in all timelines for the current scene (default None, readonly)"""

    tool_settings: ToolSettings | None
    """ (readonly, never None)"""

    transform_orientation_slots: typing.Any
    """ (default None, readonly)"""

    unit_settings: UnitSettings | None
    """ Unit editing settings (readonly, never None)"""

    use_audio: bool
    """ Play back of audio from Sequence Editor, otherwise mute audio (default False)"""

    use_audio_scrub: bool
    """ Play audio from Sequence Editor while scrubbing (default False)"""

    use_custom_simulation_range: bool
    """ Use a simulation range that is different from the scene range for simulation nodes that don't override the frame range themselves (default False)"""

    use_gravity: bool
    """ Use global gravity for all dynamics (default True)"""

    use_nodes: bool
    """ Enable the compositing node group. (default False)Unused but kept for compatibility reasons. Setting the property has no effect, and getting it always returns True. Use #scene.render.use_compositing to turn compositing to enable or disable compositing.5.0 removal planned in version 6.0"""

    use_preview_range: bool
    """ Use an alternative start/end frame range for animation playback and view renders (default False)"""

    use_stamp_note: str
    """ User defined note for the render stamping (default "", never None)"""

    view_layers: typing.Any
    """ (default None, readonly)"""

    view_settings: ColorManagedViewSettings | None
    """ Color management settings applied on image before saving (readonly)"""

    world: World | None
    """ World used for rendering the scene"""

    @classmethod
    def update_render_engine(cls) -> None:
        """Trigger a render engine update"""

    def statistics(self, view_layer: ViewLayer | None) -> str:
        """statistics

        :param view_layer: View Layer, (never None)
        :return: Statistics, (never None)
        """

    def frame_set(self, frame: int | None, *, subframe: float | None = 0.0) -> None:
        """Set scene frame updating all objects and view layers immediately

        :param frame: Frame number to set (in [-1048574, 1048574])
        :param subframe: Subframe time, between 0.0 and 1.0 (in [0, 1], optional)
        """

    def uvedit_aspect(self, object: Object | None) -> mathutils.Vector:
        """Get uv aspect for current object

        :param object: Object (never None)
        :return: aspect (array of 2 items, in [0, inf])
        """

    def ray_cast(
        self,
        depsgraph: Depsgraph | None,
        origin: collections.abc.Sequence[float] | mathutils.Vector | None,
        direction: collections.abc.Sequence[float] | mathutils.Vector | None,
        *,
        distance: float | None = 1.70141e38,
    ) -> tuple[bool, mathutils.Vector, mathutils.Vector, int, Object, mathutils.Matrix]:
        """Cast a ray onto evaluated geometry in world-space

                :param depsgraph: The current dependency graph (never None)
                :param origin: (array of 3 items, in [-inf, inf])
                :param direction: (array of 3 items, in [-inf, inf])
                :param distance: Maximum distance (in [0, inf], optional)
                :return: result, bool

        location, The hit location of this ray cast, `mathutils.Vector`

        normal, The face normal at the ray cast hit location, `mathutils.Vector`

        index, The face index, -1 when original data isnt available, int

        object, Ray cast object, `Object`

        matrix, Matrix, `mathutils.Matrix`
        """

    def sequence_editor_create(self) -> SequenceEditor:
        """Ensure sequence editor is valid in this scene

        :return: New sequence editor data or None
        """

    def sequence_editor_clear(self) -> None:
        """Clear sequence editor in this scene"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneDisplay(bpy_struct):
    """Scene display settings for 3D viewport"""

    light_direction: mathutils.Vector
    """ Direction of the light for shadows and highlights (array of 3 items, in [-inf, inf], default (0.57735, 0.57735, 0.57735))"""

    matcap_ssao_attenuation: float
    """ Attenuation constant (in [0, 100000], default 1.0)"""

    matcap_ssao_distance: float
    """ Distance of object that contribute to the cavity/edge effect (in [0, 100000], default 0.2)"""

    matcap_ssao_samples: int
    """ Number of samples (in [1, 500], default 16)"""

    render_aa: typing.Literal["OFF", "FXAA", "5", "8", "11", "16", "32"]
    """ Method of anti-aliasing when rendering final image (default '8')"""

    shading: View3DShading | None
    """ Shading settings for OpenGL render engine (readonly)"""

    shadow_focus: float
    """ Shadow factor hardness (in [0, 1], default 0.0)"""

    shadow_shift: float
    """ Shadow termination angle (in [0, 1], default 0.1)"""

    viewport_aa: typing.Literal["OFF", "FXAA", "5", "8", "11", "16", "32"]
    """ Method of anti-aliasing when rendering 3d viewport (default 'FXAA')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneEEVEE(bpy_struct):
    """Scene display settings for 3D viewport"""

    bokeh_max_size: float
    """ Max size of the bokeh shape for the depth of field (lower is faster) (in [0, 2000], default 100.0)"""

    bokeh_neighbor_max: float
    """ Maximum brightness to consider when rejecting bokeh sprites based on neighborhood (lower is faster) (in [0, 100000], default 10.0)"""

    bokeh_overblur: float
    """ Apply blur to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 5.0)"""

    bokeh_threshold: float
    """ Brightness threshold for using sprite base depth of field (in [0, 100000], default 1.0)"""

    clamp_surface_direct: float
    """ If non-zero, the maximum value for lights contribution on a surface. Higher values will be scaled down to avoid too much noise and slow convergence at the cost of accuracy. Used by light objects. (in [0, inf], default 0.0)"""

    clamp_surface_indirect: float
    """ If non-zero, the maximum value for indirect lighting on surface. Higher values will be scaled down to avoid too much noise and slow convergence at the cost of accuracy. Used by ray-tracing and light-probes. (in [0, inf], default 10.0)"""

    clamp_volume_direct: float
    """ If non-zero, the maximum value for lights contribution in volumes. Higher values will be scaled down to avoid too much noise and slow convergence at the cost of accuracy. Used by light objects. (in [0, inf], default 0.0)"""

    clamp_volume_indirect: float
    """ If non-zero, the maximum value for indirect lighting in volumes. Higher values will be scaled down to avoid too much noise and slow convergence at the cost of accuracy. Used by light-probes. (in [0, inf], default 0.0)"""

    direct_light_intensity: float
    """ Scale the contribution of direct lighting (in [0, inf], default 1.0)"""

    fast_gi_bias: float
    """ Bias the shading normal to reduce self intersection artifacts (in [0, 1], default 0.05)"""

    fast_gi_distance: float
    """ If non-zero, the maximum distance at which other surfaces will contribute to the fast GI approximation (in [0, 100000], default 0.0)"""

    fast_gi_method: typing.Literal["AMBIENT_OCCLUSION_ONLY", "GLOBAL_ILLUMINATION"]
    """ Fast GI approximation method (default 'GLOBAL_ILLUMINATION')"""

    fast_gi_quality: float
    """ Precision of the fast GI ray marching (in [0, 1], default 0.25)"""

    fast_gi_ray_count: int
    """ Amount of GI ray to trace for each pixel (in [1, 16], default 2)"""

    fast_gi_resolution: typing.Literal["1", "2", "4", "8", "16"]
    """ Control the quality of the fast GI lighting. Higher resolution uses more memory. (default '2')"""

    fast_gi_step_count: int
    """ Amount of screen sample per GI ray (in [1, 64], default 8)"""

    fast_gi_thickness_far: float
    """ Angular thickness of the surfaces when computing fast GI and ambient occlusion. Reduces energy loss and missing occlusion of far geometry. (in [0.0174533, 3.14159], default 0.785398)"""

    fast_gi_thickness_near: float
    """ Geometric thickness of the surfaces when computing fast GI and ambient occlusion. Reduces light leaking and missing contact occlusion. (in [0, 100000], default 0.25)"""

    gi_cubemap_resolution: typing.Literal["128", "256", "512", "1024", "2048", "4096"]
    """ Size of every cubemaps (default '512')"""

    gi_diffuse_bounces: int
    """ Number of times the light is reinjected inside light grids, 0 disable indirect diffuse light (in [0, inf], default 3)"""

    gi_glossy_clamp: float
    """ Clamp pixel intensity to reduce noise inside glossy reflections from reflection cubemaps (0 to disable) (in [0, inf], default 0.0)"""

    gi_irradiance_pool_size: typing.Literal[
        "16", "32", "64", "128", "256", "512", "1024"
    ]
    """ Size of the irradiance pool, a bigger pool size allows for more irradiance grid in the scene but might not fit into GPU memory and decrease performance (default '16')"""

    gi_visibility_resolution: typing.Literal["8", "16", "32", "64"]
    """ Size of the shadow map applied to each irradiance sample (default '32')"""

    indirect_light_intensity: float
    """ Scale the contribution of indirect lighting (in [0, inf], default 1.0)"""

    light_threshold: float
    """ Minimum light intensity for a light to contribute to the lighting (in [0, inf], default 0.01)"""

    motion_blur_depth_scale: float
    """ Lower values will reduce background bleeding onto foreground elements (in [0, inf], default 100.0)"""

    motion_blur_max: int
    """ Maximum blur distance a pixel can spread over (in [0, 2048], default 32)"""

    motion_blur_steps: int
    """ Controls accuracy of motion blur, more steps means longer render time (in [1, inf], default 1)"""

    overscan_size: float
    """ Percentage of render size to add as overscan to the internal render buffers (in [0, 50], default 3.0)"""

    ray_tracing_method: typing.Literal["PROBE", "SCREEN"]
    """ Select the tracing method used to find scene-ray intersections (default 'SCREEN')"""

    ray_tracing_options: RaytraceEEVEE | None
    """ EEVEE settings for tracing reflections (readonly)"""

    shadow_pool_size: typing.Literal["16", "32", "64", "128", "256", "512", "1024"]
    """ Size of the shadow pool, a bigger pool size allows for more shadows in the scene but might not fit into GPU memory (default '512')"""

    shadow_ray_count: int
    """ Amount of shadow ray to trace for each light (in [1, 4], default 1)"""

    shadow_resolution_scale: float
    """ Resolution percentage of shadow maps (in [0, 1], default 1.0)"""

    shadow_step_count: int
    """ Amount of shadow map sample per shadow ray (in [1, 16], default 6)"""

    taa_render_samples: int
    """ Number of samples per pixel for rendering (in [1, inf], default 64)"""

    taa_samples: int
    """ Number of samples, unlimited if 0 (in [0, inf], default 16)"""

    use_bokeh_jittered: bool
    """ Jitter camera position to create accurate blurring using render samples (only for final render) (default False)"""

    use_fast_gi: bool
    """ Use faster global illumination technique for high roughness surfaces (default False)"""

    use_overscan: bool
    """ Internally render past the image border to avoid screen-space effects disappearing (default False)"""

    use_raytracing: bool
    """ Enable the ray-tracing module (default False)"""

    use_shadow_jitter_viewport: bool
    """ Enable jittered shadows on the viewport. (Jittered shadows are always enabled for final renders). (default False)"""

    use_shadows: bool
    """ Enable shadow casting from lights (default True)"""

    use_taa_reprojection: bool
    """ Denoise image using temporal reprojection (can leave some ghosting) (default True)"""

    use_volume_custom_range: bool
    """ Enable custom start and end clip distances for volume computation (default False)"""

    use_volumetric_shadows: bool
    """ Cast shadows from volumetric materials onto volumetric materials (Very expensive) (default False)"""

    volumetric_end: float
    """ End distance of the volumetric effect (in [1e-06, inf], default 100.0)"""

    volumetric_light_clamp: float
    """ Maximum light contribution, reducing noise (in [0, inf], default 0.0)"""

    volumetric_ray_depth: int
    """ Maximum surface intersection count used by the accurate volume intersection method. Will create artifact if it is exceeded. Higher count increases VRAM usage. (in [1, 16], default 16)"""

    volumetric_sample_distribution: float
    """ Distribute more samples closer to the camera (in [0, 1], default 0.8)"""

    volumetric_samples: int
    """ Number of steps to compute volumetric effects. Higher step count increase VRAM usage and quality. (in [1, 256], default 64)"""

    volumetric_shadow_samples: int
    """ Number of samples to compute volumetric shadowing (in [1, 128], default 16)"""

    volumetric_start: float
    """ Start distance of the volumetric effect (in [1e-06, inf], default 0.1)"""

    volumetric_tile_size: typing.Literal["1", "2", "4", "8", "16"]
    """ Control the quality of the volumetric effects. Higher resolution uses more memory. (default '8')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneGpencil(bpy_struct):
    """Render settings"""

    aa_samples: int
    """ Number of supersampling anti-aliasing samples per pixel for final render (in [1, inf], default 8)"""

    antialias_threshold: float
    """ Threshold for edge detection algorithm (higher values might over-blur some part of the image) (in [0, inf], default 1.0)"""

    antialias_threshold_render: float
    """ Threshold for edge detection algorithm (higher values might over-blur some part of the image). Only applies to final render (in [0, inf], default 0.25)"""

    motion_blur_steps: int
    """ Controls accuracy of motion blur, more steps result in longer render time. Only used when Motion Blur is enabled. Set to 0 to disable motion blur for Grease Pencil (in [0, inf], default 8)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneHydra(bpy_struct):
    """Scene Hydra render engine settings"""

    export_method: typing.Literal["HYDRA", "USD"]
    """ How to export the Blender scene to the Hydra render engine (default 'HYDRA')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneRenderView(bpy_struct):
    """Render viewpoint for 3D stereo and multiview rendering"""

    camera_suffix: str
    """ Suffix to identify the cameras to use, and added to the render images for this view (default "", never None)"""

    file_suffix: str
    """ Suffix added to the render images for this view (default "", never None)"""

    name: str
    """ Render view name (default "", never None)"""

    use: bool
    """ Disable or enable the render view (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SceneStrip(Strip, bpy_struct):
    """Sequence strip using the rendered image of a scene"""

    alpha_mode: typing.Literal["STRAIGHT", "PREMUL"]
    """ Representation of alpha information in the RGBA pixels (default 'STRAIGHT')"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    color_multiply: float
    """ (in [0, 20], default 1.0)"""

    color_saturation: float
    """ Adjust the intensity of the input's color (in [0, 20], default 1.0)"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    crop: StripCrop | None
    """ (readonly)"""

    fps: float
    """ Frames per second (in [-inf, inf], default 0.0, readonly)"""

    multiply_alpha: bool
    """ Multiply alpha along with color channels (default False)"""

    proxy: StripProxy | None
    """ (readonly)"""

    retiming_keys: typing.Any
    """ (default None, readonly)"""

    scene: Scene | None
    """ Scene that this strip uses"""

    scene_camera: Object | None
    """ Override the scene's active camera"""

    scene_input: typing.Literal["CAMERA", "SEQUENCER"]
    """ Input type to use for the Scene strip (default 'CAMERA')"""

    strobe: float
    """ Only display every nth frame (in [1, 30], default 0.0)"""

    transform: StripTransform | None
    """ (readonly)"""

    use_annotations: bool
    """ Show Annotations in OpenGL previews (default True)"""

    use_deinterlace: bool
    """ Remove fields from video movies (default False)"""

    use_flip_x: bool
    """ Flip on the X axis (default False)"""

    use_flip_y: bool
    """ Flip on the Y axis (default False)"""

    use_float: bool
    """ Convert input to float data (default False)"""

    use_proxy: bool
    """ Use a preview proxy and/or time-code index for this strip (default False)"""

    use_reverse_frames: bool
    """ Reverse frame order (default False)"""

    volume: float
    """ Playback volume of the sound (in [0, 100], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Scopes(bpy_struct):
    """Scopes for statistical view of an image"""

    accuracy: float
    """ Proportion of original image source pixel lines to sample (in [0, 100], default 0.0)"""

    histogram: Histogram | None
    """ Histogram for viewing image statistics (readonly)"""

    use_full_resolution: bool
    """ Sample every pixel of the image (default False)"""

    vectorscope_alpha: float
    """ Opacity of the points (in [0, 1], default 0.0)"""

    vectorscope_mode: typing.Literal["LUMA", "RGB"]
    """ (default 'RGB')"""

    waveform_alpha: float
    """ Opacity of the points (in [0, 1], default 0.0)"""

    waveform_mode: typing.Literal[
        "LUMA", "PARADE", "YCBCR601", "YCBCR709", "YCBCRJPG", "RGB"
    ]
    """ (default 'LUMA')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Screen(ID, bpy_struct):
    """Screen data-block, defining the layout of areas in a window"""

    areas: typing.Any
    """ Areas the screen is subdivided into (default None, readonly)"""

    is_animation_playing: bool
    """ Animation playback is active (default False, readonly)"""

    is_scrubbing: bool
    """ True when the user is scrubbing through time (default False, readonly)"""

    is_temporary: bool
    """ (default False, readonly)"""

    show_fullscreen: bool
    """ An area is maximized, filling this screen (default False, readonly)"""

    show_statusbar: bool
    """ Show status bar (default True)"""

    use_follow: bool
    """ Follow current frame in editors (default False)"""

    use_play_3d_editors: bool
    """ (default False)"""

    use_play_animation_editors: bool
    """ (default False)"""

    use_play_clip_editors: bool
    """ (default False)"""

    use_play_image_editors: bool
    """ (default False)"""

    use_play_node_editors: bool
    """ (default False)"""

    use_play_properties_editors: bool
    """ (default False)"""

    use_play_sequence_editors: bool
    """ (default False)"""

    use_play_spreadsheet_editors: bool
    """ (default False)"""

    use_play_top_left_3d_editor: bool
    """ (default False)"""

    def statusbar_info(self) -> str:
        """statusbar_info

        :return: Status Bar Info, (never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ScrewModifier(Modifier, bpy_struct):
    """Revolve edges"""

    angle: float
    """ Angle of revolution (in [-inf, inf], default 6.28319)"""

    axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Screw axis (default 'Z')"""

    iterations: int
    """ Number of times to apply the screw operation (in [1, 10000], default 1)"""

    merge_threshold: float
    """ Limit below which to merge vertices (in [0, inf], default 0.01)"""

    object: Object | None
    """ Object to define the screw axis"""

    render_steps: int
    """ Number of steps in the revolution (in [1, 10000], default 16)"""

    screw_offset: float
    """ Offset the revolution along its axis (in [-inf, inf], default 0.0)"""

    steps: int
    """ Number of steps in the revolution (in [1, 10000], default 16)"""

    use_merge_vertices: bool
    """ Merge adjacent vertices (screw offset must be zero) (default False)"""

    use_normal_calculate: bool
    """ Calculate the order of edges (needed for meshes, but not curves) (default False)"""

    use_normal_flip: bool
    """ Flip normals of lathed faces (default False)"""

    use_object_screw_offset: bool
    """ Use the distance between the objects to make a screw (default False)"""

    use_smooth_shade: bool
    """ Output faces with smooth shading rather than flat shaded (default True)"""

    use_stretch_u: bool
    """ Stretch the U coordinates between 0 and 1 when UVs are present (default False)"""

    use_stretch_v: bool
    """ Stretch the V coordinates between 0 and 1 when UVs are present (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ScriptDirectory(bpy_struct):
    directory: str
    """ Alternate script path, matching the default layout with sub-directories: startup, add-ons, modules, and presets (requires restart) (default "", never None)"""

    name: str
    """ Identifier for the Python scripts directory (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Sculpt(Paint, bpy_struct):
    automasking_boundary_edges_propagation_steps: int
    """ Distance where boundary edge automasking is going to protect vertices from the fully masked edge (in [1, 20], default 1)"""

    automasking_cavity_blur_steps: int
    """ The number of times the cavity mask is blurred (in [0, 25], default 0)"""

    automasking_cavity_curve: CurveMapping | None
    """ Curve used for the sensitivity (readonly)"""

    automasking_cavity_curve_op: CurveMapping | None
    """ Curve used for the sensitivity (readonly)"""

    automasking_cavity_factor: float
    """ The contrast of the cavity mask (in [0, 5], default 1.0)"""

    automasking_start_normal_falloff: float
    """ Extend the angular range with a falloff gradient (in [0.0001, 1], default 0.25)"""

    automasking_start_normal_limit: float
    """ The range of angles that will be affected (in [0.0001, 3.14159], default 0.349066)"""

    automasking_view_normal_falloff: float
    """ Extend the angular range with a falloff gradient (in [0.0001, 1], default 0.25)"""

    automasking_view_normal_limit: float
    """ The range of angles that will be affected (in [0.0001, 3.14159], default 1.5708)"""

    constant_detail_resolution: float
    """ Maximum edge length for dynamic topology sculpting (as divisor of Blender unit - higher value means smaller edge length) (in [0.0001, inf], default 3.0)"""

    detail_percent: float
    """ Maximum edge length for dynamic topology sculpting (in brush percentage) (in [0.5, 100], default 25.0)"""

    detail_refine_method: typing.Literal["SUBDIVIDE", "COLLAPSE", "SUBDIVIDE_COLLAPSE"]
    """ In dynamic-topology mode, how to add or remove mesh detail (default 'SUBDIVIDE_COLLAPSE')"""

    detail_size: float
    """ Maximum edge length for dynamic topology sculpting (in pixels) (in [0.5, 40], default 12.0)"""

    detail_type_method: typing.Literal["RELATIVE", "CONSTANT", "BRUSH", "MANUAL"]
    """ In dynamic-topology mode, how mesh detail size is calculated (default 'RELATIVE')"""

    gravity: float
    """ Amount of gravity after each dab (in [0, 1], default 0.0)"""

    gravity_object: Object | None
    """ Object whose Z axis defines orientation of gravity"""

    lock_x: bool
    """ Disallow changes to the X axis of vertices (default False)"""

    lock_y: bool
    """ Disallow changes to the Y axis of vertices (default False)"""

    lock_z: bool
    """ Disallow changes to the Z axis of vertices (default False)"""

    symmetrize_direction: Literal[bpy.stub_internal.rna_enums.SymmetrizeDirectionItems]
    """ Source and destination for symmetrize operator (default 'NEGATIVE_X')"""

    transform_mode: typing.Literal["ALL_VERTICES", "RADIUS_ELASTIC"]
    """ How the transformation is going to be applied to the target (default 'ALL_VERTICES')"""

    use_automasking_boundary_edges: bool
    """ Do not affect non manifold boundary edges (default False)"""

    use_automasking_boundary_face_sets: bool
    """ Do not affect vertices that belong to a face set boundary (default False)"""

    use_automasking_cavity: bool
    """ Do not affect vertices on peaks, based on the surface curvature (default False)"""

    use_automasking_cavity_inverted: bool
    """ Do not affect vertices within crevices, based on the surface curvature (default False)"""

    use_automasking_custom_cavity_curve: bool
    """ Use custom curve (default False)"""

    use_automasking_face_sets: bool
    """ Affect only vertices that share face sets with the active vertex (default False)"""

    use_automasking_start_normal: bool
    """ Affect only vertices with a similar normal to where the stroke starts (default False)"""

    use_automasking_topology: bool
    """ Affect only vertices connected to the active vertex under the brush (default False)"""

    use_automasking_view_normal: bool
    """ Affect only vertices with a normal that faces the viewer (default False)"""

    use_automasking_view_occlusion: bool
    """ Only affect vertices that are not occluded by other faces (slower performance) (default False)"""

    use_deform_only: bool
    """ Use only deformation modifiers (temporary disable all constructive modifiers except multi-resolution) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SelectedUvElement(PropertyGroup, bpy_struct):
    element_index: int
    """ (in [0, inf], default 0)"""

    face_index: int
    """ (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequenceEditor(bpy_struct):
    """Sequence editing data for a Scene data-block"""

    active_strip: Strip | None
    """ Sequencer's active strip"""

    cache_final_size: int
    """ Size of final rendered images cache in megabytes (in [-inf, inf], default 0, readonly)"""

    cache_raw_size: int
    """ Size of raw source images cache in megabytes (in [-inf, inf], default 0, readonly)"""

    channels: typing.Any
    """ (default None, readonly)"""

    meta_stack: typing.Any
    """ Meta strip stack, last is currently edited meta strip (default None, readonly)"""

    overlay_frame: int
    """ Number of frames to offset (in [-inf, inf], default 0)"""

    proxy_dir: str
    """ (default "", never None, blend relative // prefix supported)"""

    proxy_storage: typing.Literal["PER_STRIP", "PROJECT"]
    """ How to store proxies for this project (default 'PER_STRIP')"""

    selected_retiming_keys: bool
    """ (default False, readonly)"""

    show_missing_media: bool
    """ Render missing images/movies with a solid magenta color (default False)"""

    show_overlay_frame: bool
    """ Partial overlay on top of the sequencer with a frame offset (default False)"""

    strips: typing.Any
    """ Top-level strips only (default None, readonly)"""

    strips_all: typing.Any
    """ All strips, recursively including those inside metastrips (default None, readonly)"""

    use_cache_final: bool
    """ Cache final image for each frame (default False)"""

    use_cache_raw: bool
    """ Cache raw images read from disk, for faster tweaking of strip parameters at the cost of memory usage (default False)"""

    use_overlay_frame_lock: bool
    """ (default False)"""

    use_prefetch: bool
    """ Render frames ahead of current frame in the background for faster playback (default False)"""

    def display_stack(self, meta_sequence: Strip | None) -> None:
        """Display strips stack

        :param meta_sequence: Meta Strip, Meta to display its stack
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequenceTimelineChannel(bpy_struct):
    lock: bool
    """ (default False)"""

    mute: bool
    """ (default False)"""

    name: str
    """ (default "", never None)"""

    number: int
    """ Channel number (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerCacheOverlay(bpy_struct):
    show_cache: bool
    """ Visualize cached images on the timeline (default False)"""

    show_cache_final_out: bool
    """ Visualize cached complete frames (default False)"""

    show_cache_raw: bool
    """ Visualize cached raw images (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerCompositorModifierData(StripModifier, bpy_struct):
    """Compositor Modifier"""

    node_group: NodeTree | None
    """ Node group that controls what this modifier does"""

    open_mask_input_panel: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerPreviewOverlay(bpy_struct):
    show_annotation: bool
    """ Show annotations for this view (default False)"""

    show_cursor: bool
    """ (default False)"""

    show_image_outline: bool
    """ (default False)"""

    show_metadata: bool
    """ Show metadata of first visible strip (default False)"""

    show_safe_areas: bool
    """ Show TV title safe and action safe areas in preview (default False)"""

    show_safe_center: bool
    """ Show safe areas to fit content in a different aspect ratio (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerTimelineOverlay(bpy_struct):
    show_fcurves: bool
    """ Display strip opacity/volume curve (default False)"""

    show_grid: bool
    """ Show vertical grid lines (default False)"""

    show_strip_duration: bool
    """ (default False)"""

    show_strip_name: bool
    """ (default False)"""

    show_strip_offset: bool
    """ Display strip in/out offsets (default False)"""

    show_strip_retiming: bool
    """ Display retiming keys on top of strips (default False)"""

    show_strip_source: bool
    """ Display path to source file, or name of source data-block (default False)"""

    show_strip_tag_color: bool
    """ Display the strip color tags in the sequencer (default False)"""

    thumbnail_display_style: typing.Literal["NO_THUMBNAILS", "STRIP_ENDS", "CONTINUOUS"]
    """ How thumbnails are displayed (default 'NO_THUMBNAILS')"""

    waveform_display_style: typing.Literal["FULL_WAVEFORMS", "HALF_WAVEFORMS"]
    """ How Waveforms are displayed (default 'FULL_WAVEFORMS')"""

    waveform_display_type: typing.Literal[
        "ALL_WAVEFORMS", "DEFAULT_WAVEFORMS", "NO_WAVEFORMS"
    ]
    """ How Waveforms are displayed (default 'DEFAULT_WAVEFORMS')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerTonemapModifierData(StripModifier, bpy_struct):
    """Tone mapping modifier"""

    adaptation: float
    """ If 0, global; if 1, based on pixel intensity (in [0, 1], default 0.0)"""

    contrast: float
    """ Set to 0 to use estimate from input image (in [0, 1], default 0.0)"""

    correction: float
    """ If 0, same for all channels; if 1, each independent (in [0, 1], default 0.0)"""

    gamma: float
    """ If not used, set to 1 (in [0.001, 3], default 0.0)"""

    intensity: float
    """ If less than zero, darkens image; otherwise, makes it brighter (in [-8, 8], default 0.0)"""

    key: float
    """ The value the average luminance is mapped to (in [0, 1], default 0.0)"""

    offset: float
    """ Normally always 1, but can be used as an extra control to alter the brightness curve (in [0.001, 10], default 0.0)"""

    open_mask_input_panel: bool
    """ (default False)"""

    tonemap_type: typing.Literal["RD_PHOTORECEPTOR", "RH_SIMPLE"]
    """ Tone mapping algorithm (default 'RH_SIMPLE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SequencerToolSettings(bpy_struct):
    fit_method: Literal[bpy.stub_internal.rna_enums.StripScaleMethodItems]
    """ Scale fit method (default 'FIT')"""

    overlap_mode: typing.Literal["EXPAND", "OVERWRITE", "SHUFFLE"]
    """ How to resolve overlap after transformation (default 'EXPAND')"""

    pivot_point: typing.Literal["CENTER", "MEDIAN", "CURSOR", "INDIVIDUAL_ORIGINS"]
    """ Rotation or scaling pivot point (default 'CENTER')"""

    snap_distance: int
    """ Maximum distance for snapping in pixels (in [-inf, inf], default 15)"""

    snap_ignore_muted: bool
    """ Don't snap to hidden strips (default False)"""

    snap_ignore_sound: bool
    """ Don't snap to sound strips (default False)"""

    snap_to_borders: bool
    """ Snap to preview borders (default False)"""

    snap_to_center: bool
    """ Snap to preview center (default False)"""

    snap_to_current_frame: bool
    """ Snap to current frame (default False)"""

    snap_to_frame_range: bool
    """ Snap to preview or scene start and end frame (default False)"""

    snap_to_hold_offset: bool
    """ Snap to underlying strip content start and end in cases where the strip length extends beyond this range, producing holds (default False)"""

    snap_to_markers: bool
    """ Snap to markers (default False)"""

    snap_to_retiming_keys: bool
    """ Snap to retiming keys (default False)"""

    snap_to_strips_preview: bool
    """ Snap to borders and origins of deselected, visible strips (default False)"""

    use_snap_current_frame_to_strips: bool
    """ Snap current frame to strip start or end (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFx(bpy_struct):
    """Effect affecting the Grease Pencil object"""

    name: str
    """ Effect name (default "", never None)"""

    show_expanded: bool
    """ Set effect expansion in the user interface (default False)"""

    show_in_editmode: bool
    """ Display effect in Edit mode (default False)"""

    show_render: bool
    """ Use effect during render (default False)"""

    show_viewport: bool
    """ Display effect in viewport (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.ObjectShaderfxTypeItems]
    """ (default 'FX_BLUR', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxBlur(ShaderFx, bpy_struct):
    """Gaussian Blur effect"""

    rotation: float
    """ Rotation of the effect (in [-inf, inf], default 0.0)"""

    samples: int
    """ Number of Blur Samples (zero, disable blur) (in [0, 32], default 4)"""

    size: mathutils.Vector
    """ Factor of Blur (array of 2 items, in [0, inf], default (0.0, 0.0))"""

    use_dof_mode: bool
    """ Blur using camera depth of field (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxColorize(ShaderFx, bpy_struct):
    """Colorize effect"""

    factor: float
    """ Mix factor (in [0, 1], default 0.0)"""

    high_color: typing.Any
    """ Second color used for effect (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    low_color: typing.Any
    """ First color used for effect (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    mode: typing.Literal["GRAYSCALE", "SEPIA", "DUOTONE", "TRANSPARENT", "CUSTOM"]
    """ Effect mode (default 'GRAYSCALE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxFlip(ShaderFx, bpy_struct):
    """Flip effect"""

    use_flip_x: bool
    """ Flip image horizontally (default False)"""

    use_flip_y: bool
    """ Flip image vertically (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxGlow(ShaderFx, bpy_struct):
    """Glow effect"""

    blend_mode: typing.Literal["REGULAR", "ADD", "SUBTRACT", "MULTIPLY", "DIVIDE"]
    """ Blend mode (default 'REGULAR')"""

    glow_color: mathutils.Color
    """ Color used for generated glow (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    mode: typing.Literal["LUMINANCE", "COLOR"]
    """ Glow mode (default 'LUMINANCE')"""

    opacity: float
    """ Effect Opacity (in [0, 1], default 0.0)"""

    rotation: float
    """ Rotation of the effect (in [-inf, inf], default 0.0)"""

    samples: int
    """ Number of Blur Samples (in [1, 32], default 4)"""

    select_color: mathutils.Color
    """ Color selected to apply glow (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    size: mathutils.Vector
    """ Size of the effect (array of 2 items, in [0, inf], default (0.0, 0.0))"""

    threshold: float
    """ Limit to select color for glow effect (in [0, 1], default 0.0)"""

    use_glow_under: bool
    """ Glow only areas with alpha (not supported with Regular blend mode) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxPixel(ShaderFx, bpy_struct):
    """Pixelate effect"""

    size: typing.Any
    """ Pixel size (array of 2 items, in [1, 32767], default (0, 0))"""

    use_antialiasing: bool
    """ Antialias pixels (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxRim(ShaderFx, bpy_struct):
    """Rim effect"""

    blur: typing.Any
    """ Number of pixels for blurring rim (set to 0 to disable) (array of 2 items, in [0, 32767], default (0, 0))"""

    mask_color: mathutils.Color
    """ Color that must be kept (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    mode: typing.Literal["NORMAL", "OVERLAY", "ADD", "SUBTRACT", "MULTIPLY", "DIVIDE"]
    """ Blend mode (default 'NORMAL')"""

    offset: typing.Any
    """ Offset of the rim (array of 2 items, in [-32768, 32767], default (0, 0))"""

    rim_color: mathutils.Color
    """ Color used for Rim (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    samples: int
    """ Number of Blur Samples (zero, disable blur) (in [0, 32], default 4)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxShadow(ShaderFx, bpy_struct):
    """Shadow effect"""

    amplitude: float
    """ Amplitude of Wave (in [0, inf], default 0.0)"""

    blur: typing.Any
    """ Number of pixels for blurring shadow (set to 0 to disable) (array of 2 items, in [0, 32767], default (0, 0))"""

    object: Object | None
    """ Object to determine center of rotation"""

    offset: typing.Any
    """ Offset of the shadow (array of 2 items, in [-32768, 32767], default (0, 0))"""

    orientation: typing.Literal["HORIZONTAL", "VERTICAL"]
    """ Direction of the wave (default 'HORIZONTAL')"""

    period: float
    """ Period of Wave (in [0, inf], default 0.0)"""

    phase: float
    """ Phase Shift of Wave (in [-inf, inf], default 0.0)"""

    rotation: float
    """ Rotation around center or object (in [-6.28319, 6.28319], default 0.0)"""

    samples: int
    """ Number of Blur Samples (zero, disable blur) (in [0, 32], default 4)"""

    scale: mathutils.Vector
    """ Scale of the shadow (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    shadow_color: typing.Any
    """ Color used for Shadow (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    use_object: bool
    """ Use object as center of rotation (default False)"""

    use_wave: bool
    """ Use wave effect (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxSwirl(ShaderFx, bpy_struct):
    """Swirl effect"""

    angle: float
    """ Angle of rotation (in [-31.4159, 31.4159], default 0.0)"""

    object: Object | None
    """ Object to determine center location"""

    radius: int
    """ Radius to apply (in [0, 32767], default 0)"""

    use_transparent: bool
    """ Make image transparent outside of radius (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderFxWave(ShaderFx, bpy_struct):
    """Wave Deformation effect"""

    amplitude: float
    """ Amplitude of Wave (in [0, inf], default 0.0)"""

    orientation: typing.Literal["HORIZONTAL", "VERTICAL"]
    """ Direction of the wave (default 'HORIZONTAL')"""

    period: float
    """ Period of Wave (in [0, inf], default 0.0)"""

    phase: float
    """ Phase Shift of Wave (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNode(NodeInternal, Node, bpy_struct):
    """Material shader node"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeAddShader(ShaderNode, NodeInternal, Node, bpy_struct):
    """Add two Shaders together"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeAmbientOcclusion(ShaderNode, NodeInternal, Node, bpy_struct):
    """Compute how much the hemisphere above the shading point is occluded, for example to add weathering effects to corners.
    Note: For Cycles, this may slow down renders significantly
    """

    inside: bool
    """ Trace rays towards the inside of the object (default False)"""

    only_local: bool
    """ Only consider the object itself when computing AO (default False)"""

    samples: int
    """ Number of rays to trace per shader evaluation (in [1, 128], default 0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeAttribute(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve attributes attached to objects or geometry"""

    attribute_name: str
    """ (default "", never None)"""

    attribute_type: typing.Literal["GEOMETRY", "OBJECT", "INSTANCER", "VIEW_LAYER"]
    """ General type of the attribute (default 'GEOMETRY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBackground(ShaderNode, NodeInternal, Node, bpy_struct):
    """Add background light emission.
    Note: This node should only be used for the world surface output
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBevel(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generates normals with round corners.
    Note: only supported in Cycles, and may slow down renders
    """

    samples: int
    """ Number of rays to trace per shader evaluation (in [2, 128], default 0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBlackbody(ShaderNode, NodeInternal, Node, bpy_struct):
    """Convert a blackbody temperature to an RGB value"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBrightContrast(ShaderNode, NodeInternal, Node, bpy_struct):
    """Control the brightness and contrast of the input color"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfAnisotropic(ShaderNode, NodeInternal, Node, bpy_struct):
    """Reflection with microfacet distribution, used for materials such as metal or mirrors"""

    distribution: typing.Literal["BECKMANN", "GGX", "ASHIKHMIN_SHIRLEY", "MULTI_GGX"]
    """ Light scattering distribution on rough surface (default 'BECKMANN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfDiffuse(ShaderNode, NodeInternal, Node, bpy_struct):
    """Lambertian and Oren-Nayar diffuse reflection"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfGlass(ShaderNode, NodeInternal, Node, bpy_struct):
    """Glass-like shader mixing refraction and reflection at grazing angles"""

    distribution: typing.Literal["BECKMANN", "GGX", "MULTI_GGX"]
    """ Light scattering distribution on rough surface (default 'BECKMANN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfHair(ShaderNode, NodeInternal, Node, bpy_struct):
    """Reflection and transmission shaders optimized for hair rendering"""

    component: typing.Literal["Reflection", "Transmission"]
    """ Hair BSDF component to use (default 'Reflection')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfHairPrincipled(ShaderNode, NodeInternal, Node, bpy_struct):
    """Physically-based, easy-to-use shader for rendering hair and fur"""

    model: typing.Literal["CHIANG", "HUANG"]
    """ Select from Chiang or Huang model (default 'HUANG')"""

    parametrization: typing.Literal["ABSORPTION", "MELANIN", "COLOR"]
    """ Select the shader's color parametrization (default 'COLOR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfMetallic(ShaderNode, NodeInternal, Node, bpy_struct):
    """Metallic reflection with microfacet distribution, and metallic fresnel"""

    distribution: typing.Literal["BECKMANN", "GGX", "MULTI_GGX"]
    """ Light scattering distribution on rough surface (default 'BECKMANN')"""

    fresnel_type: typing.Literal["PHYSICAL_CONDUCTOR", "F82"]
    """ Fresnel method used to tint the metal (default 'PHYSICAL_CONDUCTOR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfPrincipled(ShaderNode, NodeInternal, Node, bpy_struct):
    """Physically-based, easy-to-use shader for rendering surface materials, based on the OpenPBR model"""

    distribution: typing.Literal["GGX", "MULTI_GGX"]
    """ Light scattering distribution on rough surface (default 'GGX')"""

    subsurface_method: typing.Literal["BURLEY", "RANDOM_WALK", "RANDOM_WALK_SKIN"]
    """ Method for rendering subsurface scattering (default 'BURLEY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfRayPortal(ShaderNode, NodeInternal, Node, bpy_struct):
    """Continue tracing from an arbitrary new position and in a new direction"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfRefraction(ShaderNode, NodeInternal, Node, bpy_struct):
    """Glossy refraction with sharp or microfacet distribution, typically used for materials that transmit light"""

    distribution: typing.Literal["BECKMANN", "GGX"]
    """ Light scattering distribution on rough surface (default 'BECKMANN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfSheen(ShaderNode, NodeInternal, Node, bpy_struct):
    """Reflection for materials such as cloth.
    Typically mixed with other shaders (such as a Diffuse Shader) and is not particularly useful on its own
    """

    distribution: typing.Literal["ASHIKHMIN", "MICROFIBER"]
    """ Sheen shading model (default 'ASHIKHMIN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfToon(ShaderNode, NodeInternal, Node, bpy_struct):
    """Diffuse and Glossy shaders with cartoon light effects"""

    component: typing.Literal["DIFFUSE", "GLOSSY"]
    """ Toon BSDF component to use (default 'DIFFUSE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfTranslucent(ShaderNode, NodeInternal, Node, bpy_struct):
    """Lambertian diffuse transmission"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBsdfTransparent(ShaderNode, NodeInternal, Node, bpy_struct):
    """Transparency without refraction, passing straight through the surface as if there were no geometry"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeBump(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a perturbed normal from a height texture for bump mapping. Typically used for faking highly detailed surfaces"""

    invert: bool
    """ Invert the bump mapping direction to push into the surface instead of out (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeCameraData(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about the camera and how it relates to the current shading points position"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeClamp(ShaderNode, NodeInternal, Node, bpy_struct):
    """Clamp a value between a minimum and a maximum"""

    clamp_type: Literal[bpy.stub_internal.rna_enums.NodeClampItems]
    """ (default 'MINMAX')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeCombineColor(ShaderNode, NodeInternal, Node, bpy_struct):
    """Create a color from individual components using multiple models"""

    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeCombineXYZ(ShaderNode, NodeInternal, Node, bpy_struct):
    """Create a vector from X, Y, and Z components"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeCustomGroup(ShaderNode, NodeInternal, Node, bpy_struct):
    """Custom Shader Group Node for Python nodes"""

    node_tree: ShaderNodeTree | None

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeDisplacement(ShaderNode, NodeInternal, Node, bpy_struct):
    """Displace the surface along the surface normal"""

    space: typing.Literal["OBJECT", "WORLD"]
    """ Space of the input height (default 'OBJECT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeEeveeSpecular(ShaderNode, NodeInternal, Node, bpy_struct):
    """Similar to the Principled BSDF node but uses the specular workflow instead of metallic, which functions by specifying the facing (along normal) reflection color. Energy is not conserved, so the result may not be physically accurate"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeEmission(ShaderNode, NodeInternal, Node, bpy_struct):
    """Lambertian emission shader"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeFloatCurve(ShaderNode, NodeInternal, Node, bpy_struct):
    """Map an input float to a curve and outputs a float value"""

    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeFresnel(ShaderNode, NodeInternal, Node, bpy_struct):
    """Produce a blending factor depending on the angle between the surface normal and the view direction using Fresnel equations.
    Typically used for mixing reflections at grazing angles
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeGamma(ShaderNode, NodeInternal, Node, bpy_struct):
    """Apply a gamma correction"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeGroup(ShaderNode, NodeInternal, Node, bpy_struct):
    node_tree: ShaderNodeTree | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeHairInfo(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve hair curve information"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeHoldout(ShaderNode, NodeInternal, Node, bpy_struct):
    """Create a "hole" in the image with zero alpha transparency, which is useful for compositing.
    Note: the holdout shader can only create alpha when transparency is enabled in the film settings
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeHueSaturation(ShaderNode, NodeInternal, Node, bpy_struct):
    """Apply a color transformation in the HSV color model"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeInvert(ShaderNode, NodeInternal, Node, bpy_struct):
    """Invert a color, producing a negative"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeLayerWeight(ShaderNode, NodeInternal, Node, bpy_struct):
    """Produce a blending factor depending on the angle between the surface normal and the view direction.
    Typically used for layering shaders with the Mix Shader node
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeLightFalloff(ShaderNode, NodeInternal, Node, bpy_struct):
    """Manipulate how light intensity decreases over distance. Typically used for non-physically-based effects; in reality light always falls off quadratically"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeLightPath(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve the type of incoming ray for which the shader is being executed.
    Typically used for non-physically-based tricks
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMapRange(ShaderNode, NodeInternal, Node, bpy_struct):
    """Remap a value from a range to a target range"""

    clamp: bool
    """ Clamp the result to the target range [To Min, To Max] (default False)"""

    data_type: typing.Literal["FLOAT", "FLOAT_VECTOR"]
    """ (default 'FLOAT')"""

    interpolation_type: Literal[bpy.stub_internal.rna_enums.NodeMapRangeItems]
    """ (default 'LINEAR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMapping(ShaderNode, NodeInternal, Node, bpy_struct):
    """Transform the input vector by applying translation, rotation, and scale"""

    vector_type: Literal[bpy.stub_internal.rna_enums.MappingTypeItems]
    """ Type of vector that the mapping transforms (default 'POINT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMath(ShaderNode, NodeInternal, Node, bpy_struct):
    """Perform math operations"""

    operation: Literal[bpy.stub_internal.rna_enums.NodeMathItems]
    """ (default 'ADD')"""

    use_clamp: bool
    """ Clamp result of the node to 0.0 to 1.0 range (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMix(ShaderNode, NodeInternal, Node, bpy_struct):
    """Mix values by a factor"""

    blend_type: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ (default 'MIX')"""

    clamp_factor: bool
    """ Clamp the factor to [0,1] range (default False)"""

    clamp_result: bool
    """ Clamp the result to [0,1] range (default False)"""

    data_type: typing.Literal["FLOAT", "VECTOR", "RGBA", "ROTATION"]
    """ (default 'FLOAT')"""

    factor_mode: typing.Literal["UNIFORM", "NON_UNIFORM"]
    """ (default 'UNIFORM')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMixRGB(ShaderNode, NodeInternal, Node, bpy_struct):
    """Mix two input colors"""

    blend_type: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ (default 'MIX')"""

    use_alpha: bool
    """ Include alpha of second input in this operation (default False)"""

    use_clamp: bool
    """ Clamp result of the node to 0.0 to 1.0 range (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeMixShader(ShaderNode, NodeInternal, Node, bpy_struct):
    """Mix two shaders together. Typically used for material layering"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeNewGeometry(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve geometric information about the current shading point"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeNormal(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a normal vector and a dot product"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeNormalMap(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a perturbed normal from an RGB normal map image. Typically used for faking highly detailed surfaces"""

    base: typing.Literal["ORIGINAL", "DISPLACED"]
    """ Base surface that the normal map is applied relative to, when displacement is used (default 'DISPLACED')"""

    convention: typing.Literal["OPENGL", "DIRECTX"]
    """ OpenGL or DirectX (default 'OPENGL')"""

    space: typing.Literal[
        "TANGENT", "OBJECT", "WORLD", "BLENDER_OBJECT", "BLENDER_WORLD"
    ]
    """ Space of the input normal (default 'TANGENT')"""

    uv_map: str
    """ UV Map for tangent space maps (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeObjectInfo(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about the object instance"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeOutputAOV(ShaderNode, NodeInternal, Node, bpy_struct):
    """Arbitrary Output Variables.
    Provide custom render passes for arbitrary shader node outputs
    """

    aov_name: str
    """ Name of the AOV that this output writes to (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeOutputLight(ShaderNode, NodeInternal, Node, bpy_struct):
    """Output light information to a light object"""

    is_active_output: bool
    """ True if this node is used as the active output (default False)"""

    target: typing.Literal["ALL", "EEVEE", "CYCLES"]
    """ Which renderer and viewport shading types to use the shaders for (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeOutputLineStyle(ShaderNode, NodeInternal, Node, bpy_struct):
    """Control the mixing of texture information into the base color of line styles"""

    blend_type: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ (default 'MIX')"""

    is_active_output: bool
    """ True if this node is used as the active output (default False)"""

    target: typing.Literal["ALL", "EEVEE", "CYCLES"]
    """ Which renderer and viewport shading types to use the shaders for (default 'ALL')"""

    use_alpha: bool
    """ Include alpha of second input in this operation (default False)"""

    use_clamp: bool
    """ Clamp result of the node to 0.0 to 1.0 range (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeOutputMaterial(ShaderNode, NodeInternal, Node, bpy_struct):
    """Output surface material information for use in rendering"""

    is_active_output: bool
    """ True if this node is used as the active output (default False)"""

    target: typing.Literal["ALL", "EEVEE", "CYCLES"]
    """ Which renderer and viewport shading types to use the shaders for (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeOutputWorld(ShaderNode, NodeInternal, Node, bpy_struct):
    """Output light color information to the scenes World"""

    is_active_output: bool
    """ True if this node is used as the active output (default False)"""

    target: typing.Literal["ALL", "EEVEE", "CYCLES"]
    """ Which renderer and viewport shading types to use the shaders for (default 'ALL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeParticleInfo(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve the data of the particle that spawned the object instance, for example to give variation to multiple instances of an object"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodePointInfo(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve information about points in a point cloud"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeRGB(ShaderNode, NodeInternal, Node, bpy_struct):
    """A color picker"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeRGBCurve(ShaderNode, NodeInternal, Node, bpy_struct):
    """Apply color corrections for each color channel"""

    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeRGBToBW(ShaderNode, NodeInternal, Node, bpy_struct):
    """Convert a colors luminance to a grayscale value"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeRadialTiling(ShaderNode, NodeInternal, Node, bpy_struct):
    """Transform Coordinate System for Radial Tiling"""

    normalize: bool
    """ Normalize the X coordinate of the Segment Coordinates output to a [0, 1] interval and offset the Y coordinate into a [0, infinity) interval. When checked, the textures are stretched to fit into each angular segment. When not checked, the parts of the textures that don't fit into each angular segment are cropped (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeRaycast(ShaderNode, NodeInternal, Node, bpy_struct):
    """Cast rays and retrieve information from the hit point"""

    only_local: bool
    """ Only raycast against the object itself (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeScript(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate an OSL shader from a file or text data-block.
    Note: OSL shaders are not supported on all GPU backends
    """

    bytecode: str
    """ Compile bytecode for shader script node (default "", never None)"""

    bytecode_hash: str
    """ Hash of compile bytecode, for quick equality checking (default "", never None)"""

    filepath: str
    """ Shader script path (default "", never None, blend relative // prefix supported)"""

    mode: typing.Literal["INTERNAL", "EXTERNAL"]
    """ (default 'INTERNAL')"""

    script: Text | None
    """ Internal shader script to define the shader"""

    use_auto_update: bool
    """ Automatically update the shader when the .osl file changes (external scripts only) (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeSeparateColor(ShaderNode, NodeInternal, Node, bpy_struct):
    """Split a color into its individual components using multiple models"""

    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeSeparateXYZ(ShaderNode, NodeInternal, Node, bpy_struct):
    """Split a vector into its X, Y, and Z components"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeShaderToRGB(ShaderNode, NodeInternal, Node, bpy_struct):
    """Convert rendering effect (such as light and shadow) to color. Typically used for non-photorealistic rendering, to apply additional effects on the output of BSDFs.
    Note: only supported in EEVEE
    """

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeSqueeze(ShaderNode, NodeInternal, Node, bpy_struct):
    """Deprecated"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeSubsurfaceScattering(ShaderNode, NodeInternal, Node, bpy_struct):
    """Subsurface multiple scattering shader to simulate light entering the surface and bouncing internally.
    Typically used for materials such as skin, wax, marble or milk
    """

    falloff: typing.Literal["BURLEY", "RANDOM_WALK", "RANDOM_WALK_SKIN"]
    """ Method for rendering subsurface scattering (default 'BURLEY')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTangent(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a tangent direction for the Anisotropic BSDF"""

    axis: typing.Literal["X", "Y", "Z"]
    """ Axis for radial tangents (default 'X')"""

    direction_type: typing.Literal["RADIAL", "UV_MAP"]
    """ Method to use for the tangent (default 'RADIAL')"""

    uv_map: str
    """ UV Map for tangent generated from UV (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexBrick(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a procedural texture producing bricks"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    offset: float
    """ Determines the brick offset of the various rows (in [0, 1], default 0.5)"""

    offset_frequency: int
    """ How often rows are offset. A value of 2 gives an even/uneven pattern of rows. (in [1, 99], default 2)"""

    squash: float
    """ Factor to adjust the brick's width for particular rows determined by the Offset Frequency (in [0, 99], default 1.0)"""

    squash_frequency: int
    """ How often rows consist of "squished" bricks (in [1, 99], default 2)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexChecker(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a checkerboard texture"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexCoord(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve multiple types of texture coordinates.
    Typically used as inputs for texture nodes
    """

    from_instancer: bool
    """ Use the parent of the instance object if possible (default False)"""

    object: Object | None
    """ Use coordinates from this object (for object texture coordinates output)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexEnvironment(ShaderNode, NodeInternal, Node, bpy_struct):
    """Sample an image file as an environment texture. Typically used to light the scene with the background node"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    image: Image | None
    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly, never None)"""

    interpolation: typing.Literal["Linear", "Closest", "Cubic", "Smart"]
    """ Texture interpolation (default 'Linear')"""

    projection: typing.Literal["EQUIRECTANGULAR", "MIRROR_BALL"]
    """ Projection of the input image (default 'EQUIRECTANGULAR')"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexGabor(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate Gabor noise"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    gabor_type: typing.Literal["2D", "3D"]
    """ The type of Gabor noise to evaluate (default '2D')"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexGradient(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate interpolated color and intensity values based on the input vector"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    gradient_type: typing.Literal[
        "LINEAR",
        "QUADRATIC",
        "EASING",
        "DIAGONAL",
        "SPHERICAL",
        "QUADRATIC_SPHERE",
        "RADIAL",
    ]
    """ Style of the color blending (default 'LINEAR')"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexIES(ShaderNode, NodeInternal, Node, bpy_struct):
    """Match real world lights with IES files, which store the directional intensity distribution of light sources"""

    filepath: str
    """ IES light path (default "", never None, blend relative // prefix supported)"""

    ies: Text | None
    """ Internal IES file"""

    mode: typing.Literal["INTERNAL", "EXTERNAL"]
    """ Whether the IES file is loaded from disk or from a text data-block (default 'INTERNAL')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexImage(ShaderNode, NodeInternal, Node, bpy_struct):
    """Sample an image file as a texture"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    extension: typing.Literal["REPEAT", "EXTEND", "CLIP", "MIRROR"]
    """ How the image is extrapolated past its original bounds (default 'REPEAT')"""

    image: Image | None
    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly, never None)"""

    interpolation: typing.Literal["Linear", "Closest", "Cubic", "Smart"]
    """ Texture interpolation (default 'Linear')"""

    projection: typing.Literal["FLAT", "BOX", "SPHERE", "TUBE"]
    """ Method to project 2D image on object with a 3D texture vector (default 'FLAT')"""

    projection_blend: float
    """ For box projection, amount of blend to use between sides (in [0, 1], default 0.0)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexMagic(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a psychedelic color texture"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    turbulence_depth: int
    """ Level of detail in the added turbulent noise (in [0, 10], default 0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexNoise(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate fractal Perlin noise"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    noise_dimensions: typing.Literal["1D", "2D", "3D", "4D"]
    """ Number of dimensions to output noise for (default '1D')"""

    noise_type: typing.Literal[
        "MULTIFRACTAL",
        "RIDGED_MULTIFRACTAL",
        "HYBRID_MULTIFRACTAL",
        "FBM",
        "HETERO_TERRAIN",
    ]
    """ Type of the Noise texture (default 'MULTIFRACTAL')"""

    normalize: bool
    """ Normalize outputs to 0.0 to 1.0 range (default False)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexSky(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate a procedural sky texture"""

    aerosol_density: float
    """ Density of dust, pollution and water droplets.
0 means no aerosols, 1 means urban city aerosols(in [0, 1000], default 1.0)"""

    air_density: float
    """ Density of air molecules.
0 means no air, 1 means urban city air(in [0, 1000], default 1.0)"""

    altitude: float
    """ Height from sea level (in [0, 100000], default 100.0)"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    ground_albedo: float
    """ Ground color that is subtly reflected in the sky (in [0, 1], default 0.0)"""

    ozone_density: float
    """ Density of ozone layer.
0 means no ozone, 1 means urban city ozone(in [0, 1000], default 1.0)"""

    sky_type: typing.Literal[
        "SINGLE_SCATTERING", "MULTIPLE_SCATTERING", "PREETHAM", "HOSEK_WILKIE"
    ]
    """ Which sky model should be used (default 'PREETHAM')"""

    sun_direction: mathutils.Vector
    """ Direction from where the sun is shining (array of 3 items, in [-inf, inf], default (0.0, 0.0, 1.0))"""

    sun_disc: bool
    """ Include the sun itself in the output (default True)"""

    sun_elevation: float
    """ Sun angle from horizon (in [-inf, inf], default 0.261799)"""

    sun_intensity: float
    """ Strength of Sun (in [0, 1000], default 1.0)"""

    sun_rotation: float
    """ Rotation of sun around zenith (in [-inf, inf], default 0.0)"""

    sun_size: float
    """ Size of sun disc (in [0, 1.5708], default 0.00951204)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    turbidity: float
    """ Atmospheric turbidity (in [1, 10], default 0.0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexVoronoi(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate Worley noise based on the distance to random points. Typically used to generate textures such as stones, water, or biological cells"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    distance: typing.Literal["EUCLIDEAN", "MANHATTAN", "CHEBYCHEV", "MINKOWSKI"]
    """ The distance metric used to compute the texture (default 'EUCLIDEAN')"""

    feature: typing.Literal[
        "F1", "F2", "SMOOTH_F1", "DISTANCE_TO_EDGE", "N_SPHERE_RADIUS"
    ]
    """ The Voronoi feature that the node will compute (default 'F1')"""

    normalize: bool
    """ Normalize output Distance to 0.0 to 1.0 range (default False)"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    voronoi_dimensions: typing.Literal["1D", "2D", "3D", "4D"]
    """ Number of dimensions to output noise for (default '1D')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexWave(ShaderNode, NodeInternal, Node, bpy_struct):
    """Generate procedural bands or rings with noise"""

    bands_direction: typing.Literal["X", "Y", "Z", "DIAGONAL"]
    """ (default 'X')"""

    color_mapping: ColorMapping | None
    """ Color mapping settings (readonly, never None)"""

    rings_direction: typing.Literal["X", "Y", "Z", "SPHERICAL"]
    """ (default 'X')"""

    texture_mapping: TexMapping | None
    """ Texture coordinate mapping settings (readonly, never None)"""

    wave_profile: typing.Literal["SIN", "SAW", "TRI"]
    """ (default 'SIN')"""

    wave_type: typing.Literal["BANDS", "RINGS"]
    """ (default 'BANDS')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTexWhiteNoise(ShaderNode, NodeInternal, Node, bpy_struct):
    """Calculate a random value or color based on an input seed"""

    noise_dimensions: typing.Literal["1D", "2D", "3D", "4D"]
    """ Number of dimensions to output noise for (default '1D')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeTree(NodeTree, ID, bpy_struct):
    """Node tree consisting of linked nodes used for materials (and other shading data-blocks)"""

    def get_output_node(
        self, target: typing.Literal["ALL", "EEVEE", "CYCLES"] | None
    ) -> ShaderNode:
        """Return active shader output node for the specified target

                :param target: Target

        ALL
        All -- Use shaders for all renderers and viewports, unless there exists a more specific output.

        EEVEE
        EEVEE -- Use shaders for EEVEE renderer.

        CYCLES
        Cycles -- Use shaders for Cycles renderer.
                :return: Node
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeUVAlongStroke(ShaderNode, NodeInternal, Node, bpy_struct):
    """UV coordinates that map a texture along the stroke length"""

    use_tips: bool
    """ Lower half of the texture is for tips of the stroke (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeUVMap(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve a UV map from the geometry, or the default fallback if none is specified"""

    from_instancer: bool
    """ Use the parent of the instance object if possible (default False)"""

    uv_map: str
    """ UV coordinates to be used for mapping (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeValToRGB(ShaderNode, NodeInternal, Node, bpy_struct):
    """Map values to colors with the use of a gradient"""

    color_ramp: ColorRamp | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeValue(ShaderNode, NodeInternal, Node, bpy_struct):
    """Input numerical values to other nodes in the tree"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVectorCurve(ShaderNode, NodeInternal, Node, bpy_struct):
    """Map input vector components with curves"""

    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVectorDisplacement(ShaderNode, NodeInternal, Node, bpy_struct):
    """Displace the surface along an arbitrary direction"""

    space: typing.Literal["TANGENT", "OBJECT", "WORLD"]
    """ Space of the input height (default 'TANGENT')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVectorMath(ShaderNode, NodeInternal, Node, bpy_struct):
    """Perform vector math operation"""

    operation: Literal[bpy.stub_internal.rna_enums.NodeVecMathItems]
    """ (default 'ADD')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVectorRotate(ShaderNode, NodeInternal, Node, bpy_struct):
    """Rotate a vector around a pivot point (center)"""

    invert: bool
    """ Invert the rotation angle (default False)"""

    rotation_type: typing.Literal[
        "AXIS_ANGLE", "X_AXIS", "Y_AXIS", "Z_AXIS", "EULER_XYZ"
    ]
    """ Type of angle input (default 'AXIS_ANGLE')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVectorTransform(ShaderNode, NodeInternal, Node, bpy_struct):
    """Convert a vector, point, or normal between world, camera, and object coordinate space"""

    convert_from: typing.Literal["WORLD", "OBJECT", "CAMERA"]
    """ Space to convert from (default 'WORLD')"""

    convert_to: typing.Literal["WORLD", "OBJECT", "CAMERA"]
    """ Space to convert to (default 'WORLD')"""

    vector_type: typing.Literal["POINT", "VECTOR", "NORMAL"]
    """ (default 'VECTOR')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVertexColor(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve a color attribute, or the default fallback if none is specified"""

    layer_name: str
    """ Color Attribute (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVolumeAbsorption(ShaderNode, NodeInternal, Node, bpy_struct):
    """Absorb light as it passes through the volume"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVolumeCoefficients(ShaderNode, NodeInternal, Node, bpy_struct):
    """Model all three physical processes in a volume, represented by their coefficients"""

    phase: typing.Literal[
        "HENYEY_GREENSTEIN", "FOURNIER_FORAND", "DRAINE", "RAYLEIGH", "MIE"
    ]
    """ Phase function for the scattered light (default 'HENYEY_GREENSTEIN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVolumeInfo(ShaderNode, NodeInternal, Node, bpy_struct):
    """Read volume data attributes from volume grids"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVolumePrincipled(ShaderNode, NodeInternal, Node, bpy_struct):
    """Combine all volume shading components into a single easy to use node"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeVolumeScatter(ShaderNode, NodeInternal, Node, bpy_struct):
    """Scatter light as it passes through the volume, often used to add fog to a scene"""

    phase: typing.Literal[
        "HENYEY_GREENSTEIN", "FOURNIER_FORAND", "DRAINE", "RAYLEIGH", "MIE"
    ]
    """ Phase function for the scattered light (default 'HENYEY_GREENSTEIN')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeWavelength(ShaderNode, NodeInternal, Node, bpy_struct):
    """Convert a wavelength value to an RGB value"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShaderNodeWireframe(ShaderNode, NodeInternal, Node, bpy_struct):
    """Retrieve the edges of an object as it appears to Cycles.
    Note: as meshes are triangulated before being processed by Cycles, topology will always appear triangulated
    """

    use_pixel_size: bool
    """ Use screen pixel size instead of world units (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShapeKey(bpy_struct):
    """Shape key in a shape keys data-block"""

    data: typing.Any
    """ (default None, readonly)"""

    frame: float
    """ Frame for absolute keys (in [-inf, inf], default 0.0, readonly)"""

    interpolation: typing.Literal[
        "KEY_LINEAR", "KEY_CARDINAL", "KEY_CATMULL_ROM", "KEY_BSPLINE"
    ]
    """ Interpolation type for absolute shape keys (default 'KEY_LINEAR')"""

    lock_shape: bool
    """ Protect the shape key from accidental sculpting and editing (default False)"""

    mute: bool
    """ Toggle this shape key (default False)"""

    name: str
    """ Name of Shape Key (default "", never None)"""

    points: typing.Any
    """ Optimized access to shape keys point data, when using foreach_get/foreach_set accessors. Warning: Does not support legacy Curve shape keys. (default None, readonly)"""

    relative_key: typing_extensions.Self | None
    """ Shape used as a relative key (never None)"""

    select: bool
    """ Shape key selection state (default False)"""

    slider_max: float
    """ Maximum for slider (in [-10, 10], default 1.0)"""

    slider_min: float
    """ Minimum for slider (in [-10, 10], default 0.0)"""

    value: float
    """ Value of shape key at the current frame (in [0, 1], default 0.0)"""

    vertex_group: str
    """ Vertex weight group, to blend with basis shape (default "", never None)"""

    def normals_vertex_get(self) -> float:
        """Compute local space vertices normals for this shape key

        :return: normals, (in [-1, 1])
        """

    def normals_polygon_get(self) -> float:
        """Compute local space faces normals for this shape key

        :return: normals, (in [-1, 1])
        """

    def normals_split_get(self) -> float:
        """Compute local space face corners normals for this shape key

        :return: normals, (in [-1, 1])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShapeKeyBezierPoint(bpy_struct):
    """Point in a shape key for Bézier curves"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    handle_left: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    handle_right: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    radius: float
    """ Radius for beveling (in [0, inf], default 0.0)"""

    tilt: float
    """ Tilt in 3D View (in [-376.991, 376.991], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShapeKeyCurvePoint(bpy_struct):
    """Point in a shape key for curves"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    radius: float
    """ Radius for beveling (in [0, inf], default 0.0)"""

    tilt: float
    """ Tilt in 3D View (in [-376.991, 376.991], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShapeKeyPoint(bpy_struct):
    """Point in a shape key"""

    co: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Short2Attribute(Attribute, bpy_struct):
    """Geometry attribute that stores 2D integer vectors"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Short2AttributeValue(bpy_struct):
    """2D value in geometry attribute"""

    value: typing.Any
    """ 2D vector (array of 2 items, in [-32768, 32767], default (0, 0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShrinkwrapConstraint(Constraint, bpy_struct):
    """Create constraint-based shrinkwrap relationship"""

    cull_face: typing.Literal["OFF", "FRONT", "BACK"]
    """ Stop vertices from projecting to a face on the target when facing towards/away (default 'OFF')"""

    distance: float
    """ Distance to Target (in [0, inf], default 0.0)"""

    project_axis: Literal[bpy.stub_internal.rna_enums.ObjectAxisItems]
    """ Axis constrain to (default 'POS_X')"""

    project_axis_space: typing.Literal[
        "WORLD", "CUSTOM", "POSE", "LOCAL_WITH_PARENT", "LOCAL"
    ]
    """ Space for the projection axis (default 'WORLD')"""

    project_limit: float
    """ Limit the distance used for projection (zero disables) (in [0, inf], default 0.0)"""

    shrinkwrap_type: typing.Literal[
        "NEAREST_SURFACE", "PROJECT", "NEAREST_VERTEX", "TARGET_PROJECT"
    ]
    """ Select type of shrinkwrap algorithm for target position (default 'NEAREST_SURFACE')"""

    target: Object | None
    """ Target Mesh object"""

    track_axis: typing.Literal[
        "TRACK_X",
        "TRACK_Y",
        "TRACK_Z",
        "TRACK_NEGATIVE_X",
        "TRACK_NEGATIVE_Y",
        "TRACK_NEGATIVE_Z",
    ]
    """ Axis that is aligned to the normal (default 'TRACK_X')"""

    use_invert_cull: bool
    """ When projecting in the opposite direction invert the face cull mode (default False)"""

    use_project_opposite: bool
    """ Project in both specified and opposite directions (default False)"""

    use_track_normal: bool
    """ Align the specified axis to the surface normal (default False)"""

    wrap_mode: Literal[bpy.stub_internal.rna_enums.ModifierShrinkwrapModeItems]
    """ Select how to constrain the object to the target surface (default 'ON_SURFACE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ShrinkwrapModifier(Modifier, bpy_struct):
    """Shrink wrapping modifier to shrink wrap and object to a target"""

    auxiliary_target: Object | None
    """ Additional mesh target to shrink to"""

    cull_face: Literal[bpy.stub_internal.rna_enums.ShrinkwrapFaceCullItems]
    """ Stop vertices from projecting to a face on the target when facing towards/away (default 'OFF')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    offset: float
    """ Distance to keep from the target (in [-inf, inf], default 0.0)"""

    project_limit: float
    """ Limit the distance used for projection (zero disables) (in [0, inf], default 0.0)"""

    subsurf_levels: int
    """ Number of subdivisions that must be performed before extracting vertices' positions and normals (in [0, 6], default 0)"""

    target: Object | None
    """ Mesh target to shrink to"""

    use_invert_cull: bool
    """ When projecting in the negative direction invert the face cull mode (default False)"""

    use_negative_direction: bool
    """ Allow vertices to move in the negative direction of axis (default False)"""

    use_positive_direction: bool
    """ Allow vertices to move in the positive direction of axis (default True)"""

    use_project_x: bool
    """ (default False)"""

    use_project_y: bool
    """ (default False)"""

    use_project_z: bool
    """ (default False)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    wrap_method: Literal[bpy.stub_internal.rna_enums.ShrinkwrapTypeItems]
    """ (default 'NEAREST_SURFACEPOINT')"""

    wrap_mode: Literal[bpy.stub_internal.rna_enums.ModifierShrinkwrapModeItems]
    """ Select how vertices are constrained to the target surface (default 'ON_SURFACE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SimpleDeformModifier(Modifier, bpy_struct):
    """Simple deformation modifier to apply effects such as twisting and bending"""

    angle: float
    """ Angle of deformation (in [-inf, inf], default 0.785398)"""

    deform_axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Deform around local axis (default 'X')"""

    deform_method: typing.Literal["TWIST", "BEND", "TAPER", "STRETCH"]
    """ (default 'TWIST')"""

    factor: float
    """ Amount to deform object (in [-inf, inf], default 0.785398)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    limits: typing.Any
    """ Lower/Upper limits for deform (array of 2 items, in [0, 1], default (0.0, 1.0))"""

    lock_x: bool
    """ Do not allow deformation along the X axis (default False)"""

    lock_y: bool
    """ Do not allow deformation along the Y axis (default False)"""

    lock_z: bool
    """ Do not allow deformation along the Z axis (default False)"""

    origin: Object | None
    """ Offset the origin and orientation of the deformation"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SimulationStateItem(bpy_struct):
    attribute_domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Attribute domain where the attribute is stored in the simulation state (default 'POINT')"""

    color: typing.Any
    """ Color of the corresponding socket type in the node editor (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", never None)"""

    socket_type: Literal[bpy.stub_internal.rna_enums.NodeSocketDataTypeItems]
    """ (default 'FLOAT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SimulationZoneViewerPathElem(ViewerPathElem, bpy_struct):
    sim_output_node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SkinModifier(Modifier, bpy_struct):
    """Generate Skin"""

    branch_smoothing: float
    """ Smooth complex geometry around branches (in [0, 1], default 0.0)"""

    use_smooth_shade: bool
    """ Output faces with smooth shading rather than flat shaded (default False)"""

    use_x_symmetry: bool
    """ Avoid making unsymmetrical quads across the X axis (default True)"""

    use_y_symmetry: bool
    """ Avoid making unsymmetrical quads across the Y axis (default False)"""

    use_z_symmetry: bool
    """ Avoid making unsymmetrical quads across the Z axis (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SmoothModifier(Modifier, bpy_struct):
    """Smoothing effect modifier"""

    factor: float
    """ Strength of modifier effect (in [-inf, inf], default 0.5)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    iterations: int
    """ (in [0, 32767], default 1)"""

    use_x: bool
    """ Smooth object along X axis (default True)"""

    use_y: bool
    """ Smooth object along Y axis (default True)"""

    use_z: bool
    """ Smooth object along Z axis (default True)"""

    vertex_group: str
    """ Name of Vertex Group which determines influence of modifier per point (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SoftBodyModifier(Modifier, bpy_struct):
    """Soft body simulation modifier"""

    point_cache: PointCache | None
    """ (readonly, never None)"""

    settings: SoftBodySettings | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SoftBodySettings(bpy_struct):
    """Soft body simulation settings for an object"""

    aero: int
    """ Make edges 'sail' (in [0, 30000], default 0)"""

    aerodynamics_type: typing.Literal["SIMPLE", "LIFT_FORCE"]
    """ Method of calculating aerodynamic interaction (default 'SIMPLE')"""

    ball_damp: float
    """ Blending to inelastic collision (in [0.001, 1], default 0.0)"""

    ball_size: float
    """ Absolute ball size or factor if not manually adjusted (in [-10, 10], default 0.0)"""

    ball_stiff: float
    """ Ball inflating pressure (in [0.001, 100], default 0.0)"""

    bend: float
    """ Bending Stiffness (in [0, 10], default 0.0)"""

    choke: int
    """ 'Viscosity' inside collision target (in [0, 100], default 0)"""

    collision_collection: Collection | None
    """ Limit colliders to this collection"""

    collision_type: typing.Literal["MANUAL", "AVERAGE", "MINIMAL", "MAXIMAL", "MINMAX"]
    """ Choose Collision Type (default 'MANUAL')"""

    damping: float
    """ Edge spring friction (in [0, 50], default 0.0)"""

    effector_weights: EffectorWeights | None
    """ (readonly)"""

    error_threshold: float
    """ The Runge-Kutta ODE solver error limit, low value gives more precision, high values speed (in [0.001, 10], default 0.0)"""

    friction: float
    """ General media friction for point movements (in [0, 50], default 0.0)"""

    fuzzy: int
    """ Fuzziness while on collision, high values make collision handling faster but less stable (in [1, 100], default 0)"""

    goal_default: float
    """ Default Goal (vertex target position) value (in [0, 1], default 0.0)"""

    goal_friction: float
    """ Goal (vertex target position) friction (in [0, 50], default 0.0)"""

    goal_max: float
    """ Goal maximum, vertex weights are scaled to match this range (in [0, 1], default 0.0)"""

    goal_min: float
    """ Goal minimum, vertex weights are scaled to match this range (in [0, 1], default 0.0)"""

    goal_spring: float
    """ Goal (vertex target position) spring stiffness (in [0, 0.999], default 0.0)"""

    gravity: float
    """ Apply gravitation to point movement (in [-10, 10], default 0.0)"""

    location_mass_center: mathutils.Vector
    """ Location of center of mass (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    mass: float
    """ General Mass value (in [0, 50000], default 0.0)"""

    plastic: int
    """ Permanent deform (in [0, 100], default 0)"""

    pull: float
    """ Edge spring stiffness when longer than rest length (in [0, 0.999], default 0.0)"""

    push: float
    """ Edge spring stiffness when shorter than rest length (in [0, 0.999], default 0.0)"""

    rotation_estimate: mathutils.Matrix
    """ Estimated rotation matrix (multi-dimensional array of 3 * 3 items, in [-inf, inf], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)))"""

    scale_estimate: mathutils.Matrix
    """ Estimated scale matrix (multi-dimensional array of 3 * 3 items, in [-inf, inf], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)))"""

    shear: float
    """ Shear Stiffness (in [0, 1], default 0.0)"""

    speed: float
    """ Tweak timing for physics to control frequency and speed (in [0.01, 100], default 0.0)"""

    spring_length: int
    """ Alter spring length to shrink/blow up (unit %) 0 to disable (in [0, 200], default 0)"""

    step_max: int
    """ Maximal # solver steps/frame (in [0, 30000], default 0)"""

    step_min: int
    """ Minimal # solver steps/frame (in [0, 30000], default 0)"""

    use_auto_step: bool
    """ Use velocities for automagic step sizes (default False)"""

    use_diagnose: bool
    """ Turn on SB diagnose console prints (default False)"""

    use_edge_collision: bool
    """ Edges collide too (default False)"""

    use_edges: bool
    """ Use Edges as springs (default False)"""

    use_estimate_matrix: bool
    """ Store the estimated transforms in the soft body settings (default False)"""

    use_face_collision: bool
    """ Faces collide too, can be very slow (default False)"""

    use_goal: bool
    """ Define forces for vertices to stick to animated position (default False)"""

    use_self_collision: bool
    """ Enable naive vertex ball self collision (default False)"""

    use_stiff_quads: bool
    """ Add diagonal springs on 4-gons (default False)"""

    vertex_group_goal: str
    """ Control point weight values (default "", never None)"""

    vertex_group_mass: str
    """ Control point mass values (default "", never None)"""

    vertex_group_spring: str
    """ Control point spring strength values (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SolidifyModifier(Modifier, bpy_struct):
    """Create a solid skin, compensating for sharp angles"""

    bevel_convex: float
    """ Edge bevel weight to be added to outside edges (in [-1, 1], default 0.0)"""

    edge_crease_inner: float
    """ Assign a crease to inner edges (in [0, 1], default 0.0)"""

    edge_crease_outer: float
    """ Assign a crease to outer edges (in [0, 1], default 0.0)"""

    edge_crease_rim: float
    """ Assign a crease to the edges making up the rim (in [0, 1], default 0.0)"""

    invert_vertex_group: bool
    """ Invert the vertex group influence (default False)"""

    material_offset: int
    """ Offset material index of generated faces (in [-32768, 32767], default 0)"""

    material_offset_rim: int
    """ Offset material index of generated rim faces (in [-32768, 32767], default 0)"""

    nonmanifold_boundary_mode: typing.Literal["NONE", "ROUND", "FLAT"]
    """ Selects the boundary adjustment algorithm (default 'NONE')"""

    nonmanifold_merge_threshold: float
    """ Distance within which degenerated geometry is merged (in [0, 1], default 0.0001)"""

    nonmanifold_thickness_mode: typing.Literal["FIXED", "EVEN", "CONSTRAINTS"]
    """ Selects the used thickness algorithm (default 'CONSTRAINTS')"""

    offset: float
    """ Offset the thickness from the center (in [-inf, inf], default -1.0)"""

    rim_vertex_group: str
    """ Vertex group that the generated rim geometry will be weighted to (default "", never None)"""

    shell_vertex_group: str
    """ Vertex group that the generated shell geometry will be weighted to (default "", never None)"""

    solidify_mode: typing.Literal["EXTRUDE", "NON_MANIFOLD"]
    """ Selects the used algorithm (default 'EXTRUDE')"""

    thickness: float
    """ Thickness of the shell (in [-inf, inf], default 0.01)"""

    thickness_clamp: float
    """ Offset clamp based on geometry scale (in [0, 100], default 0.0)"""

    thickness_vertex_group: float
    """ Thickness factor to use for zero vertex group influence (in [0, 1], default 0.0)"""

    use_even_offset: bool
    """ Maintain thickness by adjusting for sharp corners (slow, disable when not needed) (default False)"""

    use_flat_faces: bool
    """ Make faces use the minimal vertex weight assigned to their vertices (ensures new faces remain parallel to their original ones, slow, disable when not needed) (default False)"""

    use_flip_normals: bool
    """ Invert the face direction (default False)"""

    use_quality_normals: bool
    """ Calculate normals which result in more even thickness (slow, disable when not needed) (default False)"""

    use_rim: bool
    """ Create edge loops between the inner and outer surfaces on face edges (slow, disable when not needed) (default True)"""

    use_rim_only: bool
    """ Only add the rim to the original data (default False)"""

    use_thickness_angle_clamp: bool
    """ Clamp thickness based on angles (default False)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Sound(ID, bpy_struct):
    """Sound data-block referencing an external or packed sound file"""

    channels: typing.Literal[
        "INVALID",
        "MONO",
        "STEREO",
        "STEREO_LFE",
        "CHANNELS_4",
        "CHANNELS_5",
        "SURROUND_51",
        "SURROUND_61",
        "SURROUND_71",
    ]
    """ Definition of audio channels (default 'INVALID', readonly)"""

    filepath: str
    """ Sound sample file used by this Sound data-block (default "", never None, blend relative // prefix supported)"""

    packed_file: PackedFile | None
    """ (readonly)"""

    samplerate: int
    """ Sample rate of the audio in Hz (in [-inf, inf], default 0, readonly)"""

    use_memory_cache: bool
    """ The sound file is decoded and loaded into RAM (default False)"""

    use_mono: bool
    """ If the file contains multiple audio channels they are rendered to a single one (default False)"""

    factory: typing.Any
    """ The aud.Factory object of the sound.(readonly)"""

    def pack(self) -> None:
        """Pack the sound into the current blend file"""

    def unpack(
        self,
        *,
        method: Literal[bpy.stub_internal.rna_enums.UnpackMethodItems]
        | None = "USE_LOCAL",
    ) -> None:
        """Unpack the sound to the samples filename

        :param method: method, How to unpack (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SoundEqualizerModifier(StripModifier, bpy_struct):
    """Equalize audio"""

    graphics: typing.Any
    """ Graphical definition equalization (default None, readonly)"""

    def new_graphic(
        self, min_freq: float | None, max_freq: float | None
    ) -> EQCurveMappingData:
        """Add a new EQ band

        :param min_freq: Minimum Frequency, Minimum Frequency (in [0, 20000])
        :param max_freq: Maximum Frequency, Maximum Frequency (in [0, 20000])
        :return: Newly created graphical Equalizer definition
        """

    def clear_soundeqs(self) -> None:
        """Remove all graphical equalizers from the Equalizer modifier"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SoundStrip(Strip, bpy_struct):
    """Sequence strip defining a sound to be played over a period of time"""

    animation_offset_end: int
    """ Animation end offset (trim end) (in [0, inf], default 0)Replaced by '.content_trim_end'.5.10 removal planned in version 6.0"""

    animation_offset_start: int
    """ Animation start offset (trim start) (in [0, inf], default 0)Replaced by '.content_trim_start'.5.10 removal planned in version 6.0"""

    content_trim_end: int
    """ Number of frames to ignore from the end of the underlying source. The source content is trimmed, and future frames are turned into holds (in [0, inf], default 0)"""

    content_trim_start: int
    """ Number of frames to ignore from the start of the underlying source. The source content is trimmed, and previous frames are turned into holds (in [0, inf], default 0)"""

    pan: float
    """ Playback panning of the sound (only for Mono sources) (in [-inf, inf], default 0.0)"""

    pitch_correction: bool
    """ Maintain the original pitch of the audio when changing playback speed (default False)"""

    retiming_keys: typing.Any
    """ (default None, readonly)"""

    show_waveform: bool
    """ Display the audio waveform inside the strip (default False)"""

    sound: Sound | None
    """ Sound data-block used by this strip"""

    sound_offset: float
    """ Subframe offset of the sound source start expressed in seconds (in [-inf, inf], default 0.0)"""

    volume: float
    """ Playback volume of the sound (in [0, 100], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Space(bpy_struct):
    """Space data for a screen area"""

    show_locked_time: bool
    """ Synchronize the visible timeline range with other time-based editors (default False)"""

    show_region_header: bool
    """ (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ Space data type (default 'EMPTY', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceClipEditor(Space, bpy_struct):
    """Clip editor space data"""

    annotation_source: typing.Literal["CLIP", "TRACK"]
    """ Where the annotation comes from (default 'CLIP')"""

    blend_factor: float
    """ Overlay blending factor of rasterized mask (in [0, 1], default 0.7)"""

    clip: MovieClip | None
    """ Movie clip displayed and edited in this space"""

    clip_user: MovieClipUser | None
    """ Parameters defining which frame of the movie clip is displayed (readonly, never None)"""

    cursor_location: mathutils.Vector
    """ 2D cursor location for this view (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    lock_selection: bool
    """ Lock viewport to selected markers during playback (default False)"""

    lock_time_cursor: bool
    """ Lock curves view to time cursor during playback and tracking (default False)"""

    mask: Mask | None
    """ Mask displayed and edited in this space"""

    mask_display_type: typing.Literal["OUTLINE", "DASH", "BLACK", "WHITE"]
    """ Display type for mask splines (default 'OUTLINE')"""

    mask_overlay_mode: typing.Literal["ALPHACHANNEL", "COMBINED"]
    """ Overlay mode of rasterized mask (default 'ALPHACHANNEL')"""

    mode: Literal[bpy.stub_internal.rna_enums.ClipEditorModeItems]
    """ Editing context being displayed (default 'TRACKING')"""

    overlay: SpaceClipOverlay | None
    """ Settings for display of overlays in the Movie Clip editor (readonly, never None)"""

    path_length: int
    """ Length of displaying path, in frames (in [0, inf], default 20)"""

    pivot_point: typing.Literal[
        "BOUNDING_BOX_CENTER", "CURSOR", "INDIVIDUAL_ORIGINS", "MEDIAN_POINT"
    ]
    """ Pivot center for rotation/scaling (default 'MEDIAN_POINT')"""

    scopes: MovieClipScopes | None
    """ Scopes to visualize movie clip statistics (readonly)"""

    show_annotation: bool
    """ Show annotations for this view (default True)"""

    show_blue_channel: bool
    """ Show blue channel in the frame (default True)"""

    show_bundles: bool
    """ Show projection of 3D markers into footage (default False)"""

    show_disabled: bool
    """ Show disabled tracks from the footage (default True)"""

    show_filters: bool
    """ Show filters for graph editor (default False)"""

    show_gizmo: bool
    """ Show gizmos of all types (default True)"""

    show_gizmo_navigate: bool
    """ Viewport navigation gizmo (default True)"""

    show_graph_frames: bool
    """ Show curve for per-frame average error (camera motion should be solved first) (default True)"""

    show_graph_hidden: bool
    """ Include channels from objects/bone that are not visible (default False)"""

    show_graph_only_selected: bool
    """ Only include channels relating to selected objects and data (default False)"""

    show_graph_tracks_error: bool
    """ Display the reprojection error curve for selected tracks (default False)"""

    show_graph_tracks_motion: bool
    """ Display speed curves for the selected tracks (default True)"""

    show_green_channel: bool
    """ Show green channel in the frame (default True)"""

    show_grid: bool
    """ Show grid showing lens distortion (default False)"""

    show_marker_pattern: bool
    """ Show pattern boundbox for markers (default True)"""

    show_marker_search: bool
    """ Show search boundbox for markers (default False)"""

    show_mask_overlay: bool
    """ (default False)"""

    show_mask_spline: bool
    """ (default True)"""

    show_metadata: bool
    """ Show metadata of clip (default False)"""

    show_names: bool
    """ Show track names and status (default False)"""

    show_red_channel: bool
    """ Show red channel in the frame (default True)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_seconds: bool
    """ Show timing as a timecode instead of frames (default False)"""

    show_stable: bool
    """ Show stable footage in editor (if stabilization is enabled) (default False)"""

    show_tiny_markers: bool
    """ Show markers in a more compact manner (default False)"""

    show_track_path: bool
    """ Show path of how track moves (default True)"""

    use_grayscale_preview: bool
    """ Display frame in grayscale mode (default False)"""

    use_manual_calibration: bool
    """ Use manual calibration helpers (default False)"""

    use_mute_footage: bool
    """ Mute footage and show black background instead (default False)"""

    view: typing.Literal["CLIP", "GRAPH", "DOPESHEET"]
    """ Type of the clip editor view (default 'CLIP')"""

    zoom_percentage: float
    """ Zoom percentage (in [0.4, 80000], default 100.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceClipOverlay(bpy_struct):
    """Settings for display of overlays in the Movie Clip editor"""

    show_cursor: bool
    """ Display 2D cursor (default True)"""

    show_overlays: bool
    """ Display overlays like cursor and annotations (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceConsole(Space, bpy_struct):
    """Interactive Python console"""

    font_size: int
    """ Font size to use for displaying the text (in [1, 256], default 0)"""

    history: typing.Any
    """ Command history (default None, readonly)"""

    language: str
    """ Command line prompt language (default "", never None)"""

    prompt: str
    """ Command line prompt (default "", never None)"""

    scrollback: typing.Any
    """ Command output (default None, readonly)"""

    select_end: int
    """ (in [0, inf], default 0)"""

    select_start: int
    """ (in [0, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceDopeSheetEditor(Space, bpy_struct):
    """Dope Sheet space data"""

    cache_cloth: bool
    """ Show the active object's cloth point cache (default False)"""

    cache_dynamicpaint: bool
    """ Show the active object's Dynamic Paint cache (default False)"""

    cache_particles: bool
    """ Show the active object's particle point cache (default False)"""

    cache_rigidbody: bool
    """ Show the active object's Rigid Body cache (default False)"""

    cache_simulation_nodes: bool
    """ Show the active object's simulation nodes cache and bake data (default False)"""

    cache_smoke: bool
    """ Show the active object's smoke cache (default False)"""

    cache_softbody: bool
    """ Show the active object's softbody point cache (default False)"""

    dopesheet: DopeSheet | None
    """ Settings for filtering animation data (readonly)"""

    mode: typing.Literal[
        "DOPESHEET", "ACTION", "SHAPEKEY", "GPENCIL", "MASK", "CACHEFILE", "TIMELINE"
    ]
    """ Editing context being displayed (default 'ACTION')"""

    overlays: SpaceDopeSheetOverlay | None
    """ Settings for display of overlays (readonly, never None)"""

    show_cache: bool
    """ Show the status of cached frames in the timeline (default False)"""

    show_extremes: bool
    """ Mark keyframes where the key value flow changes direction, based on comparison with adjacent keys (default False)"""

    show_interpolation: bool
    """ Display keyframe handle types and non-Bézier interpolation modes (default False)"""

    show_markers: bool
    """ If any exists, show markers in a separate row at the bottom of the editor (default False)"""

    show_pose_markers: bool
    """ Show markers belonging to the active action instead of Scene markers (Action and Shape Key Editors only) (default False)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_seconds: bool
    """ Show timing as a timecode instead of frames (default False)"""

    show_sliders: bool
    """ Show sliders beside F-Curve channels (default False)"""

    ui_mode: typing.Literal[
        "DOPESHEET", "ACTION", "SHAPEKEY", "GPENCIL", "MASK", "CACHEFILE"
    ]
    """ Editing context being displayed (default 'ACTION')"""

    use_auto_merge_keyframes: bool
    """ Automatically merge nearby keyframes (default True)"""

    use_marker_sync: bool
    """ Sync Markers with keyframe edits (default False)"""

    use_realtime_update: bool
    """ When transforming keyframes, changes to the animation data are flushed to other views (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceDopeSheetOverlay(bpy_struct):
    show_overlays: bool
    """ Display overlays (default True)"""

    show_scene_strip_range: bool
    """ When using scene time synchronization in the sequence editor, display the range of the current scene strip (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceFileBrowser(Space, bpy_struct):
    """File browser space data"""

    active_operator: Operator | None
    """ (readonly)"""

    bookmarks: typing.Any
    """ User's bookmarks (default None)"""

    bookmarks_active: int
    """ Index of active bookmark (-1 if none) (in [-32768, 32767], default 0)"""

    browse_mode: Literal[bpy.stub_internal.rna_enums.SpaceFileBrowseModeItems]
    """ Type of the File Editor view (regular file browsing or asset browsing) (default 'FILES')"""

    operator: Operator | None
    """ (readonly)"""

    params: FileSelectParams | None
    """ Parameters and Settings for the Filebrowser (readonly)"""

    recent_folders: typing.Any
    """ (default None)"""

    recent_folders_active: int
    """ Index of active recent folder (-1 if none) (in [-32768, 32767], default 0)"""

    show_region_tool_props: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    system_bookmarks: typing.Any
    """ System's bookmarks (default None, readonly)"""

    system_bookmarks_active: int
    """ Index of active system bookmark (-1 if none) (in [-32768, 32767], default 0)"""

    system_folders: typing.Any
    """ System's folders (usually root, available hard drives, etc) (default None, readonly)"""

    system_folders_active: int
    """ Index of active system folder (-1 if none) (in [-32768, 32767], default 0)"""

    def activate_asset_by_id(
        self, id_to_activate: ID | None, *, deferred: bool | None = False
    ) -> None:
        """Activate and select the asset entry that represents the given ID

        :param id_to_activate: id_to_activate
        :param deferred: Whether to activate the ID immediately (false) or after the file browser refreshes (true) (optional)
        """

    def activate_file_by_relative_path(self, *, relative_path: str | None = "") -> None:
        """Set active file and add to selection based on relative path to current File Browser directory

        :param relative_path: relative_path, (optional, never None)
        """

    def deselect_all(self) -> None:
        """Deselect all files"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceGraphEditor(Space, bpy_struct):
    """Graph Editor space data"""

    cursor_position_x: float
    """ Graph Editor 2D-Value cursor - X-Value component (in [-inf, inf], default 0.0)"""

    cursor_position_y: float
    """ Graph Editor 2D-Value cursor - Y-Value component (in [-inf, inf], default 0.0)"""

    dopesheet: DopeSheet | None
    """ Settings for filtering animation data (readonly)"""

    has_ghost_curves: bool
    """ Graph Editor instance has some ghost curves stored (default False, readonly)"""

    mode: Literal[bpy.stub_internal.rna_enums.SpaceGraphModeItems]
    """ Editing context being displayed (default 'FCURVES')"""

    pivot_point: typing.Literal["BOUNDING_BOX_CENTER", "CURSOR", "INDIVIDUAL_ORIGINS"]
    """ Pivot center for rotation/scaling (default 'BOUNDING_BOX_CENTER')"""

    show_cursor: bool
    """ Show 2D cursor (default True)"""

    show_extrapolation: bool
    """ (default True)"""

    show_handles: bool
    """ Show handles of Bézier control points (default True)"""

    show_markers: bool
    """ If any exists, show markers in a separate row at the bottom of the editor (default False)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_seconds: bool
    """ Show timing as a timecode instead of frames (default False)"""

    show_sliders: bool
    """ Show sliders beside F-Curve channels (default False)"""

    use_auto_lock_translation_axis: bool
    """ Automatically locks the movement of keyframes to the dominant axis (default False)"""

    use_auto_merge_keyframes: bool
    """ Automatically merge nearby keyframes (default True)"""

    use_auto_normalization: bool
    """ Automatically recalculate curve normalization on every curve edit (default True)"""

    use_normalization: bool
    """ Display curves in normalized range from -1 to 1, for easier editing of multiple curves with different ranges (default False)"""

    use_only_selected_keyframe_handles: bool
    """ Only show and edit handles of selected keyframes (default False)"""

    use_realtime_update: bool
    """ When transforming keyframes, changes to the animation data are flushed to other views (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceImageEditor(Space, bpy_struct):
    """Image and UV editor space data"""

    annotation: Annotation | None
    """ Annotation data for this space"""

    blend_factor: float
    """ Overlay blending factor of rasterized mask (in [0, 1], default 0.7)"""

    cursor_location: mathutils.Vector
    """ 2D cursor location for this view (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    display_channels: typing.Literal[
        "COLOR_ALPHA", "COLOR", "ALPHA", "Z_BUFFER", "RED", "GREEN", "BLUE"
    ]
    """ Channels of the image to display (default 'COLOR')"""

    image: Image | None
    """ Image displayed and edited in this space"""

    image_user: ImageUser | None
    """ Parameters defining which layer, pass and frame of the image is displayed (readonly, never None)"""

    mask: Mask | None
    """ Mask displayed and edited in this space"""

    mask_display_type: typing.Literal["OUTLINE", "DASH", "BLACK", "WHITE"]
    """ Display type for mask splines (default 'OUTLINE')"""

    mask_overlay_mode: typing.Literal["ALPHACHANNEL", "COMBINED"]
    """ Overlay mode of rasterized mask (default 'ALPHACHANNEL')"""

    mode: Literal[bpy.stub_internal.rna_enums.SpaceImageModeAllItems]
    """ Editing context being displayed (default 'VIEW')"""

    overlay: SpaceImageOverlay | None
    """ Settings for display of overlays in the UV/Image editor (readonly, never None)"""

    pivot_point: typing.Literal[
        "BOUNDING_BOX_CENTER",
        "CURSOR",
        "INDIVIDUAL_ORIGINS",
        "MEDIAN_POINT",
        "ACTIVE_ELEMENT",
    ]
    """ Rotation/Scaling Pivot (default 'BOUNDING_BOX_CENTER')"""

    sample_histogram: Histogram | None
    """ Sampled colors along line (readonly)"""

    scopes: Scopes | None
    """ Scopes to visualize image statistics (readonly)"""

    show_annotation: bool
    """ Show annotations for this view (default False)"""

    show_gizmo: bool
    """ Show gizmos of all types (default True)"""

    show_gizmo_active_node: bool
    """ Context sensitive gizmo for the active node (default True)"""

    show_gizmo_navigate: bool
    """ Viewport navigation gizmo (default True)"""

    show_mask_overlay: bool
    """ (default False)"""

    show_mask_spline: bool
    """ (default True)"""

    show_maskedit: bool
    """ Show Mask editing related properties (default False, readonly)"""

    show_paint: bool
    """ Show paint related properties (default False, readonly)"""

    show_region_asset_shelf: bool
    """ Display a region with assets that may currently be relevant (such as brushes in paint modes, or poses in Pose Mode) (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_tool_header: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_render: bool
    """ Show render related properties (default False, readonly)"""

    show_repeat: bool
    """ Display the image repeated outside of the main view (default False)"""

    show_sequencer_scene: bool
    """ Display the render result for the sequencer scene instead of the active scene (default False)"""

    show_stereo_3d: bool
    """ Display the image in Stereo 3D (default False)"""

    show_uvedit: bool
    """ Show UV editing related properties (default False, readonly)"""

    ui_mode: typing.Literal["VIEW", "PAINT", "MASK"]
    """ Editing context being displayed (default 'VIEW')"""

    use_image_pin: bool
    """ Display current image regardless of object selection (default False)"""

    use_realtime_update: bool
    """ Update other affected window spaces automatically to reflect changes during interactive operations such as transform (default False)"""

    uv_editor: SpaceUVEditor | None
    """ UV editor settings (readonly, never None)"""

    zoom: typing.Any
    """ Zoom factor (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    zoom_percentage: float
    """ Zoom percentage (in [0.4, 80000], default 100.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceImageOverlay(bpy_struct):
    """Settings for display of overlays in the UV/Image editor"""

    passepartout_alpha: float
    """ Opacity of the darkened overlay outside the render region (in [0, 1], default 0.5)"""

    show_grid_background: bool
    """ Show the grid background and borders (default False)"""

    show_overlays: bool
    """ Display overlays like UV Maps and Metadata (default False)"""

    show_render_size: bool
    """ Display the region of the final render (default False)"""

    show_text_info: bool
    """ Display overlay text (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceInfo(Space, bpy_struct):
    """Info space data"""

    show_report_debug: bool
    """ Display debug reporting info (default False)"""

    show_report_error: bool
    """ Display error text (default False)"""

    show_report_info: bool
    """ Display general information (default False)"""

    show_report_operator: bool
    """ Display the operator log (default False)"""

    show_report_warning: bool
    """ Display warnings (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceNLA(Space, bpy_struct):
    """NLA editor space data"""

    dopesheet: DopeSheet | None
    """ Settings for filtering animation data (readonly)"""

    show_local_markers: bool
    """ Show action-local markers on the strips, useful when synchronizing timing across strips (default True)"""

    show_markers: bool
    """ If any exists, show markers in a separate row at the bottom of the editor (default False)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_seconds: bool
    """ Show timing as a timecode instead of frames (default False)"""

    show_strip_curves: bool
    """ Show influence F-Curves on strips (default True)"""

    use_realtime_update: bool
    """ When transforming strips, changes to the animation data are flushed to other views (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceNodeEditor(Space, bpy_struct):
    """Node editor space data"""

    backdrop_channels: typing.Literal[
        "COLOR_ALPHA", "COLOR", "ALPHA", "RED", "GREEN", "BLUE"
    ]
    """ Channels of the image to draw (default 'COLOR')"""

    backdrop_offset: mathutils.Vector
    """ Backdrop offset (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    backdrop_zoom: float
    """ Backdrop zoom factor (in [0.01, inf], default 1.0)"""

    cursor_location: mathutils.Vector
    """ Location for adding new nodes (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    edit_tree: NodeTree | None
    """ Node tree being displayed and edited (readonly)"""

    id: ID | None
    """ Data-block whose nodes are being edited (readonly)"""

    id_from: ID | None
    """ Data-block from which the edited data-block is linked (readonly)"""

    insert_offset_direction: typing.Literal["RIGHT", "LEFT"]
    """ Direction to offset nodes on insertion (default 'RIGHT')"""

    node_tree: NodeTree | None
    """ Base node tree from context"""

    node_tree_sub_type: str
    overlay: SpaceNodeOverlay | None
    """ Settings for display of overlays in the Node Editor (readonly, never None)"""

    path: typing.Any
    """ Path from the data-block to the currently edited node tree (default None, readonly)"""

    pin: bool
    """ Use the pinned node tree (default False)"""

    selected_node_group: NodeTree | None
    """ Node group to edit"""

    shader_type: typing.Literal["OBJECT", "WORLD", "LINESTYLE"]
    """ Type of data to take shader from (default 'OBJECT')"""

    show_annotation: bool
    """ Show annotations for this view (default False)"""

    show_backdrop: bool
    """ Use active Viewer Node output as backdrop for compositing nodes (default False)"""

    show_gizmo: bool
    """ Show gizmos of all types (default True)"""

    show_gizmo_active_node: bool
    """ Context sensitive gizmo for the active node (default True)"""

    show_region_asset_shelf: bool
    """ Display a region with assets that may currently be relevant (such as brushes in paint modes, or poses in Pose Mode) (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    supports_previews: bool
    """ Whether the node editor's type supports displaying node previews (default False, readonly)"""

    texture_type: typing.Literal["WORLD", "BRUSH", "LINESTYLE"]
    """ Type of data to take texture from (default 'WORLD')"""

    tree_type: typing.Literal[
        "GeometryNodeTree", "CompositorNodeTree", "ShaderNodeTree", "TextureNodeTree"
    ]
    """ Node tree type to display and edit (default 'DEFAULT')"""

    def cursor_location_from_region(self, x: int | None, y: int | None) -> None:
        """Set the cursor location using region coordinates

        :param x: x, Region x coordinate (in [-inf, inf])
        :param y: y, Region y coordinate (in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceNodeOverlay(bpy_struct):
    """Settings for display of overlays in the Node Editor"""

    preview_shape: typing.Literal["FLAT", "3D"]
    """ Preview shape used by the node previews (default 'FLAT')"""

    show_context_path: bool
    """ Display breadcrumbs for the editor's context (default True)"""

    show_named_attributes: bool
    """ Show when nodes are using named attributes (default True)"""

    show_overlays: bool
    """ Display overlays like colored or dashed wires (default True)"""

    show_previews: bool
    """ Display each node's preview if node is toggled (default False)"""

    show_reroute_auto_labels: bool
    """ Label reroute nodes based on the label of connected reroute nodes (default False)"""

    show_timing: bool
    """ Display each node's last execution time (default False)"""

    show_wire_color: bool
    """ Color node links based on their connected sockets (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceOutliner(Space, bpy_struct):
    """Outliner space data"""

    display_mode: typing.Literal[
        "SCENES",
        "VIEW_LAYER",
        "SEQUENCE",
        "LIBRARIES",
        "DATA_API",
        "LIBRARY_OVERRIDES",
        "ORPHAN_DATA",
    ]
    """ Type of information to display (default 'SCENES')"""

    filter_id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems]
    """ Data-block type to show (default 'ACTION')"""

    filter_invert: bool
    """ Invert the object state filter (default False)"""

    filter_state: typing.Literal["ALL", "VISIBLE", "SELECTED", "ACTIVE", "SELECTABLE"]
    """ (default 'ALL')"""

    filter_text: str
    """ Live search filtering string (default "", never None)"""

    lib_override_view_mode: typing.Literal["PROPERTIES", "HIERARCHIES"]
    """ Choose different visualizations of library override data (default 'PROPERTIES')"""

    show_mode_column: bool
    """ Show the mode column for mode toggle and activation (default False)"""

    show_restrict_column_enable: bool
    """ Exclude from view layer (default False)"""

    show_restrict_column_hide: bool
    """ Temporarily hide in viewport (default False)"""

    show_restrict_column_holdout: bool
    """ Holdout (default False)"""

    show_restrict_column_indirect_only: bool
    """ Indirect only (default False)"""

    show_restrict_column_render: bool
    """ Globally disable in renders (default False)"""

    show_restrict_column_select: bool
    """ Selectable (default False)"""

    show_restrict_column_viewport: bool
    """ Globally disable in viewports (default False)"""

    use_filter_case_sensitive: bool
    """ Only use case sensitive matches of search string (default False)"""

    use_filter_children: bool
    """ Show children (default True)"""

    use_filter_collection: bool
    """ Show collections (default True)"""

    use_filter_complete: bool
    """ Only use complete matches of search string (default False)"""

    use_filter_id_type: bool
    """ Show only data-blocks of one type (default False)"""

    use_filter_lib_override_system: bool
    """ For libraries with overrides created, show the overridden values that are defined/controlled automatically (e.g. to make users of an overridden data-block point to the override data, not the original linked data) (default False)"""

    use_filter_object: bool
    """ Show objects (default True)"""

    use_filter_object_armature: bool
    """ Show armature objects (default True)"""

    use_filter_object_camera: bool
    """ Show camera objects (default True)"""

    use_filter_object_content: bool
    """ Show what is inside the objects elements (default True)"""

    use_filter_object_empty: bool
    """ Show empty objects (default True)"""

    use_filter_object_grease_pencil: bool
    """ Show Grease Pencil objects (default True)"""

    use_filter_object_light: bool
    """ Show light objects (default True)"""

    use_filter_object_mesh: bool
    """ Show mesh objects (default True)"""

    use_filter_object_others: bool
    """ Show curves, lattices, light probes, fonts, ... (default True)"""

    use_filter_view_layers: bool
    """ Show all the view layers (default True)"""

    use_sort_alpha: bool
    """ (default True)"""

    use_sync_select: bool
    """ Sync outliner selection with other editors (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpacePreferences(Space, bpy_struct):
    """Blender preferences space data"""

    filter_text: str
    """ Search term for filtering in the UI (default "", never None)"""

    filter_type: typing.Literal["NAME", "KEY"]
    """ Filter method (default 'NAME')"""

    search_filter: str
    """ Live search filtering string (default "", never None)"""

    show_region_ui: bool
    """ (default False)"""

    tab_search_results: bool
    """ Whether or not each visible tab has a search result (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceProperties(Space, bpy_struct):
    """Properties space data"""

    context: typing.Literal[
        "TOOL",
        "SCENE",
        "RENDER",
        "OUTPUT",
        "VIEW_LAYER",
        "WORLD",
        "COLLECTION",
        "OBJECT",
        "CONSTRAINT",
        "MODIFIER",
        "DATA",
        "BONE",
        "BONE_CONSTRAINT",
        "MATERIAL",
        "TEXTURE",
        "PARTICLES",
        "PHYSICS",
        "SHADERFX",
        "STRIP",
        "STRIP_MODIFIER",
    ]
    """ (default 'RENDER')"""

    outliner_sync: typing.Literal["ALWAYS", "NEVER", "AUTO"]
    """ Change to the corresponding tab when outliner data icons are clicked (default 'AUTO')"""

    pin_id: ID | None
    search_filter: str
    """ Live search filtering string (default "", never None)"""

    show_properties_bone: bool
    """ (default False)"""

    show_properties_bone_constraints: bool
    """ (default False)"""

    show_properties_collection: bool
    """ (default False)"""

    show_properties_constraints: bool
    """ (default False)"""

    show_properties_data: bool
    """ (default False)"""

    show_properties_effects: bool
    """ (default False)"""

    show_properties_material: bool
    """ (default False)"""

    show_properties_modifiers: bool
    """ (default False)"""

    show_properties_object: bool
    """ (default False)"""

    show_properties_output: bool
    """ (default False)"""

    show_properties_particles: bool
    """ (default False)"""

    show_properties_physics: bool
    """ (default False)"""

    show_properties_render: bool
    """ (default False)"""

    show_properties_scene: bool
    """ (default False)"""

    show_properties_strip: bool
    """ (default False)"""

    show_properties_strip_modifier: bool
    """ (default False)"""

    show_properties_texture: bool
    """ (default False)"""

    show_properties_tool: bool
    """ (default False)"""

    show_properties_view_layer: bool
    """ (default False)"""

    show_properties_world: bool
    """ (default False)"""

    tab_search_results: bool
    """ Whether or not each visible tab has a search result (default False, readonly)"""

    use_pin_id: bool
    """ Use the pinned context (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceSequenceEditor(Space, bpy_struct):
    """Sequence editor space data"""

    annotation: Annotation | None
    """ Annotation data for this Preview region"""

    cache_overlay: SequencerCacheOverlay | None
    """ Settings for display of overlays (readonly, never None)"""

    cursor_location: mathutils.Vector
    """ 2D cursor location for this view (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    display_channel: int
    """ Preview all channels less than or equal to this value. 0 shows every channel, and negative values climb that many meta-strip levels if applicable, showing every channel there. (in [-5, 128], default 0)"""

    display_mode: typing.Literal[
        "IMAGE", "WAVEFORM", "RGB_PARADE", "VECTOR_SCOPE", "HISTOGRAM"
    ]
    """ View mode to use for displaying sequencer output (default 'IMAGE')"""

    overlay_frame_type: typing.Literal["RECTANGLE", "REFERENCE", "CURRENT"]
    """ Overlay display method (default 'RECTANGLE')"""

    preview_channels: typing.Literal["COLOR_ALPHA", "COLOR"]
    """ Channels of the preview to display (default 'COLOR')"""

    preview_overlay: SequencerPreviewOverlay | None
    """ Settings for display of overlays (readonly, never None)"""

    proxy_render_size: typing.Literal[
        "NONE", "SCENE", "PROXY_25", "PROXY_50", "PROXY_75", "PROXY_100"
    ]
    """ Display preview using full resolution or different proxy resolutions (default 'SCENE')"""

    show_frames: bool
    """ Display frames rather than seconds (default False)"""

    show_gizmo: bool
    """ Show gizmos of all types (default True)"""

    show_gizmo_context: bool
    """ Context sensitive gizmos for the active item (default True)"""

    show_gizmo_navigate: bool
    """ Viewport navigation gizmo (default True)"""

    show_gizmo_tool: bool
    """ Active tool gizmo (default True)"""

    show_markers: bool
    """ If any exists, show markers in a separate row at the bottom of the editor (default False)"""

    show_overexposed: int
    """ Show overexposed areas with zebra stripes (in [0, 110], default 0)"""

    show_overlays: bool
    """ (default False)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_tool_header: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_seconds: bool
    """ Show timing as a timecode instead of frames (default True)"""

    show_transform_preview: bool
    """ Show a preview of the start or end frame of a strip while transforming its respective handle (default False)"""

    timeline_overlay: SequencerTimelineOverlay | None
    """ Settings for display of overlays (readonly, never None)"""

    use_clamp_view: bool
    """ Limit timeline height to maximum used channel slot (default False)"""

    use_marker_sync: bool
    """ Transform markers as well as strips (default False)"""

    use_proxies: bool
    """ Use optimized files for faster scrubbing when available (default False)"""

    use_zoom_to_fit: bool
    """ Automatically zoom preview image to make it fully fit the region (default False)"""

    view_type: Literal[bpy.stub_internal.rna_enums.SpaceSequencerViewTypeItems]
    """ Type of the Sequencer view (sequencer, preview or both) (default 'SEQUENCER')"""

    zoom_percentage: float
    """ Zoom percentage (in [0.4, 80000], default 100.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceSpreadsheet(Space, bpy_struct):
    """Spreadsheet space data"""

    attribute_domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Attribute domain to display (default 'POINT')"""

    geometry_component_type: Literal[
        bpy.stub_internal.rna_enums.GeometryComponentTypeItems
    ]
    """ Part of the geometry to display data from (default 'MESH')"""

    geometry_item_type: typing.Literal["DOMAIN", "BUNDLE"]
    """ Item Type (default 'DOMAIN')"""

    is_pinned: bool
    """ Context path is pinned (default False)"""

    object_eval_state: typing.Literal["EVALUATED", "ORIGINAL", "VIEWER_NODE"]
    """ (default 'EVALUATED')"""

    row_filters: typing.Any
    """ Filters to remove rows from the displayed data (default None, readonly)"""

    show_internal_attributes: bool
    """ Display attributes with names starting with a period that are meant for internal use (default False)"""

    show_only_selected: bool
    """ Only include rows that correspond to selected elements (default False)"""

    show_region_channels: bool
    """ (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    tables: typing.Any
    """ Persistent data for the tables shown in this spreadsheet editor (default None, readonly)"""

    use_filter: bool
    """ (default False)"""

    viewer_path: ViewerPath | None
    """ Path to the data that is displayed in the spreadsheet (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceTextEditor(Space, bpy_struct):
    """Text editor space data"""

    find_text: str
    """ Text to search for with the find tool (default "", never None)"""

    font_size: int
    """ Font size to use for displaying the text (in [1, 256], default 0)"""

    margin_column: int
    """ Column number to show right margin at (in [0, 1024], default 0)"""

    replace_text: str
    """ Text to replace selected text with using the replace tool (default "", never None)"""

    show_line_highlight: bool
    """ Highlight the current line (default False)"""

    show_line_numbers: bool
    """ Show line numbers next to the text (default False)"""

    show_margin: bool
    """ Show right margin (default False)"""

    show_region_footer: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_syntax_highlight: bool
    """ Syntax highlight for scripting (default False)"""

    show_word_wrap: bool
    """ Wrap words if there is not enough horizontal space (default False)"""

    tab_width: int
    """ Number of spaces to display tabs with (in [2, 8], default 0)"""

    text: Text | None
    """ Text displayed and edited in this space"""

    top: int
    """ Top line visible (in [0, inf], default 0)"""

    use_find_all: bool
    """ Search in all text data-blocks, instead of only the active one (default False)"""

    use_find_wrap: bool
    """ Search again from the start of the file when reaching the end (default False)"""

    use_live_edit: bool
    """ Run Python while editing (default False)"""

    use_match_case: bool
    """ Search string is sensitive to uppercase and lowercase letters (default False)"""

    use_overwrite: bool
    """ Overwrite characters when typing rather than inserting them (default False)"""

    visible_lines: int
    """ Amount of lines that can be visible in current editor (in [-inf, inf], default 0, readonly)"""

    def is_syntax_highlight_supported(self) -> bool:
        """Returns True if the editor supports syntax highlighting for the current text data-block

        :return:
        """

    def region_location_from_cursor(self, line: int | None, column: int | None) -> None:
        """Retrieve the region position from the given line and character position

        :param line: Line, Line index (in [-inf, inf])
        :param column: Column, Column index (in [-inf, inf])
        :return: Region coordinates (array of 2 items, in [-1, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class SpaceUVEditor(bpy_struct):
    """UV editor data for the image editor space"""

    custom_grid_subdivisions: typing.Any
    """ Number of grid units in UV space that make one UV Unit (array of 2 items, in [1, 5000], default (0, 0))"""

    display_stretch_type: typing.Literal["ANGLE", "AREA"]
    """ Type of stretch to display (default 'ANGLE')"""

    edge_display_type: typing.Literal["OUTLINE", "DASH", "BLACK", "WHITE"]
    """ Display style for UV edges (default 'OUTLINE')"""

    grid_shape_source: typing.Literal["DYNAMIC", "FIXED", "PIXEL"]
    """ Specify source for the grid shape (default 'DYNAMIC')"""

    lock_bounds: bool
    """ Constraint to stay within the image bounds while editing (default False)"""

    pixel_round_mode: typing.Literal["DISABLED", "CORNER", "CENTER"]
    """ Round UVs to pixels while editing (default 'DISABLED')"""

    show_faces: bool
    """ Display faces over the image (default True)"""

    show_grid_over_image: bool
    """ Show the grid over the image (default True)"""

    show_metadata: bool
    """ Display metadata properties of the image (default False)"""

    show_modified_edges: bool
    """ Display edges after modifiers are applied (default False)"""

    show_pixel_coords: bool
    """ Display UV coordinates in pixels rather than from 0.0 to 1.0 (default True)"""

    show_stretch: bool
    """ Display faces colored according to the difference in shape between UVs and their 3D coordinates (blue for low distortion, red for high distortion) (default False)"""

    show_uv: bool
    """ Display overlay of UV layer (default True)"""

    stretch_opacity: float
    """ Opacity of the UV Stretch overlay (in [0, 1], default 0.0)"""

    tile_grid_shape: typing.Any
    """ How many tiles will be shown in the background (array of 2 items, in [1, 100], default (0, 0))"""

    use_live_unwrap: bool
    """ Continuously unwrap the selected UV island while transforming pinned vertices (default False)"""

    uv_edge_opacity: float
    """ Opacity of edges in UV overlays (in [0, 1], default 0.0)"""

    uv_face_opacity: float
    """ Opacity of faces in UV overlays (in [0, 1], default 0.0)"""

    uv_opacity: float
    """ Opacity of UV overlays (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpaceView3D(Space, bpy_struct):
    """3D View space data"""

    camera: Object | None
    """ Active camera used in this view (when unlocked from the scene's active camera)"""

    clip_end: float
    """ 3D View far clipping distance (in [1e-06, inf], default 1000.0)"""

    clip_start: float
    """ 3D View near clipping distance (perspective view only) (in [1e-06, inf], default 0.01)"""

    icon_from_show_object_viewport: int
    """ (in [-inf, inf], default 0, readonly)"""

    lens: float
    """ Viewport lens angle (in [1, 250], default 50.0)"""

    local_view: typing_extensions.Self | None
    """ Display an isolated subset of objects, apart from the scene visibility (readonly)"""

    lock_bone: str
    """ 3D View center is locked to this bone's position (default "", never None)"""

    lock_camera: bool
    """ Enable view navigation within the camera view (default False)"""

    lock_cursor: bool
    """ 3D View center is locked to the cursor's position (default False)"""

    lock_object: Object | None
    """ 3D View center is locked to this object's position"""

    mirror_xr_session: bool
    """ Synchronize the viewer perspective of virtual reality sessions with this 3D viewport (default False)"""

    overlay: View3DOverlay | None
    """ Settings for display of overlays in the 3D viewport (readonly, never None)"""

    region_3d: RegionView3D | None
    """ 3D region for this space. When the space is in quad view, the camera region (readonly)"""

    region_quadviews: typing.Any
    """ 3D regions (the third one defines quad view settings, the fourth one is same as 'region_3d') (default None, readonly)"""

    render_border_max_x: float
    """ Maximum X value for the render region (in [0, 1], default 0.0)"""

    render_border_max_y: float
    """ Maximum Y value for the render region (in [0, 1], default 0.0)"""

    render_border_min_x: float
    """ Minimum X value for the render region (in [0, 1], default 0.0)"""

    render_border_min_y: float
    """ Minimum Y value for the render region (in [0, 1], default 0.0)"""

    shading: View3DShading | None
    """ Settings for shading in the 3D viewport (readonly, never None)"""

    show_bundle_names: bool
    """ Show names for reconstructed tracks objects (default False)"""

    show_camera_path: bool
    """ Show reconstructed camera path (default False)"""

    show_gizmo: bool
    """ Show gizmos of all types (default True)"""

    show_gizmo_camera_dof_distance: bool
    """ Gizmo to adjust camera focus distance (depends on limits display) (default False)"""

    show_gizmo_camera_lens: bool
    """ Gizmo to adjust camera focal length or orthographic scale (default False)"""

    show_gizmo_context: bool
    """ Context sensitive gizmos for the active item (default True)"""

    show_gizmo_empty_force_field: bool
    """ Gizmo to adjust the force field (default False)"""

    show_gizmo_empty_image: bool
    """ Gizmo to adjust image size and position (default False)"""

    show_gizmo_light_look_at: bool
    """ Gizmo to adjust the direction of the light (default False)"""

    show_gizmo_light_size: bool
    """ Gizmo to adjust spot and area size (default False)"""

    show_gizmo_modifier: bool
    """ Gizmos for the active modifier (default True)"""

    show_gizmo_navigate: bool
    """ Viewport navigation gizmo (default True)"""

    show_gizmo_object_rotate: bool
    """ Gizmo to adjust rotation (default False)"""

    show_gizmo_object_scale: bool
    """ Gizmo to adjust scale (default False)"""

    show_gizmo_object_translate: bool
    """ Gizmo to adjust location (default False)"""

    show_gizmo_tool: bool
    """ Active tool gizmo (default True)"""

    show_object_select_armature: bool
    """ Allow selection of armatures (default True)"""

    show_object_select_camera: bool
    """ Allow selection of cameras (default True)"""

    show_object_select_curve: bool
    """ Allow selection of curves (default True)"""

    show_object_select_curves: bool
    """ Allow selection of hair curves (default True)"""

    show_object_select_empty: bool
    """ Allow selection of empties (default True)"""

    show_object_select_font: bool
    """ Allow selection of text objects (default True)"""

    show_object_select_grease_pencil: bool
    """ Allow selection of Grease Pencil objects (default True)"""

    show_object_select_lattice: bool
    """ Allow selection of lattices (default True)"""

    show_object_select_light: bool
    """ Allow selection of lights (default True)"""

    show_object_select_light_probe: bool
    """ Allow selection of light probes (default True)"""

    show_object_select_mesh: bool
    """ Allow selection of mesh objects (default True)"""

    show_object_select_meta: bool
    """ Allow selection of metaballs (default True)"""

    show_object_select_pointcloud: bool
    """ Allow selection of point clouds (default True)"""

    show_object_select_speaker: bool
    """ Allow selection of speakers (default True)"""

    show_object_select_surf: bool
    """ Allow selection of surfaces (default True)"""

    show_object_select_volume: bool
    """ Allow selection of volumes (default True)"""

    show_object_viewport_armature: bool
    """ Show armatures (default True)"""

    show_object_viewport_camera: bool
    """ Show cameras (default True)"""

    show_object_viewport_curve: bool
    """ Show curves (default True)"""

    show_object_viewport_curves: bool
    """ Show hair curves (default True)"""

    show_object_viewport_empty: bool
    """ Show empties (default True)"""

    show_object_viewport_font: bool
    """ Show text objects (default True)"""

    show_object_viewport_grease_pencil: bool
    """ Show Grease Pencil objects (default True)"""

    show_object_viewport_lattice: bool
    """ Show lattices (default True)"""

    show_object_viewport_light: bool
    """ Show lights (default True)"""

    show_object_viewport_light_probe: bool
    """ Show light probes (default True)"""

    show_object_viewport_mesh: bool
    """ Show mesh objects (default True)"""

    show_object_viewport_meta: bool
    """ Show metaballs (default True)"""

    show_object_viewport_pointcloud: bool
    """ Show point clouds (default True)"""

    show_object_viewport_speaker: bool
    """ Show speakers (default True)"""

    show_object_viewport_surf: bool
    """ Show surfaces (default True)"""

    show_object_viewport_volume: bool
    """ Show volumes (default True)"""

    show_reconstruction: bool
    """ Display reconstruction data from active movie clip (default True)"""

    show_region_asset_shelf: bool
    """ Display a region with assets that may currently be relevant (such as brushes in paint modes, or poses in Pose Mode) (default False)"""

    show_region_hud: bool
    """ (default False)"""

    show_region_tool_header: bool
    """ (default False)"""

    show_region_toolbar: bool
    """ (default False)"""

    show_region_ui: bool
    """ (default False)"""

    show_stereo_3d_cameras: bool
    """ Show the left and right cameras (default False)"""

    show_stereo_3d_convergence_plane: bool
    """ Show the stereo 3D convergence plane (default True)"""

    show_stereo_3d_volume: bool
    """ Show the stereo 3D frustum volume (default False)"""

    show_viewer: bool
    """ Display non-final geometry from viewer nodes (default True)"""

    stereo_3d_camera: typing.Literal["LEFT", "RIGHT", "S3D"]
    """ (default 'S3D')"""

    stereo_3d_convergence_plane_alpha: float
    """ Opacity (alpha) of the convergence plane (in [0, 1], default 0.15)"""

    stereo_3d_eye: typing.Literal["LEFT_EYE", "RIGHT_EYE"]
    """ Current stereo eye being displayed (default 'LEFT_EYE', readonly)"""

    stereo_3d_volume_alpha: float
    """ Opacity (alpha) of the cameras' frustum volume (in [0, 1], default 0.05)"""

    tracks_display_size: float
    """ Display size of tracks from reconstructed data (in [0, inf], default 0.2)"""

    tracks_display_type: typing.Literal[
        "PLAIN_AXES", "ARROWS", "SINGLE_ARROW", "CIRCLE", "CUBE", "SPHERE", "CONE"
    ]
    """ Viewport display style for tracks (default 'PLAIN_AXES')"""

    use_local_camera: bool
    """ Use a local camera in this view, rather than scene's active camera (default False)"""

    use_local_collections: bool
    """ Display a different set of collections in this viewport (default False)"""

    use_render_border: bool
    """ Use a region within the frame size for rendered viewport (when not viewing through the camera) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_handler_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any],
        args: tuple[typing.Any, ...],
        region_type: str,
        draw_type: str,
    ) -> typing.Any:
        """Add a new draw handler to this space type.
        It will be called every time the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the region is drawn.
        It gets the specified arguments as input, its return value is ignored.
                :param args: Arguments that will be passed to the callback.
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :param draw_type: Usually POST_PIXEL for 2D drawing and POST_VIEW for 3D drawing. In some cases PRE_VIEW can be used. BACKDROP can be used for backdrops in the node editor.
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_handler_remove(
        cls, handler: typing.Any | None, region_type: str | None
    ) -> None:
        """Remove a draw handler that was added previously.

        :param handler: The draw handler that should be removed.
        :param region_type: Region type the callback was added to.
        """

class Speaker(ID, bpy_struct):
    """Speaker data-block for 3D audio speaker objects"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    attenuation: float
    """ How strong the distance affects volume, depending on distance model (in [0, inf], default 1.0)"""

    cone_angle_inner: float
    """ Angle of the inner cone, in degrees, inside the cone the volume is 100% (in [0, 360], default 360.0)"""

    cone_angle_outer: float
    """ Angle of the outer cone, in degrees, outside this cone the volume is the outer cone volume, between inner and outer cone the volume is interpolated (in [0, 360], default 360.0)"""

    cone_volume_outer: float
    """ Volume outside the outer cone (in [0, 1], default 1.0)"""

    distance_max: float
    """ Maximum distance for volume calculation, no matter how far away the object is (in [0, inf], default 3.40282e+38)"""

    distance_reference: float
    """ Reference distance at which volume is 100% (in [0, inf], default 1.0)"""

    muted: bool
    """ Mute the speaker (default False)"""

    pitch: float
    """ Playback pitch of the sound (in [0.1, 10], default 1.0)"""

    sound: Sound | None
    """ Sound data-block used by this speaker"""

    volume: float
    """ How loud the sound is (in [0, 1], default 1.0)"""

    volume_max: float
    """ Maximum volume, no matter how near the object is (in [0, 1], default 1.0)"""

    volume_min: float
    """ Minimum volume, no matter how far away the object is (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpeedControlStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip to control the speed of other strips"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    speed_control: typing.Literal["STRETCH", "MULTIPLY", "FRAME_NUMBER", "LENGTH"]
    """ Speed control method (default 'STRETCH')"""

    speed_factor: float
    """ Multiply the current speed of the strip with this number or remap current frame to this frame (in [-inf, inf], default 0.0)"""

    speed_frame_number: float
    """ Frame number of input strip (in [-inf, inf], default 0.0)"""

    speed_length: float
    """ Percentage of input strip length (in [-inf, inf], default 0.0)"""

    use_frame_interpolate: bool
    """ Do crossfade blending between current and next frame (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Spline(bpy_struct):
    """Element of a curve, either NURBS, Bézier or Polyline or a character with text objects"""

    bezier_points: typing.Any
    """ Collection of points for Bézier curves only (default None, readonly)"""

    character_index: int
    """ Location of this character in the text data (only for text curves) (in [0, inf], default 0, readonly)"""

    hide: bool
    """ Hide this curve in Edit mode (default False)"""

    material_index: int
    """ Material slot index of this curve (in [0, 32767], default 0)"""

    order_u: int
    """ NURBS order in the U direction. Higher values make each point influence a greater area, but have worse performance. (in [2, 64], default 0)"""

    order_v: int
    """ NURBS order in the V direction. Higher values make each point influence a greater area, but have worse performance. (in [2, 64], default 0)"""

    point_count_u: int
    """ Total number points for the curve or surface in the U direction (in [0, inf], default 0, readonly)"""

    point_count_v: int
    """ Total number points for the surface on the V direction (in [0, inf], default 0, readonly)"""

    points: typing.Any
    """ Collection of points that make up this poly or nurbs spline (default None, readonly)"""

    radius_interpolation: typing.Literal["LINEAR", "CARDINAL", "BSPLINE", "EASE"]
    """ The type of radius interpolation for Bézier curves (default 'LINEAR')"""

    resolution_u: int
    """ Curve or Surface subdivisions per segment (in [1, 1024], default 0)"""

    resolution_v: int
    """ Surface subdivisions per segment (in [1, 1024], default 0)"""

    tilt_interpolation: typing.Literal["LINEAR", "CARDINAL", "BSPLINE", "EASE"]
    """ The type of tilt interpolation for 3D, Bézier curves (default 'LINEAR')"""

    type: typing.Literal["POLY", "BEZIER", "NURBS"]
    """ The interpolation type for this curve element (default 'POLY')"""

    use_bezier_u: bool
    """ Make this nurbs curve or surface act like a Bézier spline in the U direction (default False)"""

    use_bezier_v: bool
    """ Make this nurbs surface act like a Bézier spline in the V direction (default False)"""

    use_cyclic_u: bool
    """ Make this curve or surface a closed loop in the U direction (default False)"""

    use_cyclic_v: bool
    """ Make this surface a closed loop in the V direction (default False)"""

    use_endpoint_u: bool
    """ Make this nurbs curve or surface meet the endpoints in the U direction (default False)"""

    use_endpoint_v: bool
    """ Make this nurbs surface meet the endpoints in the V direction (default False)"""

    use_smooth: bool
    """ Smooth the normals of the surface or beveled curve (default False)"""

    def calc_length(self, *, resolution: int | None = 0) -> float:
        """Calculate spline length

        :param resolution: Resolution, Spline resolution to be used, 0 defaults to the resolution_u (in [0, 1024], optional)
        :return: Length, Length of the polygonaly approximated spline (in [0, inf])
        """

    def valid_message(self, direction: int | None) -> str:
        """Return the message

        :param direction: Direction, The direction where 0-1 maps to U-V (in [0, 1])
        :return: Return value, The message or an empty string when there is no error
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SplineIKConstraint(Constraint, bpy_struct):
    """Align n bones along a curve"""

    bulge: float
    """ Factor between volume variation and stretching (in [0, 100], default 0.0)"""

    bulge_max: float
    """ Maximum volume stretching factor (in [1, 100], default 0.0)"""

    bulge_min: float
    """ Minimum volume stretching factor (in [0, 1], default 0.0)"""

    bulge_smooth: float
    """ Strength of volume stretching clamping (in [0, 1], default 0.0)"""

    chain_count: int
    """ How many bones are included in the chain (in [1, 255], default 0)"""

    joint_bindings: typing.Any
    """ (EXPERIENCED USERS ONLY) The relative positions of the joints along the chain, as percentages (array of 32 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0))"""

    target: Object | None
    """ Curve that controls this relationship"""

    use_bulge_max: bool
    """ Use upper limit for volume variation (default False)"""

    use_bulge_min: bool
    """ Use lower limit for volume variation (default False)"""

    use_chain_offset: bool
    """ Offset the entire chain relative to the root joint (default False)"""

    use_curve_radius: bool
    """ Average radius of the endpoints is used to tweak the X and Z Scaling of the bones, on top of XZ Scale mode (default True)"""

    use_even_divisions: bool
    """ Ignore the relative lengths of the bones when fitting to the curve (default False)"""

    use_original_scale: bool
    """ Apply volume preservation over the original scaling (default False)"""

    xz_scale_mode: typing.Literal[
        "NONE", "BONE_ORIGINAL", "INVERSE_PRESERVE", "VOLUME_PRESERVE"
    ]
    """ Method used for determining the scaling of the X and Z axes of the bones (default 'NONE')"""

    y_scale_mode: typing.Literal["NONE", "FIT_CURVE", "BONE_ORIGINAL"]
    """ Method used for determining the scaling of the Y axis of the bones, on top of the shape and scaling of the curve itself (default 'NONE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SplinePoint(bpy_struct):
    """Spline point without handles"""

    co: mathutils.Vector
    """ Point coordinates (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    hide: bool
    """ Visibility status (default False)"""

    radius: float
    """ Radius for beveling (in [0, inf], default 0.0)"""

    select: bool
    """ Selection status (default False)"""

    tilt: float
    """ Tilt in 3D View (in [-376.991, 376.991], default 0.0)"""

    weight: float
    """ NURBS weight (in [-inf, inf], default 0.0)"""

    weight_softbody: float
    """ Softbody goal weight (in [0.01, 100], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpotLight(Light, ID, bpy_struct):
    """Directional cone Light"""

    energy: float
    """ The energy this light would emit over its entire area if it wasn't limited by the spot angle, in units of radiant power (W) (in [-inf, inf], default 10.0)"""

    shadow_buffer_clip_start: float
    """ Shadow map clip start, below which objects will not generate shadows (in [1e-06, inf], default 0.05)"""

    shadow_filter_radius: float
    """ Blur shadow aliasing using Percentage Closer Filtering (in [0, inf], default 1.0)"""

    shadow_jitter_overblur: float
    """ Apply shadow tracing to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 10.0)"""

    shadow_maximum_resolution: float
    """ Minimum size of a shadow map pixel. Higher values use less memory at the cost of shadow quality. (in [0, inf], default 0.001)"""

    shadow_soft_size: float
    """ Light size for ray shadow sampling (Raytraced shadows) (in [0, inf], default 0.0)"""

    show_cone: bool
    """ Display transparent cone in 3D view to visualize which objects are contained in it (default False)"""

    spot_blend: float
    """ The softness of the spotlight edge (in [0, 1], default 0.15)"""

    spot_size: float
    """ Angular diameter of the spotlight beam (in [0.0174533, 3.14159], default 0.785398)"""

    use_absolute_resolution: bool
    """ Limit the resolution at 1 unit from the light origin instead of relative to the shadowed pixel (default False)"""

    use_shadow_jitter: bool
    """ Enable jittered soft shadows to increase shadow precision (disabled in viewport unless enabled in the render settings). Has a high performance impact. (default False)"""

    use_soft_falloff: bool
    """ Apply falloff to avoid sharp edges when the light geometry intersects with other objects (default True)"""

    use_square: bool
    """ Cast a square spot light shape (default False)"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this light. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetColumn(bpy_struct):
    """Persistent data associated with a spreadsheet column"""

    data_type: typing.Literal["INT32", "FLOAT", "BOOLEAN", "INSTANCES"]
    """ The data type of the corresponding column visible in the spreadsheet (default 'BOOLEAN', readonly)"""

    id: SpreadsheetColumnID | None
    """ Data used to identify the corresponding data from the data source (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetColumnID(bpy_struct):
    """Data used to identify a spreadsheet column"""

    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetRowFilter(bpy_struct):
    column_name: str
    """ (default "", never None)"""

    enabled: bool
    """ (default False)"""

    operation: typing.Literal["EQUAL", "GREATER", "LESS"]
    """ (default 'EQUAL')"""

    show_expanded: bool
    """ (default False)"""

    threshold: float
    """ How close float values need to be to be equal (in [0, inf], default 0.0)"""

    value_boolean: bool
    """ (default False)"""

    value_color: typing.Any
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    value_float: float
    """ (in [-inf, inf], default 0.0)"""

    value_float2: typing.Any
    """ (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    value_float3: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    value_float4: typing.Any
    """ (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    value_int: int
    """ (in [-inf, inf], default 0)"""

    value_int2: typing.Any
    """ (array of 2 items, in [-inf, inf], default (0, 0))"""

    value_int3: typing.Any
    """ (array of 3 items, in [-inf, inf], default (0, 0, 0))"""

    value_int8: int
    """ (in [-128, 127], default 0)"""

    value_string: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetTable(bpy_struct):
    """Persistent data associated with a table"""

    columns: typing.Any
    """ Columns within the table (default None, readonly)"""

    id: SpreadsheetTableID | None
    """ Data used to identify the table (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetTableID(bpy_struct):
    """Data used to identify a spreadsheet table"""

    type: typing.Literal["GEOMETRY"]
    """ The type of the table identifier (default 'GEOMETRY', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SpreadsheetTableIDGeometry(SpreadsheetTableID, bpy_struct):
    attribute_domain: Literal[bpy.stub_internal.rna_enums.AttributeDomainItems]
    """ Attribute domain to display (default 'POINT', readonly)"""

    geometry_component_type: Literal[
        bpy.stub_internal.rna_enums.GeometryComponentTypeItems
    ]
    """ Part of the geometry to display data from (default 'MESH', readonly)"""

    geometry_item_type: typing.Literal["DOMAIN", "BUNDLE"]
    """ Item Type (default 'DOMAIN', readonly)"""

    layer_index: int
    """ Index of the Grease Pencil layer (in [-inf, inf], default 0, readonly)"""

    object_eval_state: typing.Literal["EVALUATED", "ORIGINAL", "VIEWER_NODE"]
    """ (default 'EVALUATED', readonly)"""

    viewer_path: ViewerPath | None
    """ Path to the data that is displayed (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Stereo3dDisplay(bpy_struct):
    """Settings for stereo 3D display"""

    anaglyph_type: Literal[bpy.stub_internal.rna_enums.Stereo3DAnaglyphTypeItems]
    """ (default 'RED_CYAN')"""

    display_mode: Literal[bpy.stub_internal.rna_enums.Stereo3DDisplayItems]
    """ (default 'ANAGLYPH')"""

    interlace_type: Literal[bpy.stub_internal.rna_enums.Stereo3DInterlaceTypeItems]
    """ (default 'ROW_INTERLEAVED')"""

    use_interlace_swap: bool
    """ Swap left and right stereo channels (default False)"""

    use_sidebyside_crosseyed: bool
    """ Right eye should see left image and vice versa (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Stereo3dFormat(bpy_struct):
    """Settings for stereo output"""

    anaglyph_type: Literal[bpy.stub_internal.rna_enums.Stereo3DAnaglyphTypeItems]
    """ (default 'RED_CYAN')"""

    display_mode: typing.Literal["ANAGLYPH", "INTERLACE", "SIDEBYSIDE", "TOPBOTTOM"]
    """ (default 'ANAGLYPH')"""

    interlace_type: Literal[bpy.stub_internal.rna_enums.Stereo3DInterlaceTypeItems]
    """ (default 'ROW_INTERLEAVED')"""

    use_interlace_swap: bool
    """ Swap left and right stereo channels (default False)"""

    use_sidebyside_crosseyed: bool
    """ Right eye should see left image and vice versa (default False)"""

    use_squeezed_frame: bool
    """ Combine both views in a squeezed image (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StretchToConstraint(Constraint, bpy_struct):
    """Stretch to meet the target object"""

    bulge: float
    """ Factor between volume variation and stretching (in [0, 100], default 0.0)"""

    bulge_max: float
    """ Maximum volume stretching factor (in [1, 100], default 0.0)"""

    bulge_min: float
    """ Minimum volume stretching factor (in [0, 1], default 0.0)"""

    bulge_smooth: float
    """ Strength of volume stretching clamping (in [0, 1], default 0.0)"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    keep_axis: typing.Literal["PLANE_X", "PLANE_Z", "SWING_Y"]
    """ The rotation type and axis order to use (default 'PLANE_X')"""

    rest_length: float
    """ Length at rest position (in [0, 1000], default 0.0)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    use_bulge_max: bool
    """ Use upper limit for volume variation (default False)"""

    use_bulge_min: bool
    """ Use lower limit for volume variation (default False)"""

    volume: typing.Literal["VOLUME_XZX", "VOLUME_X", "VOLUME_Z", "NO_VOLUME"]
    """ Maintain the object's volume as it stretches (default 'VOLUME_XZX')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StringAttribute(Attribute, bpy_struct):
    """Geometry attribute that stores strings"""

    data: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StringAttributeValue(bpy_struct):
    """String value in geometry attribute"""

    value: bytes
    """ (default b"", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StringProperty(Property, bpy_struct):
    """RNA text string property definition"""

    default: str
    """ String default value (default "", readonly, never None)"""

    length_max: int
    """ Maximum length of the string, 0 means unlimited (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Strip(bpy_struct):
    """A single container for content in the Video Sequence Editor"""

    blend_alpha: float
    """ Percentage of how much the strip's colors affect other strips (in [0, 1], default 1.0)"""

    blend_type: typing.Literal[
        "REPLACE",
        "CROSS",
        "DARKEN",
        "MULTIPLY",
        "BURN",
        "LINEAR_BURN",
        "LIGHTEN",
        "SCREEN",
        "DODGE",
        "ADD",
        "OVERLAY",
        "SOFT_LIGHT",
        "HARD_LIGHT",
        "VIVID_LIGHT",
        "LINEAR_LIGHT",
        "PIN_LIGHT",
        "DIFFERENCE",
        "EXCLUSION",
        "SUBTRACT",
        "HUE",
        "SATURATION",
        "COLOR",
        "VALUE",
        "ALPHA_OVER",
        "ALPHA_UNDER",
        "GAMMA_CROSS",
    ]
    """ Method for controlling how the strip combines with other strips (default 'ALPHA_OVER')"""

    channel: int
    """ Vertical position of the strip (in [1, 128], default 0)"""

    color_tag: Literal[bpy.stub_internal.rna_enums.StripColorItems]
    """ Color tag for a strip (default 'COLOR_01')"""

    connections: typing.Any
    """ Other strips currently connected to this strip (default None, readonly)"""

    content_duration: int
    """ Length of the underlying strip source in frames, excluding handles (in [1, 1048574], default 0, readonly)"""

    content_end: int
    """ Timeline frame where underlying strip source ends (in [-inf, inf], default 0, readonly)"""

    content_start: float
    """ Timeline frame where underlying strip source begins (in [-inf, inf], default 0.0)"""

    duration: int
    """ Length of the strip in frames from left handle to right handle (in [-inf, inf], default 0, readonly)"""

    effect_fader: float
    """ Custom fade value (in [0, 1], default 0.0)"""

    frame_duration: int
    """ The length of the contents of this strip before the handles are applied (in [1, 1048574], default 0, readonly)Replaced by '.content_duration'.5.10 removal planned in version 6.0"""

    frame_final_duration: int
    """ The length of the contents of this strip after the handles are applied (in [1, 1048574], default 0)Replaced by '.duration'.5.10 removal planned in version 6.0"""

    frame_final_end: int
    """ End frame displayed in the sequence editor after offsets are applied (in [-inf, inf], default 0)Replaced by '.right_handle'.5.10 removal planned in version 6.0"""

    frame_final_start: int
    """ Start frame displayed in the sequence editor after offsets are applied, setting this is equivalent to moving the handle, not the actual start frame (in [-inf, inf], default 0)Replaced by '.left_handle'.5.10 removal planned in version 6.0"""

    frame_offset_end: float
    """ Offset from the end of the strip in frames (in [-inf, inf], default 0.0)Replaced by '.right_handle_offset'.5.10 removal planned in version 6.0"""

    frame_offset_start: float
    """ Offset from the start of the strip in frames (in [-inf, inf], default 0.0)Replaced by '.left_handle_offset'.5.10 removal planned in version 6.0"""

    frame_start: float
    """ X position where the strip begins (in [-inf, inf], default 0.0)Replaced by '.content_start'.5.10 removal planned in version 6.0"""

    left_handle: int
    """ Timeline frame of the left handle and the start frame of the strip (in [-inf, inf], default 0)"""

    left_handle_offset: float
    """ Rightward frame offset of the left handle from the start of the strip content (in [-inf, inf], default 0.0)"""

    lock: bool
    """ Lock strip so that it cannot be transformed (default False)"""

    modifiers: typing.Any
    """ Modifiers affecting this strip (default None, readonly)"""

    mute: bool
    """ Disable strip so that it does not contribute any output (default False)"""

    name: str
    """ (default "", never None)"""

    right_handle: int
    """ Timeline frame of the right handle, which is the first frame where the strip no longer contributes to the output (in [-inf, inf], default 0)"""

    right_handle_offset: float
    """ Leftward frame offset of the right handle from the end of the strip content (in [-inf, inf], default 0.0)"""

    select: bool
    """ Whether the strip is selected (default False)"""

    select_left_handle: bool
    """ Whether the left handle is selected (default False)"""

    select_right_handle: bool
    """ Whether the right handle is selected (default False)"""

    show_retiming_keys: bool
    """ Show retiming keys, so they can be moved (default False)"""

    type: typing.Literal[
        "IMAGE",
        "META",
        "SCENE",
        "MOVIE",
        "MOVIECLIP",
        "MASK",
        "SOUND",
        "CROSS",
        "ADD",
        "SUBTRACT",
        "ALPHA_OVER",
        "ALPHA_UNDER",
        "GAMMA_CROSS",
        "COMPOSITOR",
        "MULTIPLY",
        "WIPE",
        "GLOW",
        "COLOR",
        "SPEED",
        "MULTICAM",
        "ADJUSTMENT",
        "GAUSSIAN_BLUR",
        "TEXT",
        "COLORMIX",
    ]
    """ (default 'IMAGE', readonly)"""

    use_default_fade: bool
    """ Fade effect using the built-in default (usually makes the transition as long as the effect strip) (default False)"""

    use_linear_modifiers: bool
    """ Calculate modifiers in linear space instead of sequencer's space (default False)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def strip_elem_from_frame(self, frame: int | None) -> StripElement:
        """Return the strip element from a given frame or None

        :param frame: Frame, The frame to get the strip element from (in [-1048574, 1048574])
        :return: strip element of the current frame
        """

    def swap(self, other: typing_extensions.Self | None) -> None:
        """Swap the position of this strip with another

        :param other: Other, Other strip to swap with (never None)
        """

    def move_to_meta(self, meta_sequence: typing_extensions.Self | None) -> None:
        """Move this strip into a meta Strip

        :param meta_sequence: Destination Meta Strip, Meta to move the strip into (never None)
        """

    def parent_meta(self) -> typing_extensions.Self:
        """Returns parent meta Strip

        :return: Parent meta strip
        """

    def invalidate_cache(self, type: typing.Literal["RAW", "COMPOSITE"] | None) -> None:
        """Invalidate cached images for strip and all dependent strips

        :param type: Type, Cache Type (never None)
        """

    def split(
        self,
        frame: int | None,
        split_method: typing.Literal["SOFT", "HARD"] | None,
        *,
        ignore_connections: bool | None = False,
    ) -> typing_extensions.Self:
        """Split Strip

        :param frame: Frame where to split the strip (in [-inf, inf])
        :param split_method: (never None)
        :param ignore_connections: Dont propagate split to connected strips (optional)
        :return: Right side Strip
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripColorBalance(StripColorBalanceData, bpy_struct):
    """Color balance parameters for a sequence strip"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripColorBalanceData(bpy_struct):
    """Color balance parameters for a sequence strip and its modifiers"""

    correction_method: typing.Literal["LIFT_GAMMA_GAIN", "OFFSET_POWER_SLOPE"]
    """ (default 'LIFT_GAMMA_GAIN')"""

    gain: mathutils.Color
    """ Color balance gain (highlights) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    gamma: mathutils.Color
    """ Color balance gamma (midtones) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    invert_gain: bool
    """ Invert the gain color (default False)"""

    invert_gamma: bool
    """ Invert the gamma color (default False)"""

    invert_lift: bool
    """ Invert the lift color (default False)"""

    invert_offset: bool
    """ Invert the offset color (default False)"""

    invert_power: bool
    """ Invert the power color (default False)"""

    invert_slope: bool
    """ Invert the slope color (default False)"""

    lift: mathutils.Color
    """ Color balance lift (shadows) (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    offset: mathutils.Color
    """ Correction for entire tonal range (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    power: mathutils.Color
    """ Correction for midtones (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    slope: mathutils.Color
    """ Correction for highlights (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripCrop(bpy_struct):
    """Cropping parameters for a sequence strip"""

    max_x: int
    """ Number of pixels to crop from the right side (in [-inf, inf], default 0)"""

    max_y: int
    """ Number of pixels to crop from the top (in [-inf, inf], default 0)"""

    min_x: int
    """ Number of pixels to crop from the left side (in [-inf, inf], default 0)"""

    min_y: int
    """ Number of pixels to crop from the bottom (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripElement(bpy_struct):
    """Sequence strip data for a single frame"""

    filename: str
    """ Name of the source file (default "", never None)"""

    orig_fps: float
    """ Original frames per second (in [-inf, inf], default 0.0, readonly)"""

    orig_height: int
    """ Original image height (in [-inf, inf], default 0, readonly)"""

    orig_width: int
    """ Original image width (in [-inf, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripModifier(bpy_struct):
    """Modifier for sequence strip"""

    enable: bool
    """ Enable this modifier (default True)"""

    input_mask_id: Mask | None
    """ Mask ID used as mask input for the modifier"""

    input_mask_strip: Strip | None
    """ Strip used as mask input for the modifier"""

    input_mask_type: typing.Literal["STRIP", "ID"]
    """ Type of input data used for mask (default 'STRIP')"""

    is_active: bool
    """ This modifier is active (default False)"""

    mask_time: typing.Literal["RELATIVE", "ABSOLUTE"]
    """ Time to use for the Mask animation (default 'RELATIVE')"""

    mute: bool
    """ Mute this modifier (default False)"""

    name: str
    """ (default "", never None)"""

    show_expanded: bool
    """ Mute expanded settings for the modifier (default False)"""

    type: Literal[bpy.stub_internal.rna_enums.StripModifierTypeItems]
    """ (default 'BRIGHT_CONTRAST', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripProxy(bpy_struct):
    """Proxy parameters for a sequence strip"""

    build_100: bool
    """ Build 100% proxy resolution (default False)"""

    build_25: bool
    """ Build 25% proxy resolution (default False)"""

    build_50: bool
    """ Build 50% proxy resolution (default False)"""

    build_75: bool
    """ Build 75% proxy resolution (default False)"""

    build_record_run: bool
    """ Build record run time code index (default False)"""

    directory: str
    """ Location to store the proxy files (default "", never None, blend relative // prefix supported)"""

    filepath: str
    """ Location of custom proxy file (default "", never None, blend relative // prefix supported)"""

    quality: int
    """ Quality of proxies to build (in [0, 32767], default 0)"""

    timecode: typing.Literal["NONE", "RECORD_RUN", "RECORD_RUN_NO_GAPS"]
    """ Method for reading the inputs timecode (default 'NONE')"""

    use_overwrite: bool
    """ Overwrite existing proxy files when building (default True)"""

    use_proxy_custom_directory: bool
    """ Use a custom directory to store data (default False)"""

    use_proxy_custom_file: bool
    """ Use a custom file to read proxy data from (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StripTransform(bpy_struct):
    """Transform parameters for a sequence strip"""

    filter: typing.Literal[
        "AUTO", "NEAREST", "BILINEAR", "CUBIC_MITCHELL", "CUBIC_BSPLINE", "BOX"
    ]
    """ Type of filter to use for image transformation (default 'AUTO')"""

    offset_x: float
    """ Move along X axis (in [-inf, inf], default 0.0)"""

    offset_y: float
    """ Move along Y axis (in [-inf, inf], default 0.0)"""

    origin: typing.Any
    """ Origin of image for transformation (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    rotation: float
    """ Rotate around image center (in [-inf, inf], default 0.0)"""

    scale_x: float
    """ Scale along X axis (in [0, inf], default 1.0)"""

    scale_y: float
    """ Scale along Y axis (in [0, inf], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Struct(bpy_struct):
    """RNA structure definition"""

    base: typing_extensions.Self | None
    """ Struct definition this is derived from (readonly)"""

    description: str
    """ Description of the Struct's purpose (default "", readonly, never None)"""

    functions: typing.Any
    """ (default None, readonly)"""

    identifier: str
    """ Unique name used in the code and scripting (default "", readonly, never None)"""

    name: str
    """ Human readable name (default "", readonly, never None)"""

    name_property: StringProperty | None
    """ Property that gives the name of the struct (readonly)"""

    nested: typing_extensions.Self | None
    """ Struct in which this struct is always nested, and to which it logically belongs (readonly)"""

    properties: typing.Any
    """ Properties in the struct (default None, readonly)"""

    property_tags: typing.Any
    """ Tags that properties can use to influence behavior (default None, readonly)"""

    translation_context: str
    """ Translation context of the struct's name (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | typing_extensions.Self | None = None,
        /,
    ) -> typing_extensions.Self:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StucciTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    noise_type: typing.Literal["SOFT_NOISE", "HARD_NOISE"]
    """ (default 'SOFT_NOISE')"""

    stucci_type: typing.Literal["PLASTIC", "WALL_IN", "WALL_OUT"]
    """ (default 'PLASTIC')"""

    turbulence: float
    """ Turbulence of the noise (in [0.0001, inf], default 5.0)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class StudioLight(bpy_struct):
    """Studio light"""

    has_specular_highlight_pass: bool
    """ Studio light image file has separate "diffuse" and "specular" passes (default False, readonly)"""

    index: int
    """ (in [-inf, inf], default 0, readonly)"""

    is_user_defined: bool
    """ (default False, readonly)"""

    light_ambient: mathutils.Color
    """ Color of the ambient light that uniformly lit the scene (array of 3 items, in [0, inf], default (0.0, 0.0, 0.0), readonly)"""

    name: str
    """ (default "", readonly, never None)"""

    path: str
    """ (default "", readonly, never None)"""

    solid_lights: typing.Any
    """ Lights used to display objects in solid draw mode (default None, readonly)"""

    type: typing.Literal["STUDIO", "WORLD", "MATCAP"]
    """ (default 'STUDIO', readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SubsurfModifier(Modifier, bpy_struct):
    """Subdivision surface modifier"""

    adaptive_object_edge_length: float
    """ Target object space edge length for adaptive subdivision (in [0.0001, 1000], default 0.01)"""

    adaptive_pixel_size: float
    """ Target polygon pixel size for adaptive subdivision (in [0.1, 1000], default 1.0)"""

    adaptive_space: typing.Literal["PIXEL", "OBJECT"]
    """ How to adaptively subdivide the mesh (default 'PIXEL')"""

    boundary_smooth: Literal[bpy.stub_internal.rna_enums.SubdivisionBoundarySmoothItems]
    """ Controls how open boundaries are smoothed (default 'ALL')"""

    levels: int
    """ Number of subdivisions to perform in the 3D viewport (in [0, 11], default 1)"""

    open_adaptive_subdivision_panel: bool
    """ (default False)"""

    open_advanced_panel: bool
    """ (default False)"""

    quality: int
    """ Accuracy of vertex positions, lower value is faster but less precise (in [1, 10], default 3)"""

    render_levels: int
    """ Number of subdivisions to perform when rendering (in [0, 11], default 2)"""

    show_only_control_edges: bool
    """ Skip displaying interior subdivided edges (default True)"""

    subdivision_type: typing.Literal["CATMULL_CLARK", "SIMPLE"]
    """ Select type of subdivision algorithm (default 'CATMULL_CLARK')"""

    use_adaptive_subdivision: bool
    """ Adaptively subdivide mesh based on camera distance (default False)"""

    use_creases: bool
    """ Use mesh crease information to sharpen edges or corners (default True)"""

    use_custom_normals: bool
    """ Interpolates existing custom normals to resulting mesh (default False)"""

    use_limit_surface: bool
    """ Place vertices at the surface that would be produced with infinite levels of subdivision (smoothest possible shape) (default True)"""

    uv_smooth: Literal[bpy.stub_internal.rna_enums.SubdivisionUvSmoothItems]
    """ Controls how smoothing is applied to UVs (default 'PRESERVE_BOUNDARIES')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SubtractStrip(EffectStrip, Strip, bpy_struct):
    """Subtract Strip"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SunLight(Light, ID, bpy_struct):
    """Constant direction parallel ray Light"""

    angle: float
    """ Angular diameter of the Sun as seen from the Earth (in [0, 3.14159], default 0.00918043)"""

    energy: float
    """ Sunlight strength in watts per meter squared (W/m²) (in [-inf, inf], default 10.0)"""

    shadow_buffer_clip_start: float
    """ Shadow map clip start, below which objects will not generate shadows (in [1e-06, inf], default 0.05)"""

    shadow_cascade_count: int
    """ Number of texture used by the cascaded shadow map (in [1, 4], default 4)"""

    shadow_cascade_exponent: float
    """ Higher value increase resolution towards the viewpoint (in [0, 1], default 0.8)"""

    shadow_cascade_fade: float
    """ How smooth is the transition between each cascade (in [0, 1], default 0.1)"""

    shadow_cascade_max_distance: float
    """ End distance of the cascaded shadow map (only in perspective view) (in [0, inf], default 200.0)"""

    shadow_filter_radius: float
    """ Blur shadow aliasing using Percentage Closer Filtering (in [0, inf], default 1.0)"""

    shadow_jitter_overblur: float
    """ Apply shadow tracing to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 10.0)"""

    shadow_maximum_resolution: float
    """ Minimum size of a shadow map pixel. Higher values use less memory at the cost of shadow quality. (in [0, inf], default 0.001)"""

    shadow_soft_size: float
    """ Light size for ray shadow sampling (Raytraced shadows) (in [0, inf], default 0.0)"""

    use_shadow_jitter: bool
    """ Enable jittered soft shadows to increase shadow precision (disabled in viewport unless enabled in the render settings). Has a high performance impact. (default False)"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this light. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SurfaceCurve(Curve, ID, bpy_struct):
    """Curve data-block used for storing surfaces"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SurfaceDeformModifier(Modifier, bpy_struct):
    falloff: float
    """ Controls how much nearby polygons influence deformation (in [2, 16], default 4.0)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    is_bound: bool
    """ Whether geometry has been bound to target mesh (default False, readonly)"""

    strength: float
    """ Strength of modifier deformations (in [-100, 100], default 1.0)"""

    target: Object | None
    """ Mesh object to deform with"""

    use_sparse_bind: bool
    """ Only record binding data for vertices matching the vertex group at the time of bind (default False)"""

    vertex_group: str
    """ Vertex group name for selecting/weighting the affected areas (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class SurfaceModifier(Modifier, bpy_struct):
    """Surface modifier defining modifier stack position used for surface fields"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TEXTURE_UL_texpaintslots(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TEXTURE_UL_texslots(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TexMapping(bpy_struct):
    """Texture coordinate mapping settings"""

    mapping: typing.Literal["FLAT", "CUBE", "TUBE", "SPHERE"]
    """ (default 'FLAT')"""

    mapping_x: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'NONE')"""

    mapping_y: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'NONE')"""

    mapping_z: typing.Literal["NONE", "X", "Y", "Z"]
    """ (default 'NONE')"""

    max: mathutils.Vector
    """ Maximum value for clipping (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    min: mathutils.Vector
    """ Minimum value for clipping (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation: mathutils.Euler
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    scale: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    translation: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    use_max: bool
    """ Whether to use maximum clipping value (default False)"""

    use_min: bool
    """ Whether to use minimum clipping value (default False)"""

    vector_type: Literal[bpy.stub_internal.rna_enums.MappingTypeItems]
    """ Type of vector that the mapping transforms (default 'POINT')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TexPaintSlot(bpy_struct):
    """Slot that contains information about texture painting"""

    icon_value: int
    """ Paint slot icon (in [-inf, inf], default 0, readonly)"""

    is_valid: bool
    """ Slot has a valid image and UV map (default False, readonly)"""

    name: str
    """ Name of the slot (default "", readonly, never None)"""

    uv_layer: str
    """ Name of UV map (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Text(ID, bpy_struct):
    """Text data-block referencing an external or packed text file"""

    current_character: int
    """ Index of current character in current line, and also start index of character in selection if one exists (in [0, inf], default 0)"""

    current_line: TextLine | None
    """ Current line, and start line of selection if one exists (readonly, never None)"""

    current_line_index: int
    """ Index of current TextLine in TextLine collection (in [-inf, inf], default 0)"""

    filepath: str
    """ Filename of the text file (default "", never None)"""

    indentation: typing.Literal["TABS", "SPACES"]
    """ Use tabs or spaces for indentation (default 'TABS')"""

    is_dirty: bool
    """ Text file has been edited since last save (default False, readonly)"""

    is_in_memory: bool
    """ Text file is in memory, without a corresponding file on disk (default False, readonly)"""

    is_modified: bool
    """ Text file on disk is different than the one in memory (default False, readonly)"""

    lines: typing.Any
    """ Lines of text (default None, readonly)"""

    select_end_character: int
    """ Index of character after end of selection in the selection end line (in [0, inf], default 0)"""

    select_end_line: TextLine | None
    """ End line of selection (readonly, never None)"""

    select_end_line_index: int
    """ Index of last TextLine in selection (in [-inf, inf], default 0)"""

    use_module: bool
    """ Run this text as a Python script on loading (default False)"""

    def clear(self) -> None:
        """clear the text block"""

    def write(self, text: str | None) -> None:
        """write text at the cursor location and advance to the end of the text block

        :param text: New text for this data-block (never None)
        """

    def from_string(self, text: str | None) -> None:
        """Replace text with this string.

        :param text: (never None)
        """

    def as_string(self) -> str:
        """Return the text as a string

        :return: (never None)
        """

    def is_syntax_highlight_supported(self) -> bool:
        """Returns True if the editor supports syntax highlighting for the current text data-block

        :return:
        """

    def select_set(
        self,
        line_start: int | None,
        char_start: int | None,
        line_end: int | None,
        char_end: int | None,
    ) -> None:
        """Set selection range by line and character index

        :param line_start: Start Line, (in [-inf, inf])
        :param char_start: Start Character, (in [-inf, inf])
        :param line_end: End Line, (in [-inf, inf])
        :param char_end: End Character, (in [-inf, inf])
        """

    def cursor_set(
        self,
        line: int | None,
        *,
        character: int | None = 0,
        select: bool | None = False,
    ) -> None:
        """Set cursor by line and (optionally) character index

        :param line: Line, (in [0, inf])
        :param character: Character, (in [0, inf], optional)
        :param select: Select when moving the cursor (optional)
        """

    def as_module(self) -> None: ...
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def region_as_string(
        self, *, range: None | tuple[tuple[int, int], tuple[int, int]] | None = None
    ) -> str:
        """

                :param range: The region of text to be returned, defaulting to the selection when no range is passed.
        Each int pair represents a line and column: ((start_line, start_column), (end_line, end_column))
        The values match Pythons slicing logic (negative values count backwards from the end, the end value is not inclusive).
                :return: The specified region as a string.
        """

    def region_from_string(
        self,
        body: str | None,
        /,
        *,
        range: None | tuple[tuple[int, int], tuple[int, int]] | None = None,
    ) -> None:
        """

                :param body: The text to be inserted.
                :param range: The region of text to be returned, defaulting to the selection when no range is passed.
        Each int pair represents a line and column: ((start_line, start_column), (end_line, end_column))
        The values match Pythons slicing logic (negative values count backwards from the end, the end value is not inclusive).
        """

class TextBox(bpy_struct):
    """Text bounding box for layout"""

    height: float
    """ (in [0, inf], default 0.0)"""

    width: float
    """ (in [0, inf], default 0.0)"""

    x: float
    """ (in [-inf, inf], default 0.0)"""

    y: float
    """ (in [-inf, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextCharacterFormat(bpy_struct):
    """Text character formatting settings"""

    kerning: float
    """ Spacing between characters (in [-inf, inf], default 0.0)"""

    material_index: int
    """ Material slot index of this character (in [0, inf], default 0)"""

    use_bold: bool
    """ (default False)"""

    use_italic: bool
    """ (default False)"""

    use_small_caps: bool
    """ (default False)"""

    use_underline: bool
    """ (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextCurve(Curve, ID, bpy_struct):
    """Curve data-block used for storing text"""

    active_textbox: int | None
    """ (in [-inf, inf], default 0)"""

    align_x: typing.Literal["LEFT", "CENTER", "RIGHT", "JUSTIFY", "FLUSH"]
    """ Text horizontal alignment from the object or text box center (default 'LEFT')"""

    align_y: typing.Literal[
        "TOP", "TOP_BASELINE", "CENTER", "BOTTOM_BASELINE", "BOTTOM"
    ]
    """ Text vertical alignment from the object center (default 'TOP_BASELINE')"""

    body: str
    """ Content of this text object (default "", never None)"""

    body_format: typing.Any
    """ Stores the style of each character (default None, readonly)"""

    edit_format: TextCharacterFormat | None
    """ Editing settings character formatting (readonly)"""

    family: str
    """ Use objects as font characters (give font objects a common name followed by the character they represent, eg. 'family-a', 'family-b', etc, set this setting to 'family-', and turn on Vertex Instancing) (default "", never None)"""

    follow_curve: Object | None
    """ Curve deforming text object"""

    font: VectorFont | None
    font_bold: VectorFont | None
    font_bold_italic: VectorFont | None
    font_italic: VectorFont | None
    has_selection: bool
    """ Whether there is any text selected (default False, readonly)"""

    is_select_bold: bool
    """ Whether the selected text is bold (default False, readonly)"""

    is_select_italic: bool
    """ Whether the selected text is italics (default False, readonly)"""

    is_select_smallcaps: bool
    """ Whether the selected text is small caps (default False, readonly)"""

    is_select_underline: bool
    """ Whether the selected text is underlined (default False, readonly)"""

    offset_x: float
    """ Horizontal offset from the object origin (in [-inf, inf], default 0.0)"""

    offset_y: float
    """ Vertical offset from the object origin (in [-inf, inf], default 0.0)"""

    overflow: typing.Literal["NONE", "SCALE", "TRUNCATE"]
    """ Handle the text behavior when it does not fit in the text boxes (default 'NONE')"""

    shear: float
    """ Italic angle of the characters (in [-1, 1], default 0.0)"""

    size: float
    """ (in [0.0001, 10000], default 1.0)"""

    small_caps_scale: float
    """ Scale of small capitals (in [-inf, inf], default 0.75)"""

    space_character: float
    """ (in [0, 10], default 1.0)"""

    space_line: float
    """ (in [0, 10], default 1.0)"""

    space_word: float
    """ (in [0, 10], default 1.0)"""

    text_boxes: typing.Any
    """ (default None, readonly)"""

    underline_height: float
    """ (in [0, 0.8], default 0.05)"""

    underline_position: float
    """ Vertical position of underline (in [-0.2, 0.8], default 0.0)"""

    use_fast_edit: bool
    """ Don't fill polygons while editing (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextLine(bpy_struct):
    """Line of text in a Text data-block"""

    body: str
    """ Text in the line (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip creating text"""

    alignment_x: typing.Literal["LEFT", "CENTER", "RIGHT"]
    """ Horizontal text alignment (default 'LEFT')"""

    anchor_x: typing.Literal["LEFT", "CENTER", "RIGHT"]
    """ Horizontal position of the text box relative to Location (default 'LEFT')"""

    anchor_y: typing.Literal["TOP", "CENTER", "BOTTOM"]
    """ Vertical position of the text box relative to Location (default 'TOP')"""

    box_color: typing.Any
    """ (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    box_margin: float
    """ Box margin as factor of image width (in [0, 1], default 0.01)"""

    box_roundness: float
    """ Box corner radius as a factor of box height (in [0, 1], default 0.0)"""

    color: typing.Any
    """ Text color (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    font: VectorFont | None
    """ Font of the text. Falls back to the UI font by default."""

    font_size: float
    """ Size of the text (in [0, 2000], default 0.0)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    location: mathutils.Vector
    """ Location of the text (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    outline_color: typing.Any
    """ (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    outline_width: float
    """ (in [0, 1], default 0.05)"""

    shadow_angle: float
    """ (in [0, 6.28319], default 1.13446)"""

    shadow_blur: float
    """ (in [0, 1], default 0.0)"""

    shadow_color: typing.Any
    """ (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    shadow_offset: float
    """ (in [0, 1], default 0.04)"""

    text: str
    """ Text that will be displayed (default "", never None)"""

    use_bold: bool
    """ Display text as bold (default False)"""

    use_box: bool
    """ Display colored box behind text (default False)"""

    use_italic: bool
    """ Display text as italic (default False)"""

    use_outline: bool
    """ Display outline around text (default False)"""

    use_shadow: bool
    """ Display shadow behind text (default False)"""

    wrap_width: float
    """ Word wrap width as factor, zero disables (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Texture(ID, bpy_struct):
    """Texture data-block used by materials, lights, worlds and brushes"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    color_ramp: ColorRamp | None
    """ (readonly)"""

    contrast: float
    """ Adjust the contrast of the texture (in [0, 5], default 1.0)"""

    factor_blue: float
    """ (in [0, 2], default 1.0)"""

    factor_green: float
    """ (in [0, 2], default 1.0)"""

    factor_red: float
    """ (in [0, 2], default 1.0)"""

    intensity: float
    """ Adjust the brightness of the texture (in [0, 2], default 1.0)"""

    node_tree: TextureNodeTree | None
    """ Node tree for node-based textures"""

    saturation: float
    """ Adjust the saturation of colors in the texture (in [0, 2], default 1.0)"""

    type: Literal[bpy.stub_internal.rna_enums.TextureTypeItems]
    """ (default 'IMAGE')"""

    use_clamp: bool
    """ Set negative texture RGB and intensity values to zero, for some uses like displacement this option can be disabled to get the full range (default False)"""

    use_color_ramp: bool
    """ Map the texture intensity to the color ramp. Note that the alpha value is used for image textures, enable "Calculate Alpha" for images without an alpha channel. (default False)"""

    use_nodes: bool
    """ Make this a node-based texture (default False)"""

    use_preview_alpha: bool
    """ Show Alpha in Preview Render (default False)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    def evaluate(
        self, value: collections.abc.Sequence[float] | mathutils.Vector | None
    ) -> mathutils.Vector:
        """Evaluate the texture at the given coordinate and returns the result

        :param value: The coordinates (x,y,z) of the texture, in case of a 3D texture, the z value is the slice of the texture that is evaluated. For 2D textures such as images, the z value is ignored., (array of 3 items, in [-inf, inf])
        :return: The result of the texture where (x,y,z,w) are (red, green, blue, intensity). For grayscale textures, often intensity only will be used., (array of 4 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNode(NodeInternal, Node, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeAt(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeBricks(TextureNode, NodeInternal, Node, bpy_struct):
    offset: float
    """ Determines the brick offset of the various rows (in [0, 1], default 0.0)"""

    offset_frequency: int
    """ Offset every N rows (in [2, 99], default 0)"""

    squash: float
    """ Factor to adjust the brick's width for particular rows determined by the Offset Frequency (in [0, 99], default 0.0)"""

    squash_frequency: int
    """ Squash every N rows (in [2, 99], default 0)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeChecker(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeCombineColor(TextureNode, NodeInternal, Node, bpy_struct):
    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeCompose(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeCoordinates(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeCurveRGB(TextureNode, NodeInternal, Node, bpy_struct):
    mapping: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeCurveTime(TextureNode, NodeInternal, Node, bpy_struct):
    curve: CurveMapping | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeDecompose(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeDistance(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeGroup(TextureNode, NodeInternal, Node, bpy_struct):
    node_tree: TextureNodeTree | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeHueSaturation(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeImage(TextureNode, NodeInternal, Node, bpy_struct):
    image: Image | None
    image_user: ImageUser | None
    """ Parameters defining the image duration, offset and related settings (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeInvert(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeMath(TextureNode, NodeInternal, Node, bpy_struct):
    operation: Literal[bpy.stub_internal.rna_enums.NodeMathItems]
    """ (default 'ADD')"""

    use_clamp: bool
    """ Clamp result of the node to 0.0 to 1.0 range (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeMixRGB(TextureNode, NodeInternal, Node, bpy_struct):
    blend_type: Literal[bpy.stub_internal.rna_enums.RampBlendItems]
    """ (default 'MIX')"""

    use_alpha: bool
    """ Include alpha of second input in this operation (default False)"""

    use_clamp: bool
    """ Clamp result of the node to 0.0 to 1.0 range (default False)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeOutput(TextureNode, NodeInternal, Node, bpy_struct):
    filepath: str
    """ (default "", never None)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeRGBToBW(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeRotate(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeScale(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeSeparateColor(TextureNode, NodeInternal, Node, bpy_struct):
    mode: Literal[bpy.stub_internal.rna_enums.NodeCombsepColorItems]
    """ Mode of color processing (default 'RGB')"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexBlend(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexClouds(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexDistNoise(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexMagic(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexMarble(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexMusgrave(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexNoise(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexStucci(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexVoronoi(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexWood(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTexture(TextureNode, NodeInternal, Node, bpy_struct):
    node_output: int
    """ For node-based textures, which output node to use (in [-32768, 32767], default 0)"""

    texture: Texture | None

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTranslate(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeTree(NodeTree, ID, bpy_struct):
    """Node tree consisting of linked nodes used for textures"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeValToNor(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeValToRGB(TextureNode, NodeInternal, Node, bpy_struct):
    color_ramp: ColorRamp | None
    """ (readonly)"""

    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureNodeViewer(TextureNode, NodeInternal, Node, bpy_struct):
    @classmethod
    def is_registered_node_type(cls) -> bool:
        """True if a registered node type

        :return: Result
        """

    @classmethod
    def input_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Input socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def output_template(cls, index: int | None) -> NodeInternalSocketTemplate:
        """Output socket template

        :param index: Index, (in [0, inf])
        :return: result
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TextureSlot(bpy_struct):
    """Texture slot defining the mapping and influence of a texture"""

    blend_type: typing.Literal[
        "MIX",
        "DARKEN",
        "MULTIPLY",
        "LIGHTEN",
        "SCREEN",
        "ADD",
        "OVERLAY",
        "SOFT_LIGHT",
        "LINEAR_LIGHT",
        "DIFFERENCE",
        "SUBTRACT",
        "DIVIDE",
        "HUE",
        "SATURATION",
        "COLOR",
        "VALUE",
    ]
    """ Mode used to apply the texture (default 'MIX')"""

    color: mathutils.Color
    """ Default color for textures that don't return RGB or when RGB to intensity is enabled (array of 3 items, in [0, inf], default (1.0, 1.0, 1.0))"""

    default_value: float
    """ Value to use for Ref, Spec, Amb, Emit, Alpha, RayMir, TransLu and Hard (in [-inf, inf], default 1.0)"""

    name: str
    """ Texture slot name (default "", readonly, never None)"""

    offset: mathutils.Vector
    """ Fine tune of the texture mapping X, Y and Z locations (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    output_node: typing.Literal["DEFAULT"]
    """ Which output node to use, for node-based textures (default 'DEFAULT')"""

    scale: mathutils.Vector
    """ Set scaling for the texture's X, Y and Z sizes (array of 3 items, in [-inf, inf], default (1.0, 1.0, 1.0))"""

    texture: Texture | None
    """ Texture data-block used by this texture slot"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Theme(bpy_struct):
    """User interface styling and color settings"""

    bone_color_sets: typing.Any
    """ (default None, readonly, never None)"""

    clip_editor: ThemeClipEditor | None
    """ (readonly, never None)"""

    collection_color: typing.Any
    """ (default None, readonly, never None)"""

    common: ThemeCommon | None
    """ Theme properties shared by different editors (readonly, never None)"""

    console: ThemeConsole | None
    """ (readonly, never None)"""

    dopesheet_editor: ThemeDopeSheet | None
    """ (readonly, never None)"""

    file_browser: ThemeFileBrowser | None
    """ (readonly, never None)"""

    filepath: str
    """ The path to the preset loaded into this theme (if any) (default "", never None)"""

    graph_editor: ThemeGraphEditor | None
    """ (readonly, never None)"""

    image_editor: ThemeImageEditor | None
    """ (readonly, never None)"""

    info: ThemeInfo | None
    """ (readonly, never None)"""

    name: str
    """ Name of the theme (default "", never None)"""

    nla_editor: ThemeNLAEditor | None
    """ (readonly, never None)"""

    node_editor: ThemeNodeEditor | None
    """ (readonly, never None)"""

    outliner: ThemeOutliner | None
    """ (readonly, never None)"""

    preferences: ThemePreferences | None
    """ (readonly, never None)"""

    properties: ThemeProperties | None
    """ (readonly, never None)"""

    regions: ThemeRegions | None
    """ Theme properties for common editor regions (readonly, never None)"""

    sequence_editor: ThemeSequenceEditor | None
    """ (readonly, never None)"""

    spreadsheet: ThemeSpreadsheet | None
    """ (readonly, never None)"""

    statusbar: ThemeStatusBar | None
    """ (readonly, never None)"""

    strip_color: typing.Any
    """ (default None, readonly, never None)"""

    text_editor: ThemeTextEditor | None
    """ (readonly, never None)"""

    theme_area: typing.Literal[
        "USER_INTERFACE",
        "STYLE",
        "REGIONS",
        "COMMON",
        "VIEW_3D",
        "DOPESHEET_EDITOR",
        "FILE_BROWSER",
        "GRAPH_EDITOR",
        "IMAGE_EDITOR",
        "INFO",
        "CLIP_EDITOR",
        "NODE_EDITOR",
        "NLA_EDITOR",
        "OUTLINER",
        "PREFERENCES",
        "PROPERTIES",
        "CONSOLE",
        "SPREADSHEET",
        "STATUSBAR",
        "TEXT_EDITOR",
        "TOPBAR",
        "SEQUENCE_EDITOR",
        "BONE_COLOR_SETS",
    ]
    """ (default 'USER_INTERFACE')"""

    topbar: ThemeTopBar | None
    """ (readonly, never None)"""

    user_interface: ThemeUserInterface | None
    """ (readonly, never None)"""

    view_3d: ThemeView3D | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeBoneColorSet(bpy_struct):
    """Theme settings for bone color sets"""

    active: mathutils.Color | None
    """ Color used for active bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    normal: mathutils.Color
    """ Color used for the surface of bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    select: mathutils.Color
    """ Color used for selected bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    show_colored_constraints: bool
    """ Allow the use of colors indicating constraints/keyed status (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeClipEditor(bpy_struct):
    """Theme settings for the Movie Clip Editor"""

    active_marker: mathutils.Color | None
    """ Color of active marker (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    disabled_marker: mathutils.Color
    """ Color of disabled marker (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    grid: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    locked_marker: mathutils.Color
    """ Color of locked marker (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    marker: mathutils.Color
    """ Color of marker (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    marker_outline: mathutils.Color
    """ Color of marker's outline (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    metadatabg: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    metadatatext: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    path_after: mathutils.Color
    """ Color of path after current frame (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    path_before: mathutils.Color
    """ Color of path before current frame (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    path_keyframe_after: mathutils.Color
    """ Color of keyframes on a path after current frame (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    path_keyframe_before: mathutils.Color
    """ Color of keyframes on a path before current frame (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    selected_marker: mathutils.Color
    """ Color of selected marker (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeCollectionColor(bpy_struct):
    """Theme settings for collection colors"""

    color: mathutils.Color
    """ Collection Color Tag (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeCommon(bpy_struct):
    """Theme properties shared by different editors"""

    anim: ThemeCommonAnim | None
    """ (readonly, never None)"""

    curves: ThemeCommonCurves | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeCommonAnim(bpy_struct):
    """Shared animation theme properties"""

    channel: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    channel_group: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    channel_group_active: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    channel_selected: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    channels: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    channels_sub: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    keyframe: mathutils.Color
    """ Color of regular keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_breakdown: mathutils.Color
    """ Color of breakdown keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_breakdown_selected: mathutils.Color
    """ Color of selected breakdown keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_extreme: mathutils.Color
    """ Color of extreme keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_extreme_selected: mathutils.Color
    """ Color of selected extreme keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_generated: mathutils.Color
    """ Color of generated keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_generated_selected: mathutils.Color
    """ Color of selected generated keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_jitter: mathutils.Color
    """ Color of jitter keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_jitter_selected: mathutils.Color
    """ Color of selected jitter keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_moving_hold: mathutils.Color
    """ Color of moving hold keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_moving_hold_selected: mathutils.Color
    """ Color of selected moving hold keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_selected: mathutils.Color
    """ Color of selected keyframe (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    long_key: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    long_key_selected: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    playhead: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    preview_range: typing.Any
    """ Color of preview range overlay (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    scene_strip_range: typing.Any
    """ Color of scene strip range overlay (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeCommonCurves(bpy_struct):
    """Shared curve theme properties"""

    handle_align: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_auto: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_auto_clamped: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_free: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_sel_align: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_sel_auto: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_sel_auto_clamped: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_sel_free: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_sel_vect: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_vect: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_vertex: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_vertex_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    handle_vertex_size: int
    """ (in [1, 100], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeConsole(bpy_struct):
    """Theme settings for the Console"""

    cursor: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_error: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_info: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_input: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_output: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeDopeSheet(bpy_struct):
    """Theme settings for the Dope Sheet"""

    anim_interpolation_constant: typing.Any
    """ Color of lines showing constant interpolation mode (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    anim_interpolation_linear: typing.Any
    """ Color of lines showing linear interpolation mode (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    anim_interpolation_other: typing.Any
    """ Color of lines showing easings & dynamic interpolation mode (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    grid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_border: typing.Any
    """ Color of keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    keyframe_border_selected: typing.Any
    """ Color of selected keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    keyframe_scale_factor: float
    """ Scale factor for adjusting the height of keyframes (in [0.8, 5], default 1.0)"""

    simulated_frames: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    summary: typing.Any
    """ Color of summary channel (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeFileBrowser(bpy_struct):
    """Theme settings for the File Browser"""

    row_alternate: typing.Any
    """ Overlay color on every other row (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    selected_file: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeFontStyle(bpy_struct):
    """Theme settings for Font"""

    character_weight: int
    """ Weight of the characters. 100-900, 400 is normal. (in [100, 900], default 400)"""

    points: float
    """ Font size in points (in [6, 32], default 0.0)"""

    shadow: int
    """ Shadow type (0 none, 3, 5 blur, 6 outline) (in [0, 6], default 0)"""

    shadow_alpha: float
    """ (in [0, 1], default 0.0)"""

    shadow_offset_x: int
    """ Shadow offset in pixels (in [-10, 10], default 0)"""

    shadow_offset_y: int
    """ Shadow offset in pixels (in [-10, 10], default 0)"""

    shadow_value: float
    """ Shadow color in gray value (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeGradientColors(bpy_struct):
    """Theme settings for background colors and gradient"""

    background_type: typing.Literal["SINGLE_COLOR", "LINEAR", "RADIAL"]
    """ Type of background in the 3D viewport (default 'SINGLE_COLOR')"""

    gradient: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    high_gradient: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeGraphEditor(bpy_struct):
    """Theme settings for the graph editor"""

    grid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    vertex: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_active: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_size: int
    """ (in [1, 32], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeImageEditor(bpy_struct):
    """Theme settings for the Image Editor"""

    edge_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    edge_width: int
    """ (in [1, 32], default 0)"""

    editmesh_active: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_mode_select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    facedot_size: int
    """ (in [1, 10], default 0)"""

    grid: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    metadatabg: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    metadatatext: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    preview_stitch_active: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    preview_stitch_edge: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    preview_stitch_face: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    preview_stitch_stitchable: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    preview_stitch_unstitchable: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    preview_stitch_vert: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    scope_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    uv_shadow: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    vertex: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_size: int
    """ (in [1, 32], default 0)"""

    wire_edit: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeInfo(bpy_struct):
    """Theme settings for Info"""

    info_debug: typing.Any
    """ Background color of Debug icon (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    info_debug_text: mathutils.Color
    """ Foreground color of Debug icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_error_text: mathutils.Color
    """ Foreground color of Error icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_info_text: mathutils.Color
    """ Foreground color of Info icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_operator: typing.Any
    """ Background color of Operator icon (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    info_operator_text: mathutils.Color
    """ Foreground color of Operator icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_property: typing.Any
    """ Background color of Property icon (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    info_property_text: mathutils.Color
    """ Foreground color of Property icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_selected: mathutils.Color
    """ Background color of selected line (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_selected_text: mathutils.Color
    """ Text color of selected line (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    info_warning_text: mathutils.Color
    """ Foreground color of Warning icon (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeNLAEditor(bpy_struct):
    """Theme settings for the NLA Editor"""

    active_action: typing.Any
    """ Animation data-block has active action (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    active_action_unset: typing.Any
    """ Animation data-block does not have active action (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    grid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_border: typing.Any
    """ Color of keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    keyframe_border_selected: typing.Any
    """ Color of selected keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    meta_strips: mathutils.Color
    """ Unselected Meta Strip (for grouping related strips) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    meta_strips_selected: mathutils.Color
    """ Selected Meta Strip (for grouping related strips) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    sound_strips: mathutils.Color
    """ Unselected Sound Strip (for timing speaker sounds) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    sound_strips_selected: mathutils.Color
    """ Selected Sound Strip (for timing speaker sounds) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    strips: mathutils.Color
    """ Unselected Action-Clip Strip (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    strips_selected: mathutils.Color
    """ Selected Action-Clip Strip (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transition_strips: mathutils.Color
    """ Unselected Transition Strip (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transition_strips_selected: mathutils.Color
    """ Selected Transition Strip (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    tweak: mathutils.Color
    """ Color for strip/action being "tweaked" or edited (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    tweak_duplicate: mathutils.Color
    """ Warning/error indicator color for strips referencing the strip being tweaked (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeNodeEditor(bpy_struct):
    """Theme settings for the Node Editor"""

    attribute_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    closure_zone: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    color_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    converter_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    dash_alpha: float
    """ Opacity for the dashed lines in wires (in [0, 1], default 0.5)"""

    distor_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    filter_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    foreach_geometry_element_zone: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    frame_node: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    geometry_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    grid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    grid_levels: int
    """ Number of subdivisions for the dot grid displayed in the background (in [0, 3], default 3)"""

    group_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    group_socket_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    input_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    matte_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    node_active: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    node_backdrop: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    node_outline: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    node_selected: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    noodle_curving: int
    """ Curving of the noodle (in [0, 10], default 5)"""

    output_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    repeat_zone: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    script_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    shader_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    simulation_zone: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    texture_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vector_node: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    wire: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    wire_inner: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    wire_select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeOutliner(bpy_struct):
    """Theme settings for the Outliner"""

    active: mathutils.Color | None
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    active_object: mathutils.Color | None
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    edited_object: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    match: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    row_alternate: typing.Any
    """ Overlay color on every other row (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    selected_highlight: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    selected_object: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemePreferences(bpy_struct):
    """Theme settings for the Blender Preferences"""

    match: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeProperties(bpy_struct):
    """Theme settings for the Properties"""

    match: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeRegions(bpy_struct):
    """Theme settings for regions that are common among editors"""

    asset_shelf: ThemeRegionsAssetShelf | None
    """ (readonly, never None)"""

    channels: ThemeRegionsChannels | None
    """ (readonly, never None)"""

    scrubbing: ThemeRegionsScrubbing | None
    """ (readonly, never None)"""

    sidebars: ThemeRegionsSidebars | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeRegionsAssetShelf(bpy_struct):
    """Theme settings for asset shelves"""

    back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    header_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeRegionsChannels(bpy_struct):
    back: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_selected: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeRegionsScrubbing(bpy_struct):
    back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    time_marker: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    time_marker_selected: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeRegionsSidebars(bpy_struct):
    back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    tab_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeSequenceEditor(bpy_struct):
    """Theme settings for the Sequence Editor"""

    active_strip: mathutils.Color | None
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    audio_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    color_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    effect_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    grid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    image_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    keyframe_border: typing.Any
    """ Color of keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    keyframe_border_selected: typing.Any
    """ Color of selected keyframe border (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    mask_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    meta_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    metadatabg: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    metadatatext: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    movie_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    movieclip_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    preview_back: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    row_alternate: typing.Any
    """ Overlay color on every other row (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    scene_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    selected_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    selected_text: typing.Any
    """ Text strip editing selection (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    text_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_strip_cursor: typing.Any
    """ Text strip editing cursor (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    transition_strip: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeSpaceGeneric(bpy_struct):
    back: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    header: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    header_text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    header_text_hi: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_hi: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    title: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeSpaceGradient(bpy_struct):
    gradients: ThemeGradientColors | None
    """ (readonly, never None)"""

    header: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    header_text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    header_text_hi: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_hi: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    title: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeSpreadsheet(bpy_struct):
    """Theme settings for the Spreadsheet"""

    row_alternate: typing.Any
    """ Overlay color on every other row (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeStatusBar(bpy_struct):
    """Theme settings for the Status Bar"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeStripColor(bpy_struct):
    """Theme settings for strip colors"""

    color: mathutils.Color
    """ Strip Color (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeStyle(bpy_struct):
    """Theme settings for style sets"""

    panel_title: ThemeFontStyle | None
    """ (readonly, never None)"""

    tooltip: ThemeFontStyle | None
    """ (readonly, never None)"""

    widget: ThemeFontStyle | None
    """ (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeTextEditor(bpy_struct):
    """Theme settings for the Text Editor"""

    cursor: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_numbers: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    line_numbers_background: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    selected_text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    syntax_builtin: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_comment: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_numbers: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_preprocessor: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_reserved: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_special: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_string: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    syntax_symbols: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeTopBar(bpy_struct):
    """Theme settings for the Top Bar"""

    space: ThemeSpaceGeneric | None
    """ Settings for space (readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeUserInterface(bpy_struct):
    """Theme settings for user interface elements"""

    axis_w: mathutils.Color
    """ W-axis for quaternion and axis-angle rotations (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    axis_x: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    axis_y: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    axis_z: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    editor_border: mathutils.Color
    """ Color of the border between editors (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    editor_outline: typing.Any
    """ Color of the outline of each editor, except the active one (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    editor_outline_active: typing.Any
    """ Color of the outline of the active editor (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    gizmo_a: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gizmo_b: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gizmo_hi: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gizmo_primary: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gizmo_secondary: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gizmo_view_align: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    icon_alpha: float
    """ Transparency of icons in the interface, to reduce contrast (in [0, 1], default 0.0)"""

    icon_autokey: typing.Any
    """ Color of Auto Keying indicator when enabled (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_border_intensity: float
    """ Control the intensity of the border around themes icons (in [0, 1], default 0.0)"""

    icon_collection: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_folder: typing.Any
    """ Color of folders in the file browser (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_modifier: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_object: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_object_data: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_saturation: float
    """ Saturation of icons in the interface (in [0, 1], default 0.0)"""

    icon_scene: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    icon_shading: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    menu_shadow_fac: float
    """ Blending factor for panel and menu shadows (in [0.01, 1], default 0.0)"""

    menu_shadow_width: int
    """ Width of panel and menu shadows, set to zero to disable (in [0, 24], default 0)"""

    panel_active: typing.Any
    """ Color of the outline of top-level panels that are active (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    panel_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    panel_header: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    panel_outline: typing.Any
    """ Color of the outline of top-level panels (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    panel_roundness: float
    """ Roundness of the corners of panels and sub-panels (in [0, 1], default 0.4)"""

    panel_sub_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    panel_text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    panel_title: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transparent_checker_primary: mathutils.Color
    """ Primary color of checkerboard pattern indicating transparent areas (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transparent_checker_secondary: mathutils.Color
    """ Secondary color of checkerboard pattern indicating transparent areas (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transparent_checker_size: int
    """ Size of checkerboard pattern indicating transparent areas (in [2, 48], default 0)"""

    wcol_box: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_curve: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_list_item: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_menu: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_menu_back: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_menu_item: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_num: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_numslider: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_option: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_pie_menu: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_progress: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_pulldown: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_radio: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_regular: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_scroll: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_state: ThemeWidgetStateColors | None
    """ (readonly, never None)"""

    wcol_tab: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_text: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_toggle: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_tool: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_toolbar_item: ThemeWidgetColors | None
    """ (readonly, never None)"""

    wcol_tooltip: ThemeWidgetColors | None
    """ (readonly, never None)"""

    widget_emboss: typing.Any
    """ Color of the 1px shadow line underlying widgets (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    widget_text_cursor: mathutils.Color
    """ Color of the text insertion cursor (caret) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeView3D(bpy_struct):
    """Theme settings for the 3D viewport"""

    after_current_frame: mathutils.Color
    """ The color for things after the current frame (for onion skinning, motion paths, etc.) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    before_current_frame: mathutils.Color
    """ The color for things before the current frame (for onion skinning, motion paths, etc.) (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    bevel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    bone_locked_weight: typing.Any
    """ Shade for bones corresponding to a locked weight group during painting (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    bone_pose: mathutils.Color
    """ Outline color of selected pose bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    bone_pose_active: mathutils.Color
    """ Outline color of active pose bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    bone_solid: mathutils.Color
    """ Default color of the solid shapes of bones (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    bundle_solid: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    camera: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    camera_passepartout: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    camera_path: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    clipping_border_3d: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    crease: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    edge_mode_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    edge_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    edge_width: int
    """ (in [1, 32], default 0)"""

    editmesh_active: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    empty: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    extra_edge_angle: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    extra_edge_len: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    extra_face_angle: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    extra_face_area: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    face: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_back: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_front: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_mode_select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_retopology: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    face_select: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    facedot_size: int
    """ (in [1, 10], default 0)"""

    freestyle: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    gp_vertex: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gp_vertex_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    gp_vertex_size: int
    """ (in [1, 10], default 0)"""

    gp_wire_edit: typing.Any
    """ Grease Pencil wireframe color when in edit mode (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    grid: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    grid_major: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    light: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    normal: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    nurb_sel_uline: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    nurb_sel_vline: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    nurb_uline: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    nurb_vline: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    object_active: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    object_origin_size: int
    """ Diameter in pixels for object/light origin display (in [4, 10], default 0)"""

    object_selected: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    outline_width: int
    """ (in [1, 5], default 0)"""

    seam: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    sharp: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    skin_root: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    space: ThemeSpaceGradient | None
    """ Settings for space (readonly, never None)"""

    speaker: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    split_normal: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_grease_pencil: mathutils.Color
    """ Color for indicating Grease Pencil keyframes (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    transform: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_normal: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_select: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    vertex_size: int
    """ (in [1, 32], default 0)"""

    vertex_unreferenced: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    view_overlay: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    wire: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    wire_edit: mathutils.Color
    """ Color for wireframe when in edit mode, but edge selection is active (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeWidgetColors(bpy_struct):
    """Theme settings for widget color sets"""

    inner: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    inner_sel: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    item: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    outline: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    outline_sel: typing.Any
    """ (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    roundness: float
    """ Amount of edge rounding (in [0, 1], default 0.0)"""

    shadedown: int
    """ (in [-100, 100], default 0)"""

    shadetop: int
    """ (in [-100, 100], default 0)"""

    show_shaded: bool
    """ (default False)"""

    text: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    text_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ThemeWidgetStateColors(bpy_struct):
    """Theme settings for widget state colors"""

    blend: float
    """ (in [0, 1], default 0.0)"""

    error: typing.Any
    """ Color for error items (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    info: typing.Any
    """ Color for informational items (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    inner_anim: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_anim_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_changed: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_changed_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_driven: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_driven_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_key: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_key_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_overridden: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    inner_overridden_sel: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    success: typing.Any
    """ Color for successful items (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    warning: typing.Any
    """ Color for warning items (array of 4 items, in [0, 1], default (0.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TimelineMarker(bpy_struct):
    """Marker for noting points in the timeline"""

    camera: Object | None
    """ Camera that becomes active on this frame"""

    frame: int
    """ The frame on which the timeline marker appears (in [-inf, inf], default 0)"""

    name: str
    """ (default "", never None)"""

    select: bool
    """ Marker selection state (default False)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Timer(bpy_struct):
    """Window event timer"""

    time_delta: float
    """ Time since last step in seconds (in [-inf, inf], default 0.0, readonly)"""

    time_duration: float
    """ Time since the timer started seconds (in [-inf, inf], default 0.0, readonly)"""

    time_step: float
    """ (in [-inf, inf], default 0.0, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ToolSettings(bpy_struct):
    anim_fix_to_cam_use_loc: bool
    """ Create location keys when fixing to the scene camera (default True)"""

    anim_fix_to_cam_use_rot: bool
    """ Create rotation keys when fixing to the scene camera (default True)"""

    anim_fix_to_cam_use_scale: bool
    """ Create scale keys when fixing to the scene camera (default True)"""

    anim_mirror_bone: str
    """ Bone to use for the mirroring (default "", never None)"""

    anim_mirror_object: Object | None
    """ Object to mirror over. Leave empty and name a bone to always mirror over that bone of the active armature"""

    anim_relative_object: Object | None
    """ Object to which matrices are made relative"""

    annotation_stroke_placement_view2d: typing.Literal["IMAGE", "VIEW"]
    """ (default 'IMAGE')"""

    annotation_stroke_placement_view3d: typing.Literal["CURSOR", "VIEW", "SURFACE"]
    """ How annotation strokes are orientated in 3D space (default 'CURSOR')"""

    annotation_thickness: int
    """ Thickness of annotation strokes (in [1, 10], default 3)"""

    auto_keying_mode: typing.Literal["ADD_REPLACE_KEYS", "REPLACE_KEYS"]
    """ Mode of automatic keyframe insertion for objects, bones and masks (default 'ADD_REPLACE_KEYS')"""

    curve_paint_settings: CurvePaintSettings | None
    """ (readonly, never None)"""

    curves_sculpt: CurvesSculpt | None
    """ (readonly)"""

    custom_bevel_profile_preset: CurveProfile | None
    """ Used for defining a profile's path (readonly)"""

    double_threshold: float
    """ Threshold distance for Auto Merge (in [0, 1], default 0.001)"""

    gpencil_interpolate: GPencilInterpolateSettings | None
    """ Settings for Grease Pencil interpolation tools (readonly)"""

    gpencil_paint: GpPaint | None
    """ (readonly)"""

    gpencil_sculpt: GPencilSculptSettings | None
    """ Settings for stroke sculpting tools and brushes (readonly)"""

    gpencil_sculpt_paint: GpSculptPaint | None
    """ (readonly)"""

    gpencil_selectmode_edit: Literal[
        bpy.stub_internal.rna_enums.GreasePencilSelectmodeItems
    ]
    """ (default 'POINT')"""

    gpencil_stroke_placement_view3d: typing.Literal[
        "ORIGIN", "CURSOR", "SURFACE", "STROKE"
    ]
    """ (default 'ORIGIN')"""

    gpencil_stroke_snap_mode: typing.Literal["NONE", "ENDS", "FIRST"]
    """ (default 'NONE')"""

    gpencil_surface_offset: float
    """ Offset along the normal when drawing on surfaces (in [-inf, inf], default 0.15)"""

    gpencil_vertex_paint: GpVertexPaint | None
    """ (readonly)"""

    gpencil_weight_paint: GpWeightPaint | None
    """ (readonly)"""

    image_paint: ImagePaint | None
    """ (readonly)"""

    keyframe_type: Literal[bpy.stub_internal.rna_enums.BeztripleKeyframeTypeItems]
    """ Type of keyframes to create when inserting keyframes (default 'KEYFRAME')"""

    lock_markers: bool
    """ Prevent marker editing (default False)"""

    lock_object_mode: bool
    """ Restrict selection to objects using the same mode as the active object, to prevent accidental mode switch when selecting (default True)"""

    mesh_select_mode: typing.Any
    """ Which mesh elements selection works on (array of 3 items, default (False, False, False))"""

    normal_vector: mathutils.Vector
    """ Normal vector used to copy, add or multiply (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    paint_mode: PaintModeSettings | None
    """ (readonly)"""

    particle_edit: ParticleEdit | None
    """ (readonly)"""

    plane_axis: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ The axis used for placing the base region (default 'Z')"""

    plane_axis_auto: bool
    """ Select the closest axis when placing objects (surface overrides) (default True)"""

    plane_depth: typing.Literal["SURFACE", "CURSOR_PLANE", "CURSOR_VIEW"]
    """ The initial depth used when placing the cursor (default 'SURFACE')"""

    plane_orientation: typing.Literal["SURFACE", "DEFAULT"]
    """ The initial depth used when placing the cursor (default 'SURFACE')"""

    playhead_snap_distance: int
    """ Maximum distance for snapping in pixels (in [-inf, inf], default 20)"""

    proportional_distance: float
    """ Display size for proportional editing circle (in [1e-05, 5000], default 1.0)"""

    proportional_edit_falloff: Literal[
        bpy.stub_internal.rna_enums.ProportionalFalloffItems
    ]
    """ Falloff type for proportional editing mode (default 'SMOOTH')"""

    proportional_size: float
    """ Display size for proportional editing circle (in [1e-05, 5000], default 1.0)"""

    sculpt: Sculpt | None
    """ (readonly)"""

    sequencer_tool_settings: SequencerToolSettings | None
    """ (readonly, never None)"""

    show_uv_local_view: bool
    """ Display only faces with the currently displayed image assigned (default False)"""

    snap_angle_increment_2d: float
    """ Angle used for rotation increments in 2D editors (in [0, 3.14159], default 0.0872665)"""

    snap_angle_increment_2d_precision: float
    """ Precision angle used for rotation increments in 2D editors (in [0, 3.14159], default 0.0174533)"""

    snap_angle_increment_3d: float
    """ Angle used for rotation increments in 3D editors (in [0, 3.14159], default 0.0872665)"""

    snap_angle_increment_3d_precision: float
    """ Precision angle used for rotation increments in 3D editors (in [0, 3.14159], default 0.0174533)"""

    snap_anim_element: Literal[bpy.stub_internal.rna_enums.SnapAnimationElementItems]
    """ Type of element to snap to (default 'FRAME')"""

    snap_elements: set[Literal[bpy.stub_internal.rna_enums.SnapElementItems]]
    """ Type of element to snap to (default {'INCREMENT'})"""

    snap_elements_base: set[
        typing.Literal[
            "INCREMENT",
            "GRID",
            "VERTEX",
            "EDGE",
            "FACE",
            "VOLUME",
            "EDGE_MIDPOINT",
            "EDGE_PERPENDICULAR",
            "FACE_MIDPOINT",
        ]
    ]
    """ Type of element for the "Snap Base" to snap to (default {'INCREMENT'})"""

    snap_elements_individual: set[typing.Literal["FACE_PROJECT", "FACE_NEAREST"]]
    """ Type of element for individual transformed elements to snap to (default set())"""

    snap_elements_tool: typing.Literal["GEOMETRY", "DEFAULT"]
    """ The target to use while snapping (default 'GEOMETRY')"""

    snap_face_nearest_steps: int
    """ Number of steps to break transformation into for face nearest snapping (in [1, 100], default 1)"""

    snap_playhead_element: set[
        typing.Literal["FRAME", "SECOND", "MARKER", "KEY", "Strip"]
    ]
    """ Type of element to snap to (default {'KEY', 'Strip'})"""

    snap_playhead_frame_step: int
    """ At which interval to snap to frames (in [1, 32768], default 2)"""

    snap_playhead_second_step: int
    """ At which interval to snap to seconds (in [1, 32768], default 1)"""

    snap_target: Literal[bpy.stub_internal.rna_enums.SnapSourceItems]
    """ Which part to snap onto the target (default 'CLOSEST')"""

    snap_uv_element: set[typing.Literal["INCREMENT", "GRID", "VERTEX"]]
    """ Type of element to snap to (default {'INCREMENT'})"""

    statvis: MeshStatVis | None
    """ (readonly, never None)"""

    transform_pivot_point: typing.Literal[
        "BOUNDING_BOX_CENTER",
        "CURSOR",
        "INDIVIDUAL_ORIGINS",
        "MEDIAN_POINT",
        "ACTIVE_ELEMENT",
    ]
    """ Pivot center for rotation/scaling (default 'MEDIAN_POINT')"""

    use_annotation_project_only_selected: bool
    """ Project the strokes only onto selected objects (default False)"""

    use_annotation_stroke_endpoints: bool
    """ Only use the first and last parts of the stroke for snapping (default False)"""

    use_auto_normalize: bool
    """ Ensure all bone-deforming vertex groups add up to 1.0 while weight painting or assigning to vertices (default False)"""

    use_edge_path_live_unwrap: bool
    """ Changing edge seams recalculates UV unwrap (default False)"""

    use_gpencil_automerge_strokes: bool
    """ Join the last drawn stroke with previous strokes in the active layer by distance (default False)"""

    use_gpencil_draw_additive: bool
    """ When creating new frames, the strokes from the previous/active frame are included as the basis for the new one (default False)"""

    use_gpencil_draw_onback: bool
    """ New strokes are drawn below of all strokes in the layer (default False)"""

    use_gpencil_project_only_selected: bool
    """ Project the strokes only onto selected objects (default False)"""

    use_gpencil_select_mask_point: bool
    """ Only sculpt selected stroke points (default False)"""

    use_gpencil_select_mask_segment: bool
    """ Only sculpt selected stroke points between other strokes (default False)"""

    use_gpencil_select_mask_stroke: bool
    """ Only sculpt selected strokes (default False)"""

    use_gpencil_thumbnail_list: bool
    """ Show compact list of colors instead of thumbnails (default True)"""

    use_gpencil_vertex_select_mask_point: bool
    """ Only paint selected stroke points (default False)"""

    use_gpencil_vertex_select_mask_segment: bool
    """ Only paint selected stroke points between other strokes (default False)"""

    use_gpencil_vertex_select_mask_stroke: bool
    """ Only paint selected strokes (default False)"""

    use_gpencil_weight_data_add: bool
    """ Weight data for new strokes is added according to the current vertex group and weight. If no vertex group selected, weight is not added. (default False)"""

    use_grease_pencil_multi_frame_editing: bool
    """ Enable multi-frame editing (default False)"""

    use_keyframe_cycle_aware: bool
    """ For channels with cyclic extrapolation, keyframe insertion is automatically remapped inside the cycle time range, and keeps ends in sync. Curves newly added to actions with a Manual Frame Range and Cyclic Animation are automatically made cyclic. (default False)"""

    use_keyframe_insert_auto: bool
    """ Automatic keyframe insertion for objects, bones and masks (default True)"""

    use_keyframe_insert_keyingset: bool
    """ Automatic keyframe insertion using active Keying Set only (default False)"""

    use_lock_relative: bool
    """ Display bone-deforming groups as if all locked deform groups were deleted, and the remaining ones were re-normalized (default False)"""

    use_mesh_automerge: bool
    """ Automatically merge vertices moved to the same location (default False)"""

    use_mesh_automerge_and_split: bool
    """ Automatically split edges and faces (default False)"""

    use_multipaint: bool
    """ Paint across the weights of all selected bones, maintaining their relative influence (default False)"""

    use_proportional_action: bool
    """ Proportional editing in action editor (default False)"""

    use_proportional_connected: bool
    """ Proportional Editing using connected geometry only (default False)"""

    use_proportional_edit: bool
    """ Proportional edit mode (default False)"""

    use_proportional_edit_mask: bool
    """ Proportional editing mask mode (default False)"""

    use_proportional_edit_objects: bool
    """ Proportional editing object mode (default False)"""

    use_proportional_fcurve: bool
    """ Proportional editing in F-Curve editor (default False)"""

    use_proportional_projected: bool
    """ Proportional Editing using screen space locations (default False)"""

    use_record_with_nla: bool
    """ Add a new NLA Track + Strip for every loop/pass made over the animation to allow non-destructive tweaking (default False)"""

    use_snap: bool
    """ Snap during transform (default False)"""

    use_snap_align_rotation: bool
    """ Align rotation with the snapping target (default False)"""

    use_snap_anim: bool
    """ Enable snapping when transforming keyframes (default True)"""

    use_snap_backface_culling: bool
    """ Exclude back facing geometry from snapping (default False)"""

    use_snap_driver: bool
    """ Enable snapping when transforming keys in the Driver Editor (default False)"""

    use_snap_driver_absolute: bool
    """ Snap to full values (default False)"""

    use_snap_edit: bool
    """ Snap onto non-active objects in edit mode (edit mode only) (default True)"""

    use_snap_grid_absolute: bool
    """ Absolute grid alignment while translating (based on the pivot center) (default False)"""

    use_snap_node: bool
    """ Snap Node during transform (default False)"""

    use_snap_nonedit: bool
    """ Snap onto objects not in edit mode (edit mode only) (default True)"""

    use_snap_peel_object: bool
    """ Consider objects as whole when finding volume center (default False)"""

    use_snap_playhead: bool
    """ Snap playhead when scrubbing (default False)"""

    use_snap_rotate: bool
    """ Rotate is affected by the snapping settings (default False)"""

    use_snap_scale: bool
    """ Scale is affected by snapping settings (default False)"""

    use_snap_selectable: bool
    """ Snap only onto objects that are selectable (default False)"""

    use_snap_self: bool
    """ Snap onto itself only if enabled (edit mode only) (default True)"""

    use_snap_sequencer: bool
    """ Snap strips during transform (default True)"""

    use_snap_time_absolute: bool
    """ Absolute time alignment when transforming keyframes (default False)"""

    use_snap_to_same_target: bool
    """ Snap only to target that source was initially near ("Face Nearest" only) (default False)"""

    use_snap_translate: bool
    """ Move is affected by snapping settings (default True)"""

    use_snap_uv: bool
    """ Snap UV during transform (default False)"""

    use_transform_correct_face_attributes: bool
    """ Correct data such as UVs and color attributes when transforming (default False)"""

    use_transform_correct_keep_connected: bool
    """ During the Face Attributes correction, merge attributes connected to the same vertex (default False)"""

    use_transform_data_origin: bool
    """ Transform object origins, while leaving the shape in place (default False)"""

    use_transform_pivot_point_align: bool
    """ Only transform object locations, without affecting rotation or scaling (default False)"""

    use_transform_skip_children: bool
    """ Transform the parents, leaving the children in place (default False)"""

    use_uv_custom_region: bool
    """ Custom defined region (default False)"""

    use_uv_select_island: bool
    """ Island selection (default False)"""

    use_uv_select_sync: bool
    """ Keep UV and edit mode mesh selection in sync (default True)"""

    uv_sculpt: UvSculpt | None
    """ (readonly)"""

    uv_sculpt_all_islands: bool
    """ Brush operates on all islands (default False)"""

    uv_sculpt_lock_borders: bool
    """ Disable editing of boundary edges (default False)"""

    uv_select_mode: Literal[bpy.stub_internal.rna_enums.MeshSelectModeUvItems]
    """ UV selection and display mode (default 'VERTEX')"""

    uv_sticky_select_mode: typing.Literal[
        "DISABLED", "SHARED_LOCATION", "SHARED_VERTEX"
    ]
    """ Method for extending UV vertex selection (default 'SHARED_LOCATION')"""

    vertex_group_subset: typing.Literal["ALL", "BONE_DEFORM", "OTHER_DEFORM"]
    """ Filter Vertex groups for Display (default 'ALL')"""

    vertex_group_user: typing.Literal["NONE", "ACTIVE", "ALL"]
    """ Display unweighted vertices (default 'ACTIVE')"""

    vertex_group_weight: float
    """ Weight to assign in vertex groups (in [0, 1], default 1.0)"""

    vertex_paint: VertexPaint | None
    """ (readonly)"""

    weight_paint: VertexPaint | None
    """ (readonly)"""

    workspace_tool_type: typing.Literal["DEFAULT", "FALLBACK"]
    """ Action when dragging in the viewport (default 'FALLBACK')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TrackToConstraint(Constraint, bpy_struct):
    """Aim the constrained object toward the target"""

    head_tail: float
    """ Target along length of bone: Head is 0, Tail is 1 (in [0, 1], default 0.0)"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    track_axis: typing.Literal[
        "TRACK_X",
        "TRACK_Y",
        "TRACK_Z",
        "TRACK_NEGATIVE_X",
        "TRACK_NEGATIVE_Y",
        "TRACK_NEGATIVE_Z",
    ]
    """ Axis that points to the target object (default 'TRACK_X')"""

    up_axis: typing.Literal["UP_X", "UP_Y", "UP_Z"]
    """ Axis that points upward (default 'UP_X')"""

    use_bbone_shape: bool
    """ Follow shape of B-Bone segments when calculating Head/Tail position (default False)"""

    use_target_z: bool
    """ Target's Z axis, not World Z axis, will constrain the Up direction (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TransformCacheConstraint(Constraint, bpy_struct):
    """Look up transformation from an external file"""

    cache_file: CacheFile | None
    object_path: str
    """ Path to the object in the Alembic archive used to lookup the transform matrix (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TransformConstraint(Constraint, bpy_struct):
    """Map transformations of the target to the object"""

    from_max_x: float
    """ Top range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_max_x_rot: float
    """ Top range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_max_x_scale: float
    """ Top range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_max_y: float
    """ Top range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_max_y_rot: float
    """ Top range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_max_y_scale: float
    """ Top range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_max_z: float
    """ Top range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_max_z_rot: float
    """ Top range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_max_z_scale: float
    """ Top range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_min_x: float
    """ Bottom range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_min_x_rot: float
    """ Bottom range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_min_x_scale: float
    """ Bottom range of X axis source motion (in [-inf, inf], default 0.0)"""

    from_min_y: float
    """ Bottom range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_min_y_rot: float
    """ Bottom range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_min_y_scale: float
    """ Bottom range of Y axis source motion (in [-inf, inf], default 0.0)"""

    from_min_z: float
    """ Bottom range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_min_z_rot: float
    """ Bottom range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_min_z_scale: float
    """ Bottom range of Z axis source motion (in [-inf, inf], default 0.0)"""

    from_rotation_mode: Literal[
        bpy.stub_internal.rna_enums.DriverTargetRotationModeItems
    ]
    """ Specify the type of rotation channels to use (default 'AUTO')"""

    map_from: typing.Literal["LOCATION", "ROTATION", "SCALE"]
    """ The transformation type to use from the target (default 'LOCATION')"""

    map_to: typing.Literal["LOCATION", "ROTATION", "SCALE"]
    """ The transformation type to affect on the constrained object (default 'LOCATION')"""

    map_to_x_from: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ The source axis constrained object's X axis uses (default 'X')"""

    map_to_y_from: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ The source axis constrained object's Y axis uses (default 'X')"""

    map_to_z_from: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ The source axis constrained object's Z axis uses (default 'X')"""

    mix_mode: typing.Literal["REPLACE", "ADD"]
    """ Specify how to combine the new location with original (default 'ADD')"""

    mix_mode_rot: typing.Literal["REPLACE", "ADD", "BEFORE", "AFTER"]
    """ Specify how to combine the new rotation with original (default 'ADD')"""

    mix_mode_scale: typing.Literal["REPLACE", "MULTIPLY"]
    """ Specify how to combine the new scale with original (default 'REPLACE')"""

    subtarget: str
    """ Armature bone, mesh or lattice vertex group, ... (default "", never None)"""

    target: Object | None
    """ Target object"""

    to_euler_order: typing.Literal["AUTO", "XYZ", "XZY", "YXZ", "YZX", "ZXY", "ZYX"]
    """ Explicitly specify the output euler rotation order (default 'AUTO')"""

    to_max_x: float
    """ Top range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_x_rot: float
    """ Top range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_x_scale: float
    """ Top range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_y: float
    """ Top range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_y_rot: float
    """ Top range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_y_scale: float
    """ Top range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_z: float
    """ Top range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_z_rot: float
    """ Top range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    to_max_z_scale: float
    """ Top range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_x: float
    """ Bottom range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_x_rot: float
    """ Bottom range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_x_scale: float
    """ Bottom range of X axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_y: float
    """ Bottom range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_y_rot: float
    """ Bottom range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_y_scale: float
    """ Bottom range of Y axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_z: float
    """ Bottom range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_z_rot: float
    """ Bottom range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    to_min_z_scale: float
    """ Bottom range of Z axis destination motion (in [-inf, inf], default 0.0)"""

    use_motion_extrapolate: bool
    """ Extrapolate ranges (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TransformOrientation(bpy_struct):
    matrix: mathutils.Matrix
    """ (multi-dimensional array of 3 * 3 items, in [-inf, inf], default ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)))"""

    name: str
    """ Name of the custom transform orientation (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TransformOrientationSlot(bpy_struct):
    custom_orientation: TransformOrientation | None
    """ (readonly)"""

    type: Literal[bpy.stub_internal.rna_enums.TransformOrientationItems]
    """ Transformation orientation (default 'GLOBAL')"""

    use: bool
    """ Use scene orientation instead of a custom setting (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class TriangulateModifier(Modifier, bpy_struct):
    """Triangulate Mesh"""

    keep_custom_normals: bool
    """ Try to preserve custom normals.
Warning: Depending on chosen triangulation method, shading may not be fully preserved, "Fixed" method usually gives the best result here(default False)"""

    min_vertices: int
    """ Triangulate only polygons with vertex count greater than or equal to this number (in [4, inf], default 4)"""

    ngon_method: Literal[bpy.stub_internal.rna_enums.ModifierTriangulateNgonMethodItems]
    """ Method for splitting the n-gons into triangles (default 'BEAUTY')"""

    quad_method: Literal[bpy.stub_internal.rna_enums.ModifierTriangulateQuadMethodItems]
    """ Method for splitting the quads into triangles (default 'SHORTEST_DIAGONAL')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UDIMTile(bpy_struct):
    """Properties of the UDIM tile"""

    channels: int
    """ Number of channels in the tile pixels buffer (in [0, inf], default 0, readonly)"""

    generated_color: typing.Any
    """ Fill color for the generated image (array of 4 items, in [0, inf], default (0.0, 0.0, 0.0, 0.0))"""

    generated_height: int
    """ Generated image height (in [1, 65536], default 0)"""

    generated_type: Literal[bpy.stub_internal.rna_enums.ImageGeneratedTypeItems]
    """ Generated image type (default 'BLANK')"""

    generated_width: int
    """ Generated image width (in [1, 65536], default 0)"""

    is_generated_tile: bool
    """ Is this image tile generated (default False, readonly)"""

    label: str
    """ Tile label (default "", never None)"""

    number: int
    """ Number of the position that this tile covers (in [-inf, inf], default 0)"""

    size: typing.Any
    """ Width and height of the tile buffer in pixels, zero when image data cannot be loaded (array of 2 items, in [-inf, inf], default (0, 0), readonly)"""

    use_generated_float: bool
    """ Generate floating-point buffer (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UILayout(bpy_struct):
    """User interface layout in a panel or header"""

    activate_init: bool
    """ When true, buttons defined in popups will be activated on first display (use so you can type into a field without having to click on it first) (default False)"""

    active: bool | None
    """ (default False)"""

    active_default: bool | None
    """ When true, an operator button defined after this will be activated when pressing return(use with popup dialogs) (default False)"""

    alert: bool
    """ (default False)"""

    alignment: typing.Literal["EXPAND", "LEFT", "CENTER", "RIGHT"]
    """ (default 'EXPAND')"""

    direction: typing.Literal["HORIZONTAL", "VERTICAL"]
    """ (default 'HORIZONTAL', readonly)"""

    emboss: typing.Literal[
        "NORMAL", "NONE", "PULLDOWN_MENU", "PIE_MENU", "NONE_OR_STATUS"
    ]
    """ (default 'NORMAL')"""

    enabled: bool
    """ When false, this (sub)layout is grayed out (default False)"""

    operator_context: Literal[bpy.stub_internal.rna_enums.OperatorContextItems]
    """ Typically set to 'INVOKE_REGION_WIN', except some cases in `bpy.types.Menu` when it's set to 'EXEC_REGION_WIN'. (default 'INVOKE_DEFAULT')"""

    scale_x: float
    """ Scale factor along the X for items in this (sub)layout (in [0, inf], default 0.0)"""

    scale_y: float
    """ Scale factor along the Y for items in this (sub)layout (in [0, inf], default 0.0)"""

    ui_units_x: float
    """ Fixed size along the X for items in this (sub)layout (in [0, inf], default 0.0)"""

    ui_units_y: float
    """ Fixed size along the Y for items in this (sub)layout (in [0, inf], default 0.0)"""

    use_property_decorate: bool
    """ (default False)"""

    use_property_split: bool
    """ (default False)"""

    def row(
        self,
        *,
        align: bool | None = False,
        heading: str | None = "",
        heading_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> typing_extensions.Self:
        """Sub-layout. Items placed in this sublayout are placed next to each other in a row.

        :param align: Align buttons to each other (optional)
        :param heading: Heading, Label to insert into the layout for this sub-layout (optional, never None)
        :param heading_ctxt: Override automatic translation context of the given heading (optional, never None)
        :param translate: Translate the given heading, when UI translation is enabled (optional)
        :return: Sub-layout to put items in
        """

    def column(
        self,
        *,
        align: bool | None = False,
        heading: str | None = "",
        heading_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> typing_extensions.Self:
        """Sub-layout. Items placed in this sublayout are placed under each other in a column.

        :param align: Align buttons to each other (optional)
        :param heading: Heading, Label to insert into the layout for this sub-layout (optional, never None)
        :param heading_ctxt: Override automatic translation context of the given heading (optional, never None)
        :param translate: Translate the given heading, when UI translation is enabled (optional)
        :return: Sub-layout to put items in
        """

    def panel(
        self, idname: str | None, *, default_closed: bool | None = False
    ) -> tuple[UILayout, UILayout]:
        """Creates a collapsible panel. Whether it is open or closed is stored in the region using the given idname. This can only be used when the panel has the full width of the panel region available to it. So it cant be used in e.g. in a box or columns.

                :param idname: Identifier of the panel (never None)
                :param default_closed: Open by Default, When true, the panel will be open the first time it is shown (optional)
                :return: layout_header, Sub-layout to put items in, `UILayout`

        layout_body, Sub-layout to put items in. Will be none if the panel is collapsed., `UILayout`
        """

    def panel_prop(
        self, data: typing.Any | None, property: str | None
    ) -> tuple[UILayout, UILayout]:
        """Similar to .panel(...) but instead of storing whether it is open or closed in the region, it is stored in the provided boolean property. This should be used when multiple instances of the same panel can exist. For example one for every item in a collection property or list. This can only be used when the panel has the full width of the panel region available to it. So it cant be used in e.g. in a box or columns.

                :param data: Data from which to take the open-state property (never None)
                :param property: Identifier of the boolean property that determines whether the panel is open or closed (never None)
                :return: layout_header, Sub-layout to put items in, `UILayout`

        layout_body, Sub-layout to put items in. Will be none if the panel is collapsed., `UILayout`
        """

    def column_flow(
        self, *, columns: int | None = 0, align: bool | None = False
    ) -> typing_extensions.Self:
        """column_flow

        :param columns: Number of columns, 0 is automatic (in [0, inf], optional)
        :param align: Align buttons to each other (optional)
        :return: Sub-layout to put items in
        """

    def grid_flow(
        self,
        *,
        row_major: bool | None = False,
        columns: int | None = 0,
        even_columns: bool | None = False,
        even_rows: bool | None = False,
        align: bool | None = False,
    ) -> typing_extensions.Self:
        """grid_flow

        :param row_major: Fill row by row, instead of column by column (optional)
        :param columns: Number of columns, positive are absolute fixed numbers, 0 is automatic, negative are automatic multiple numbers along major axis (e.g. -2 will only produce 2, 4, 6 etc. columns for row major layout, and 2, 4, 6 etc. rows for column major layout). (in [-inf, inf], optional)
        :param even_columns: All columns will have the same width (optional)
        :param even_rows: All rows will have the same height (optional)
        :param align: Align buttons to each other (optional)
        :return: Sub-layout to put items in
        """

    def box(self) -> typing_extensions.Self:
        """Sublayout (items placed in this sublayout are placed under each other in a column and are surrounded by a box)

        :return: Sub-layout to put items in
        """

    def split(
        self, *, factor: float | None = 0.0, align: bool | None = False
    ) -> typing_extensions.Self:
        """split

        :param factor: Percentage, Percentage of width to split at (leave unset for automatic calculation) (in [0, 1], optional)
        :param align: Align buttons to each other (optional)
        :return: Sub-layout to put items in
        """

    def menu_pie(self) -> typing_extensions.Self:
        """Sublayout. Items placed in this sublayout are placed in a radial fashion around the menu center).

        :return: Sub-layout to put items in
        """

    @classmethod
    def icon(cls, data: typing.Any | None) -> int:
        """Return the custom icon for this data, use it e.g. to get materials or texture icons.

        :param data: Data from which to take the icon (never None)
        :return: Icon identifier (in [0, inf])
        """

    @classmethod
    def enum_item_name(
        cls, data: typing.Any | None, property: str | None, identifier: str | None
    ) -> str:
        """Return the UI name for this enum item

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param identifier: Identifier of the enum item (never None)
        :return: UI name of the enum item (never None)
        """

    @classmethod
    def enum_item_description(
        cls, data: typing.Any | None, property: str | None, identifier: str | None
    ) -> str:
        """Return the UI description for this enum item

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param identifier: Identifier of the enum item (never None)
        :return: UI description of the enum item (never None)
        """

    @classmethod
    def enum_item_icon(
        cls, data: typing.Any | None, property: str | None, identifier: str | None
    ) -> int:
        """Return the icon for this enum item

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param identifier: Identifier of the enum item (never None)
        :return: Icon identifier (in [0, inf])
        """

    def prop(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        placeholder: str | None = "",
        expand: bool | None = False,
        slider: bool | None = False,
        toggle: int | None = -1,
        icon_only: bool | None = False,
        event: bool | None = False,
        full_event: bool | None = False,
        emboss: bool | None = True,
        index: int | None = -1,
        icon_value: int | None = 0,
        invert_checkbox: bool | None = False,
    ) -> None:
        """Item. Exposes an RNA item and places it into the layout.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param placeholder: Hint describing the expected value when empty (optional)
        :param expand: Expand button to show more detail (optional)
        :param slider: Use slider widget for numeric values (optional)
        :param toggle: Use toggle widget for boolean values, or a checkbox when disabled (the default is -1 which uses toggle only when an icon is displayed) (in [-1, 1], optional)
        :param icon_only: Draw only icons in buttons, no text (optional)
        :param event: Use button to input key events (optional)
        :param full_event: Use button to input full events including modifiers (optional)
        :param emboss: Draw the button itself, not just the icon/text. When false, corresponds to the NONE_OR_STATUS layout emboss type. (optional)
        :param index: The index of this button, when set a single member of an array can be accessed, when set to -1 all array members are used (in [-2, inf], optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        :param invert_checkbox: Draw checkbox value inverted (optional)
        """

    def props_enum(self, data: typing.Any | None, property: str | None) -> None:
        """props_enum

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def prop_menu_enum(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
    ) -> None:
        """prop_menu_enum

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        """

    def prop_with_popover(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_only: bool | None = False,
        panel: str | None = None,
    ) -> None:
        """prop_with_popover

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param icon_only: Draw only icons in tabs, no text (optional)
        :param panel: Identifier of the panel (never None)
        """

    def prop_with_menu(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_only: bool | None = False,
        menu: str | None = None,
    ) -> None:
        """prop_with_menu

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param icon_only: Draw only icons in tabs, no text (optional)
        :param menu: Identifier of the menu (never None)
        """

    def prop_tabs_enum(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        data_highlight: typing.Any | None = None,
        property_highlight: str | None = "",
        icon_only: bool | None = False,
        expand_as: typing.Literal["DEFAULT", "ROW"] | None = "DEFAULT",
    ) -> None:
        """prop_tabs_enum

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param data_highlight: Data from which to take highlight property (optional, never None)
        :param property_highlight: Identifier of highlight property in data (optional, never None)
        :param icon_only: Draw only icons in tabs, no text (optional)
        :param expand_as: (optional)
        """

    def prop_enum(
        self,
        data: typing.Any | None,
        property: str | None,
        value: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
    ) -> None:
        """prop_enum

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param value: Enum property value (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        """

    def prop_search(
        self,
        data: typing.Any | None,
        property: str | None,
        search_data: typing.Any | None,
        search_property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        results_are_suggestions: bool | None = False,
        item_search_property: str | None = "",
    ) -> None:
        """prop_search

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param search_data: Data from which to take collection to search in (never None)
        :param search_property: Identifier of search collection property (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param results_are_suggestions: Accept inputs that do not match any item (optional)
        :param item_search_property: Identifier of the string property in each collections items to use for searching (defaults to the items type name property) (optional, never None)
        """

    def prop_decorator(
        self, data: typing.Any | None, property: str | None, *, index: int | None = -1
    ) -> None:
        """prop_decorator

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param index: The index of this button, when set a single member of an array can be accessed, when set to -1 all array members are used (in [-2, inf], optional)
        """

    def operator(
        self,
        operator: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        emboss: bool | None = True,
        depress: bool | None = False,
        icon_value: int | None = 0,
        search_weight: float | None = 0.0,
    ) -> OperatorProperties:
        """Item. Places a button into the layout to call an Operator.

        :param operator: Identifier of the operator (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param emboss: Draw the button itself, not just the icon/text (optional)
        :param depress: Draw pressed in (optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        :param search_weight: Search Weight, Influences the sorting when using menu-seach (in [-inf, inf], optional)
        :return: Operator properties to fill in
        """

    def operator_menu_hold(
        self,
        operator: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        emboss: bool | None = True,
        depress: bool | None = False,
        icon_value: int | None = 0,
        menu: str | None = None,
    ) -> OperatorProperties:
        """Item. Places a button into the layout to call an Operator.

        :param operator: Identifier of the operator (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param emboss: Draw the button itself, not just the icon/text (optional)
        :param depress: Draw pressed in (optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        :param menu: Identifier of the menu (never None)
        :return: Operator properties to fill in
        """

    def operator_enum(
        self,
        operator: str | None,
        property: str | None,
        *,
        icon_only: bool | None = False,
    ) -> None:
        """operator_enum

        :param operator: Identifier of the operator (never None)
        :param property: Identifier of property in operator (never None)
        :param icon_only: Draw only icons in buttons, no text (optional)
        """

    def operator_menu_enum(
        self,
        operator: str | None,
        property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
    ) -> OperatorProperties:
        """operator_menu_enum

        :param operator: Identifier of the operator (never None)
        :param property: Identifier of property in operator (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :return: Operator properties to fill in
        """

    def label(
        self,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_value: int | None = 0,
    ) -> None:
        """Item. Displays text and/or icon in the layout.

        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        """

    def menu(
        self,
        menu: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_value: int | None = 0,
    ) -> None:
        """menu

        :param menu: Identifier of the menu (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        """

    def menu_contents(self, menu: str | None) -> None:
        """menu_contents

        :param menu: Identifier of the menu (never None)
        """

    def popover(
        self,
        panel: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_value: int | None = 0,
        direction: typing.Literal["VERTICAL", "HORIZONTAL"] | None = "VERTICAL",
    ) -> None:
        """popover

                :param panel: Identifier of the panel (never None)
                :param text: Override automatic text of the item (optional)
                :param text_ctxt: Override automatic translation context of the given text (optional)
                :param translate: Translate the given text, when UI translation is enabled (optional)
                :param icon: Icon, Override automatic icon of the item (optional)
                :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
                :param direction: Popup Direction, The direction in which the popup panel is drawn relative to button position (optional)

        VERTICAL
        Vertical -- Draw popup panel above or below the button.

        HORIZONTAL
        Horizontal -- Draw popup panel to the side of the button.
        """

    def popover_group(
        self,
        space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems] | None,
        region_type: Literal[bpy.stub_internal.rna_enums.RegionTypeItems] | None,
        context: str | None,
        category: str | None,
    ) -> None:
        """popover_group

        :param space_type: Space Type
        :param region_type: Region Type
        :param context: panel type context (never None)
        :param category: panel type category (never None)
        """

    def separator(
        self,
        *,
        factor: float | None = 1.0,
        type: typing.Literal["AUTO", "SPACE", "LINE"] | None = "AUTO",
    ) -> None:
        """Item. Inserts empty space into the layout between items.

                :param factor: Percentage, Percentage of width to space (leave unset for default space) (in [0, inf], optional)
                :param type: Type, The type of the separator (optional)

        AUTO
        Auto -- Best guess at what type of separator is needed..

        SPACE
        Empty space -- Horizontal or Vertical empty space, depending on layout direction..

        LINE
        Line -- Horizontal or Vertical line, depending on layout direction..
        """

    def separator_spacer(self) -> None:
        """Item. Inserts horizontal spacing empty space into the layout between items."""

    def progress(
        self,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        factor: float | None = 0.0,
        type: typing.Literal["BAR", "RING"] | None = "BAR",
    ) -> None:
        """Progress indicator

        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param factor: Factor, Amount of progress from 0.0f to 1.0f (in [0, 1], optional)
        :param type: Type, The type of progress indicator (optional)
        """

    def context_pointer_set(self, name: str | None, data: typing.Any | None) -> None:
        """context_pointer_set

        :param name: Name, Name of entry in the context (never None)
        :param data: Pointer to put in context
        """

    def context_string_set(self, name: str | None, value: str | None) -> None:
        """context_string_set

        :param name: Name, Name of entry in the context (never None)
        :param value: Value, String to put in context (never None)
        """

    def template_header(self) -> None:
        """Inserts common Space header UI (editor type selector)"""

    def template_ID(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        new: str | None = "",
        open: str | None = "",
        unlink: str | None = "",
        filter: typing.Literal["ALL", "AVAILABLE"] | None = "ALL",
        live_icon: bool | None = False,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """template_ID

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param new: Operator identifier to create a new ID block (optional, never None)
        :param open: Operator identifier to open a file for creating a new ID block (optional, never None)
        :param unlink: Operator identifier to unlink the ID block (optional, never None)
        :param filter: Optionally limit the items which can be selected (optional)
        :param live_icon: Show preview instead of fixed icon (optional)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_ID_session_uid(
        self,
        data: typing.Any | None,
        property: str | None,
        id_type: Literal[bpy.stub_internal.rna_enums.IdTypeItems] | None,
    ) -> None:
        """Template ID search menu button for session_uid Int properties

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param id_type:
        """

    def template_ID_preview(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        new: str | None = "",
        open: str | None = "",
        unlink: str | None = "",
        rows: int | None = 0,
        cols: int | None = 0,
        filter: typing.Literal["ALL", "AVAILABLE"] | None = "ALL",
        hide_buttons: bool | None = False,
    ) -> None:
        """template_ID_preview

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param new: Operator identifier to create a new ID block (optional, never None)
        :param open: Operator identifier to open a file for creating a new ID block (optional, never None)
        :param unlink: Operator identifier to unlink the ID block (optional, never None)
        :param rows: Number of thumbnail preview rows to display, (in [0, inf], optional)
        :param cols: Number of thumbnail preview columns to display, (in [0, inf], optional)
        :param filter: Optionally limit the items which can be selected (optional)
        :param hide_buttons: Show only list, no buttons (optional)
        """

    def template_matrix(self, data: typing.Any | None, property: str | None) -> None:
        """Insert a readonly Matrix UI. The UI displays the matrix components - translation, rotation and scale. The property argument must be the identifier of an existing 4x4 float vector property of subtype MATRIX.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_any_ID(
        self,
        data: typing.Any | None,
        property: str | None,
        type_property: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """template_any_ID

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param type_property: Identifier of property in data giving the type of the ID-blocks to use (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_ID_tabs(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        new: str | None = "",
        menu: str | None = "",
        filter: typing.Literal["ALL", "AVAILABLE"] | None = "ALL",
    ) -> None:
        """template_ID_tabs

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param new: Operator identifier to create a new ID block (optional, never None)
        :param menu: Context menu identifier (optional, never None)
        :param filter: Optionally limit the items which can be selected (optional)
        """

    def template_action(
        self,
        id: ID | None,
        *,
        new: str | None = "",
        unlink: str | None = "",
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """template_action

        :param id: The data-block for which to select an Action (never None)
        :param new: Operator identifier to create a new ID block (optional, never None)
        :param unlink: Operator identifier to unlink the ID block (optional, never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_search(
        self,
        data: typing.Any | None,
        property: str | None,
        search_data: typing.Any | None,
        search_property: str | None,
        *,
        new: str | None = "",
        unlink: str | None = "",
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """template_search

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param search_data: Data from which to take collection to search in (never None)
        :param search_property: Identifier of search collection property (never None)
        :param new: Operator identifier to create a new item for the collection (optional, never None)
        :param unlink: Operator identifier to unlink or delete the active item from the collection (optional, never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_search_preview(
        self,
        data: typing.Any | None,
        property: str | None,
        search_data: typing.Any | None,
        search_property: str | None,
        *,
        new: str | None = "",
        unlink: str | None = "",
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        rows: int | None = 0,
        cols: int | None = 0,
    ) -> None:
        """template_search_preview

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param search_data: Data from which to take collection to search in (never None)
        :param search_property: Identifier of search collection property (never None)
        :param new: Operator identifier to create a new item for the collection (optional, never None)
        :param unlink: Operator identifier to unlink or delete the active item from the collection (optional, never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param rows: Number of thumbnail preview rows to display, (in [0, inf], optional)
        :param cols: Number of thumbnail preview columns to display, (in [0, inf], optional)
        """

    def template_path_builder(
        self,
        data: typing.Any | None,
        property: str | None,
        root: ID | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """template_path_builder

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param root: ID-block from which path is evaluated from
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_modifiers(self) -> None:
        """Generates the UI layout for the modifier stack"""

    def template_strip_modifiers(self) -> None:
        """Generates the UI layout for the strip modifier stack"""

    def template_collection_exporters(self) -> None:
        """Generates the UI layout for collection exporters"""

    def template_constraints(self, *, use_bone_constraints: bool | None = True) -> None:
        """Generates the panels for the constraint stack

        :param use_bone_constraints: Add panels for bone constraints instead of object constraints (optional)
        """

    def template_shaderfx(self) -> None:
        """Generates the panels for the shader effect stack"""

    def template_greasepencil_color(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        rows: int | None = 0,
        cols: int | None = 0,
        scale: float | None = 1.0,
        filter: typing.Literal["ALL", "AVAILABLE"] | None = "ALL",
    ) -> None:
        """template_greasepencil_color

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param rows: Number of thumbnail preview rows to display, (in [0, inf], optional)
        :param cols: Number of thumbnail preview columns to display, (in [0, inf], optional)
        :param scale: Scale of the image thumbnails, (in [0.1, 1.5], optional)
        :param filter: Optionally limit the items which can be selected (optional)
        """

    def template_constraint_header(self, data: Constraint | None) -> None:
        """Generates the header for constraint panels

        :param data: Constraint data (never None)
        """

    def template_preview(
        self,
        id: ID | None,
        *,
        show_buttons: bool | None = True,
        parent: ID | None = None,
        slot: TextureSlot | None = None,
        preview_id: str | None = "",
    ) -> None:
        """Item. A preview window for materials, textures, lights or worlds.

        :param id: ID data-block
        :param show_buttons: Show preview buttons? (optional)
        :param parent: ID data-block (optional)
        :param slot: Texture slot (optional)
        :param preview_id: Identifier of this preview widget, if not set the ID type will be used (i.e. all previews of materials without explicit ID will have the same size...). (optional, never None)
        """

    def template_curve_mapping(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        type: typing.Literal["NONE", "VECTOR", "COLOR", "HUE"] | None = "NONE",
        levels: bool | None = False,
        brush: bool | None = False,
        use_negative_slope: bool | None = False,
        show_tone: bool | None = False,
        show_presets: bool | None = False,
    ) -> None:
        """Item. A curve mapping widget used for e.g falloff curves for lights.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param type: Type, Type of curves to display (optional)
        :param levels: Show black/white levels (optional)
        :param brush: Show brush options (optional)
        :param use_negative_slope: Use a negative slope by default (optional)
        :param show_tone: Show tone options (optional)
        :param show_presets: Show preset options (optional)
        """

    def template_curveprofile(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """A profile path editor used for custom profiles

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_color_ramp(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        expand: bool | None = False,
    ) -> None:
        """Item. A color ramp widget.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param expand: Expand button to show more detail (optional)
        """

    def template_icon(
        self, icon_value: int | None, *, scale: float | None = 1.0
    ) -> None:
        """Display a large icon

        :param icon_value: Icon to display, (in [0, inf])
        :param scale: Scale, Scale the icon size (by the button size) (in [1, 100], optional)
        """

    def template_icon_view(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        show_labels: bool | None = False,
        scale: float | None = 6.0,
        scale_popup: float | None = 5.0,
    ) -> None:
        """Enum. Large widget showing Icon previews.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param show_labels: Show enum label in preview buttons (optional)
        :param scale: UI Units, Scale the button icon size (by the button size) (in [1, 100], optional)
        :param scale_popup: Scale, Scale the popup icon size (by the button size) (in [1, 100], optional)
        """

    def template_histogram(self, data: typing.Any | None, property: str | None) -> None:
        """Item. A histogramm widget to analyze imaga data.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_waveform(self, data: typing.Any | None, property: str | None) -> None:
        """Item. A waveform widget to analyze imaga data.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_vectorscope(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Item. A vectorscope widget to analyze imaga data.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_layers(
        self,
        data: typing.Any | None,
        property: str | None,
        used_layers_data: typing.Any | None,
        used_layers_property: str | None,
        active_layer: int | None,
    ) -> None:
        """template_layers

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param used_layers_data: Data from which to take property
        :param used_layers_property: Identifier of property in data (never None)
        :param active_layer: Active Layer, (in [0, inf])
        """

    def template_color_picker(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        value_slider: bool | None = False,
        lock: bool | None = False,
        lock_luminosity: bool | None = False,
        cubic: bool | None = False,
    ) -> None:
        """Item. A color wheel widget to pick colors.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param value_slider: Display the value slider to the right of the color wheel (optional)
        :param lock: Lock the color wheel display to value 1.0 regardless of actual color (optional)
        :param lock_luminosity: Keep the color at its original vector length (optional)
        :param cubic: Cubic saturation for picking values close to white (optional)
        """

    def template_palette(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        color: bool | None = False,
    ) -> None:
        """Item. A palette used to pick colors.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param color: Display the colors as colors or values (optional)
        """

    def template_image_layers(
        self, image: Image | None, image_user: ImageUser | None
    ) -> None:
        """template_image_layers

        :param image:
        :param image_user:
        """

    def template_image(
        self,
        data: typing.Any | None,
        property: str | None,
        image_user: ImageUser | None,
        *,
        compact: bool | None = False,
        multiview: bool | None = False,
    ) -> None:
        """Item(s). User interface for selecting images and their source paths.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param image_user: (never None)
        :param compact: Use more compact layout (optional)
        :param multiview: Expose Multi-View options (optional)
        """

    def template_image_settings(
        self,
        image_settings: ImageFormatSettings | None,
        *,
        color_management: bool | None = False,
    ) -> None:
        """User interface for setting image format options

        :param image_settings: (never None)
        :param color_management: Show color management settings (optional)
        """

    def template_image_stereo_3d(self, stereo_3d_format: Stereo3dFormat | None) -> None:
        """User interface for setting image stereo 3d options

        :param stereo_3d_format: (never None)
        """

    def template_image_views(self, image_settings: ImageFormatSettings | None) -> None:
        """User interface for setting image views output options

        :param image_settings: (never None)
        """

    def template_movieclip(
        self,
        data: typing.Any | None,
        property: str | None,
        *,
        compact: bool | None = False,
    ) -> None:
        """Item(s). User interface for selecting movie clips and their source paths.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param compact: Use more compact layout (optional)
        """

    def template_track(self, data: typing.Any | None, property: str | None) -> None:
        """Item. A movie-track widget to preview tracking image.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_marker(
        self,
        data: typing.Any | None,
        property: str | None,
        clip_user: MovieClipUser | None,
        track: MovieTrackingTrack | None,
        *,
        compact: bool | None = False,
    ) -> None:
        """Item. A widget to control single marker settings.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param clip_user: (never None)
        :param track: (never None)
        :param compact: Use more compact layout (optional)
        """

    def template_movieclip_information(
        self,
        data: typing.Any | None,
        property: str | None,
        clip_user: MovieClipUser | None,
    ) -> None:
        """Item. Movie clip information data.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        :param clip_user: (never None)
        """

    def template_list(
        self,
        listtype_name: str | None,
        list_id: str | None,
        dataptr: typing.Any | None,
        propname: str | None,
        active_dataptr: typing.Any | None,
        active_propname: str | None,
        *,
        item_dyntip_propname: str | None = "",
        rows: int | None = 5,
        maxrows: int | None = 5,
        type: Literal[bpy.stub_internal.rna_enums.UilistLayoutTypeItems]
        | None = "DEFAULT",
        columns: int | None = 9,
        sort_reverse: bool | None = False,
        sort_lock: bool | None = False,
    ) -> None:
        """Item. A list widget to display data, e.g. vertexgroups.

        :param listtype_name: Identifier of the list type to use (never None)
        :param list_id: Identifier of this list widget. Necessary to tell apart different list widgets. Mandatory when using default "UI_UL_list" class. If this not an empty string, the uilist gets a custom ID, otherwise it takes the name of the class used to define the uilist (for example, if the class name is "OBJECT_UL_vgroups", and list_id is not set by the script, then bl_idname = "OBJECT_UL_vgroups") (never None)
        :param dataptr: Data from which to take the Collection property
        :param propname: Identifier of the Collection property in data (never None)
        :param active_dataptr: Data from which to take the integer property, index of the active item (never None)
        :param active_propname: Identifier of the integer property in active_data, index of the active item (never None)
        :param item_dyntip_propname: Identifier of a string property in items, to use as tooltip content (optional, never None)
        :param rows: Default and minimum number of rows to display (in [0, inf], optional)
        :param maxrows: Default maximum number of rows to display (in [0, inf], optional)
        :param type: Type, Type of layout to use (optional)
        :param columns: Number of items to display per row, for GRID layout (in [0, inf], optional)
        :param sort_reverse: Display items in reverse order by default (optional)
        :param sort_lock: Lock display order to default value (optional)
        """

    def template_running_jobs(self) -> None:
        """template_running_jobs"""

    def template_operator_search(self) -> None:
        """template_operator_search"""

    def template_menu_search(self) -> None:
        """template_menu_search"""

    def template_header_3D_mode(self) -> None: ...
    def template_edit_mode_selection(self) -> None:
        """Inserts common 3DView Edit modes header UI (selector for selection mode)"""

    def template_reports_banner(self) -> None:
        """template_reports_banner"""

    def template_input_status(self) -> None:
        """template_input_status"""

    def template_status_info(self) -> None:
        """template_status_info"""

    def template_node_link(
        self, ntree: NodeTree | None, node: Node | None, socket: NodeSocket | None
    ) -> None:
        """template_node_link

        :param ntree:
        :param node:
        :param socket:
        """

    def template_node_view(
        self, ntree: NodeTree | None, node: Node | None, socket: NodeSocket | None
    ) -> None:
        """template_node_view

        :param ntree:
        :param node:
        :param socket:
        """

    def template_node_operator_registration_errors(
        self, *, idname: str | None = ""
    ) -> None:
        """template_node_operator_registration_errors

        :param idname: (optional, never None)
        """

    def template_node_asset_menu_items(
        self,
        *,
        catalog_path: str | None = "",
        operator: typing.Literal["ADD", "SWAP"] | None = "ADD",
    ) -> None:
        """template_node_asset_menu_items

                :param catalog_path: (optional, never None)
                :param operator: Operator, The operator the asset menu will use (optional)

        ADD
        Add Node -- Add a node to the active tree..

        SWAP
        Swap Node -- Replace the selected nodes with the specified type..
        """

    def template_modifier_asset_menu_items(
        self, *, catalog_path: str | None = "", skip_essentials: bool | None = False
    ) -> None:
        """template_modifier_asset_menu_items

        :param catalog_path: (optional, never None)
        :param skip_essentials: (optional)
        """

    def template_node_operator_asset_menu_items(
        self, *, catalog_path: str | None = ""
    ) -> None:
        """template_node_operator_asset_menu_items

        :param catalog_path: (optional, never None)
        """

    def template_node_operator_asset_root_items(self) -> None:
        """template_node_operator_asset_root_items"""

    def template_texture_user(self) -> None:
        """template_texture_user"""

    def template_keymap_item_properties(self, item: KeyMapItem | None) -> None:
        """template_keymap_item_properties

        :param item: (never None)
        """

    def template_component_menu(
        self, data: typing.Any | None, property: str | None, *, name: str | None = ""
    ) -> None:
        """Item. Display expanded property in a popup menu

        :param data: Data from which to take property
        :param property: Identifier of property in data (never None)
        :param name: (optional, never None)
        """

    def template_colorspace_settings(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Item. A widget to control input color space settings.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_colormanaged_view_settings(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Item. A widget to control color managed view settings.

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_node_socket(
        self, *, color: collections.abc.Sequence[float] | None = (0.0, 0.0, 0.0, 1.0)
    ) -> None:
        """Node Socket Icon

        :param color: Color, (array of 4 items, in [0, 1], optional)
        """

    def template_cache_file(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Item(s). User interface for selecting cache files and their source paths

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_cache_file_velocity(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Show cache files velocity properties

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_cache_file_time_settings(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Show cache files time settings

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_cache_file_layers(
        self, data: typing.Any | None, property: str | None
    ) -> None:
        """Show cache files override layers properties

        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_recent_files(self, *, rows: int | None = 6) -> int:
        """Show list of recently saved .blend files

        :param rows: Maximum number of items to show (in [1, inf], optional)
        :return: Number of items drawn (in [0, inf])
        """

    def template_file_select_path(self, params: FileSelectParams | None) -> None:
        """Item. A text button to set the active file browser path.

        :param params:
        """

    def template_event_from_keymap_item(
        self,
        item: KeyMapItem | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> None:
        """Display keymap item as icons/text

        :param item: Item, (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        """

    def template_light_linking_collection(
        self,
        context_layout: typing_extensions.Self | None,
        data: typing.Any | None,
        property: str | None,
    ) -> None:
        """Visualization of a content of a light linking collection

        :param context_layout: Layout to set active list element as context properties (never None)
        :param data: Data from which to take property (never None)
        :param property: Identifier of property in data (never None)
        """

    def template_bone_collection_tree(self) -> None:
        """Show bone collections tree"""

    def template_grease_pencil_layer_tree(self) -> None:
        """View of the active Grease Pencil layer tree"""

    def template_node_tree_interface(self, interface: NodeTreeInterface | None) -> None:
        """Show a node tree interface

        :param interface: Node Tree Interface, Interface of a node tree to display (never None)
        """

    def template_node_inputs(self, node: Node | None) -> None:
        """Show a node settings and input socket values

        :param node: Node, Display inputs of this node (never None)
        """

    def template_asset_shelf_popover(
        self,
        asset_shelf: str | None,
        *,
        name: str | None = "",
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        icon_value: int | None = 0,
    ) -> None:
        """Create a button to open an asset shelf in a popover

        :param asset_shelf: Identifier of the asset shelf to display (bl_idname) (never None)
        :param name: Optional name to indicate the active asset (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param icon_value: Icon Value, Override automatic icon of the item (in [0, inf], optional)
        """

    def template_popup_confirm(
        self,
        operator: str | None,
        *,
        text: str | None = "",
        text_ctxt: str | None = "",
        translate: bool | None = True,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        cancel_text: str | None = "",
        cancel_default: bool | None = False,
    ) -> OperatorProperties:
        """Add confirm & cancel buttons into a popup which will close the popup when pressed

        :param operator: Identifier of the operator (never None)
        :param text: Override automatic text of the item (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :param icon: Icon, Override automatic icon of the item (optional)
        :param cancel_text: Optional text to use for the cancel, not shown when an empty string (optional, never None)
        :param cancel_default: Cancel button by default (optional)
        :return: Operator properties to fill in
        """

    def template_shape_key_tree(self) -> None:
        """Shape Key tree view"""

    @classmethod
    def bl_rna_get_subclass(
        cls, id: str | None, /, *, default: None | Struct | None = None
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls, id: str | None, /, *, default: None | typing.Any | None = None
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    def introspect(self) -> list[dict[str, typing.Any]]:
        """Return a list of dictionaries containing a textual representation of the UI layout.

        :return:
        """

class UIList(bpy_struct):
    """UI list containing the elements of a collection"""

    bitflag_filter_item: int
    """ The value of the reserved bitflag 'FILTER_ITEM' (in filter_flags values) (in [0, inf], default 0, readonly)"""

    bitflag_item_never_show: int
    """ Skip the item from displaying in the list (in [0, inf], default 0, readonly)"""

    bl_idname: str
    """ If this is set, the uilist gets a custom ID, otherwise it takes the name of the class used to define the uilist (for example, if the class name is "OBJECT_UL_vgroups", and bl_idname is not set by the script, then bl_idname = "OBJECT_UL_vgroups") (default "", never None)"""

    filter_name: str
    """ Only show items matching this name (use '*' as wildcard) (default "", never None)"""

    layout_type: Literal[bpy.stub_internal.rna_enums.UilistLayoutTypeItems]
    """ (default 'DEFAULT', readonly)"""

    list_id: str
    """ Identifier of the list, if any was passed to the "list_id" parameter of "template_list()" (default "", readonly, never None)"""

    use_filter_invert: bool
    """ Invert filtering (show hidden items, and vice versa) (default False)"""

    use_filter_show: bool
    """ Show filtering options (default False)"""

    use_filter_sort_alpha: bool
    """ Sort items by their name (default False)"""

    use_filter_sort_lock: bool
    """ Lock the order of shown items (user cannot change it) (default False)"""

    use_filter_sort_reverse: bool
    """ Reverse the order of shown items (default False)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    def draw_item(
        self,
        context: Context,
        layout: UILayout | None,
        data: typing.Any | None,
        item: typing.Any | None,
        icon: int | None,
        active_data: typing.Any | None,
        active_property: str | None,
        index: int | None,
        flt_flag: int | None,
    ) -> None:
        """Draw an item in the list (NOTE: when you define your own draw_item function, you may want to check given item is of the right type...)

        :param context:
        :param layout: Layout to draw the item (never None)
        :param data: Data from which to take Collection property
        :param item: Item of the collection property
        :param icon: Icon of the item in the collection (in [0, inf])
        :param active_data: Data from which to take property for the active element (never None)
        :param active_property: Identifier of property in active_data, for the active element (optional for registration, never None)
        :param index: Index of the item in the collection (in [0, inf])
        :param flt_flag: The filter-flag result for this item (in [0, inf])
        """

    def draw_filter(self, context: Context, layout: UILayout | None) -> None:
        """Draw filtering options

        :param context:
        :param layout: Layout to draw the item (never None)
        """

    def filter_items(
        self, context: Context, data: typing.Any | None, property: str | None
    ) -> tuple:
        """Filter and/or re-order items of the collection (output filter results in filter_flags, and reorder results in filter_neworder arrays)

                :param context:
                :param data: Data from which to take Collection property
                :param property: Identifier of property in data, for the collection (never None)
                :return: filter_flags, An array of filter flags, one for each item in the collection (NOTE: The upper 16 bits, including FILTER_ITEM, are reserved, only use the lower 16 bits for custom usages), `bpy_prop_array`[int]

        filter_neworder, An array of indices, one for each item in the collection, mapping the org index to the new one, `bpy_prop_array`[int]
        """

    @classmethod
    def append(cls, draw_func) -> None:
        """Append a draw function to this menu,
        takes the same arguments as the menus draw function

                :param draw_func:
        """

    @classmethod
    def is_extended(cls) -> None: ...
    @classmethod
    def prepend(cls, draw_func) -> None:
        """Prepend a draw function to this menu, takes the same arguments as
        the menus draw function

                :param draw_func:
        """

    @classmethod
    def remove(cls, draw_func) -> None:
        """Remove a draw function that has been added to this menu.

        :param draw_func:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UIPieMenu(bpy_struct):
    layout: UILayout | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UIPopover(bpy_struct):
    layout: UILayout | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UIPopupMenu(bpy_struct):
    layout: UILayout | None
    """ (readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UI_UL_list(UIList, bpy_struct):
    @staticmethod
    def filter_items_by_name(
        pattern, bitflag, items, propname="name", flags=None, reverse=False
    ) -> None:
        """Set FILTER_ITEM for items which name matches filter_name one (case-insensitive).
        pattern is the filtering pattern.
        propname is the name of the string property to use for filtering.
        flags must be a list of integers the same length as items, or None!
        return a list of flags (based on given flags if not None),
        or an empty list if no flags were given and no filtering has been done.

                :param pattern:
                :param bitflag:
                :param items:
                :param propname:
                :param flags:
                :param reverse:
        """

    @classmethod
    def sort_items_by_name(cls, items, propname="name") -> None:
        """Re-order items using their names (case-insensitive).
        propname is the name of the string property to use for sorting.
        return a list mapping org_idx -> new_idx,
        or an empty list if no sorting has been done.

                :param items:
                :param propname:
        """

    @staticmethod
    def sort_items_helper(sort_data, key, reverse=False) -> None:
        """Common sorting utility. Returns a neworder list mapping org_idx -> new_idx.
        sort_data must be an (unordered) list of tuples [(org_idx, ...), (org_idx, ...), ...].
        key must be the same kind of callable you would use for sorted() builtin function.
        reverse will reverse the sorting!

                :param sort_data:
                :param key:
                :param reverse:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class USDHook(bpy_struct):
    """Defines callback functions to extend USD IO"""

    bl_description: str
    """ A short description of the USD hook (default "", never None)"""

    bl_idname: str
    """ (default "", never None)"""

    bl_label: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class USERPREF_UL_asset_libraries(UIList, bpy_struct):
    def draw_item(
        self,
        context,
        layout,
        _data,
        item,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param context:
        :param layout:
        :param _data:
        :param item:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, context, data, property) -> None:
        """

        :param context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class USERPREF_UL_extension_repos(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        item,
        icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, propname) -> None:
        """

        :param _context:
        :param data:
        :param propname:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UVProjectModifier(Modifier, bpy_struct):
    """UV projection modifier to set UVs from a projector"""

    aspect_x: float
    """ Horizontal aspect ratio (only used for camera projectors) (in [1, inf], default 1.0)"""

    aspect_y: float
    """ Vertical aspect ratio (only used for camera projectors) (in [1, inf], default 1.0)"""

    projector_count: int
    """ Number of projectors to use (in [1, 10], default 1)"""

    projectors: typing.Any
    """ (default None, readonly)"""

    scale_x: float
    """ Horizontal scale (only used for camera projectors) (in [0, inf], default 1.0)"""

    scale_y: float
    """ Vertical scale (only used for camera projectors) (in [0, inf], default 1.0)"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UVProjector(bpy_struct):
    """UV projector used by the UV project modifier"""

    object: Object | None
    """ Object to use as projector transform"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UVWarpModifier(Modifier, bpy_struct):
    """Add target position to UV coordinates"""

    axis_u: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Pole axis for rotation (default 'X')"""

    axis_v: Literal[bpy.stub_internal.rna_enums.AxisXyzItems]
    """ Pole axis for rotation (default 'Y')"""

    bone_from: str
    """ Bone defining offset (default "", never None)"""

    bone_to: str
    """ Bone defining offset (default "", never None)"""

    center: typing.Any
    """ Center point for rotate/scale (array of 2 items, in [-inf, inf], default (0.5, 0.5))"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object_from: Object | None
    """ Object defining offset"""

    object_to: Object | None
    """ Object defining offset"""

    offset: typing.Any
    """ 2D Offset for the warp (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    rotation: float
    """ 2D Rotation for the warp (in [-inf, inf], default 0.0)"""

    scale: typing.Any
    """ 2D Scale for the warp (array of 2 items, in [-inf, inf], default (1.0, 1.0))"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UnifiedPaintSettings(bpy_struct):
    """Overrides for some of the active brushs settings"""

    color: mathutils.Color
    """ (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    hue_jitter: float
    """ Color jitter effect on hue (in [0, 1], default 0.0)"""

    input_samples: int
    """ Number of input samples to average together to smooth the brush stroke (in [1, 64], default 1)"""

    saturation_jitter: float
    """ Color jitter effect on saturation (in [0, 1], default 0.0)"""

    secondary_color: mathutils.Color
    """ (array of 3 items, in [0, 1], default (1.0, 1.0, 1.0))"""

    size: int
    """ Diameter of the brush (in [1, 10000], default 100)"""

    strength: float
    """ How powerful the effect of the brush is when applied (in [0, 10], default 0.5)"""

    unprojected_size: float
    """ Diameter of brush in Blender units (in [0.001, inf], default 0.58)"""

    use_color_jitter: bool
    """ Jitter brush color (default False)"""

    use_locked_size: typing.Literal["VIEW", "SCENE"]
    """ Measure brush size relative to the view or the scene (default 'VIEW')"""

    use_random_press_hue: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_sat: bool
    """ Use pressure to modulate randomness (default False)"""

    use_random_press_val: bool
    """ Use pressure to modulate randomness (default False)"""

    use_stroke_random_hue: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_sat: bool
    """ Use randomness at stroke level (default False)"""

    use_stroke_random_val: bool
    """ Use randomness at stroke level (default False)"""

    use_unified_color: bool
    """ Instead of per-brush color, the color is shared across brushes (default True)"""

    use_unified_input_samples: bool
    """ Instead of per-brush input samples, the value is shared across brushes (default False)"""

    use_unified_size: bool
    """ Instead of per-brush size, the size is shared across brushes (default True)"""

    use_unified_strength: bool
    """ Instead of per-brush strength, the strength is shared across brushes (default False)"""

    use_unified_weight: bool
    """ Instead of per-brush weight, the weight is shared across brushes (default False)"""

    value_jitter: float
    """ Color jitter effect on value (in [0, 1], default 0.0)"""

    weight: float
    """ Weight to assign in vertex groups (in [0, 1], default 0.5)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UnitSettings(bpy_struct):
    length_unit: typing.Literal["DEFAULT"]
    """ Unit that will be used to display length values (default 'DEFAULT')"""

    mass_unit: typing.Literal["DEFAULT"]
    """ Unit that will be used to display mass values (default 'DEFAULT')"""

    scale_length: float
    """ Scale to use when converting between Blender units and dimensions. When working at microscopic or astronomical scale, a small or large unit scale respectively can be used to avoid numerical precision problems (in [1e-09, inf], default 0.0)"""

    system: typing.Literal["NONE", "METRIC", "IMPERIAL"]
    """ The unit system to use for user interface controls (default 'NONE')"""

    system_rotation: typing.Literal["DEGREES", "RADIANS"]
    """ Unit to use for displaying/editing rotation values (default 'DEGREES')"""

    temperature_unit: typing.Literal["DEFAULT"]
    """ Unit that will be used to display temperature values (default 'DEFAULT')"""

    time_unit: typing.Literal["DEFAULT"]
    """ Unit that will be used to display time values (default 'DEFAULT')"""

    use_separate: bool
    """ Display units in pairs (e.g. 1m 0cm) (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UnknownType(bpy_struct):
    """Stub RNA type used for pointers to unknown or internal data"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UserAssetLibrary(bpy_struct):
    """Settings to define a reusable library for Asset Browsers to use"""

    enabled: bool
    """ Enable the asset library (default True)"""

    import_method: typing.Literal["LINK", "APPEND", "APPEND_REUSE", "PACK"]
    """ Determine how the asset will be imported, unless overridden by the Asset Browser (default 'PACK')"""

    name: str
    """ Identifier (not necessarily unique) for the asset library (default "", never None)"""

    path: str
    """ Path to a directory with .blend files to use as an asset library (default "", never None)"""

    remote_url: str
    """ Remote URL to the asset library (default "", never None)"""

    use_relative_path: bool
    """ Use relative path when linking assets from this asset library (default True)"""

    use_remote_url: bool
    """ Synchronize the asset library with a remote URL (default False, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UserExtensionRepo(bpy_struct):
    """Settings to define an extension repository"""

    access_token: str
    """ Personal access token, may be required by some repositories (default "", never None)"""

    custom_directory: str
    """ The local directory containing extensions (default "", never None)"""

    directory: str
    """ The local directory containing extensions (default "", readonly, never None)"""

    enabled: bool
    """ Enable the repository (default False)"""

    module: str
    """ Unique module identifier (default "", never None)"""

    name: str
    """ Unique repository name (default "", never None)"""

    remote_url: str
    """ Remote URL to the extension repository, the file-system may be referenced using the file URI scheme: "file://" (default "", never None)"""

    source: typing.Literal["USER", "SYSTEM"]
    """ Select if the repository is in a user managed or system provided directory (default 'USER')"""

    use_access_token: bool
    """ Repository requires an access token (default False)"""

    use_cache: bool
    """ Downloaded package files are deleted after installation (default False)"""

    use_custom_directory: bool
    """ Manually set the path for extensions to be stored. When disabled a user's extensions directory is created. (default False)"""

    use_remote_url: bool
    """ Synchronize the repository with a remote URL (default False)"""

    use_sync_on_startup: bool
    """ Allow Blender to check for updates upon launch (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UserSolidLight(bpy_struct):
    """Light used for Studio lighting in solid shading mode"""

    diffuse_color: mathutils.Color
    """ Color of the light's diffuse highlight (array of 3 items, in [0, inf], default (0.8, 0.8, 0.8))"""

    direction: mathutils.Vector
    """ Direction that the light is shining (array of 3 items, in [-inf, inf], default (0.0, 0.0, 1.0))"""

    smooth: float
    """ Smooth the lighting from this light (in [0, 1], default 0.5)"""

    specular_color: mathutils.Color
    """ Color of the light's specular highlight (array of 3 items, in [0, inf], default (0.8, 0.8, 0.8))"""

    use: bool
    """ Enable this light in solid shading mode (default True)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class UvSculpt(bpy_struct):
    curve_distance_falloff: CurveMapping | None
    """ (readonly)"""

    curve_distance_falloff_preset: Literal[
        bpy.stub_internal.rna_enums.BrushCurvePresetItems
    ]
    """ (default 'CUSTOM')"""

    size: int
    """ (in [1, 10000], default 100)"""

    strength: float
    """ (in [0, 1], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_gpencil_paint(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_gpencil_sculpt(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_gpencil_vertex(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_gpencil_weight(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_sculpt(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_sculpt_curves(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_texture_paint(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_vertex_paint(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_brush_weight_paint(AssetShelf, bpy_struct):
    @classmethod
    def brush_type_poll(cls, context, asset) -> None:
        """

        :param context:
        :param asset:
        """

    @staticmethod
    def draw_popup_selector(layout, context, brush, show_name=True) -> None:
        """

        :param layout:
        :param context:
        :param brush:
        :param show_name:
        """

    @staticmethod
    def get_shelf_name_from_context(context) -> None:
        """

        :param context:
        """

    @classmethod
    def has_tool_with_brush_type(cls, context, brush_type) -> None:
        """

        :param context:
        :param brush_type:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_AST_pose_library(AssetShelf, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_FH_camera_background_image(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_FH_empty_image(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEW3D_FH_vdb_volume(FileHandler, bpy_struct):
    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEWLAYER_UL_aov(UIList, bpy_struct):
    @staticmethod
    def aov_icon(item) -> None:
        """

        :param item:
        """

    def draw_item(
        self, _context, layout, _data, item, icon, _active_data, _active_propname
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VIEWLAYER_UL_linesets(UIList, bpy_struct):
    def draw_item(
        self, _context, layout, _data, item, icon, _active_data, _active_propname, index
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param item:
        :param icon:
        :param _active_data:
        :param _active_propname:
        :param index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VOLUME_UL_grids(UIList, bpy_struct):
    def draw_item(
        self,
        _context,
        layout,
        _data,
        grid,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param _context:
        :param layout:
        :param _data:
        :param grid:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VectorFont(ID, bpy_struct):
    """Vector font for Text objects"""

    filepath: str
    """ (default "", never None, blend relative // prefix supported)"""

    packed_file: PackedFile | None
    """ (readonly)"""

    def pack(self) -> None:
        """Pack the font into the current blend file"""

    def unpack(
        self,
        *,
        method: Literal[bpy.stub_internal.rna_enums.UnpackMethodItems]
        | None = "USE_LOCAL",
    ) -> None:
        """Unpack the font to the samples filename

        :param method: method, How to unpack (optional)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexGroup(bpy_struct):
    """Group of vertices, used for armature deform and other purposes"""

    index: int
    """ Index number of the vertex group (in [0, inf], default 0, readonly)"""

    lock_weight: bool
    """ Maintain the relative weights for the group (default False)"""

    name: str
    """ Vertex group name (default "", never None)"""

    def add(
        self,
        index: collections.abc.Sequence[int] | None,
        weight: float | None,
        type: typing.Literal["REPLACE", "ADD", "SUBTRACT"] | None,
    ) -> None:
        """Add vertices to the group

                :param index: List of indices (array of 1 items, in [-inf, inf])
                :param weight: Vertex weight (in [0, 1])
                :param type: Vertex assign mode

        REPLACE
        Replace -- Replace.

        ADD
        Add -- Add.

        SUBTRACT
        Subtract -- Subtract.
        """

    def remove(self, index: collections.abc.Sequence[int] | None) -> None:
        """Remove vertices from the group

        :param index: List of indices (array of 1 items, in [-inf, inf])
        """

    def weight(self, index: int | None) -> float:
        """Get a vertex weight from the group

        :param index: Index, The index of the vertex (in [0, inf])
        :return: Vertex weight (in [0, 1])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexGroupElement(bpy_struct):
    """Weight value of a vertex in a vertex group"""

    group: int
    """ (in [0, inf], default 0, readonly)"""

    weight: float
    """ Vertex Weight (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexPaint(Paint, bpy_struct):
    """Properties of vertex and weight paint mode"""

    use_group_restrict: bool
    """ Restrict painting to vertices in the group (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexWeightEditModifier(Modifier, bpy_struct):
    """Edit the weights of vertices in a group"""

    add_threshold: float
    """ Lower (inclusive) bound for a vertex's weight to be added to the vgroup (in [-1000, 1000], default 0.01)"""

    default_weight: float
    """ Default weight a vertex will have if it is not in the vgroup (in [0, 1], default 0.0)"""

    falloff_type: typing.Literal[
        "LINEAR",
        "CURVE",
        "SHARP",
        "SMOOTH",
        "ROOT",
        "ICON_SPHERECURVE",
        "RANDOM",
        "STEP",
    ]
    """ How weights are mapped to their new values (default 'LINEAR')"""

    invert_falloff: bool
    """ Invert the resulting falloff weight (default False)"""

    invert_mask_vertex_group: bool
    """ Invert vertex group mask influence (default False)"""

    map_curve: CurveMapping | None
    """ Custom mapping curve (readonly)"""

    mask_constant: float
    """ Global influence of current modifications on vgroup (in [-inf, inf], default 1.0)"""

    mask_tex_map_bone: str
    """ Which bone to take texture coordinates from (default "", never None)"""

    mask_tex_map_object: Object | None
    """ Which object to take texture coordinates from"""

    mask_tex_mapping: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ Which texture coordinates to use for mapping (default 'LOCAL')"""

    mask_tex_use_channel: typing.Literal[
        "INT", "RED", "GREEN", "BLUE", "HUE", "SAT", "VAL", "ALPHA"
    ]
    """ Which texture channel to use for masking (default 'INT')"""

    mask_tex_uv_layer: str
    """ UV map name (default "", never None)"""

    mask_texture: Texture | None
    """ Masking texture"""

    mask_vertex_group: str
    """ Masking vertex group name (default "", never None)"""

    normalize: bool
    """ Normalize the resulting weights (otherwise they are only clamped within 0.0 to 1.0 range) (default False)"""

    remove_threshold: float
    """ Upper (inclusive) bound for a vertex's weight to be removed from the vgroup (in [-1000, 1000], default 0.01)"""

    use_add: bool
    """ Add vertices with weight over threshold to vgroup (default False)"""

    use_remove: bool
    """ Remove vertices with weight below threshold from vgroup (default False)"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexWeightMixModifier(Modifier, bpy_struct):
    """Mix the weights of two vertex groups"""

    default_weight_a: float
    """ Default weight a vertex will have if it is not in the first A vgroup (in [0, 1], default 0.0)"""

    default_weight_b: float
    """ Default weight a vertex will have if it is not in the second B vgroup (in [0, 1], default 0.0)"""

    invert_mask_vertex_group: bool
    """ Invert vertex group mask influence (default False)"""

    invert_vertex_group_a: bool
    """ Invert the influence of vertex group A (default False)"""

    invert_vertex_group_b: bool
    """ Invert the influence of vertex group B (default False)"""

    mask_constant: float
    """ Global influence of current modifications on vgroup (in [-inf, inf], default 1.0)"""

    mask_tex_map_bone: str
    """ Which bone to take texture coordinates from (default "", never None)"""

    mask_tex_map_object: Object | None
    """ Which object to take texture coordinates from"""

    mask_tex_mapping: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ Which texture coordinates to use for mapping (default 'LOCAL')"""

    mask_tex_use_channel: typing.Literal[
        "INT", "RED", "GREEN", "BLUE", "HUE", "SAT", "VAL", "ALPHA"
    ]
    """ Which texture channel to use for masking (default 'INT')"""

    mask_tex_uv_layer: str
    """ UV map name (default "", never None)"""

    mask_texture: Texture | None
    """ Masking texture"""

    mask_vertex_group: str
    """ Masking vertex group name (default "", never None)"""

    mix_mode: typing.Literal[
        "SET", "ADD", "SUB", "MUL", "DIV", "DIF", "AVG", "MIN", "MAX"
    ]
    """ How weights from vgroup B affect weights of vgroup A (default 'SET')"""

    mix_set: typing.Literal["ALL", "A", "B", "OR", "AND"]
    """ Which vertices should be affected (default 'AND')"""

    normalize: bool
    """ Normalize the resulting weights (otherwise they are only clamped within 0.0 to 1.0 range) (default False)"""

    vertex_group_a: str
    """ First vertex group name (default "", never None)"""

    vertex_group_b: str
    """ Second vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VertexWeightProximityModifier(Modifier, bpy_struct):
    """Set the weights of vertices in a group from a target objects distance"""

    falloff_type: typing.Literal[
        "LINEAR",
        "CURVE",
        "SHARP",
        "SMOOTH",
        "ROOT",
        "ICON_SPHERECURVE",
        "RANDOM",
        "STEP",
    ]
    """ How weights are mapped to their new values (default 'LINEAR')"""

    invert_falloff: bool
    """ Invert the resulting falloff weight (default False)"""

    invert_mask_vertex_group: bool
    """ Invert vertex group mask influence (default False)"""

    map_curve: CurveMapping | None
    """ Custom mapping curve (readonly)"""

    mask_constant: float
    """ Global influence of current modifications on vgroup (in [-inf, inf], default 1.0)"""

    mask_tex_map_bone: str
    """ Which bone to take texture coordinates from (default "", never None)"""

    mask_tex_map_object: Object | None
    """ Which object to take texture coordinates from"""

    mask_tex_mapping: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ Which texture coordinates to use for mapping (default 'LOCAL')"""

    mask_tex_use_channel: typing.Literal[
        "INT", "RED", "GREEN", "BLUE", "HUE", "SAT", "VAL", "ALPHA"
    ]
    """ Which texture channel to use for masking (default 'INT')"""

    mask_tex_uv_layer: str
    """ UV map name (default "", never None)"""

    mask_texture: Texture | None
    """ Masking texture"""

    mask_vertex_group: str
    """ Masking vertex group name (default "", never None)"""

    max_dist: float
    """ Distance mapping to weight 1.0 (in [0, inf], default 1.0)"""

    min_dist: float
    """ Distance mapping to weight 0.0 (in [0, inf], default 0.0)"""

    normalize: bool
    """ Normalize the resulting weights (otherwise they are only clamped within 0.0 to 1.0 range) (default False)"""

    proximity_geometry: set[typing.Literal["VERTEX", "EDGE", "FACE"]]
    """ Use the shortest computed distance to target object's geometry as weight (default {'FACE'})"""

    proximity_mode: typing.Literal["OBJECT", "GEOMETRY"]
    """ Which distances to target object to use (default 'GEOMETRY')"""

    target: Object | None
    """ Object to calculate vertices distances from"""

    vertex_group: str
    """ Vertex group name (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class View2D(bpy_struct):
    """Scroll and zoom for a 2D region"""

    def region_to_view(self, x: float | None, y: float | None) -> None:
        """Transform region coordinates to 2D view

        :param x: x, Region x coordinate (in [-inf, inf])
        :param y: y, Region y coordinate (in [-inf, inf])
        :return: Result, View coordinates (array of 2 items, in [-inf, inf])
        """

    def view_to_region(
        self, x: float | None, y: float | None, *, clip: bool | None = True
    ) -> None:
        """Transform 2D view coordinates to region

        :param x: x, 2D View x coordinate (in [-inf, inf])
        :param y: y, 2D View y coordinate (in [-inf, inf])
        :param clip: Clip, Clip coordinates to the visible region (optional)
        :return: Result, Region coordinates (array of 2 items, in [-inf, inf])
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class View3DCursor(bpy_struct):
    location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    matrix: mathutils.Matrix
    """ Matrix combining location and rotation of the cursor (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)))"""

    rotation_axis_angle: typing.Any
    """ Angle of Rotation for Axis-Angle rotation representation (array of 4 items, in [-inf, inf], default (0.0, 0.0, 1.0, 0.0))"""

    rotation_euler: mathutils.Euler
    """ 3D rotation (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    rotation_mode: Literal[bpy.stub_internal.rna_enums.ObjectRotationModeItems]
    """ The kind of rotation to apply, values from other rotation modes are not used (default 'XYZ')"""

    rotation_quaternion: mathutils.Quaternion
    """ Rotation in quaternions (keep normalized) (array of 4 items, in [-inf, inf], default (1.0, 0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class View3DOverlay(bpy_struct):
    """Settings for display of overlays in the 3D viewport"""

    bone_wire_alpha: float
    """ Maximum opacity of bones in wireframe display mode (in [0, inf], default 1.0)"""

    display_handle: typing.Literal["NONE", "SELECTED", "ALL"]
    """ Limit the display of curve handles in Edit Mode (default 'SELECTED')"""

    fade_inactive_alpha: float
    """ Strength of the fade effect (in [0, 1], default 0.4)"""

    gpencil_fade_layer: float
    """ Fade layer opacity for Grease Pencil layers except the active one (in [0, 1], default 0.5)"""

    gpencil_fade_objects: float
    """ Fade factor (in [0, 1], default 0.5)"""

    gpencil_grid_color: mathutils.Color
    """ Canvas grid color (array of 3 items, in [0, 1], default (0.5, 0.5, 0.5))"""

    gpencil_grid_offset: typing.Any
    """ Canvas grid offset (array of 2 items, in [-inf, inf], default (0.0, 0.0))"""

    gpencil_grid_opacity: float
    """ Canvas grid opacity (in [0.1, 1], default 0.9)"""

    gpencil_grid_scale: mathutils.Vector
    """ Canvas grid scale (array of 2 items, in [0, inf], default (1.0, 1.0))"""

    gpencil_grid_subdivisions: int
    """ Canvas grid subdivisions (in [1, 100], default 4)"""

    gpencil_vertex_paint_opacity: float
    """ Vertex Paint mix factor (in [0, 1], default 1.0)"""

    grid_lines: int
    """ Number of grid lines to display in perspective view (in [0, 1024], default 16)"""

    grid_scale: float
    """ Multiplier for the distance between 3D View grid lines (in [0, inf], default 1.0)"""

    grid_scale_unit: float
    """ Grid cell size scaled by scene unit system settings (in [-inf, inf], default 0.0, readonly)"""

    grid_subdivisions: int
    """ Number of subdivisions between grid lines (in [1, 1024], default 10)"""

    normals_constant_screen_size: float
    """ Screen size for normals in the 3D view (in [0, 100000], default 7.0)"""

    normals_length: float
    """ Display size for normals in the 3D view (in [1e-05, 100000], default 0.1)"""

    retopology_offset: float
    """ Offset used to draw edit mesh in front of other geometry (in [0, inf], default 0.01)"""

    sculpt_curves_cage_opacity: float
    """ Opacity of the cage overlay in curves sculpt mode (in [0, 1], default 0.0)"""

    sculpt_mode_face_sets_opacity: float
    """ (in [0, 1], default 1.0)"""

    sculpt_mode_mask_opacity: float
    """ (in [0, 1], default 0.75)"""

    show_annotation: bool
    """ Show annotations for this view (default True)"""

    show_axis_x: bool
    """ Show the X axis line (default True)"""

    show_axis_y: bool
    """ Show the Y axis line (default True)"""

    show_axis_z: bool
    """ Show the Z axis line (default False)"""

    show_bones: bool
    """ Display bones (disable to show motion paths only) (default True)"""

    show_camera_guides: bool
    """ Show camera composition guides (default True)"""

    show_camera_passepartout: bool
    """ Show camera passepartout (default True)"""

    show_cursor: bool
    """ Display 3D Cursor Overlay (default True)"""

    show_curve_normals: bool
    """ Display 3D curve normals in Edit Mode (default False)"""

    show_edge_bevel_weight: bool
    """ Display weights created for the Bevel modifier (default True)"""

    show_edge_crease: bool
    """ Display creases created for Subdivision Surface modifier (default True)"""

    show_edge_seams: bool
    """ Display UV unwrapping seams (default True)"""

    show_edge_sharp: bool
    """ Display sharp edges, used with the Edge Split modifier (default True)"""

    show_extra_edge_angle: bool
    """ Display selected edge angle, using global values when set in the transform panel (default False)"""

    show_extra_edge_length: bool
    """ Display selected edge lengths, using global values when set in the transform panel (default False)"""

    show_extra_face_angle: bool
    """ Display the angles in the selected edges, using global values when set in the transform panel (default False)"""

    show_extra_face_area: bool
    """ Display the area of selected faces, using global values when set in the transform panel (default False)"""

    show_extra_indices: bool
    """ Display the index numbers of selected vertices, edges, and faces (default False)"""

    show_extras: bool
    """ Object details, including empty wire, cameras and other visual guides (default True)"""

    show_face_center: bool
    """ Display face center when face selection is enabled in solid shading modes (default False)"""

    show_face_normals: bool
    """ Display face normals as lines (default False)"""

    show_face_orientation: bool
    """ Show the Face Orientation Overlay (default False)"""

    show_faces: bool
    """ Display a face selection overlay (default True)"""

    show_fade_inactive: bool
    """ Fade inactive geometry using the viewport background color (default False)"""

    show_floor: bool
    """ Show the ground plane grid (default True)"""

    show_freestyle_edge_marks: bool
    """ Display Freestyle edge marks, used with the Freestyle renderer (default True)"""

    show_freestyle_face_marks: bool
    """ Display Freestyle face marks, used with the Freestyle renderer (default True)"""

    show_light_colors: bool
    """ Show light colors (default False)"""

    show_look_dev: bool
    """ Show reference spheres with neutral shading that react to lighting to assist in look development (default False)"""

    show_motion_paths: bool
    """ Show the Motion Paths Overlay (default True)"""

    show_object_origins: bool
    """ Show object center dots (default True)"""

    show_object_origins_all: bool
    """ Show the object origin center dot for all (selected and unselected) objects (default False)"""

    show_onion_skins: bool
    """ Show the Onion Skinning Overlay (default False)"""

    show_ortho_grid: bool
    """ Show grid in orthographic side view (default True)"""

    show_outline_selected: bool
    """ Show an outline highlight around selected objects (default True)"""

    show_overlays: bool
    """ Display overlays like gizmos and outlines (default True)"""

    show_paint_wire: bool
    """ Use wireframe display in painting modes (default False)"""

    show_performance: bool
    """ (default False)"""

    show_relationship_lines: bool
    """ Show dashed lines indicating parent or constraint relationships (default True)"""

    show_retopology: bool
    """ Hide the solid mesh and offset the overlay towards the view. Selection is occluded by inactive geometry, unless X-Ray is enabled (default False)"""

    show_sculpt_curves_cage: bool
    """ Show original curves that are currently being edited (default False)"""

    show_sculpt_face_sets: bool
    """ (default True)"""

    show_sculpt_mask: bool
    """ (default True)"""

    show_split_normals: bool
    """ Display vertex-per-face normals as lines (default False)"""

    show_stats: bool
    """ Display scene statistics overlay text (default False)"""

    show_statvis: bool
    """ Display statistical information about the mesh (default False)"""

    show_text: bool
    """ Display overlay text (default True)"""

    show_vertex_normals: bool
    """ Display vertex normals as lines (default False)"""

    show_viewer_attribute: bool
    """ Show attribute overlay for active viewer node (default True)"""

    show_viewer_text: bool
    """ Show attribute values as text in viewport (default False)"""

    show_weight: bool
    """ Display weights in editmode (default False)"""

    show_wireframes: bool
    """ Show face edges wires (default False)"""

    show_wpaint_contours: bool
    """ Show contour lines formed by points with the same interpolated weight (default False)"""

    show_xray_bone: bool
    """ Show the bone selection overlay (default False)"""

    texture_paint_mode_opacity: float
    """ Opacity of the texture paint mode stencil mask overlay (in [0, 1], default 1.0)"""

    use_debug_freeze_view_culling: bool
    """ Freeze view culling bounds (default False)"""

    use_gpencil_canvas_xray: bool
    """ Show Canvas grid in front (default False)"""

    use_gpencil_edit_lines: bool
    """ Show Edit Lines when editing strokes (default True)"""

    use_gpencil_fade_gp_objects: bool
    """ Fade Grease Pencil Objects, except the active one (default False)"""

    use_gpencil_fade_layers: bool
    """ Toggle fading of Grease Pencil layers except the active one (default False)"""

    use_gpencil_fade_objects: bool
    """ Fade all viewport objects with a full color layer to improve visibility (default False)"""

    use_gpencil_grid: bool
    """ Display a grid over Grease Pencil paper (default False)"""

    use_gpencil_multiedit_line_only: bool
    """ Show Edit Lines only in multiframe (default False)"""

    use_gpencil_onion_skin: bool
    """ Show ghosts of the keyframes before and after the current frame (default False)"""

    use_gpencil_onion_skin_active_object: bool
    """ Show only the onion skins of the active object (default False)"""

    use_gpencil_show_directions: bool
    """ Show stroke drawing direction with a bigger green dot (start) and smaller red dot (end) points (default False)"""

    use_gpencil_show_material_name: bool
    """ Show material name assigned to each stroke (default False)"""

    use_normals_constant_screen_size: bool
    """ Keep size of normals constant in relation to 3D view (default False)"""

    vertex_opacity: float
    """ Opacity for edit vertices (in [0, 1], default 1.0)"""

    vertex_paint_mode_opacity: float
    """ Opacity of the texture paint mode stencil mask overlay (in [0, 1], default 1.0)"""

    viewer_attribute_opacity: float
    """ Opacity of the attribute that is currently visualized (in [0, 1], default 1.0)"""

    weight_paint_mode_opacity: float
    """ Opacity of the weight paint mode overlay (in [0, 1], default 1.0)"""

    wireframe_opacity: float
    """ Opacity of the displayed edges (1.0 for opaque) (in [0, 1], default 1.0)"""

    wireframe_threshold: float
    """ Adjust the angle threshold for displaying edges (1.0 for all) (in [0, 1], default 1.0)"""

    xray_alpha_bone: float
    """ Opacity to use for bone selection (in [0, 1], default 0.5)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class View3DShading(bpy_struct):
    """Settings for shading in the 3D viewport"""

    aov_name: str
    """ Name of the active Shader AOV (default "", never None)"""

    background_color: mathutils.Color
    """ Color for custom background color (array of 3 items, in [0, 1], default (0.05, 0.05, 0.05))"""

    background_type: typing.Literal["THEME", "WORLD", "VIEWPORT"]
    """ Way to display the background (default 'THEME')"""

    cavity_ridge_factor: float
    """ Factor for the cavity ridges (in [0, 250], default 1.0)"""

    cavity_type: typing.Literal["WORLD", "SCREEN", "BOTH"]
    """ Way to display the cavity shading (default 'SCREEN')"""

    cavity_valley_factor: float
    """ Factor for the cavity valleys (in [0, 250], default 1.0)"""

    color_type: typing.Literal[
        "MATERIAL", "OBJECT", "RANDOM", "VERTEX", "TEXTURE", "SINGLE"
    ]
    """ Color Type (default 'MATERIAL')"""

    curvature_ridge_factor: float
    """ Factor for the curvature ridges (in [0, 2], default 1.0)"""

    curvature_valley_factor: float
    """ Factor for the curvature valleys (in [0, 2], default 1.0)"""

    cycles: typing.Any
    """ (readonly)"""

    light: typing.Literal["STUDIO", "MATCAP", "FLAT"]
    """ Lighting Method for Solid/Texture Viewport Shading (default 'STUDIO')"""

    object_outline_color: mathutils.Color
    """ Color for object outline (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    render_pass: typing.Literal[
        "COMBINED",
        "EMISSION",
        "ENVIRONMENT",
        "AO",
        "SHADOW",
        "TRANSPARENT",
        "DIFFUSE_LIGHT",
        "DIFFUSE_COLOR",
        "SPECULAR_LIGHT",
        "SPECULAR_COLOR",
        "VOLUME_LIGHT",
        "POSITION",
        "NORMAL",
        "MIST",
        "CryptoObject",
        "CryptoAsset",
        "CryptoMaterial",
        "AOV",
    ]
    """ Render Pass to show in the viewport (default 'COMBINED')"""

    selected_studio_light: StudioLight | None
    """ Selected StudioLight (readonly)"""

    shadow_intensity: float
    """ Darkness of shadows (in [0, 1], default 0.5)"""

    show_backface_culling: bool
    """ Use back face culling to hide the back side of faces (default False)"""

    show_cavity: bool
    """ Show Cavity (default False)"""

    show_object_outline: bool
    """ Show Object Outline (default False)"""

    show_shadows: bool
    """ Show Shadow (default False)"""

    show_specular_highlight: bool
    """ Render specular highlights (default True)"""

    show_xray: bool
    """ Show whole scene transparent (default False)"""

    show_xray_wireframe: bool
    """ Show whole scene transparent (default True)"""

    single_color: mathutils.Color
    """ Color for single color mode (array of 3 items, in [0, 1], default (0.8, 0.8, 0.8))"""

    studio_light: typing.Literal["DEFAULT"]
    """ Studio lighting setup (default 'DEFAULT')"""

    studiolight_background_alpha: float
    """ Show the studiolight in the background (in [0, 1], default 0.0)"""

    studiolight_background_blur: float
    """ Blur the studiolight in the background (in [0, 1], default 0.5)"""

    studiolight_intensity: float
    """ Strength of the studiolight (in [0, inf], default 1.0)"""

    studiolight_rotate_z: float
    """ Rotation of the studiolight around the Z-Axis (in [-3.14159, 3.14159], default 0.0)"""

    type: Literal[bpy.stub_internal.rna_enums.ShadingTypeItems]
    """ Method to display/shade objects in the 3D View (default 'SOLID')"""

    use_compositor: typing.Literal["DISABLED", "CAMERA", "ALWAYS"]
    """ When to preview the compositor output inside the viewport (default 'DISABLED')"""

    use_dof: bool
    """ Use depth of field on viewport using the values from the active camera (default False)"""

    use_scene_lights: bool
    """ Render lights and light probes of the scene (default False)"""

    use_scene_lights_render: bool
    """ Render lights and light probes of the scene (default True)"""

    use_scene_world: bool
    """ Use scene world for lighting (default False)"""

    use_scene_world_render: bool
    """ Use scene world for lighting (default True)"""

    use_studiolight_view_rotation: bool
    """ Make the HDR rotation fixed and not follow the camera (default True)"""

    use_world_space_lighting: bool
    """ Make the lighting fixed and not follow the camera (default False)"""

    wireframe_color_type: typing.Literal["THEME", "OBJECT", "RANDOM"]
    """ Wire Color Type (default 'THEME')"""

    xray_alpha: float
    """ Amount of opacity to use (in [0, 1], default 0.5)"""

    xray_alpha_wireframe: float
    """ Amount of opacity to use (in [0, 1], default 0.5)"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewLayer(bpy_struct):
    """View layer"""

    active_aov: AOV | None
    """ Active AOV (readonly)"""

    active_aov_index: int | None
    """ Index of active AOV (in [0, inf], default 0)"""

    active_layer_collection: LayerCollection | None
    """ Active layer collection in this view layer's hierarchy (never None)"""

    active_lightgroup: Lightgroup | None
    """ Active Lightgroup (readonly)"""

    active_lightgroup_index: int | None
    """ Index of active lightgroup (in [0, inf], default 0)"""

    aovs: typing.Any
    """ (default None, readonly)"""

    cycles: typing.Any
    """ Cycles ViewLayer Settings (readonly)"""

    depsgraph: Depsgraph | None
    """ Dependencies in the scene data (readonly)"""

    eevee: ViewLayerEEVEE | None
    """ View layer settings for EEVEE (readonly, never None)"""

    freestyle_settings: FreestyleSettings | None
    """ (readonly, never None)"""

    has_export_collections: bool
    """ At least one Collection in this View Layer has an exporter (default False, readonly)"""

    layer_collection: LayerCollection | None
    """ Root of collections hierarchy of this view layer, its 'collection' pointer property is the same as the scene's master collection (readonly, never None)"""

    lightgroups: typing.Any
    """ (default None, readonly)"""

    material_override: Material | None
    """ Material to override all other materials in this view layer"""

    name: str
    """ View layer name (default "", never None)"""

    objects: typing.Any
    """ All the objects in this layer (default None, readonly)"""

    pass_alpha_threshold: float
    """ Z, Index, normal, UV and vector passes are only affected by surfaces with alpha transparency equal to or higher than this threshold (in [0, 1], default 0.5)"""

    pass_cryptomatte_depth: int
    """ Sets how many unique objects can be distinguished per pixel (in [2, 16], default 6)"""

    samples: int
    """ Override number of render samples for this view layer, 0 will use the scene setting (in [0, inf], default 0)"""

    use: bool
    """ Enable or disable rendering of this View Layer (default True)"""

    use_ao: bool
    """ Render Ambient Occlusion in this Layer (default True)"""

    use_freestyle: bool
    """ Render stylized strokes in this Layer (default True)"""

    use_grease_pencil: bool
    """ Render Grease Pencil on this layer (default True)"""

    use_motion_blur: bool
    """ Render motion blur in this Layer, if enabled in the scene (default True)"""

    use_pass_ambient_occlusion: bool
    """ Deliver Ambient Occlusion pass (default False)"""

    use_pass_combined: bool
    """ Deliver full combined RGBA buffer (default True)"""

    use_pass_cryptomatte_accurate: bool
    """ Generate a more accurate cryptomatte pass (default True)"""

    use_pass_cryptomatte_asset: bool
    """ Render cryptomatte asset pass, for isolating groups of objects with the same parent (default False)"""

    use_pass_cryptomatte_material: bool
    """ Render cryptomatte material pass, for isolating materials in compositing (default False)"""

    use_pass_cryptomatte_object: bool
    """ Render cryptomatte object pass, for isolating objects in compositing (default False)"""

    use_pass_diffuse_color: bool
    """ Deliver diffuse color pass (default False)"""

    use_pass_diffuse_direct: bool
    """ Deliver diffuse direct pass (default False)"""

    use_pass_diffuse_indirect: bool
    """ Deliver diffuse indirect pass (default False)"""

    use_pass_emit: bool
    """ Deliver emission pass (default False)"""

    use_pass_environment: bool
    """ Deliver environment lighting pass (default False)"""

    use_pass_glossy_color: bool
    """ Deliver glossy color pass (default False)"""

    use_pass_glossy_direct: bool
    """ Deliver glossy direct pass (default False)"""

    use_pass_glossy_indirect: bool
    """ Deliver glossy indirect pass (default False)"""

    use_pass_grease_pencil: bool
    """ Deliver Grease Pencil render result in a separate pass (default False)"""

    use_pass_material_index: bool
    """ Deliver material index pass (default False)"""

    use_pass_mist: bool
    """ Deliver mist factor pass (0.0 to 1.0) (default False)"""

    use_pass_normal: bool
    """ Deliver normal pass (default False)"""

    use_pass_object_index: bool
    """ Deliver object index pass (default False)"""

    use_pass_position: bool
    """ Deliver position pass (default False)"""

    use_pass_shadow: bool
    """ Deliver shadow pass (default False)"""

    use_pass_subsurface_color: bool
    """ Deliver subsurface color pass (default False)"""

    use_pass_subsurface_direct: bool
    """ Deliver subsurface direct pass (default False)"""

    use_pass_subsurface_indirect: bool
    """ Deliver subsurface indirect pass (default False)"""

    use_pass_transmission_color: bool
    """ Deliver transmission color pass (default False)"""

    use_pass_transmission_direct: bool
    """ Deliver transmission direct pass (default False)"""

    use_pass_transmission_indirect: bool
    """ Deliver transmission indirect pass (default False)"""

    use_pass_uv: bool
    """ Deliver texture UV pass (default False)"""

    use_pass_vector: bool
    """ Deliver speed vector pass (default False)"""

    use_pass_z: bool
    """ Deliver depth values pass (default False)"""

    use_sky: bool
    """ Render Sky in this Layer (default True)"""

    use_solid: bool
    """ Render Solid faces in this Layer (default True)"""

    use_strand: bool
    """ Render Strands in this Layer (default True)"""

    use_volumes: bool
    """ Render volumes in this Layer (default True)"""

    world_override: World | None
    """ Override world in this view layer"""

    def bl_system_properties_get(
        self, *, do_create: bool | None = False
    ) -> PropertyGroup:
        """DEBUG ONLY. Internal access to runtime-defined RNA data storage, intended solely for testing and debugging purposes. Do not access it in regular scripting work, and in particular, do not assume that it contains writable data

        :param do_create: Ensure that system properties are created if they do not exist yet (optional)
        :return: The system properties root container, or None if there are no system properties stored in this data yet, and its creation was not requested
        """

    @classmethod
    def update_render_passes(cls) -> None:
        """Requery the enabled render passes from the render engine"""

    def update(self) -> None:
        """Update data tagged to be updated from previous access to data or operators"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewLayerEEVEE(bpy_struct):
    """View Layer settings for EEVEE"""

    ambient_occlusion_distance: float
    """ Distance of object that contribute to the ambient occlusion effect (in [0, 100000], default 10.0)"""

    use_pass_bloom: bool
    """ Deliver bloom pass (deprecated) (default False)"""

    use_pass_transparent: bool
    """ Deliver alpha blended surfaces in a separate pass (default False)"""

    use_pass_volume_direct: bool
    """ Deliver volume direct light pass (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewerNodeViewerPathElem(ViewerPathElem, bpy_struct):
    node_id: int
    """ (in [-inf, inf], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewerPath(bpy_struct):
    """Path to data that is viewed"""

    path: typing.Any
    """ (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class ViewerPathElem(bpy_struct):
    """Element of a viewer path"""

    type: typing.Literal[
        "ID",
        "MODIFIER",
        "GROUP_NODE",
        "SIMULATION_ZONE",
        "VIEWER_NODE",
        "REPEAT_ZONE",
        "FOREACH_GEOMETRY_ELEMENT_ZONE",
        "EVALUATE_CLOSURE",
    ]
    """ Type of the path element (default 'ID', readonly)"""

    ui_name: str
    """ Name that can be displayed in the UI for this element (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Volume(ID, bpy_struct):
    """Volume data-block for 3D volume grids"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    display: VolumeDisplay | None
    """ Volume display settings for 3D viewport (readonly)"""

    filepath: str
    """ Volume file used by this Volume data-block (default "", never None, blend relative // prefix supported)"""

    frame_duration: int
    """ Number of frames of the sequence to use (in [0, 1048574], default 0)"""

    frame_offset: int
    """ Offset the number of the frame to use in the animation (in [-inf, inf], default 0)"""

    frame_start: int
    """ Global starting frame of the sequence, assuming first has a #1 (in [-1048574, 1048574], default 1)"""

    grids: typing.Any
    """ 3D volume grids (default None, readonly)"""

    is_sequence: bool
    """ Whether the cache is separated in a series of files (default False)"""

    materials: typing.Any
    """ (default None, readonly)"""

    packed_file: PackedFile | None
    """ (readonly)"""

    render: VolumeRender | None
    """ Volume render settings for 3D viewport (readonly)"""

    sequence_mode: typing.Literal["CLIP", "EXTEND", "REPEAT", "PING_PONG"]
    """ Sequence playback mode (default 'CLIP')"""

    velocity_grid: str
    """ Name of the velocity field, or the base name if the velocity is split into multiple grids (default "", never None)"""

    velocity_scale: float
    """ Factor to control the amount of motion blur (in [0, inf], default 1.0)"""

    velocity_unit: Literal[bpy.stub_internal.rna_enums.VelocityUnitItems]
    """ Define how the velocity vectors are interpreted with regard to time, 'frame' means the delta time is 1 frame, 'second' means the delta time is 1 / FPS (default 'FRAME')"""

    velocity_x_grid: str
    """ Name of the grid for the X axis component of the velocity field if it was split into multiple grids (default "", readonly, never None)"""

    velocity_y_grid: str
    """ Name of the grid for the Y axis component of the velocity field if it was split into multiple grids (default "", readonly, never None)"""

    velocity_z_grid: str
    """ Name of the grid for the Z axis component of the velocity field if it was split into multiple grids (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeDisplaceModifier(Modifier, bpy_struct):
    strength: float
    """ Strength of the displacement (in [-inf, inf], default 0.0)"""

    texture: Texture | None
    texture_map_mode: typing.Literal["LOCAL", "GLOBAL", "OBJECT"]
    """ (default 'LOCAL')"""

    texture_map_object: Object | None
    """ Object to use for texture mapping"""

    texture_mid_level: mathutils.Vector
    """ Subtracted from the texture color to get a displacement vector (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    texture_sample_radius: float
    """ Smaller values result in better performance but might cut off the volume (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeDisplay(bpy_struct):
    """Volume object display settings for 3D viewport"""

    density: float
    """ Thickness of volume display in the viewport (in [1e-05, inf], default 1.0)"""

    interpolation_method: typing.Literal["LINEAR", "CUBIC", "CLOSEST"]
    """ Interpolation method to use for volumes in solid mode (default 'LINEAR')"""

    slice_axis: typing.Literal["AUTO", "X", "Y", "Z"]
    """ (default 'AUTO')"""

    slice_depth: float
    """ Position of the slice (in [0, 1], default 0.5)"""

    use_slice: bool
    """ Perform a single slice of the domain object (default False)"""

    wireframe_detail: typing.Literal["COARSE", "FINE"]
    """ Amount of detail for wireframe display (default 'COARSE')"""

    wireframe_type: typing.Literal["NONE", "BOUNDS", "BOXES", "POINTS"]
    """ Type of wireframe display (default 'BOXES')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeGrid(bpy_struct):
    """3D volume grid"""

    channels: int
    """ Number of dimensions of the grid data type (in [0, inf], default 0, readonly)"""

    data_type: Literal[bpy.stub_internal.rna_enums.VolumeGridDataTypeItems]
    """ Data type of voxel values (default 'UNKNOWN', readonly)"""

    is_loaded: bool
    """ Grid tree is loaded in memory (default False, readonly)"""

    matrix_object: mathutils.Matrix
    """ Transformation matrix from voxel index to object space (multi-dimensional array of 4 * 4 items, in [-inf, inf], default ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), readonly)"""

    name: str
    """ Volume grid name (default "", readonly, never None)"""

    def load(self) -> bool:
        """Load grid tree from file

        :return: True if grid tree was successfully loaded
        """

    def unload(self) -> None:
        """Unload grid tree and voxel data from memory, leaving only metadata"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeRender(bpy_struct):
    """Volume object render settings"""

    clipping: float
    """ Value under which voxels are considered empty space to optimize rendering (in [0, 1], default 0.001)"""

    precision: typing.Literal["FULL", "HALF", "VARIABLE"]
    """ Specify volume data precision. Lower values reduce memory consumption at the cost of detail. (default 'HALF')"""

    space: typing.Literal["OBJECT", "WORLD"]
    """ Specify volume density and step size in object or world space (default 'OBJECT')"""

    step_size: float
    """ Distance between volume samples. Lower values render more detail at the cost of performance. If set to zero, the step size is automatically determined based on voxel size. (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VolumeToMeshModifier(Modifier, bpy_struct):
    adaptivity: float
    """ Reduces the final face count by simplifying geometry where detail is not needed (in [0, 1], default 0.0)"""

    grid_name: str
    """ Grid in the volume object that is converted to a mesh (default "", never None)"""

    object: Object | None
    """ Object"""

    resolution_mode: typing.Literal["GRID", "VOXEL_AMOUNT", "VOXEL_SIZE"]
    """ Mode for how the desired voxel size is specified (default 'GRID')"""

    threshold: float
    """ Voxels with a larger value are inside the generated mesh (in [0, inf], default 0.0)"""

    use_smooth_shade: bool
    """ Output faces with smooth shading rather than flat shaded (default False)"""

    voxel_amount: int
    """ Approximate number of voxels along one axis (in [0, inf], default 0)"""

    voxel_size: float
    """ Smaller values result in a higher resolution output (in [0, inf], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class VoronoiTexture(Texture, ID, bpy_struct):
    """Procedural voronoi texture"""

    color_mode: typing.Literal[
        "INTENSITY", "POSITION", "POSITION_OUTLINE", "POSITION_OUTLINE_INTENSITY"
    ]
    """ (default 'INTENSITY')"""

    distance_metric: typing.Literal[
        "DISTANCE",
        "DISTANCE_SQUARED",
        "MANHATTAN",
        "CHEBYCHEV",
        "MINKOVSKY_HALF",
        "MINKOVSKY_FOUR",
        "MINKOVSKY",
    ]
    """ Algorithm used to calculate distance of sample points to feature points (default 'DISTANCE')"""

    minkovsky_exponent: float
    """ Minkowski exponent (in [0.01, 10], default 2.5)"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_intensity: float
    """ Scales the intensity of the noise (in [0.01, 10], default 1.0)"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    weight_1: float
    """ Voronoi feature weight 1 (in [-2, 2], default 1.0)"""

    weight_2: float
    """ Voronoi feature weight 2 (in [-2, 2], default 0.0)"""

    weight_3: float
    """ Voronoi feature weight 3 (in [-2, 2], default 0.0)"""

    weight_4: float
    """ Voronoi feature weight 4 (in [-2, 2], default 0.0)"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WORKSPACE_UL_addons_items(UIList, bpy_struct):
    def draw_item(
        self,
        context,
        layout,
        _data,
        addon,
        _icon,
        _active_data,
        _active_propname,
        _index,
    ) -> None:
        """

        :param context:
        :param layout:
        :param _data:
        :param addon:
        :param _icon:
        :param _active_data:
        :param _active_propname:
        :param _index:
        """

    def filter_items(self, _context, data, property) -> None:
        """

        :param _context:
        :param data:
        :param property:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WalkNavigation(bpy_struct):
    """Walk navigation settings"""

    jump_height: float
    """ Maximum height of a jump (in [0.1, 100], default 0.4)"""

    mouse_speed: float
    """ Speed factor for when looking around, high values mean faster mouse movement (in [0.01, 10], default 1.0)"""

    teleport_time: float
    """ Interval of time warp when teleporting in navigation mode (in [0, 10], default 0.2)"""

    use_gravity: bool
    """ Walk with gravity, or free navigate (default False)"""

    use_mouse_reverse: bool
    """ Reverse the vertical movement of the mouse (default False)"""

    view_height: float
    """ View distance from the floor when walking (in [0, 1000], default 1.6)"""

    walk_speed: float
    """ Base speed for walking and flying (in [0.01, 100], default 2.5)"""

    walk_speed_factor: float
    """ Multiplication factor when using the fast or slow modifiers (in [0.01, 10], default 5.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WarpModifier(Modifier, bpy_struct):
    """Warp modifier"""

    bone_from: str
    """ Bone to transform from (default "", never None)"""

    bone_to: str
    """ Bone defining offset (default "", never None)"""

    falloff_curve: CurveMapping | None
    """ Custom falloff curve (readonly)"""

    falloff_radius: float
    """ Radius to apply (in [-inf, inf], default 1.0)"""

    falloff_type: typing.Literal[
        "NONE",
        "CURVE",
        "SMOOTH",
        "SPHERE",
        "ROOT",
        "INVERSE_SQUARE",
        "SHARP",
        "LINEAR",
        "CONSTANT",
    ]
    """ (default 'SMOOTH')"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    object_from: Object | None
    """ Object to transform from"""

    object_to: Object | None
    """ Object to transform to"""

    strength: float
    """ (in [-inf, inf], default 1.0)"""

    texture: Texture | None
    texture_coords: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ (default 'LOCAL')"""

    texture_coords_bone: str
    """ Bone to set the texture coordinates (default "", never None)"""

    texture_coords_object: Object | None
    """ Object to set the texture coordinates"""

    use_volume_preserve: bool
    """ Preserve volume when rotations are used (default False)"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    vertex_group: str
    """ Vertex group name for modulating the deform (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WaveModifier(Modifier, bpy_struct):
    """Wave effect modifier"""

    damping_time: float
    """ Number of frames in which the wave damps out after it dies (in [-1.04857e+06, 1.04857e+06], default 10.0)"""

    falloff_radius: float
    """ Distance after which it fades out (in [0, inf], default 0.0)"""

    height: float
    """ Height of the wave (in [-inf, inf], default 0.5)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    lifetime: float
    """ Lifetime of the wave in frames, zero means infinite (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    narrowness: float
    """ Distance between the top and the base of a wave, the higher the value, the more narrow the wave (in [0, inf], default 1.5)"""

    speed: float
    """ Speed of the wave, towards the starting point when negative (in [-inf, inf], default 0.25)"""

    start_position_object: Object | None
    """ Object which defines the wave center"""

    start_position_x: float
    """ X coordinate of the start position (in [-inf, inf], default 0.0)"""

    start_position_y: float
    """ Y coordinate of the start position (in [-inf, inf], default 0.0)"""

    texture: Texture | None
    texture_coords: typing.Literal["LOCAL", "GLOBAL", "OBJECT", "UV"]
    """ (default 'LOCAL')"""

    texture_coords_bone: str
    """ Bone to set the texture coordinates (default "", never None)"""

    texture_coords_object: Object | None
    """ Object to set the texture coordinates"""

    time_offset: float
    """ Either the starting frame (for positive speed) or ending frame (for negative speed) (in [-1.04857e+06, 1.04857e+06], default 0.0)"""

    use_cyclic: bool
    """ Cyclic wave effect (default True)"""

    use_normal: bool
    """ Displace along normals (default False)"""

    use_normal_x: bool
    """ Enable displacement along the X normal (default True)"""

    use_normal_y: bool
    """ Enable displacement along the Y normal (default True)"""

    use_normal_z: bool
    """ Enable displacement along the Z normal (default True)"""

    use_x: bool
    """ X axis motion (default True)"""

    use_y: bool
    """ Y axis motion (default True)"""

    uv_layer: str
    """ UV map name (default "", never None)"""

    vertex_group: str
    """ Vertex group name for modulating the wave (default "", never None)"""

    width: float
    """ Distance between the waves (in [0, inf], default 1.5)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WeightedNormalModifier(Modifier, bpy_struct):
    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    keep_sharp: bool
    """ Keep sharp edges as computed for default custom normals, instead of setting a single weighted normal for each vertex (default False)"""

    mode: typing.Literal["FACE_AREA", "CORNER_ANGLE", "FACE_AREA_WITH_ANGLE"]
    """ Weighted vertex normal mode to use (default 'FACE_AREA')"""

    thresh: float
    """ Threshold value for different weights to be considered equal (in [0, 10], default 0.01)"""

    use_face_influence: bool
    """ Use influence of face for weighting (default False)"""

    vertex_group: str
    """ Vertex group name for modifying the selected areas (default "", never None)"""

    weight: int
    """ Corrective factor applied to faces' weights, 50 is neutral, lower values increase weight of weak faces, higher values increase weight of strong faces (in [1, 100], default 50)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WeldModifier(Modifier, bpy_struct):
    """Weld modifier"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    loose_edges: bool
    """ Collapse edges without faces, cloth sewing edges (default False)"""

    merge_threshold: float
    """ Limit below which to merge vertices (in [0, inf], default 0.001)"""

    mode: typing.Literal["ALL", "CONNECTED"]
    """ Mode defines the merge rule (default 'ALL')"""

    vertex_group: str
    """ Vertex group name for selecting the affected areas (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WhiteBalanceModifier(StripModifier, bpy_struct):
    """White balance modifier for sequence strip"""

    open_mask_input_panel: bool
    """ (default False)"""

    white_value: mathutils.Color
    """ This color defines white in the strip (array of 3 items, in [0, 1], default (0.0, 0.0, 0.0))"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class Window(bpy_struct):
    """Open window"""

    height: int
    """ Window height (in [0, 32767], default 0, readonly)"""

    modal_operators: typing.Any
    """ A list of currently running modal operators (default None, readonly)"""

    parent: Window | None
    """ Active workspace and scene follow this window (readonly)"""

    scene: Scene | None
    """ Active scene to be edited in the window (never None)"""

    screen: Screen | None
    """ Active workspace screen showing in the window (never None)"""

    stereo_3d_display: Stereo3dDisplay | None
    """ Settings for stereo 3D display (readonly, never None)"""

    support_hdr_color: bool
    """ The window has a HDR graphics buffer that wide gamut and high dynamic range colors can be written to, in extended sRGB color space. (default False, readonly)"""

    view_layer: ViewLayer | None
    """ The active workspace view layer showing in the window (never None)"""

    width: int
    """ Window width (in [0, 32767], default 0, readonly)"""

    workspace: WorkSpace | None
    """ Active workspace showing in the window (never None)"""

    x: int
    """ Horizontal location of the window (in [-32768, 32767], default 0, readonly)"""

    y: int
    """ Vertical location of the window (in [-32768, 32767], default 0, readonly)"""

    def cursor_warp(self, x: int | None, y: int | None) -> None:
        """Set the cursor position

        :param x: (in [-inf, inf])
        :param y: (in [-inf, inf])
        """

    def cursor_set(
        self, cursor: Literal[bpy.stub_internal.rna_enums.WindowCursorItems] | None
    ) -> None:
        """Set the cursor

        :param cursor: cursor
        """

    def cursor_modal_set(
        self, cursor: Literal[bpy.stub_internal.rna_enums.WindowCursorItems] | None
    ) -> None:
        """Set the cursor, so the previous cursor can be restored

        :param cursor: cursor
        """

    def cursor_modal_restore(self) -> None:
        """Restore the previous cursor after calling cursor_modal_set"""

    def event_simulate(
        self,
        type: Literal[bpy.stub_internal.rna_enums.EventTypeItems] | None,
        value: Literal[bpy.stub_internal.rna_enums.EventValueItems] | None,
        *,
        unicode: str | None = "",
        x: int | None = 0,
        y: int | None = 0,
        shift: bool | None = False,
        ctrl: bool | None = False,
        alt: bool | None = False,
        oskey: bool | None = False,
        hyper: bool | None = False,
    ) -> Event:
        """event_simulate

        :param type: Type
        :param value: Value
        :param unicode: (optional)
        :param x: (in [-inf, inf], optional)
        :param y: (in [-inf, inf], optional)
        :param shift: Shift, (optional)
        :param ctrl: Ctrl, (optional)
        :param alt: Alt, (optional)
        :param oskey: OS Key, (optional)
        :param hyper: Hyper, (optional)
        :return: Item, Added key map item
        """

    def find_playing_scene(self, *, scrub: bool | None = False) -> Scene:
        """find_playing_scene

        :param scrub: Scrubbing, Check if time in the scene is being scrubbed (optional)
        :return: Scene, Scene that is currently playing
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WindowManager(ID, bpy_struct):
    """Window manager data-block defining open windows and other user interface data"""

    addon_filter: str
    """ Filter add-ons by category"""

    addon_search: str
    """ Filter by add-on name, author & category (default "", never None)"""

    addon_support: set[typing.Literal["OFFICIAL", "COMMUNITY", "TESTING"]]
    """ Display support level (default {'COMMUNITY', 'OFFICIAL'})"""

    addon_tags: typing.Any
    """ (default None, readonly)"""

    asset_path_dummy: str
    """ Full path to the Blender file containing the active asset (default "", readonly, never None)"""

    extension_repo_filter: str
    """ Filter extensions by repository"""

    extension_search: str
    """ Filter by extension name, author & category (default "", never None)"""

    extension_show_panel_available: bool
    """ Show the available extensions panel (default True)"""

    extension_show_panel_installed: bool
    """ Show the installed extensions panel (default True)"""

    extension_tags: typing.Any
    """ (default None, readonly)"""

    extension_type: typing.Literal["ALL", "ADDON", "THEME"]
    """ Show extensions by type (default 'ADDON')"""

    extension_use_filter: bool
    """ Filter Extensions by Tags & Repository (default False)"""

    extensions_blocked: int
    """ Number of installed extensions which are blocked (in [-inf, inf], default 0)"""

    extensions_updates: int
    """ Number of extensions with available update (in [-inf, inf], default 0)"""

    is_interface_locked: bool
    """ If true, the interface is currently locked by a running job and data should not be modified from application timers. Otherwise, the running job might conflict with the handler causing unexpected results or even crashes. (default False, readonly)"""

    keyconfigs: typing.Any
    """ Registered key configurations (default None, readonly)"""

    operators: typing.Any
    """ Operator registry (default None, readonly)"""

    poselib_previous_action: Action | None
    preset_name: str
    """ Name for new preset (default "New Preset", never None)"""

    windows: typing.Any
    """ Open windows (default None, readonly)"""

    xr_session_settings: XrSessionSettings | None
    """ (readonly, never None)"""

    xr_session_state: XrSessionState | None
    """ Runtime state information about the VR session (readonly)"""

    clipboard: str
    """ Clipboard text storage."""

    @classmethod
    def fileselect_add(cls, operator: Operator | None) -> None:
        """Opens a file selector with an operator.This method is used from the operators invoke callback
        which must then return {RUNNING_MODAL}.Accepting the file selector will run the operators execute callback.The following properties are supported:

                :param operator: Operator to call
        """

    @classmethod
    def modal_handler_add(cls, operator: Operator | None) -> bool:
        """Add a modal handler to the window manager, for the given modal operator (called by invoke() with self, just before returning {RUNNING_MODAL})

        :param operator: Operator to call
        :return: Whether adding the handler was successful
        """

    def event_timer_add(
        self, time_step: float | None, *, window: Window | None = None
    ) -> Timer:
        """Add a timer to the given window, to generate periodic TIMER events

        :param time_step: Time Step, Interval in seconds between timer events (in [0, inf])
        :param window: Window to attach the timer to, or None (optional)
        :return:
        """

    def event_timer_remove(self, timer: Timer | None) -> None:
        """event_timer_remove

        :param timer: (never None)
        """

    @classmethod
    def gizmo_group_type_ensure(cls, identifier: str | None) -> None:
        """Activate an existing widget group (when the persistent option isnt set)

        :param identifier: Gizmo group type name (never None)
        """

    @classmethod
    def gizmo_group_type_unlink_delayed(cls, identifier: str | None) -> None:
        """Unlink a widget group (when the persistent option is set)

        :param identifier: Gizmo group type name (never None)
        """

    def progress_begin(self, min: float | None, max: float | None) -> None:
        """Start progress report

        :param min: min, any value in range [0,9999] (in [-inf, inf])
        :param max: max, any value in range [min+1,9998] (in [-inf, inf])
        """

    def progress_update(self, value: float | None) -> None:
        """Update the progress feedback

        :param value: value, Any value between min and max as set in progress_begin() (in [-inf, inf])
        """

    def progress_end(self) -> None:
        """Terminate progress report"""

    @classmethod
    def invoke_props_popup(
        cls, operator: Operator | None, event: Event | None
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Operator popup invoke (show operator properties and execute it automatically on changes)

        :param operator: Operator to call
        :param event: Event
        :return: result
        """

    @classmethod
    def invoke_props_dialog(
        cls,
        operator: Operator | None,
        *,
        width: int | None = 300,
        title: str | None = "",
        confirm_text: str | None = "",
        cancel_default: bool | None = False,
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Operator dialog (non-autoexec popup) invoke (show operator properties and only execute it on click on OK button)

        :param operator: Operator to call
        :param width: Width of the popup (in [0, inf], optional)
        :param title: Title, Optional text to show as title of the popup (optional, never None)
        :param confirm_text: Confirm Text, Optional text to show instead to the default "OK" confirmation button text (optional, never None)
        :param cancel_default: cancel_default, (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :return: result
        """

    @classmethod
    def invoke_search_popup(cls, operator: Operator | None) -> None:
        """Operator search popup invoke which searches values of the operators `bpy.types.Operator.bl_property` (which must be an EnumProperty), executing it on confirmation

        :param operator: Operator to call
        """

    @classmethod
    def invoke_popup(
        cls, operator: Operator | None, *, width: int | None = 300
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Operator popup invoke (only shows operators properties, without executing it)

        :param operator: Operator to call
        :param width: Width of the popup (in [0, inf], optional)
        :return: result
        """

    @classmethod
    def invoke_confirm(
        cls,
        operator: Operator | None,
        event: Event | None,
        *,
        title: str | None = "",
        message: str | None = "",
        confirm_text: str | None = "",
        icon: typing.Literal["NONE", "WARNING", "QUESTION", "ERROR", "INFO"]
        | None = "NONE",
        text_ctxt: str | None = "",
        translate: bool | None = True,
    ) -> set[Literal[bpy.stub_internal.rna_enums.OperatorReturnItems]]:
        """Operator confirmation popup (only to let user confirm the execution, no operator properties shown)

        :param operator: Operator to call
        :param event: Event
        :param title: Title, Optional text to show as title of the popup (optional, never None)
        :param message: Message, Optional first line of content text (optional, never None)
        :param confirm_text: Confirm Text, Optional text to show instead to the default "OK" confirmation button text (optional, never None)
        :param icon: Icon, Optional icon displayed in the dialog (optional)
        :param text_ctxt: Override automatic translation context of the given text (optional)
        :param translate: Translate the given text, when UI translation is enabled (optional)
        :return: result
        """

    @classmethod
    def popmenu_begin__internal(
        cls,
        title: str | None,
        *,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
    ) -> UIPopupMenu:
        """popmenu_begin__internal

        :param title: (never None)
        :param icon: icon, (optional)
        :return: (never None)
        """

    @classmethod
    def popmenu_end__internal(cls, menu: UIPopupMenu | None) -> None:
        """popmenu_end__internal

        :param menu: (never None)
        """

    @classmethod
    def popover_begin__internal(
        cls, *, ui_units_x: int | None = 0, from_active_button: bool | None = False
    ) -> UIPopover:
        """popover_begin__internal

        :param ui_units_x: ui_units_x, (in [0, inf], optional)
        :param from_active_button: Use Button, Use the active button for positioning (optional)
        :return: (never None)
        """

    @classmethod
    def popover_end__internal(
        cls, menu: UIPopover | None, *, keymap: KeyMap | None = None
    ) -> None:
        """popover_end__internal

        :param menu: (never None)
        :param keymap: Key Map, Active key map (optional)
        """

    @classmethod
    def piemenu_begin__internal(
        cls,
        title: str | None,
        *,
        icon: Literal[bpy.stub_internal.rna_enums.IconItems] | None = "NONE",
        event: Event | None = None,
    ) -> UIPieMenu:
        """piemenu_begin__internal

        :param title: (never None)
        :param icon: icon, (optional)
        :param event: (optional, never None)
        :return: (never None)
        """

    @classmethod
    def piemenu_end__internal(cls, menu: UIPieMenu | None) -> None:
        """piemenu_end__internal

        :param menu: (never None)
        """

    @classmethod
    def operator_properties_last(cls, operator: str | None) -> OperatorProperties:
        """operator_properties_last

        :param operator: (never None)
        :return: (never None)
        """

    def print_undo_steps(self) -> None:
        """print_undo_steps"""

    @classmethod
    def tag_script_reload(cls) -> None:
        """Tag for refreshing the interface after scripts have been reloaded"""

    @classmethod
    def asset_library_status_begin_loading(
        cls, library_url: str | None, *, timeout: float | None = 0.3
    ) -> None:
        """Inform the asset system that the asset library at the given URL is being loaded.

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        :param timeout: Timeout, Maximum time in seconds after which the asset library loading will be considered cancelled, if no further status reporting is done (e.g. by repeated calls to asset_library_status_ping_still_loading()). (in [0, inf], optional)
        """

    @classmethod
    def asset_library_status_ping_still_loading(cls, library_url: str | None) -> None:
        """Inform the asset system that the loading is still ongoing. Call this regularly to prevent the loading status to timeout.

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        """

    @classmethod
    def asset_library_status_ping_metafiles_in_place(
        cls, library_url: str | None
    ) -> None:
        """Inform the asset system that the asset meta files (_asset-library-meta.json, asset-listing.json, blender_assets.cats.txt) are in place and ready to be loaded

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        """

    @classmethod
    def asset_library_status_ping_loaded_new_pages(
        cls, library_url: str | None
    ) -> None:
        """Inform the asset system that new content

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        """

    @classmethod
    def asset_library_status_ping_loaded_new_preview(
        cls, preview_full_path: str | None
    ) -> None:
        """Inform the asset system that a new preview is available and ready for display

        :param preview_full_path: URL, The full path (not URL!) pointing to the the asset preview that should be available now (never None)
        """

    @classmethod
    def asset_library_status_ping_loaded_new_assets(
        cls, library_url: str | None
    ) -> None:
        """Inform the asset system that new assets were downloaded and available at the expected location on disk

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        """

    @classmethod
    def asset_library_status_finished_loading(cls, library_url: str | None) -> None:
        """Inform the asset system that the asset library at the given URL has successfully finished loading.

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        """

    @classmethod
    def asset_library_status_failed_loading(
        cls, library_url: str | None, *, message: str | None = ""
    ) -> None:
        """Inform the asset system that the asset library at the given URL failed loading, and should be aborted.

        :param library_url: URL, The URL identifying the asset library being loaded (never None)
        :param message: Message, An error message to show to users (optional, never None)
        """

    def popover(
        self, draw_func, *, ui_units_x=0, keymap=None, from_active_button=False
    ) -> None:
        """

        :param draw_func:
        :param ui_units_x:
        :param keymap:
        :param from_active_button:
        """

    def popup_menu(self, draw_func, *, title="", icon="NONE") -> None:
        """Popup menus can be useful for creating menus without having to register menu classes.Note that they will not block the scripts execution, so the caller cant wait for user input.

        :param draw_func:
        :param title:
        :param icon:
        """

    def popup_menu_pie(self, event, draw_func, *, title="", icon="NONE") -> None:
        """

        :param event:
        :param draw_func:
        :param title:
        :param icon:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

    @classmethod
    def draw_cursor_add(
        cls,
        callback: collections.abc.Callable[..., typing.Any] | None,
        args: tuple[typing.Any, ...] | None,
        space_type: str | None,
        region_type: str | None,
    ) -> typing.Any:
        """Add a new draw cursor handler to this space type.
        It will be called every time the cursor for the specified region in the space type will be drawn.
        Note: All arguments are positional only for now.

                :param callback: A function that will be called when the cursor is drawn.
        It gets the specified arguments as input with the mouse position (tuple[int, int]) as last argument.
                :param args: Arguments that will be passed to the callback.
                :param space_type: The space type the callback draws in; for example VIEW_3D. (`bpy.types.Space.type`)
                :param region_type: The region type the callback draws in; usually WINDOW. (`bpy.types.Region.type`)
                :return: Handler that can be removed later on.
        """

    @classmethod
    def draw_cursor_remove(cls, handler: typing.Any | None) -> None:
        """Remove a draw cursor handler that was added previously.

        :param handler: The draw cursor handler that should be removed.
        """

class WipeStrip(EffectStrip, Strip, bpy_struct):
    """Sequence strip creating a wipe transition"""

    angle: float
    """ Angle of the transition (in [-1.5708, 1.5708], default 0.0)"""

    blur_width: float
    """ Width of the blur for the transition, in percentage relative to the image size (in [0, 1], default 0.0)"""

    direction: typing.Literal["OUT", "IN"]
    """ Whether to fade in or out (default 'OUT')"""

    input_1: Strip | None
    """ First input for the effect strip (never None)"""

    input_2: Strip | None
    """ Second input for the effect strip (never None)"""

    input_count: int
    """ (in [0, inf], default 0, readonly)"""

    transition_type: typing.Literal["SINGLE", "DOUBLE", "IRIS", "CLOCK"]
    """ (default 'SINGLE')"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WireframeModifier(Modifier, bpy_struct):
    """Wireframe effect modifier"""

    crease_weight: float
    """ Crease weight (if active) (in [-inf, inf], default 1.0)"""

    invert_vertex_group: bool
    """ Invert vertex group influence (default False)"""

    material_offset: int
    """ Offset material index of generated faces (in [-32768, 32767], default 0)"""

    offset: float
    """ Offset the thickness from the center (in [-inf, inf], default 0.0)"""

    thickness: float
    """ Thickness factor (in [-inf, inf], default 0.02)"""

    thickness_vertex_group: float
    """ Thickness factor to use for zero vertex group influence (in [0, 1], default 0.0)"""

    use_boundary: bool
    """ Support face boundaries (default False)"""

    use_crease: bool
    """ Crease hub edges for improved subdivision surface (default False)"""

    use_even_offset: bool
    """ Scale the offset to give more even thickness (default True)"""

    use_relative_offset: bool
    """ Scale the offset by surrounding geometry (default False)"""

    use_replace: bool
    """ Remove original geometry (default True)"""

    vertex_group: str
    """ Vertex group name for selecting the affected areas (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WoodTexture(Texture, ID, bpy_struct):
    """Procedural noise texture"""

    nabla: float
    """ Size of derivative offset used for calculating normal (in [0.001, 0.1], default 0.025)"""

    noise_basis: typing.Literal[
        "BLENDER_ORIGINAL",
        "ORIGINAL_PERLIN",
        "IMPROVED_PERLIN",
        "VORONOI_F1",
        "VORONOI_F2",
        "VORONOI_F3",
        "VORONOI_F4",
        "VORONOI_F2_F1",
        "VORONOI_CRACKLE",
        "CELL_NOISE",
    ]
    """ Noise basis used for turbulence (default 'BLENDER_ORIGINAL')"""

    noise_basis_2: typing.Literal["SIN", "SAW", "TRI"]
    """ (default 'SIN')"""

    noise_scale: float
    """ Scaling for noise input (in [0.0001, inf], default 0.25)"""

    noise_type: typing.Literal["SOFT_NOISE", "HARD_NOISE"]
    """ (default 'SOFT_NOISE')"""

    turbulence: float
    """ Turbulence of the bandnoise and ringnoise types (in [0.0001, inf], default 5.0)"""

    wood_type: typing.Literal["BANDS", "RINGS", "BANDNOISE", "RINGNOISE"]
    """ (default 'BANDS')"""

    users_material: tuple[Material, ...]
    """ Materials that use this texture(readonly)"""

    users_object_modifier: tuple[Object, ...]
    """ Object modifiers that use this texture(readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WorkSpace(ID, bpy_struct):
    """Workspace data-block, defining the working environment for the user"""

    active_addon: int | None
    """ Active Add-on in the Workspace Add-ons filter (in [-inf, inf], default 0)"""

    asset_library_reference: typing.Literal["ALL", "LOCAL", "ESSENTIALS", "CUSTOM"]
    """ Active asset library to show in the UI, not used by the Asset Browser (which has its own active asset library) (default 'ALL')"""

    object_mode: Literal[bpy.stub_internal.rna_enums.WorkspaceObjectModeItems]
    """ Switch to this object mode when activating the workspace (default 'OBJECT')"""

    owner_ids: typing.Any
    """ (default None, readonly)"""

    screens: typing.Any
    """ Screen layouts of a workspace (default None, readonly)"""

    sequencer_scene: Scene | None
    tools: typing.Any
    """ (default None, readonly)"""

    use_filter_by_owner: bool
    """ Filter the UI by tags (default False)"""

    use_pin_scene: bool
    """ Remember the last used scene for the workspace and switch to it whenever this workspace is activated again (default False)"""

    use_scene_time_sync: bool
    """ Set the active scene and time based on the current scene strip (default False)"""

    @classmethod
    def status_text_set_internal(cls, text: str | None) -> None:
        """Set the status bar text, typically key shortcuts for modal operators

        :param text: Text, New string for the status bar, None clears the text
        """

    def status_text_set(self, text) -> None:
        """Set the status text or None to clear,
        When text is a function, this will be called with the (header, context) arguments.

                :param text:
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WorkSpaceTool(bpy_struct):
    brush_type: typing.Literal["DEFAULT"]
    """ If the tool uses brushes and is limited to a specific brush type, the identifier of the brush type (default 'DEFAULT', readonly)"""

    has_datablock: bool
    """ (default False, readonly)"""

    idname: str
    """ (default "", never None)"""

    idname_fallback: str
    """ (default "", never None)"""

    index: int
    """ (in [-inf, inf], default 0, readonly)"""

    mode: typing.Literal["DEFAULT"]
    """ (default 'DEFAULT', readonly)"""

    space_type: Literal[bpy.stub_internal.rna_enums.SpaceTypeItems]
    """ (default 'EMPTY', readonly)"""

    use_brushes: bool
    """ (default False, readonly)"""

    use_paint_canvas: bool
    """ Does this tool use a painting canvas (default False, readonly)"""

    widget: str
    """ (default "", readonly, never None)"""

    def setup(
        self,
        idname: str | None,
        *,
        cursor: Literal[bpy.stub_internal.rna_enums.WindowCursorItems]
        | None = "DEFAULT",
        keymap: str | None = "",
        gizmo_group: str | None = "",
        brush_type: str | None = "",
        data_block: str | None = "",
        operator: str | None = "",
        index: int | None = 0,
        options: set[typing.Literal["KEYMAP_FALLBACK", "USE_BRUSHES"]] | None = set(),
        idname_fallback: str | None = "",
        keymap_fallback: str | None = "",
    ) -> None:
        """Set the tool settings

                :param idname: Identifier, (never None)
                :param cursor: cursor, (optional)
                :param keymap: Key Map, (optional, never None)
                :param gizmo_group: Gizmo Group, (optional, never None)
                :param brush_type: Brush Type, Limit this tool to a specific type of brush (optional)
                :param data_block: Data Block, (optional, never None)
                :param operator: Operator, (optional, never None)
                :param index: Index, (in [-inf, inf], optional)
                :param options: Tool Options, (optional)

        KEYMAP_FALLBACK
        Fallback.

        USE_BRUSHES
        Uses Brushes -- Allow this tool to use brushes via the asset system.
                :param idname_fallback: Fallback Identifier, (optional, never None)
                :param keymap_fallback: Fallback Key Map, (optional, never None)
        """

    def operator_properties(self, operator: str | None) -> OperatorProperties:
        """operator_properties

        :param operator: (never None)
        :return: (never None)
        """

    def gizmo_group_properties(self, group: str | None) -> GizmoGroupProperties:
        """gizmo_group_properties

        :param group: (never None)
        :return: (never None)
        """

    def refresh_from_context(self) -> None:
        """refresh_from_context"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class World(ID, bpy_struct):
    """World data-block describing the environment and ambient lighting of a scene"""

    animation_data: AnimData | None
    """ Animation data for this data-block (readonly)"""

    color: mathutils.Color
    """ Color of the background (array of 3 items, in [0, inf], default (0.05, 0.05, 0.05))"""

    cycles: typing.Any
    """ Cycles world settings (readonly)"""

    cycles_visibility: typing.Any
    """ Cycles visibility settings (readonly)"""

    light_settings: WorldLighting | None
    """ World lighting settings (readonly, never None)"""

    lightgroup: str
    """ Lightgroup that the world belongs to (default "", never None)"""

    mist_settings: WorldMistSettings | None
    """ World mist settings (readonly, never None)"""

    node_tree: ShaderNodeTree | None
    """ Node tree for node based worlds"""

    probe_resolution: typing.Literal["128", "256", "512", "1024", "2048", "4096"]
    """ Resolution when baked to a texture (default '1024')"""

    sun_angle: float
    """ Angular diameter of the Sun as seen from the Earth (in [0, 3.14159], default 0.00918043)"""

    sun_shadow_filter_radius: float
    """ Blur shadow aliasing using Percentage Closer Filtering (in [0, inf], default 1.0)"""

    sun_shadow_jitter_overblur: float
    """ Apply shadow tracing to each jittered sample to reduce under-sampling artifacts (in [0, 100], default 10.0)"""

    sun_shadow_maximum_resolution: float
    """ Maximum size of a shadow map pixel. Higher values use less memory at the cost of shadow quality. (in [0, inf], default 0.001)"""

    sun_threshold: float
    """ If non-zero, the maximum value for world contribution that will be recorded inside the world light probe. The excess contribution is converted to a sun light. This reduces the light bleeding caused by very bright light sources. (in [0, inf], default 10.0)"""

    use_eevee_finite_volume: bool
    """ The world's volume used to be rendered by EEVEE Legacy. Conversion is needed for it to render properly. (default False)"""

    use_nodes: bool
    """ Use shader nodes to render the world (default False)Unused but kept for compatibility reasons. Setting the property has no effect, and getting it always returns True.5.0 removal planned in version 6.0"""

    use_sun_shadow: bool
    """ Enable sun shadow casting (default True)"""

    use_sun_shadow_jitter: bool
    """ Enable jittered soft shadows to increase shadow precision (disabled in viewport unless enabled in the render settings). Has a high performance impact. (default False)"""

    def inline_shader_nodes(self) -> None:
        """Get the inlined shader nodes of this world. This preprocesses the node tree
        to remove nested groups, repeat zones and more.

                :return: The inlined shader nodes.
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WorldLighting(bpy_struct):
    """Lighting for a World data-block"""

    ao_factor: float
    """ Factor for ambient occlusion blending (in [0, inf], default 1.0)"""

    distance: float
    """ Length of rays, defines how far away other faces give occlusion effect (in [0, inf], default 10.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class WorldMistSettings(bpy_struct):
    """Mist settings for a World data-block"""

    depth: float
    """ Distance over which the mist effect fades in (in [0, inf], default 25.0)"""

    falloff: typing.Literal["QUADRATIC", "LINEAR", "INVERSE_QUADRATIC"]
    """ Type of transition used to fade mist (default 'QUADRATIC')"""

    height: float
    """ Control how much mist density decreases with height (in [0, 100], default 0.0)"""

    intensity: float
    """ Overall minimum intensity of the mist effect (in [0, 1], default 0.0)"""

    start: float
    """ Starting distance of the mist, measured from the camera (in [0, inf], default 5.0)"""

    use_mist: bool
    """ Occlude objects with the environment color as they are further away (default False)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMap(bpy_struct):
    actionmap_items: typing.Any
    """ Items in the action map, mapping an XR event to an operator, pose, or haptic output (default None, readonly)"""

    name: str
    """ Name of the action map (default "", never None)"""

    selected_item: int
    """ (in [-32768, 32767], default 0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMapBinding(bpy_struct):
    """Binding in an XR action map item"""

    axis0_region: typing.Literal["ANY", "POSITIVE", "NEGATIVE"]
    """ Action execution region for the first input axis (default 'ANY')"""

    axis1_region: typing.Literal["ANY", "POSITIVE", "NEGATIVE"]
    """ Action execution region for the second input axis (default 'ANY')"""

    component_paths: typing.Any
    """ OpenXR component paths (default None, readonly)"""

    name: str
    """ Name of the action map binding (default "", never None)"""

    pose_location: mathutils.Vector
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    pose_rotation: mathutils.Euler
    """ (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    profile: str
    """ OpenXR interaction profile path (default "", never None)"""

    threshold: float
    """ Input threshold for button/axis actions (in [0, 1], default 0.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrActionMapItem(bpy_struct):
    bimanual: bool
    """ The action depends on the states/poses of both user paths (default False)"""

    bindings: typing.Any
    """ Bindings for the action map item, mapping the action to an XR input (default None, readonly)"""

    haptic_amplitude: float
    """ Intensity of the haptic vibration, ranging from 0.0 to 1.0 (in [0, 1], default 0.0)"""

    haptic_duration: float
    """ Haptic duration in seconds. 0.0 is the minimum supported duration. (in [0, inf], default 0.0)"""

    haptic_frequency: float
    """ Frequency of the haptic vibration in hertz. 0.0 specifies the OpenXR runtime's default frequency. (in [0, inf], default 0.0)"""

    haptic_match_user_paths: bool
    """ Apply haptics to the same user paths for the haptic action and this action (default False)"""

    haptic_mode: typing.Literal["PRESS", "RELEASE", "PRESS_RELEASE", "REPEAT"]
    """ Haptic application mode (default 'PRESS')"""

    haptic_name: str
    """ Name of the haptic action to apply when executing this action (default "", never None)"""

    name: str
    """ Name of the action map item (default "", never None)"""

    op: str
    """ Identifier of operator to call on action event (default "", never None)"""

    op_mode: typing.Literal["PRESS", "RELEASE", "MODAL"]
    """ Operator execution mode (default 'PRESS')"""

    op_name: str
    """ Name of operator (translated) to call on action event (default "", readonly, never None)"""

    op_properties: OperatorProperties | None
    """ Properties to set when the operator is called (readonly)"""

    pose_is_controller_aim: bool
    """ The action poses will be used for the VR controller aims (default False)"""

    pose_is_controller_grip: bool
    """ The action poses will be used for the VR controller grips (default False)"""

    selected_binding: int
    """ Currently selected binding (in [-32768, 32767], default 0)"""

    type: typing.Literal["FLOAT", "VECTOR2D", "POSE", "VIBRATION"]
    """ Action type (default 'FLOAT')"""

    user_paths: typing.Any
    """ OpenXR user paths (default None, readonly)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrComponentPath(bpy_struct):
    path: str
    """ OpenXR component path (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrEventData(bpy_struct):
    """XR Data for Window Manager Event"""

    action: str
    """ XR action name (default "", readonly, never None)"""

    action_set: str
    """ XR action set name (default "", readonly, never None)"""

    bimanual: bool
    """ Whether bimanual interaction is occurring (default False, readonly)"""

    controller_location: mathutils.Vector
    """ Location of the action's corresponding controller aim in world space (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    controller_location_other: mathutils.Vector
    """ Controller aim location of the other user path for bimanual actions (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    controller_rotation: mathutils.Quaternion
    """ Rotation of the action's corresponding controller aim in world space (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    controller_rotation_other: mathutils.Quaternion
    """ Controller aim rotation of the other user path for bimanual actions (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    float_threshold: float
    """ Input threshold for float/2D vector actions (in [-inf, inf], default 0.0, readonly)"""

    state: typing.Any
    """ XR action values corresponding to type (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    state_other: typing.Any
    """ State of the other user path for bimanual actions (array of 2 items, in [-inf, inf], default (0.0, 0.0), readonly)"""

    type: typing.Literal["FLOAT", "VECTOR2D", "POSE", "VIBRATION"]
    """ XR action type (default 'FLOAT', readonly)"""

    user_path: str
    """ User path of the action. E.g. "/user/hand/left" (default "", readonly, never None)"""

    user_path_other: str
    """ Other user path, for bimanual actions. E.g. "/user/hand/right" (default "", readonly, never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrNavigation(bpy_struct):
    """VR navigation settings"""

    invert_rotation: bool
    """ Reverses the direction of rotation input (default False)"""

    snap_turn: bool
    """ Instantly rotates the camera by a fixed angle instead of smoothly turning (default True)"""

    turn_amount: float
    """ Amount in degrees per turn when using snap turn (in [0, 6.28319], default 0.523599)"""

    turn_speed: float
    """ Turn speed in degrees per second (in [0, inf], default 1.0472)"""

    vignette_intensity: float
    """ Intensity of vignette that appears when moving (in [0, 100], default 70.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrSessionSettings(bpy_struct):
    base_pose_angle: float
    """ Rotation angle around the Z-Axis to apply the rotation deltas from the VR headset to (in [-inf, inf], default 0.0)"""

    base_pose_location: mathutils.Vector
    """ Coordinates to apply translation deltas from the VR headset to (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    base_pose_object: Object | None
    """ Object to take the location and rotation to which translation and rotation deltas from the VR headset will be applied to"""

    base_pose_type: typing.Literal["SCENE_CAMERA", "OBJECT", "CUSTOM"]
    """ Define where the location and rotation for the VR view come from, to which translation and rotation deltas from the VR headset will be applied to (default 'SCENE_CAMERA')"""

    base_scale: float
    """ Uniform scale to apply to VR view (in [1e-06, inf], default 1.0)"""

    clip_end: float
    """ VR viewport far clipping distance (in [1e-06, inf], default 0.0)"""

    clip_start: float
    """ VR viewport near clipping distance (in [1e-06, inf], default 0.0)"""

    controller_draw_style: typing.Literal["DARK", "LIGHT", "DARK_RAY", "LIGHT_RAY"]
    """ Style to use when drawing VR controllers (default 'DARK')"""

    fly_speed: float
    """ Fly speed in meters per second (in [1e-06, inf], default 0.0)"""

    icon_from_show_object_viewport: int
    """ (in [-inf, inf], default 0, readonly)"""

    shading: View3DShading | None
    """ (readonly, never None)"""

    show_annotation: bool
    """ Show annotations for this view (default False)"""

    show_controllers: bool
    """ Show VR controllers (requires VR actions for controller poses) (default False)"""

    show_custom_overlays: bool
    """ Show custom VR overlays (default False)"""

    show_floor: bool
    """ Show the ground plane grid (default False)"""

    show_object_extras: bool
    """ Show object extras, including empties, lights, and cameras (default False)"""

    show_object_select_armature: bool
    """ Allow selection of armatures (default True)"""

    show_object_select_camera: bool
    """ Allow selection of cameras (default True)"""

    show_object_select_curve: bool
    """ Allow selection of curves (default True)"""

    show_object_select_curves: bool
    """ Allow selection of hair curves (default True)"""

    show_object_select_empty: bool
    """ Allow selection of empties (default True)"""

    show_object_select_font: bool
    """ Allow selection of text objects (default True)"""

    show_object_select_grease_pencil: bool
    """ Allow selection of Grease Pencil objects (default True)"""

    show_object_select_lattice: bool
    """ Allow selection of lattices (default True)"""

    show_object_select_light: bool
    """ Allow selection of lights (default True)"""

    show_object_select_light_probe: bool
    """ Allow selection of light probes (default True)"""

    show_object_select_mesh: bool
    """ Allow selection of mesh objects (default True)"""

    show_object_select_meta: bool
    """ Allow selection of metaballs (default True)"""

    show_object_select_pointcloud: bool
    """ Allow selection of point clouds (default True)"""

    show_object_select_speaker: bool
    """ Allow selection of speakers (default True)"""

    show_object_select_surf: bool
    """ Allow selection of surfaces (default True)"""

    show_object_select_volume: bool
    """ Allow selection of volumes (default True)"""

    show_object_viewport_armature: bool
    """ Show armatures (default True)"""

    show_object_viewport_camera: bool
    """ Show cameras (default True)"""

    show_object_viewport_curve: bool
    """ Show curves (default True)"""

    show_object_viewport_curves: bool
    """ Show hair curves (default True)"""

    show_object_viewport_empty: bool
    """ Show empties (default True)"""

    show_object_viewport_font: bool
    """ Show text objects (default True)"""

    show_object_viewport_grease_pencil: bool
    """ Show Grease Pencil objects (default True)"""

    show_object_viewport_lattice: bool
    """ Show lattices (default True)"""

    show_object_viewport_light: bool
    """ Show lights (default True)"""

    show_object_viewport_light_probe: bool
    """ Show light probes (default True)"""

    show_object_viewport_mesh: bool
    """ Show mesh objects (default True)"""

    show_object_viewport_meta: bool
    """ Show metaballs (default True)"""

    show_object_viewport_pointcloud: bool
    """ Show point clouds (default True)"""

    show_object_viewport_speaker: bool
    """ Show speakers (default True)"""

    show_object_viewport_surf: bool
    """ Show surfaces (default True)"""

    show_object_viewport_volume: bool
    """ Show volumes (default True)"""

    show_passthrough: bool
    """ Show the passthrough view (default False)"""

    show_selection: bool
    """ Show selection outlines (default False)"""

    use_absolute_tracking: bool
    """ Allow the VR tracking origin to be defined independently of the headset location (default False)"""

    use_positional_tracking: bool
    """ Allow VR headsets to affect the location in virtual space, in addition to the rotation (default False)"""

    view_scale: float
    """ Scaling factor applied on top of scene scale for adjustments to the VR view. When possible, prefer modifying the scene scale instead (in [1e-06, inf], default 1.0)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrSessionState(bpy_struct):
    """Runtime state information about the VR session"""

    actionmaps: typing.Any
    """ (default None, readonly)"""

    active_actionmap: int | None
    """ (in [-inf, inf], default 0)"""

    navigation_location: mathutils.Vector
    """ Location offset to apply to base pose when determining viewer location (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0))"""

    navigation_rotation: mathutils.Quaternion
    """ Rotation offset to apply to base pose when determining viewer rotation (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0))"""

    navigation_scale: float
    """ Additional scale multiplier to apply to base scale when determining viewer scale (in [-inf, inf], default 0.0, readonly)"""

    selected_actionmap: int
    """ (in [-inf, inf], default 0)"""

    viewer_pose_location: mathutils.Vector
    """ Last known location of the viewer pose (center between the eyes) in world space (array of 3 items, in [-inf, inf], default (0.0, 0.0, 0.0), readonly)"""

    viewer_pose_rotation: mathutils.Quaternion
    """ Last known rotation of the viewer pose (center between the eyes) in world space (array of 4 items, in [-inf, inf], default (0.0, 0.0, 0.0, 0.0), readonly)"""

    @classmethod
    def is_running(cls, context: Context) -> bool:
        """Query if the VR session is currently running

        :param context: (never None)
        :return: Result
        """

    @classmethod
    def reset_to_base_pose(cls, context: Context) -> None:
        """Force resetting of position and rotation deltas

        :param context: (never None)
        """

    @classmethod
    def action_set_create(cls, context: Context, actionmap: XrActionMap | None) -> bool:
        """Create a VR action set

        :param context: (never None)
        :param actionmap: (never None)
        :return: Result
        """

    @classmethod
    def action_create(
        cls,
        context: Context,
        actionmap: XrActionMap | None,
        actionmap_item: XrActionMapItem | None,
    ) -> bool:
        """Create a VR action

        :param context: (never None)
        :param actionmap: (never None)
        :param actionmap_item: (never None)
        :return: Result
        """

    @classmethod
    def action_binding_create(
        cls,
        context: Context,
        actionmap: XrActionMap | None,
        actionmap_item: XrActionMapItem | None,
        actionmap_binding: XrActionMapBinding | None,
    ) -> bool:
        """Create a VR action binding

        :param context: (never None)
        :param actionmap: (never None)
        :param actionmap_item: (never None)
        :param actionmap_binding: (never None)
        :return: Result
        """

    @classmethod
    def active_action_set_set(cls, context: Context, action_set: str | None) -> bool:
        """Set the active VR action set

        :param context: (never None)
        :param action_set: Action Set, Action set name (never None)
        :return: Result
        """

    @classmethod
    def controller_pose_actions_set(
        cls,
        context: Context,
        action_set: str | None,
        grip_action: str | None,
        aim_action: str | None,
    ) -> bool:
        """Set the actions that determine the VR controller poses

        :param context: (never None)
        :param action_set: Action Set, Action set name (never None)
        :param grip_action: Grip Action, Name of the action representing the controller grips (never None)
        :param aim_action: Aim Action, Name of the action representing the controller aims (never None)
        :return: Result
        """

    @classmethod
    def action_state_get(
        cls,
        context: Context,
        action_set_name: str | None,
        action_name: str | None,
        user_path: str | None,
    ) -> None:
        """Get the current state of a VR action

        :param context: (never None)
        :param action_set_name: Action Set, Action set name (never None)
        :param action_name: Action, Action name (never None)
        :param user_path: User Path, OpenXR user path (never None)
        :return: Action State, Current state of the VR action. Second float value is only set for 2D vector type actions. (array of 2 items, in [-inf, inf], never None)
        """

    @classmethod
    def haptic_action_apply(
        cls,
        context: Context,
        action_set_name: str | None,
        action_name: str | None,
        user_path: str | None,
        duration: float | None,
        frequency: float | None,
        amplitude: float | None,
    ) -> bool:
        """Apply a VR haptic action

        :param context: (never None)
        :param action_set_name: Action Set, Action set name (never None)
        :param action_name: Action, Action name (never None)
        :param user_path: User Path, Optional OpenXR user path. If not set, the action will be applied to all paths. (never None)
        :param duration: Duration, Haptic duration in seconds. 0.0 is the minimum supported duration. (in [0, inf])
        :param frequency: Frequency, Frequency of the haptic vibration in hertz. 0.0 specifies the OpenXR runtimes default frequency. (in [0, inf])
        :param amplitude: Amplitude, Haptic amplitude, ranging from 0.0 to 1.0 (in [0, 1])
        :return: Result
        """

    @classmethod
    def haptic_action_stop(
        cls,
        context: Context,
        action_set_name: str | None,
        action_name: str | None,
        user_path: str | None,
    ) -> None:
        """Stop a VR haptic action

        :param context: (never None)
        :param action_set_name: Action Set, Action set name (never None)
        :param action_name: Action, Action name (never None)
        :param user_path: User Path, Optional OpenXR user path. If not set, the action will be stopped for all paths. (never None)
        """

    @classmethod
    def controller_grip_location_get(
        cls, context: Context, index: int | None
    ) -> mathutils.Vector:
        """Get the last known controller grip location in world space

        :param context: (never None)
        :param index: Index, Controller index (in [0, 255])
        :return: Location, Controller grip location (array of 3 items, in [-inf, inf], never None)
        """

    @classmethod
    def controller_grip_rotation_get(
        cls, context: Context, index: int | None
    ) -> mathutils.Quaternion:
        """Get the last known controller grip rotation (quaternion) in world space

        :param context: (never None)
        :param index: Index, Controller index (in [0, 255])
        :return: Rotation, Controller grip quaternion rotation (array of 4 items, in [-inf, inf], never None)
        """

    @classmethod
    def controller_aim_location_get(
        cls, context: Context, index: int | None
    ) -> mathutils.Vector:
        """Get the last known controller aim location in world space

        :param context: (never None)
        :param index: Index, Controller index (in [0, 255])
        :return: Location, Controller aim location (array of 3 items, in [-inf, inf], never None)
        """

    @classmethod
    def controller_aim_rotation_get(
        cls, context: Context, index: int | None
    ) -> mathutils.Quaternion:
        """Get the last known controller aim rotation (quaternion) in world space

        :param context: (never None)
        :param index: Index, Controller index (in [0, 255])
        :return: Rotation, Controller aim quaternion rotation (array of 4 items, in [-inf, inf], never None)
        """

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class XrUserPath(bpy_struct):
    path: str
    """ OpenXR user path (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class wmOwnerID(bpy_struct):
    name: str
    """ (default "", never None)"""

    @classmethod
    def bl_rna_get_subclass(
        cls,
        id: str | None,
        default: None | Struct | None = None,
        /,
    ) -> Struct:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The RNA type or default when not found.
        """

    @classmethod
    def bl_rna_get_subclass_py(
        cls,
        id: str | None,
        default: None | typing.Any | None = None,
        /,
    ) -> typing.Any:
        """

        :param id: The RNA type identifier.
        :param default: The value to return when not found.
        :return: The class or default when not found.
        """

class bpy_prop_collection_idprop[_GenericType1](bpy_prop_collection):
    """built-in class used for user defined collections."""

    def add(self) -> _GenericType1:
        """This is a function to add a new item to a collection.

        :return: A newly created item.
        """

    def clear(self) -> None:
        """This is a function to remove all items from a collection."""

    def move(self, src_index: int | None, dst_index: int | None) -> None:
        """This is a function to move an item in a collection.

        :param src_index: Source item index.
        :param dst_index: Destination item index.
        """

    def remove(self, index: int | None) -> None:
        """This is a function to remove an item from a collection.

        :param index: Index of the item to be removed.
        """

    @typing.overload
    def __getitem__(self, key: int | str) -> _GenericType1:
        """

        :param key:
        :return:
        """

    @typing.overload
    def __getitem__(self, key: slice) -> list[_GenericType1]:
        """

        :param key:
        :return:
        """

    def __setitem__(self, key: int | str, value: _GenericType1 | None) -> None:
        """

        :param key:
        :param value:
        """

    @typing.overload
    def __setitem__(self, key: int, value: _GenericType1 | None) -> None:
        """

        :param key:
        :param value:
        """

    @typing.overload
    def __setitem__(self, key: str, value: _GenericType1) -> None:
        """

        :param key:
        :param value:
        """

    def __iter__(self) -> collections.abc.Iterator[_GenericType1]:
        """

        :return:
        """

    def __next__(self) -> _GenericType1:
        """

        :return:
        """

    def __len__(self) -> int:
        """

        :return:
        """

    def __contains__(self, key: str | tuple[str, ...] | _GenericType1) -> bool:
        """

        :param key:
        :return:
        """

    def get[_GenericType2](
        self, key: str, default: _GenericType2 = None
    ) -> _GenericType1 | _GenericType2:
        """

        :param key:
        :param default:
        :return:
        """

    def values(self) -> list[_GenericType1]:
        """

        :return:
        """

    def items(self) -> list[tuple[str, _GenericType1]]:
        """

        :return:
        """

ANIM_MT_keyframe_insert_pie: bl_ui.anim.ANIM_MT_keyframe_insert_pie

ANIM_OT_keying_set_export: bl_operators.anim.ANIM_OT_keying_set_export

ANIM_OT_slot_new_for_id: bl_operators.anim.ANIM_OT_slot_new_for_id

ANIM_OT_slot_unassign_from_constraint: bl_operators.anim.ANIM_OT_slot_unassign_from_constraint

ANIM_OT_slot_unassign_from_id: bl_operators.anim.ANIM_OT_slot_unassign_from_id

ANIM_OT_slot_unassign_from_nla_strip: bl_operators.anim.ANIM_OT_slot_unassign_from_nla_strip

ANIM_OT_version_bone_hide_property: bl_operators.anim.ANIM_OT_version_bone_hide_property

ARMATURE_MT_collection_context_menu: bl_ui.properties_data_armature.ARMATURE_MT_collection_context_menu

ARMATURE_MT_collection_tree_context_menu: bl_ui.properties_data_armature.ARMATURE_MT_collection_tree_context_menu

ARMATURE_OT_collection_remove_unused: bl_operators.anim.ARMATURE_OT_collection_remove_unused

ARMATURE_OT_collection_show_all: bl_operators.anim.ARMATURE_OT_collection_show_all

ARMATURE_OT_collection_unsolo_all: bl_operators.anim.ARMATURE_OT_collection_unsolo_all

ARMATURE_OT_copy_bone_color_to_selected: bl_operators.anim.ARMATURE_OT_copy_bone_color_to_selected

ASSETBROWSER_MT_catalog: bl_ui.space_filebrowser.ASSETBROWSER_MT_catalog

ASSETBROWSER_MT_context_menu: bl_ui.space_filebrowser.ASSETBROWSER_MT_context_menu

ASSETBROWSER_MT_editor_menus: bl_ui.space_filebrowser.ASSETBROWSER_MT_editor_menus

ASSETBROWSER_MT_metadata_preview_menu: bl_ui.space_filebrowser.ASSETBROWSER_MT_metadata_preview_menu

ASSETBROWSER_MT_select: bl_ui.space_filebrowser.ASSETBROWSER_MT_select

ASSETBROWSER_MT_view: bl_ui.space_filebrowser.ASSETBROWSER_MT_view

ASSETBROWSER_PT_display: bl_ui.space_filebrowser.ASSETBROWSER_PT_display

ASSETBROWSER_PT_filter: bl_ui.space_filebrowser.ASSETBROWSER_PT_filter

ASSETBROWSER_PT_import_settings: bl_ui.space_filebrowser.ASSETBROWSER_PT_import_settings

ASSETBROWSER_PT_metadata: bl_ui.space_filebrowser.ASSETBROWSER_PT_metadata

ASSETBROWSER_PT_metadata_preview: bl_ui.space_filebrowser.ASSETBROWSER_PT_metadata_preview

ASSETBROWSER_PT_metadata_tags: bl_ui.space_filebrowser.ASSETBROWSER_PT_metadata_tags

ASSETBROWSER_UL_metadata_tags: bl_ui.space_filebrowser.ASSETBROWSER_UL_metadata_tags

ASSETSHELF_PT_display: bl_ui.asset_shelf.ASSETSHELF_PT_display

ASSETSHELF_PT_filter: bl_ui.asset_shelf.ASSETSHELF_PT_filter

ASSET_OT_open_containing_blend_file: bl_operators.assets.ASSET_OT_open_containing_blend_file

ASSET_OT_tag_add: bl_operators.assets.ASSET_OT_tag_add

ASSET_OT_tag_remove: bl_operators.assets.ASSET_OT_tag_remove

BONE_PT_bActionConstraint: bl_ui.properties_constraint.BONE_PT_bActionConstraint

BONE_PT_bActionConstraint_action: bl_ui.properties_constraint.BONE_PT_bActionConstraint_action

BONE_PT_bActionConstraint_target: bl_ui.properties_constraint.BONE_PT_bActionConstraint_target

BONE_PT_bArmatureConstraint: bl_ui.properties_constraint.BONE_PT_bArmatureConstraint

BONE_PT_bArmatureConstraint_bones: bl_ui.properties_constraint.BONE_PT_bArmatureConstraint_bones

BONE_PT_bCameraSolverConstraint: bl_ui.properties_constraint.BONE_PT_bCameraSolverConstraint

BONE_PT_bChildOfConstraint: bl_ui.properties_constraint.BONE_PT_bChildOfConstraint

BONE_PT_bClampToConstraint: bl_ui.properties_constraint.BONE_PT_bClampToConstraint

BONE_PT_bDampTrackConstraint: bl_ui.properties_constraint.BONE_PT_bDampTrackConstraint

BONE_PT_bDistLimitConstraint: bl_ui.properties_constraint.BONE_PT_bDistLimitConstraint

BONE_PT_bFollowPathConstraint: bl_ui.properties_constraint.BONE_PT_bFollowPathConstraint

BONE_PT_bFollowTrackConstraint: bl_ui.properties_constraint.BONE_PT_bFollowTrackConstraint

BONE_PT_bGeometryAttributeConstraint: bl_ui.properties_constraint.BONE_PT_bGeometryAttributeConstraint

BONE_PT_bKinematicConstraint: bl_ui.properties_constraint.BONE_PT_bKinematicConstraint

BONE_PT_bLocLimitConstraint: bl_ui.properties_constraint.BONE_PT_bLocLimitConstraint

BONE_PT_bLocateLikeConstraint: bl_ui.properties_constraint.BONE_PT_bLocateLikeConstraint

BONE_PT_bLockTrackConstraint: bl_ui.properties_constraint.BONE_PT_bLockTrackConstraint

BONE_PT_bMinMaxConstraint: bl_ui.properties_constraint.BONE_PT_bMinMaxConstraint

BONE_PT_bObjectSolverConstraint: bl_ui.properties_constraint.BONE_PT_bObjectSolverConstraint

BONE_PT_bPivotConstraint: bl_ui.properties_constraint.BONE_PT_bPivotConstraint

BONE_PT_bRotLimitConstraint: bl_ui.properties_constraint.BONE_PT_bRotLimitConstraint

BONE_PT_bRotateLikeConstraint: bl_ui.properties_constraint.BONE_PT_bRotateLikeConstraint

BONE_PT_bSameVolumeConstraint: bl_ui.properties_constraint.BONE_PT_bSameVolumeConstraint

BONE_PT_bShrinkwrapConstraint: bl_ui.properties_constraint.BONE_PT_bShrinkwrapConstraint

BONE_PT_bSizeLikeConstraint: bl_ui.properties_constraint.BONE_PT_bSizeLikeConstraint

BONE_PT_bSizeLimitConstraint: bl_ui.properties_constraint.BONE_PT_bSizeLimitConstraint

BONE_PT_bSplineIKConstraint: bl_ui.properties_constraint.BONE_PT_bSplineIKConstraint

BONE_PT_bSplineIKConstraint_chain_scaling: bl_ui.properties_constraint.BONE_PT_bSplineIKConstraint_chain_scaling

BONE_PT_bSplineIKConstraint_fitting: bl_ui.properties_constraint.BONE_PT_bSplineIKConstraint_fitting

BONE_PT_bStretchToConstraint: bl_ui.properties_constraint.BONE_PT_bStretchToConstraint

BONE_PT_bTrackToConstraint: bl_ui.properties_constraint.BONE_PT_bTrackToConstraint

BONE_PT_bTransLikeConstraint: bl_ui.properties_constraint.BONE_PT_bTransLikeConstraint

BONE_PT_bTransformCacheConstraint: bl_ui.properties_constraint.BONE_PT_bTransformCacheConstraint

BONE_PT_bTransformCacheConstraint_layers: bl_ui.properties_constraint.BONE_PT_bTransformCacheConstraint_layers

BONE_PT_bTransformCacheConstraint_time: bl_ui.properties_constraint.BONE_PT_bTransformCacheConstraint_time

BONE_PT_bTransformCacheConstraint_velocity: bl_ui.properties_constraint.BONE_PT_bTransformCacheConstraint_velocity

BONE_PT_bTransformConstraint: bl_ui.properties_constraint.BONE_PT_bTransformConstraint

BONE_PT_bTransformConstraint_from: bl_ui.properties_constraint.BONE_PT_bTransformConstraint_from

BONE_PT_bTransformConstraint_to: bl_ui.properties_constraint.BONE_PT_bTransformConstraint_to

BONE_PT_collections: bl_ui.properties_data_bone.BONE_PT_collections

BONE_PT_constraints: bl_ui.properties_constraint.BONE_PT_constraints

BONE_PT_context_bone: bl_ui.properties_data_bone.BONE_PT_context_bone

BONE_PT_curved: bl_ui.properties_data_bone.BONE_PT_curved

BONE_PT_custom_props: bl_ui.properties_data_bone.BONE_PT_custom_props

BONE_PT_deform: bl_ui.properties_data_bone.BONE_PT_deform

BONE_PT_display: bl_ui.properties_data_bone.BONE_PT_display

BONE_PT_display_custom_shape: bl_ui.properties_data_bone.BONE_PT_display_custom_shape

BONE_PT_inverse_kinematics: bl_ui.properties_data_bone.BONE_PT_inverse_kinematics

BONE_PT_relations: bl_ui.properties_data_bone.BONE_PT_relations

BONE_PT_transform: bl_ui.properties_data_bone.BONE_PT_transform

CAMERA_PT_presets: bl_ui.properties_data_camera.CAMERA_PT_presets

CAMERA_PT_safe_areas_presets: bl_ui.properties_data_camera.CAMERA_PT_safe_areas_presets

CLIP_HT_header: bl_ui.space_clip.CLIP_HT_header

CLIP_MT_clip: bl_ui.space_clip.CLIP_MT_clip

CLIP_MT_marker_pie: bl_ui.space_clip.CLIP_MT_marker_pie

CLIP_MT_masking_editor_menus: bl_ui.space_clip.CLIP_MT_masking_editor_menus

CLIP_MT_pivot_pie: bl_ui.space_clip.CLIP_MT_pivot_pie

CLIP_MT_plane_track_image_context_menu: bl_ui.space_clip.CLIP_MT_plane_track_image_context_menu

CLIP_MT_proxy: bl_ui.space_clip.CLIP_MT_proxy

CLIP_MT_reconstruction: bl_ui.space_clip.CLIP_MT_reconstruction

CLIP_MT_reconstruction_pie: bl_ui.space_clip.CLIP_MT_reconstruction_pie

CLIP_MT_select: bl_ui.space_clip.CLIP_MT_select

CLIP_MT_select_graph: bl_ui.space_clip.CLIP_MT_select_graph

CLIP_MT_select_grouped: bl_ui.space_clip.CLIP_MT_select_grouped

CLIP_MT_solving_pie: bl_ui.space_clip.CLIP_MT_solving_pie

CLIP_MT_stabilize_2d_context_menu: bl_ui.space_clip.CLIP_MT_stabilize_2d_context_menu

CLIP_MT_stabilize_2d_rotation_context_menu: bl_ui.space_clip.CLIP_MT_stabilize_2d_rotation_context_menu

CLIP_MT_track: bl_ui.space_clip.CLIP_MT_track

CLIP_MT_track_animation: bl_ui.space_clip.CLIP_MT_track_animation

CLIP_MT_track_cleanup: bl_ui.space_clip.CLIP_MT_track_cleanup

CLIP_MT_track_clear: bl_ui.space_clip.CLIP_MT_track_clear

CLIP_MT_track_motion: bl_ui.space_clip.CLIP_MT_track_motion

CLIP_MT_track_refine: bl_ui.space_clip.CLIP_MT_track_refine

CLIP_MT_track_transform: bl_ui.space_clip.CLIP_MT_track_transform

CLIP_MT_track_visibility: bl_ui.space_clip.CLIP_MT_track_visibility

CLIP_MT_tracking_context_menu: bl_ui.space_clip.CLIP_MT_tracking_context_menu

CLIP_MT_tracking_editor_menus: bl_ui.space_clip.CLIP_MT_tracking_editor_menus

CLIP_MT_tracking_pie: bl_ui.space_clip.CLIP_MT_tracking_pie

CLIP_MT_view: bl_ui.space_clip.CLIP_MT_view

CLIP_MT_view_pie: bl_ui.space_clip.CLIP_MT_view_pie

CLIP_MT_view_zoom: bl_ui.space_clip.CLIP_MT_view_zoom

CLIP_OT_bundles_to_mesh: bl_operators.clip.CLIP_OT_bundles_to_mesh

CLIP_OT_constraint_to_fcurve: bl_operators.clip.CLIP_OT_constraint_to_fcurve

CLIP_OT_delete_proxy: bl_operators.clip.CLIP_OT_delete_proxy

CLIP_OT_filter_tracks: bl_operators.clip.CLIP_OT_filter_tracks

CLIP_OT_set_active_clip: bl_operators.clip.CLIP_OT_set_active_clip

CLIP_OT_set_viewport_background: bl_operators.clip.CLIP_OT_set_viewport_background

CLIP_OT_setup_tracking_scene: bl_operators.clip.CLIP_OT_setup_tracking_scene

CLIP_OT_track_settings_as_default: bl_operators.clip.CLIP_OT_track_settings_as_default

CLIP_OT_track_settings_to_track: bl_operators.clip.CLIP_OT_track_settings_to_track

CLIP_OT_track_to_empty: bl_operators.clip.CLIP_OT_track_to_empty

CLIP_PT_2d_cursor: bl_ui.space_clip.CLIP_PT_2d_cursor

CLIP_PT_active_mask_point: bl_ui.space_clip.CLIP_PT_active_mask_point

CLIP_PT_active_mask_spline: bl_ui.space_clip.CLIP_PT_active_mask_spline

CLIP_PT_animation: bl_ui.space_clip.CLIP_PT_animation

CLIP_PT_annotation: bl_ui.space_clip.CLIP_PT_annotation

CLIP_PT_camera_presets: bl_ui.space_clip.CLIP_PT_camera_presets

CLIP_PT_clip_display: bl_ui.space_clip.CLIP_PT_clip_display

CLIP_PT_display: bl_ui.space_clip.CLIP_PT_display

CLIP_PT_footage: bl_ui.space_clip.CLIP_PT_footage

CLIP_PT_gizmo_display: bl_ui.space_clip.CLIP_PT_gizmo_display

CLIP_PT_marker: bl_ui.space_clip.CLIP_PT_marker

CLIP_PT_mask: bl_ui.space_clip.CLIP_PT_mask

CLIP_PT_mask_animation: bl_ui.space_clip.CLIP_PT_mask_animation

CLIP_PT_mask_layers: bl_ui.space_clip.CLIP_PT_mask_layers

CLIP_PT_objects: bl_ui.space_clip.CLIP_PT_objects

CLIP_PT_overlay: bl_ui.space_clip.CLIP_PT_overlay

CLIP_PT_overlay_display: bl_ui.space_clip.CLIP_PT_overlay_display

CLIP_PT_overlay_guides: bl_ui.space_clip.CLIP_PT_overlay_guides

CLIP_PT_overlay_mask: bl_ui.space_clip.CLIP_PT_overlay_mask

CLIP_PT_plane_track: bl_ui.space_clip.CLIP_PT_plane_track

CLIP_PT_proportional_edit: bl_ui.space_clip.CLIP_PT_proportional_edit

CLIP_PT_proxy: bl_ui.space_clip.CLIP_PT_proxy

CLIP_PT_stabilization: bl_ui.space_clip.CLIP_PT_stabilization

CLIP_PT_tools_cleanup: bl_ui.space_clip.CLIP_PT_tools_cleanup

CLIP_PT_tools_clip: bl_ui.space_clip.CLIP_PT_tools_clip

CLIP_PT_tools_geometry: bl_ui.space_clip.CLIP_PT_tools_geometry

CLIP_PT_tools_grease_pencil_draw: bl_ui.space_clip.CLIP_PT_tools_grease_pencil_draw

CLIP_PT_tools_marker: bl_ui.space_clip.CLIP_PT_tools_marker

CLIP_PT_tools_mask_tools: bl_ui.space_clip.CLIP_PT_tools_mask_tools

CLIP_PT_tools_mask_transforms: bl_ui.space_clip.CLIP_PT_tools_mask_transforms

CLIP_PT_tools_object: bl_ui.space_clip.CLIP_PT_tools_object

CLIP_PT_tools_orientation: bl_ui.space_clip.CLIP_PT_tools_orientation

CLIP_PT_tools_plane_tracking: bl_ui.space_clip.CLIP_PT_tools_plane_tracking

CLIP_PT_tools_scenesetup: bl_ui.space_clip.CLIP_PT_tools_scenesetup

CLIP_PT_tools_solve: bl_ui.space_clip.CLIP_PT_tools_solve

CLIP_PT_tools_tracking: bl_ui.space_clip.CLIP_PT_tools_tracking

CLIP_PT_track: bl_ui.space_clip.CLIP_PT_track

CLIP_PT_track_color_presets: bl_ui.space_clip.CLIP_PT_track_color_presets

CLIP_PT_track_settings: bl_ui.space_clip.CLIP_PT_track_settings

CLIP_PT_track_settings_extras: bl_ui.space_clip.CLIP_PT_track_settings_extras

CLIP_PT_tracking_camera: bl_ui.space_clip.CLIP_PT_tracking_camera

CLIP_PT_tracking_lens: bl_ui.space_clip.CLIP_PT_tracking_lens

CLIP_PT_tracking_settings: bl_ui.space_clip.CLIP_PT_tracking_settings

CLIP_PT_tracking_settings_extras: bl_ui.space_clip.CLIP_PT_tracking_settings_extras

CLIP_PT_tracking_settings_presets: bl_ui.space_clip.CLIP_PT_tracking_settings_presets

CLIP_UL_tracking_objects: bl_ui.space_clip.CLIP_UL_tracking_objects

CLOTH_PT_presets: bl_ui.properties_physics_cloth.CLOTH_PT_presets

COLLECTION_MT_context_menu: bl_ui.properties_object.COLLECTION_MT_context_menu

COLLECTION_MT_context_menu_instance_offset: bl_ui.properties_collection.COLLECTION_MT_context_menu_instance_offset

COLLECTION_PT_collection_custom_props: bl_ui.properties_collection.COLLECTION_PT_collection_custom_props

COLLECTION_PT_collection_flags: bl_ui.properties_collection.COLLECTION_PT_collection_flags

COLLECTION_PT_exporters: bl_ui.properties_collection.COLLECTION_PT_exporters

COLLECTION_PT_instancing: bl_ui.properties_collection.COLLECTION_PT_instancing

COLLECTION_PT_lineart_collection: bl_ui.properties_collection.COLLECTION_PT_lineart_collection

COLLECTION_PT_viewlayer_flags: bl_ui.properties_collection.COLLECTION_PT_viewlayer_flags

CONSOLE_HT_header: bl_ui.space_console.CONSOLE_HT_header

CONSOLE_MT_console: bl_ui.space_console.CONSOLE_MT_console

CONSOLE_MT_context_menu: bl_ui.space_console.CONSOLE_MT_context_menu

CONSOLE_MT_editor_menus: bl_ui.space_console.CONSOLE_MT_editor_menus

CONSOLE_MT_language: bl_ui.space_console.CONSOLE_MT_language

CONSOLE_MT_view: bl_ui.space_console.CONSOLE_MT_view

CONSTRAINT_OT_add_target: bl_operators.constraint.CONSTRAINT_OT_add_target

CONSTRAINT_OT_disable_keep_transform: bl_operators.constraint.CONSTRAINT_OT_disable_keep_transform

CONSTRAINT_OT_normalize_target_weights: bl_operators.constraint.CONSTRAINT_OT_normalize_target_weights

CONSTRAINT_OT_remove_target: bl_operators.constraint.CONSTRAINT_OT_remove_target

CURVES_MT_add_attribute: bl_ui.properties_data_curves.CURVES_MT_add_attribute

CURVES_MT_attribute_context_menu: bl_ui.properties_data_curves.CURVES_MT_attribute_context_menu

CURVES_UL_attributes: bl_ui.properties_data_curves.CURVES_UL_attributes

DATA_PT_CURVES_attributes: bl_ui.properties_data_curves.DATA_PT_CURVES_attributes

DATA_PT_EEVEE_light: bl_ui.properties_data_light.DATA_PT_EEVEE_light

DATA_PT_EEVEE_light_distance: bl_ui.properties_data_light.DATA_PT_EEVEE_light_distance

DATA_PT_EEVEE_light_influence: bl_ui.properties_data_light.DATA_PT_EEVEE_light_influence

DATA_PT_EEVEE_light_shadow: bl_ui.properties_data_light.DATA_PT_EEVEE_light_shadow

DATA_PT_armature_animation: bl_ui.properties_data_armature.DATA_PT_armature_animation

DATA_PT_bone_collections: bl_ui.properties_data_armature.DATA_PT_bone_collections

DATA_PT_camera: bl_ui.properties_data_camera.DATA_PT_camera

DATA_PT_camera_animation: bl_ui.properties_data_camera.DATA_PT_camera_animation

DATA_PT_camera_background_image: bl_ui.properties_data_camera.DATA_PT_camera_background_image

DATA_PT_camera_display: bl_ui.properties_data_camera.DATA_PT_camera_display

DATA_PT_camera_display_composition_guides: bl_ui.properties_data_camera.DATA_PT_camera_display_composition_guides

DATA_PT_camera_dof: bl_ui.properties_data_camera.DATA_PT_camera_dof

DATA_PT_camera_dof_aperture: bl_ui.properties_data_camera.DATA_PT_camera_dof_aperture

DATA_PT_camera_safe_areas: bl_ui.properties_data_camera.DATA_PT_camera_safe_areas

DATA_PT_camera_safe_areas_center_cut: bl_ui.properties_data_camera.DATA_PT_camera_safe_areas_center_cut

DATA_PT_camera_stereoscopy: bl_ui.properties_data_camera.DATA_PT_camera_stereoscopy

DATA_PT_cone: bl_ui.properties_data_speaker.DATA_PT_cone

DATA_PT_context_arm: bl_ui.properties_data_armature.DATA_PT_context_arm

DATA_PT_context_camera: bl_ui.properties_data_camera.DATA_PT_context_camera

DATA_PT_context_curve: bl_ui.properties_data_curve.DATA_PT_context_curve

DATA_PT_context_curves: bl_ui.properties_data_curves.DATA_PT_context_curves

DATA_PT_context_grease_pencil: bl_ui.properties_data_grease_pencil.DATA_PT_context_grease_pencil

DATA_PT_context_lattice: bl_ui.properties_data_lattice.DATA_PT_context_lattice

DATA_PT_context_light: bl_ui.properties_data_light.DATA_PT_context_light

DATA_PT_context_lightprobe: bl_ui.properties_data_lightprobe.DATA_PT_context_lightprobe

DATA_PT_context_mesh: bl_ui.properties_data_mesh.DATA_PT_context_mesh

DATA_PT_context_metaball: bl_ui.properties_data_metaball.DATA_PT_context_metaball

DATA_PT_context_pointcloud: bl_ui.properties_data_pointcloud.DATA_PT_context_pointcloud

DATA_PT_context_speaker: bl_ui.properties_data_speaker.DATA_PT_context_speaker

DATA_PT_context_volume: bl_ui.properties_data_volume.DATA_PT_context_volume

DATA_PT_curve_animation: bl_ui.properties_data_curve.DATA_PT_curve_animation

DATA_PT_curve_texture_space: bl_ui.properties_data_curve.DATA_PT_curve_texture_space

DATA_PT_curves_animation: bl_ui.properties_data_curves.DATA_PT_curves_animation

DATA_PT_curves_surface: bl_ui.properties_data_curves.DATA_PT_curves_surface

DATA_PT_custom_props_arm: bl_ui.properties_data_armature.DATA_PT_custom_props_arm

DATA_PT_custom_props_bcoll: bl_ui.properties_data_armature.DATA_PT_custom_props_bcoll

DATA_PT_custom_props_camera: bl_ui.properties_data_camera.DATA_PT_custom_props_camera

DATA_PT_custom_props_curve: bl_ui.properties_data_curve.DATA_PT_custom_props_curve

DATA_PT_custom_props_curves: bl_ui.properties_data_curves.DATA_PT_custom_props_curves

DATA_PT_custom_props_lattice: bl_ui.properties_data_lattice.DATA_PT_custom_props_lattice

DATA_PT_custom_props_light: bl_ui.properties_data_light.DATA_PT_custom_props_light

DATA_PT_custom_props_mesh: bl_ui.properties_data_mesh.DATA_PT_custom_props_mesh

DATA_PT_custom_props_metaball: bl_ui.properties_data_metaball.DATA_PT_custom_props_metaball

DATA_PT_custom_props_pointcloud: bl_ui.properties_data_pointcloud.DATA_PT_custom_props_pointcloud

DATA_PT_custom_props_speaker: bl_ui.properties_data_speaker.DATA_PT_custom_props_speaker

DATA_PT_custom_props_volume: bl_ui.properties_data_volume.DATA_PT_custom_props_volume

DATA_PT_customdata: bl_ui.properties_data_mesh.DATA_PT_customdata

DATA_PT_display: bl_ui.properties_data_armature.DATA_PT_display

DATA_PT_distance: bl_ui.properties_data_speaker.DATA_PT_distance

DATA_PT_empty: bl_ui.properties_data_empty.DATA_PT_empty

DATA_PT_empty_image: bl_ui.properties_data_empty.DATA_PT_empty_image

DATA_PT_font: bl_ui.properties_data_curve.DATA_PT_font

DATA_PT_font_transform: bl_ui.properties_data_curve.DATA_PT_font_transform

DATA_PT_geometry_curve: bl_ui.properties_data_curve.DATA_PT_geometry_curve

DATA_PT_geometry_curve_bevel: bl_ui.properties_data_curve.DATA_PT_geometry_curve_bevel

DATA_PT_geometry_curve_start_end: bl_ui.properties_data_curve.DATA_PT_geometry_curve_start_end

DATA_PT_grease_pencil_animation: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_animation

DATA_PT_grease_pencil_attributes: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_attributes

DATA_PT_grease_pencil_custom_props: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_custom_props

DATA_PT_grease_pencil_layer_adjustments: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_adjustments

DATA_PT_grease_pencil_layer_display: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_display

DATA_PT_grease_pencil_layer_group_display: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_group_display

DATA_PT_grease_pencil_layer_masks: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_masks

DATA_PT_grease_pencil_layer_relations: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_relations

DATA_PT_grease_pencil_layer_transform: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layer_transform

DATA_PT_grease_pencil_layers: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_layers

DATA_PT_grease_pencil_onion_skinning: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_onion_skinning

DATA_PT_grease_pencil_onion_skinning_custom_colors: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_onion_skinning_custom_colors

DATA_PT_grease_pencil_onion_skinning_display: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_onion_skinning_display

DATA_PT_grease_pencil_settings: bl_ui.properties_data_grease_pencil.DATA_PT_grease_pencil_settings

DATA_PT_iksolver_itasc: bl_ui.properties_data_armature.DATA_PT_iksolver_itasc

DATA_PT_lattice: bl_ui.properties_data_lattice.DATA_PT_lattice

DATA_PT_lattice_animation: bl_ui.properties_data_lattice.DATA_PT_lattice_animation

DATA_PT_lens: bl_ui.properties_data_camera.DATA_PT_lens

DATA_PT_light: bl_ui.properties_data_light.DATA_PT_light

DATA_PT_light_animation: bl_ui.properties_data_light.DATA_PT_light_animation

DATA_PT_lightprobe: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe

DATA_PT_lightprobe_animation: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_animation

DATA_PT_lightprobe_bake: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_bake

DATA_PT_lightprobe_bake_capture: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_bake_capture

DATA_PT_lightprobe_bake_clamping: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_bake_clamping

DATA_PT_lightprobe_bake_offset: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_bake_offset

DATA_PT_lightprobe_bake_resolution: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_bake_resolution

DATA_PT_lightprobe_capture: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_capture

DATA_PT_lightprobe_display: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_display

DATA_PT_lightprobe_display_eevee: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_display_eevee

DATA_PT_lightprobe_eevee: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_eevee

DATA_PT_lightprobe_parallax: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_parallax

DATA_PT_lightprobe_visibility: bl_ui.properties_data_lightprobe.DATA_PT_lightprobe_visibility

DATA_PT_mball_texture_space: bl_ui.properties_data_metaball.DATA_PT_mball_texture_space

DATA_PT_mesh_animation: bl_ui.properties_data_mesh.DATA_PT_mesh_animation

DATA_PT_mesh_attributes: bl_ui.properties_data_mesh.DATA_PT_mesh_attributes

DATA_PT_metaball: bl_ui.properties_data_metaball.DATA_PT_metaball

DATA_PT_metaball_animation: bl_ui.properties_data_metaball.DATA_PT_metaball_animation

DATA_PT_metaball_element: bl_ui.properties_data_metaball.DATA_PT_metaball_element

DATA_PT_modifiers: bl_ui.properties_data_modifier.DATA_PT_modifiers

DATA_PT_motion_paths: bl_ui.properties_data_armature.DATA_PT_motion_paths

DATA_PT_motion_paths_display: bl_ui.properties_data_armature.DATA_PT_motion_paths_display

DATA_PT_paragraph: bl_ui.properties_data_curve.DATA_PT_paragraph

DATA_PT_paragraph_alignment: bl_ui.properties_data_curve.DATA_PT_paragraph_alignment

DATA_PT_paragraph_spacing: bl_ui.properties_data_curve.DATA_PT_paragraph_spacing

DATA_PT_pathanim: bl_ui.properties_data_curve.DATA_PT_pathanim

DATA_PT_pointcloud_attributes: bl_ui.properties_data_pointcloud.DATA_PT_pointcloud_attributes

DATA_PT_pose: bl_ui.properties_data_armature.DATA_PT_pose

DATA_PT_preview: bl_ui.properties_data_light.DATA_PT_preview

DATA_PT_remesh: bl_ui.properties_data_mesh.DATA_PT_remesh

DATA_PT_shader_fx: bl_ui.properties_data_shaderfx.DATA_PT_shader_fx

DATA_PT_shape_curve: bl_ui.properties_data_curve.DATA_PT_shape_curve

DATA_PT_shape_keys: bl_ui.properties_data_mesh.DATA_PT_shape_keys

DATA_PT_speaker: bl_ui.properties_data_speaker.DATA_PT_speaker

DATA_PT_speaker_animation: bl_ui.properties_data_speaker.DATA_PT_speaker_animation

DATA_PT_spot: bl_ui.properties_data_light.DATA_PT_spot

DATA_PT_text_boxes: bl_ui.properties_data_curve.DATA_PT_text_boxes

DATA_PT_texture_space: bl_ui.properties_data_mesh.DATA_PT_texture_space

DATA_PT_uv_texture: bl_ui.properties_data_mesh.DATA_PT_uv_texture

DATA_PT_vertex_colors: bl_ui.properties_data_mesh.DATA_PT_vertex_colors

DATA_PT_vertex_groups: bl_ui.properties_data_mesh.DATA_PT_vertex_groups

DATA_PT_volume_animation: bl_ui.properties_data_volume.DATA_PT_volume_animation

DATA_PT_volume_file: bl_ui.properties_data_volume.DATA_PT_volume_file

DATA_PT_volume_grids: bl_ui.properties_data_volume.DATA_PT_volume_grids

DATA_PT_volume_render: bl_ui.properties_data_volume.DATA_PT_volume_render

DATA_PT_volume_viewport_display: bl_ui.properties_data_volume.DATA_PT_volume_viewport_display

DATA_PT_volume_viewport_display_slicing: bl_ui.properties_data_volume.DATA_PT_volume_viewport_display_slicing

DATA_UL_bone_collections: bl_ui.properties_data_armature.DATA_UL_bone_collections

DOPESHEET_HT_header: bl_ui.space_dopesheet.DOPESHEET_HT_header

DOPESHEET_HT_playback_controls: bl_ui.space_dopesheet.DOPESHEET_HT_playback_controls

DOPESHEET_MT_action: bl_ui.space_dopesheet.DOPESHEET_MT_action

DOPESHEET_MT_cache: bl_ui.space_dopesheet.DOPESHEET_MT_cache

DOPESHEET_MT_channel: bl_ui.space_dopesheet.DOPESHEET_MT_channel

DOPESHEET_MT_channel_context_menu: bl_ui.space_dopesheet.DOPESHEET_MT_channel_context_menu

DOPESHEET_MT_context_menu: bl_ui.space_dopesheet.DOPESHEET_MT_context_menu

DOPESHEET_MT_delete: bl_ui.space_dopesheet.DOPESHEET_MT_delete

DOPESHEET_MT_editor_menus: bl_ui.space_dopesheet.DOPESHEET_MT_editor_menus

DOPESHEET_MT_gpencil_channel: bl_ui.space_dopesheet.DOPESHEET_MT_gpencil_channel

DOPESHEET_MT_key: bl_ui.space_dopesheet.DOPESHEET_MT_key

DOPESHEET_MT_key_transform: bl_ui.space_dopesheet.DOPESHEET_MT_key_transform

DOPESHEET_MT_marker: bl_ui.space_dopesheet.DOPESHEET_MT_marker

DOPESHEET_MT_select: bl_ui.space_dopesheet.DOPESHEET_MT_select

DOPESHEET_MT_snap_pie: bl_ui.space_dopesheet.DOPESHEET_MT_snap_pie

DOPESHEET_MT_view: bl_ui.space_dopesheet.DOPESHEET_MT_view

DOPESHEET_MT_view_pie: bl_ui.space_dopesheet.DOPESHEET_MT_view_pie

DOPESHEET_PT_ShapeKey: bl_ui.space_dopesheet.DOPESHEET_PT_ShapeKey

DOPESHEET_PT_action: bl_ui.space_dopesheet.DOPESHEET_PT_action

DOPESHEET_PT_action_slot: bl_ui.space_dopesheet.DOPESHEET_PT_action_slot

DOPESHEET_PT_custom_props_action: bl_ui.space_dopesheet.DOPESHEET_PT_custom_props_action

DOPESHEET_PT_dopesheet_overlay: bl_ui.space_dopesheet.DOPESHEET_PT_dopesheet_overlay

DOPESHEET_PT_filters: bl_ui.space_dopesheet.DOPESHEET_PT_filters

DOPESHEET_PT_grease_pencil_layer_adjustments: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_layer_adjustments

DOPESHEET_PT_grease_pencil_layer_display: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_layer_display

DOPESHEET_PT_grease_pencil_layer_masks: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_layer_masks

DOPESHEET_PT_grease_pencil_layer_relations: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_layer_relations

DOPESHEET_PT_grease_pencil_layer_transform: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_layer_transform

DOPESHEET_PT_grease_pencil_mode: bl_ui.space_dopesheet.DOPESHEET_PT_grease_pencil_mode

DOPESHEET_PT_overlay: bl_ui.space_dopesheet.DOPESHEET_PT_overlay

DOPESHEET_PT_proportional_edit: bl_ui.space_dopesheet.DOPESHEET_PT_proportional_edit

DOPESHEET_PT_snapping: bl_ui.space_dopesheet.DOPESHEET_PT_snapping

EEVEE_MATERIAL_PT_context_material: bl_ui.properties_material.EEVEE_MATERIAL_PT_context_material

EEVEE_MATERIAL_PT_displacement: bl_ui.properties_material.EEVEE_MATERIAL_PT_displacement

EEVEE_MATERIAL_PT_settings: bl_ui.properties_material.EEVEE_MATERIAL_PT_settings

EEVEE_MATERIAL_PT_settings_surface: bl_ui.properties_material.EEVEE_MATERIAL_PT_settings_surface

EEVEE_MATERIAL_PT_settings_volume: bl_ui.properties_material.EEVEE_MATERIAL_PT_settings_volume

EEVEE_MATERIAL_PT_surface: bl_ui.properties_material.EEVEE_MATERIAL_PT_surface

EEVEE_MATERIAL_PT_thickness: bl_ui.properties_material.EEVEE_MATERIAL_PT_thickness

EEVEE_MATERIAL_PT_viewport_settings: bl_ui.properties_material.EEVEE_MATERIAL_PT_viewport_settings

EEVEE_MATERIAL_PT_volume: bl_ui.properties_material.EEVEE_MATERIAL_PT_volume

EEVEE_WORLD_PT_lightprobe: bl_ui.properties_world.EEVEE_WORLD_PT_lightprobe

EEVEE_WORLD_PT_mist: bl_ui.properties_world.EEVEE_WORLD_PT_mist

EEVEE_WORLD_PT_settings: bl_ui.properties_world.EEVEE_WORLD_PT_settings

EEVEE_WORLD_PT_sun: bl_ui.properties_world.EEVEE_WORLD_PT_sun

EEVEE_WORLD_PT_sun_shadow: bl_ui.properties_world.EEVEE_WORLD_PT_sun_shadow

EEVEE_WORLD_PT_surface: bl_ui.properties_world.EEVEE_WORLD_PT_surface

EEVEE_WORLD_PT_volume: bl_ui.properties_world.EEVEE_WORLD_PT_volume

FILEBROWSER_HT_header: bl_ui.space_filebrowser.FILEBROWSER_HT_header

FILEBROWSER_MT_bookmarks_context_menu: bl_ui.space_filebrowser.FILEBROWSER_MT_bookmarks_context_menu

FILEBROWSER_MT_bookmarks_recents_specials_menu: bl_ui.space_filebrowser.FILEBROWSER_MT_bookmarks_recents_specials_menu

FILEBROWSER_MT_context_menu: bl_ui.space_filebrowser.FILEBROWSER_MT_context_menu

FILEBROWSER_MT_editor_menus: bl_ui.space_filebrowser.FILEBROWSER_MT_editor_menus

FILEBROWSER_MT_select: bl_ui.space_filebrowser.FILEBROWSER_MT_select

FILEBROWSER_MT_view: bl_ui.space_filebrowser.FILEBROWSER_MT_view

FILEBROWSER_MT_view_pie: bl_ui.space_filebrowser.FILEBROWSER_MT_view_pie

FILEBROWSER_PT_advanced_filter: bl_ui.space_filebrowser.FILEBROWSER_PT_advanced_filter

FILEBROWSER_PT_bookmarks_favorites: bl_ui.space_filebrowser.FILEBROWSER_PT_bookmarks_favorites

FILEBROWSER_PT_bookmarks_recents: bl_ui.space_filebrowser.FILEBROWSER_PT_bookmarks_recents

FILEBROWSER_PT_bookmarks_system: bl_ui.space_filebrowser.FILEBROWSER_PT_bookmarks_system

FILEBROWSER_PT_bookmarks_volumes: bl_ui.space_filebrowser.FILEBROWSER_PT_bookmarks_volumes

FILEBROWSER_PT_directory_path: bl_ui.space_filebrowser.FILEBROWSER_PT_directory_path

FILEBROWSER_PT_display: bl_ui.space_filebrowser.FILEBROWSER_PT_display

FILEBROWSER_PT_filter: bl_ui.space_filebrowser.FILEBROWSER_PT_filter

FILEBROWSER_UL_dir: bl_ui.space_filebrowser.FILEBROWSER_UL_dir

FLUID_PT_presets: bl_ui.properties_physics_fluid.FLUID_PT_presets

GPENCIL_UL_annotation_layer: bl_ui.properties_grease_pencil_common.GPENCIL_UL_annotation_layer

GPENCIL_UL_matslots: bl_ui.properties_material_gpencil.GPENCIL_UL_matslots

GRAPH_HT_header: bl_ui.space_graph.GRAPH_HT_header

GRAPH_HT_playback_controls: bl_ui.space_graph.GRAPH_HT_playback_controls

GRAPH_MT_channel: bl_ui.space_graph.GRAPH_MT_channel

GRAPH_MT_context_menu: bl_ui.space_graph.GRAPH_MT_context_menu

GRAPH_MT_delete: bl_ui.space_graph.GRAPH_MT_delete

GRAPH_MT_editor_menus: bl_ui.space_graph.GRAPH_MT_editor_menus

GRAPH_MT_key: bl_ui.space_graph.GRAPH_MT_key

GRAPH_MT_key_blending: bl_ui.space_graph.GRAPH_MT_key_blending

GRAPH_MT_key_density: bl_ui.space_graph.GRAPH_MT_key_density

GRAPH_MT_key_smoothing: bl_ui.space_graph.GRAPH_MT_key_smoothing

GRAPH_MT_key_snap: bl_ui.space_graph.GRAPH_MT_key_snap

GRAPH_MT_key_transform: bl_ui.space_graph.GRAPH_MT_key_transform

GRAPH_MT_marker: bl_ui.space_graph.GRAPH_MT_marker

GRAPH_MT_pivot_pie: bl_ui.space_graph.GRAPH_MT_pivot_pie

GRAPH_MT_select: bl_ui.space_graph.GRAPH_MT_select

GRAPH_MT_snap_pie: bl_ui.space_graph.GRAPH_MT_snap_pie

GRAPH_MT_view: bl_ui.space_graph.GRAPH_MT_view

GRAPH_MT_view_pie: bl_ui.space_graph.GRAPH_MT_view_pie

GRAPH_PT_driver_snapping: bl_ui.space_graph.GRAPH_PT_driver_snapping

GRAPH_PT_filters: bl_ui.space_graph.GRAPH_PT_filters

GRAPH_PT_proportional_edit: bl_ui.space_graph.GRAPH_PT_proportional_edit

GRAPH_PT_snapping: bl_ui.space_graph.GRAPH_PT_snapping

GREASE_PENCIL_MT_Layers: bl_ui.space_view3d.GREASE_PENCIL_MT_Layers

GREASE_PENCIL_MT_draw_delete: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_draw_delete

GREASE_PENCIL_MT_grease_pencil_add_layer_extra: bl_ui.properties_data_grease_pencil.GREASE_PENCIL_MT_grease_pencil_add_layer_extra

GREASE_PENCIL_MT_group_context_menu: bl_ui.properties_data_grease_pencil.GREASE_PENCIL_MT_group_context_menu

GREASE_PENCIL_MT_layer_active: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_layer_active

GREASE_PENCIL_MT_layer_group: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_layer_group

GREASE_PENCIL_MT_layer_mask_add: bl_ui.properties_data_grease_pencil.GREASE_PENCIL_MT_layer_mask_add

GREASE_PENCIL_MT_material_context_menu: bl_ui.properties_material_gpencil.GREASE_PENCIL_MT_material_context_menu

GREASE_PENCIL_MT_move_to_layer: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_move_to_layer

GREASE_PENCIL_MT_move_to_layer_SEARCH: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_move_to_layer_SEARCH

GREASE_PENCIL_MT_snap: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_snap

GREASE_PENCIL_MT_snap_pie: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_snap_pie

GREASE_PENCIL_MT_stroke_simplify: bl_ui.properties_grease_pencil_common.GREASE_PENCIL_MT_stroke_simplify

GREASE_PENCIL_OT_relative_layer_mask_add: bl_operators.grease_pencil.GREASE_PENCIL_OT_relative_layer_mask_add

GREASE_PENCIL_UL_attributes: bl_ui.properties_data_grease_pencil.GREASE_PENCIL_UL_attributes

GREASE_PENCIL_UL_masks: bl_ui.properties_data_grease_pencil.GREASE_PENCIL_UL_masks

IMAGE_AST_brush_paint: bl_ui.space_image.IMAGE_AST_brush_paint

IMAGE_FH_drop_handler: bl_operators.image.IMAGE_FH_drop_handler

IMAGE_HT_header: bl_ui.space_image.IMAGE_HT_header

IMAGE_HT_tool_header: bl_ui.space_image.IMAGE_HT_tool_header

IMAGE_MT_editor_menus: bl_ui.space_image.IMAGE_MT_editor_menus

IMAGE_MT_image: bl_ui.space_image.IMAGE_MT_image

IMAGE_MT_image_invert: bl_ui.space_image.IMAGE_MT_image_invert

IMAGE_MT_image_transform: bl_ui.space_image.IMAGE_MT_image_transform

IMAGE_MT_mask_context_menu: bl_ui.space_image.IMAGE_MT_mask_context_menu

IMAGE_MT_pivot_pie: bl_ui.space_image.IMAGE_MT_pivot_pie

IMAGE_MT_select: bl_ui.space_image.IMAGE_MT_select

IMAGE_MT_select_linked: bl_ui.space_image.IMAGE_MT_select_linked

IMAGE_MT_uvs: bl_ui.space_image.IMAGE_MT_uvs

IMAGE_MT_uvs_align: bl_ui.space_image.IMAGE_MT_uvs_align

IMAGE_MT_uvs_context_menu: bl_ui.space_image.IMAGE_MT_uvs_context_menu

IMAGE_MT_uvs_merge: bl_ui.space_image.IMAGE_MT_uvs_merge

IMAGE_MT_uvs_mirror: bl_ui.space_image.IMAGE_MT_uvs_mirror

IMAGE_MT_uvs_select_mode: bl_ui.space_image.IMAGE_MT_uvs_select_mode

IMAGE_MT_uvs_showhide: bl_ui.space_image.IMAGE_MT_uvs_showhide

IMAGE_MT_uvs_snap: bl_ui.space_image.IMAGE_MT_uvs_snap

IMAGE_MT_uvs_snap_pie: bl_ui.space_image.IMAGE_MT_uvs_snap_pie

IMAGE_MT_uvs_split: bl_ui.space_image.IMAGE_MT_uvs_split

IMAGE_MT_uvs_transform: bl_ui.space_image.IMAGE_MT_uvs_transform

IMAGE_MT_uvs_unwrap: bl_ui.space_image.IMAGE_MT_uvs_unwrap

IMAGE_MT_view: bl_ui.space_image.IMAGE_MT_view

IMAGE_MT_view_pie: bl_ui.space_image.IMAGE_MT_view_pie

IMAGE_MT_view_zoom: bl_ui.space_image.IMAGE_MT_view_zoom

IMAGE_OT_convert_to_mesh_plane: bl_operators.image_as_planes.IMAGE_OT_convert_to_mesh_plane

IMAGE_OT_import_as_mesh_planes: bl_operators.image_as_planes.IMAGE_OT_import_as_mesh_planes

IMAGE_OT_open_images: bl_operators.image.IMAGE_OT_open_images

IMAGE_PT_active_mask_point: bl_ui.space_image.IMAGE_PT_active_mask_point

IMAGE_PT_active_mask_spline: bl_ui.space_image.IMAGE_PT_active_mask_spline

IMAGE_PT_active_tool: bl_ui.space_image.IMAGE_PT_active_tool

IMAGE_PT_annotation: bl_ui.space_image.IMAGE_PT_annotation

IMAGE_PT_gizmo_display: bl_ui.space_image.IMAGE_PT_gizmo_display

IMAGE_PT_image_properties: bl_ui.space_image.IMAGE_PT_image_properties

IMAGE_PT_mask: bl_ui.space_image.IMAGE_PT_mask

IMAGE_PT_mask_animation: bl_ui.space_image.IMAGE_PT_mask_animation

IMAGE_PT_mask_layers: bl_ui.space_image.IMAGE_PT_mask_layers

IMAGE_PT_overlay: bl_ui.space_image.IMAGE_PT_overlay

IMAGE_PT_overlay_guides: bl_ui.space_image.IMAGE_PT_overlay_guides

IMAGE_PT_overlay_image: bl_ui.space_image.IMAGE_PT_overlay_image

IMAGE_PT_overlay_mask: bl_ui.space_image.IMAGE_PT_overlay_mask

IMAGE_PT_overlay_render_guides: bl_ui.space_image.IMAGE_PT_overlay_render_guides

IMAGE_PT_overlay_uv_display: bl_ui.space_image.IMAGE_PT_overlay_uv_display

IMAGE_PT_overlay_uv_edit_geometry: bl_ui.space_image.IMAGE_PT_overlay_uv_edit_geometry

IMAGE_PT_overlay_uv_stretch: bl_ui.space_image.IMAGE_PT_overlay_uv_stretch

IMAGE_PT_paint_clone: bl_ui.space_image.IMAGE_PT_paint_clone

IMAGE_PT_paint_color: bl_ui.space_image.IMAGE_PT_paint_color

IMAGE_PT_paint_curve: bl_ui.space_image.IMAGE_PT_paint_curve

IMAGE_PT_paint_select: bl_ui.space_image.IMAGE_PT_paint_select

IMAGE_PT_paint_settings: bl_ui.space_image.IMAGE_PT_paint_settings

IMAGE_PT_paint_settings_advanced: bl_ui.space_image.IMAGE_PT_paint_settings_advanced

IMAGE_PT_paint_stroke: bl_ui.space_image.IMAGE_PT_paint_stroke

IMAGE_PT_paint_stroke_smooth_stroke: bl_ui.space_image.IMAGE_PT_paint_stroke_smooth_stroke

IMAGE_PT_paint_swatches: bl_ui.space_image.IMAGE_PT_paint_swatches

IMAGE_PT_proportional_edit: bl_ui.space_image.IMAGE_PT_proportional_edit

IMAGE_PT_render_slots: bl_ui.space_image.IMAGE_PT_render_slots

IMAGE_PT_sample_line: bl_ui.space_image.IMAGE_PT_sample_line

IMAGE_PT_scope_sample: bl_ui.space_image.IMAGE_PT_scope_sample

IMAGE_PT_snapping: bl_ui.space_image.IMAGE_PT_snapping

IMAGE_PT_tools_active: bl_ui.space_toolsystem_toolbar.IMAGE_PT_tools_active

IMAGE_PT_tools_brush_display: bl_ui.space_image.IMAGE_PT_tools_brush_display

IMAGE_PT_tools_brush_texture: bl_ui.space_image.IMAGE_PT_tools_brush_texture

IMAGE_PT_tools_imagepaint_symmetry: bl_ui.space_image.IMAGE_PT_tools_imagepaint_symmetry

IMAGE_PT_tools_mask_texture: bl_ui.space_image.IMAGE_PT_tools_mask_texture

IMAGE_PT_udim_tiles: bl_ui.space_image.IMAGE_PT_udim_tiles

IMAGE_PT_uv_cursor: bl_ui.space_image.IMAGE_PT_uv_cursor

IMAGE_PT_uv_sculpt_curve: bl_ui.space_image.IMAGE_PT_uv_sculpt_curve

IMAGE_PT_uv_sculpt_options: bl_ui.space_image.IMAGE_PT_uv_sculpt_options

IMAGE_PT_view_display: bl_ui.space_image.IMAGE_PT_view_display

IMAGE_PT_view_histogram: bl_ui.space_image.IMAGE_PT_view_histogram

IMAGE_PT_view_vectorscope: bl_ui.space_image.IMAGE_PT_view_vectorscope

IMAGE_PT_view_waveform: bl_ui.space_image.IMAGE_PT_view_waveform

IMAGE_UL_render_slots: bl_ui.space_image.IMAGE_UL_render_slots

IMAGE_UL_udim_tiles: bl_ui.space_image.IMAGE_UL_udim_tiles

INFO_HT_header: bl_ui.space_info.INFO_HT_header

INFO_MT_area: bl_ui.space_info.INFO_MT_area

INFO_MT_context_menu: bl_ui.space_info.INFO_MT_context_menu

INFO_MT_editor_menus: bl_ui.space_info.INFO_MT_editor_menus

INFO_MT_info: bl_ui.space_info.INFO_MT_info

INFO_MT_view: bl_ui.space_info.INFO_MT_view

MASK_MT_add: bl_ui.properties_mask_common.MASK_MT_add

MASK_MT_animation: bl_ui.properties_mask_common.MASK_MT_animation

MASK_MT_mask: bl_ui.properties_mask_common.MASK_MT_mask

MASK_MT_select: bl_ui.properties_mask_common.MASK_MT_select

MASK_MT_transform: bl_ui.properties_mask_common.MASK_MT_transform

MASK_MT_visibility: bl_ui.properties_mask_common.MASK_MT_visibility

MASK_UL_layers: bl_ui.properties_mask_common.MASK_UL_layers

MATERIAL_MT_context_menu: bl_ui.properties_material.MATERIAL_MT_context_menu

MATERIAL_PT_animation: bl_ui.properties_material.MATERIAL_PT_animation

MATERIAL_PT_custom_props: bl_ui.properties_material.MATERIAL_PT_custom_props

MATERIAL_PT_freestyle_line: bl_ui.properties_freestyle.MATERIAL_PT_freestyle_line

MATERIAL_PT_gpencil_animation: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_animation

MATERIAL_PT_gpencil_custom_props: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_custom_props

MATERIAL_PT_gpencil_fillcolor: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_fillcolor

MATERIAL_PT_gpencil_material_presets: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_material_presets

MATERIAL_PT_gpencil_preview: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_preview

MATERIAL_PT_gpencil_settings: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_settings

MATERIAL_PT_gpencil_slots: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_slots

MATERIAL_PT_gpencil_strokecolor: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_strokecolor

MATERIAL_PT_gpencil_surface: bl_ui.properties_material_gpencil.MATERIAL_PT_gpencil_surface

MATERIAL_PT_lineart: bl_ui.properties_material.MATERIAL_PT_lineart

MATERIAL_PT_preview: bl_ui.properties_material.MATERIAL_PT_preview

MATERIAL_PT_viewport: bl_ui.properties_material.MATERIAL_PT_viewport

MATERIAL_UL_matslots: bl_ui.properties_material.MATERIAL_UL_matslots

MESH_MT_attribute_context_menu: bl_ui.properties_data_mesh.MESH_MT_attribute_context_menu

MESH_MT_color_attribute_context_menu: bl_ui.properties_data_mesh.MESH_MT_color_attribute_context_menu

MESH_MT_shape_key_context_menu: bl_ui.properties_data_mesh.MESH_MT_shape_key_context_menu

MESH_MT_shape_key_tree_context_menu: bl_ui.properties_data_mesh.MESH_MT_shape_key_tree_context_menu

MESH_MT_vertex_group_context_menu: bl_ui.properties_data_mesh.MESH_MT_vertex_group_context_menu

MESH_UL_attributes: bl_ui.properties_data_mesh.MESH_UL_attributes

MESH_UL_color_attributes: bl_ui.properties_data_mesh.MESH_UL_color_attributes

MESH_UL_color_attributes_selector: bl_ui.properties_data_mesh.MESH_UL_color_attributes_selector

MESH_UL_uvmaps: bl_ui.properties_data_mesh.MESH_UL_uvmaps

MESH_UL_vgroups: bl_ui.properties_data_mesh.MESH_UL_vgroups

NLA_HT_header: bl_ui.space_nla.NLA_HT_header

NLA_HT_playback_controls: bl_ui.space_nla.NLA_HT_playback_controls

NLA_MT_add: bl_ui.space_nla.NLA_MT_add

NLA_MT_channel_context_menu: bl_ui.space_nla.NLA_MT_channel_context_menu

NLA_MT_context_menu: bl_ui.space_nla.NLA_MT_context_menu

NLA_MT_editor_menus: bl_ui.space_nla.NLA_MT_editor_menus

NLA_MT_marker: bl_ui.space_nla.NLA_MT_marker

NLA_MT_marker_select: bl_ui.space_nla.NLA_MT_marker_select

NLA_MT_select: bl_ui.space_nla.NLA_MT_select

NLA_MT_snap_pie: bl_ui.space_nla.NLA_MT_snap_pie

NLA_MT_strips: bl_ui.space_nla.NLA_MT_strips

NLA_MT_strips_transform: bl_ui.space_nla.NLA_MT_strips_transform

NLA_MT_tracks: bl_ui.space_nla.NLA_MT_tracks

NLA_MT_view: bl_ui.space_nla.NLA_MT_view

NLA_MT_view_pie: bl_ui.space_nla.NLA_MT_view_pie

NLA_OT_bake: bl_operators.anim.NLA_OT_bake

NLA_PT_action: bl_ui.space_nla.NLA_PT_action

NLA_PT_filters: bl_ui.space_nla.NLA_PT_filters

NLA_PT_snapping: bl_ui.space_nla.NLA_PT_snapping

NODE_AST_compositor: bl_ui.space_node.NODE_AST_compositor

NODE_FH_image_node: bl_operators.node.NODE_FH_image_node

NODE_HT_header: bl_ui.space_node.NODE_HT_header

NODE_MT_add: bl_ui.space_node.NODE_MT_add

NODE_MT_context_menu: bl_ui.space_node.NODE_MT_context_menu

NODE_MT_context_menu_select_menu: bl_ui.space_node.NODE_MT_context_menu_select_menu

NODE_MT_context_menu_show_hide_menu: bl_ui.space_node.NODE_MT_context_menu_show_hide_menu

NODE_MT_editor_menus: bl_ui.space_node.NODE_MT_editor_menus

NODE_MT_node: bl_ui.space_node.NODE_MT_node

NODE_MT_node_color_context_menu: bl_ui.space_node.NODE_MT_node_color_context_menu

NODE_MT_node_tree_interface_context_menu: bl_ui.space_node.NODE_MT_node_tree_interface_context_menu

NODE_MT_node_tree_interface_new_item: bl_ui.space_node.NODE_MT_node_tree_interface_new_item

NODE_MT_select: bl_ui.space_node.NODE_MT_select

NODE_MT_swap: bl_ui.space_node.NODE_MT_swap

NODE_MT_view: bl_ui.space_node.NODE_MT_view

NODE_MT_view_pie: bl_ui.space_node.NODE_MT_view_pie

NODE_OT_add_closure_zone: bl_operators.node.NODE_OT_add_closure_zone

NODE_OT_add_empty_group: bl_operators.node.NODE_OT_add_empty_group

NODE_OT_add_foreach_geometry_element_zone: bl_operators.node.NODE_OT_add_foreach_geometry_element_zone

NODE_OT_add_node: bl_operators.node.NODE_OT_add_node

NODE_OT_add_repeat_zone: bl_operators.node.NODE_OT_add_repeat_zone

NODE_OT_add_simulation_zone: bl_operators.node.NODE_OT_add_simulation_zone

NODE_OT_add_zone: bl_operators.node.NODE_OT_add_zone

NODE_OT_collapse_hide_unused_toggle: bl_operators.node.NODE_OT_collapse_hide_unused_toggle

NODE_OT_connect_to_output: bl_operators.connect_to_output.NODE_OT_connect_to_output

NODE_OT_interface_item_duplicate: bl_operators.node.NODE_OT_interface_item_duplicate

NODE_OT_interface_item_make_panel_toggle: bl_operators.node.NODE_OT_interface_item_make_panel_toggle

NODE_OT_interface_item_new: bl_operators.node.NODE_OT_interface_item_new

NODE_OT_interface_item_new_panel_toggle: bl_operators.node.NODE_OT_interface_item_new_panel_toggle

NODE_OT_interface_item_remove: bl_operators.node.NODE_OT_interface_item_remove

NODE_OT_interface_item_unlink_panel_toggle: bl_operators.node.NODE_OT_interface_item_unlink_panel_toggle

NODE_OT_swap_empty_group: bl_operators.node.NODE_OT_swap_empty_group

NODE_OT_swap_node: bl_operators.node.NODE_OT_swap_node

NODE_OT_swap_zone: bl_operators.node.NODE_OT_swap_zone

NODE_OT_tree_path_parent: bl_operators.node.NODE_OT_tree_path_parent

NODE_OT_viewer_shortcut_get: bl_operators.node.NODE_OT_viewer_shortcut_get

NODE_OT_viewer_shortcut_set: bl_operators.node.NODE_OT_viewer_shortcut_set

NODE_PT_active_node_custom_properties: bl_ui.space_node.NODE_PT_active_node_custom_properties

NODE_PT_active_node_generic: bl_ui.space_node.NODE_PT_active_node_generic

NODE_PT_active_node_properties: bl_ui.space_node.NODE_PT_active_node_properties

NODE_PT_active_tool: bl_ui.space_node.NODE_PT_active_tool

NODE_PT_annotation: bl_ui.space_node.NODE_PT_annotation

NODE_PT_backdrop: bl_ui.space_node.NODE_PT_backdrop

NODE_PT_geometry_node_tool_mode: bl_ui.space_node.NODE_PT_geometry_node_tool_mode

NODE_PT_geometry_node_tool_object_types: bl_ui.space_node.NODE_PT_geometry_node_tool_object_types

NODE_PT_geometry_node_tool_options: bl_ui.space_node.NODE_PT_geometry_node_tool_options

NODE_PT_gizmo_display: bl_ui.space_node.NODE_PT_gizmo_display

NODE_PT_material_slots: bl_ui.space_node.NODE_PT_material_slots

NODE_PT_node_color_presets: bl_ui.space_node.NODE_PT_node_color_presets

NODE_PT_node_tree_animation: bl_ui.space_node.NODE_PT_node_tree_animation

NODE_PT_node_tree_properties: bl_ui.space_node.NODE_PT_node_tree_properties

NODE_PT_overlay: bl_ui.space_node.NODE_PT_overlay

NODE_PT_quality: bl_ui.space_node.NODE_PT_quality

NODE_PT_texture_mapping: bl_ui.space_node.NODE_PT_texture_mapping

NODE_PT_tools_active: bl_ui.space_toolsystem_toolbar.NODE_PT_tools_active

OBJECT_MT_light_linking_context_menu: bl_ui.properties_object.OBJECT_MT_light_linking_context_menu

OBJECT_MT_modifier_add: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add

OBJECT_MT_modifier_add_color: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_color

OBJECT_MT_modifier_add_deform: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_deform

OBJECT_MT_modifier_add_edit: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_edit

OBJECT_MT_modifier_add_generate: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_generate

OBJECT_MT_modifier_add_normals: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_normals

OBJECT_MT_modifier_add_physics: bl_ui.properties_data_modifier.OBJECT_MT_modifier_add_physics

OBJECT_MT_shadow_linking_context_menu: bl_ui.properties_object.OBJECT_MT_shadow_linking_context_menu

OBJECT_OT_assign_property_defaults: bl_operators.object.OBJECT_OT_assign_property_defaults

OBJECT_OT_copy_global_transform: bl_operators.copy_global_transform.OBJECT_OT_copy_global_transform

OBJECT_OT_copy_relative_transform: bl_operators.copy_global_transform.OBJECT_OT_copy_relative_transform

OBJECT_OT_delete_fix_to_camera_keys: bl_operators.copy_global_transform.OBJECT_OT_delete_fix_to_camera_keys

OBJECT_OT_fix_to_camera: bl_operators.copy_global_transform.OBJECT_OT_fix_to_camera

OBJECT_OT_paste_transform: bl_operators.copy_global_transform.OBJECT_OT_paste_transform

OBJECT_PT_animation: bl_ui.properties_object.OBJECT_PT_animation

OBJECT_PT_bActionConstraint: bl_ui.properties_constraint.OBJECT_PT_bActionConstraint

OBJECT_PT_bActionConstraint_action: bl_ui.properties_constraint.OBJECT_PT_bActionConstraint_action

OBJECT_PT_bActionConstraint_target: bl_ui.properties_constraint.OBJECT_PT_bActionConstraint_target

OBJECT_PT_bArmatureConstraint: bl_ui.properties_constraint.OBJECT_PT_bArmatureConstraint

OBJECT_PT_bArmatureConstraint_bones: bl_ui.properties_constraint.OBJECT_PT_bArmatureConstraint_bones

OBJECT_PT_bCameraSolverConstraint: bl_ui.properties_constraint.OBJECT_PT_bCameraSolverConstraint

OBJECT_PT_bChildOfConstraint: bl_ui.properties_constraint.OBJECT_PT_bChildOfConstraint

OBJECT_PT_bClampToConstraint: bl_ui.properties_constraint.OBJECT_PT_bClampToConstraint

OBJECT_PT_bDampTrackConstraint: bl_ui.properties_constraint.OBJECT_PT_bDampTrackConstraint

OBJECT_PT_bDistLimitConstraint: bl_ui.properties_constraint.OBJECT_PT_bDistLimitConstraint

OBJECT_PT_bFollowPathConstraint: bl_ui.properties_constraint.OBJECT_PT_bFollowPathConstraint

OBJECT_PT_bFollowTrackConstraint: bl_ui.properties_constraint.OBJECT_PT_bFollowTrackConstraint

OBJECT_PT_bGeometryAttributeConstraint: bl_ui.properties_constraint.OBJECT_PT_bGeometryAttributeConstraint

OBJECT_PT_bKinematicConstraint: bl_ui.properties_constraint.OBJECT_PT_bKinematicConstraint

OBJECT_PT_bLocLimitConstraint: bl_ui.properties_constraint.OBJECT_PT_bLocLimitConstraint

OBJECT_PT_bLocateLikeConstraint: bl_ui.properties_constraint.OBJECT_PT_bLocateLikeConstraint

OBJECT_PT_bLockTrackConstraint: bl_ui.properties_constraint.OBJECT_PT_bLockTrackConstraint

OBJECT_PT_bMinMaxConstraint: bl_ui.properties_constraint.OBJECT_PT_bMinMaxConstraint

OBJECT_PT_bObjectSolverConstraint: bl_ui.properties_constraint.OBJECT_PT_bObjectSolverConstraint

OBJECT_PT_bPivotConstraint: bl_ui.properties_constraint.OBJECT_PT_bPivotConstraint

OBJECT_PT_bRotLimitConstraint: bl_ui.properties_constraint.OBJECT_PT_bRotLimitConstraint

OBJECT_PT_bRotateLikeConstraint: bl_ui.properties_constraint.OBJECT_PT_bRotateLikeConstraint

OBJECT_PT_bSameVolumeConstraint: bl_ui.properties_constraint.OBJECT_PT_bSameVolumeConstraint

OBJECT_PT_bShrinkwrapConstraint: bl_ui.properties_constraint.OBJECT_PT_bShrinkwrapConstraint

OBJECT_PT_bSizeLikeConstraint: bl_ui.properties_constraint.OBJECT_PT_bSizeLikeConstraint

OBJECT_PT_bSizeLimitConstraint: bl_ui.properties_constraint.OBJECT_PT_bSizeLimitConstraint

OBJECT_PT_bStretchToConstraint: bl_ui.properties_constraint.OBJECT_PT_bStretchToConstraint

OBJECT_PT_bTrackToConstraint: bl_ui.properties_constraint.OBJECT_PT_bTrackToConstraint

OBJECT_PT_bTransLikeConstraint: bl_ui.properties_constraint.OBJECT_PT_bTransLikeConstraint

OBJECT_PT_bTransformCacheConstraint: bl_ui.properties_constraint.OBJECT_PT_bTransformCacheConstraint

OBJECT_PT_bTransformCacheConstraint_layers: bl_ui.properties_constraint.OBJECT_PT_bTransformCacheConstraint_layers

OBJECT_PT_bTransformCacheConstraint_time: bl_ui.properties_constraint.OBJECT_PT_bTransformCacheConstraint_time

OBJECT_PT_bTransformCacheConstraint_velocity: bl_ui.properties_constraint.OBJECT_PT_bTransformCacheConstraint_velocity

OBJECT_PT_bTransformConstraint: bl_ui.properties_constraint.OBJECT_PT_bTransformConstraint

OBJECT_PT_bTransformConstraint_destination: bl_ui.properties_constraint.OBJECT_PT_bTransformConstraint_destination

OBJECT_PT_bTransformConstraint_source: bl_ui.properties_constraint.OBJECT_PT_bTransformConstraint_source

OBJECT_PT_collections: bl_ui.properties_object.OBJECT_PT_collections

OBJECT_PT_constraints: bl_ui.properties_constraint.OBJECT_PT_constraints

OBJECT_PT_context_object: bl_ui.properties_object.OBJECT_PT_context_object

OBJECT_PT_custom_props: bl_ui.properties_object.OBJECT_PT_custom_props

OBJECT_PT_delta_transform: bl_ui.properties_object.OBJECT_PT_delta_transform

OBJECT_PT_display: bl_ui.properties_object.OBJECT_PT_display

OBJECT_PT_instancing: bl_ui.properties_object.OBJECT_PT_instancing

OBJECT_PT_instancing_size: bl_ui.properties_object.OBJECT_PT_instancing_size

OBJECT_PT_light_linking: bl_ui.properties_object.OBJECT_PT_light_linking

OBJECT_PT_lineart: bl_ui.properties_object.OBJECT_PT_lineart

OBJECT_PT_motion_paths: bl_ui.properties_object.OBJECT_PT_motion_paths

OBJECT_PT_motion_paths_display: bl_ui.properties_object.OBJECT_PT_motion_paths_display

OBJECT_PT_parent_inverse_transform: bl_ui.properties_object.OBJECT_PT_parent_inverse_transform

OBJECT_PT_relations: bl_ui.properties_object.OBJECT_PT_relations

OBJECT_PT_shading: bl_ui.properties_object.OBJECT_PT_shading

OBJECT_PT_shadow_linking: bl_ui.properties_object.OBJECT_PT_shadow_linking

OBJECT_PT_shadow_terminator: bl_ui.properties_object.OBJECT_PT_shadow_terminator

OBJECT_PT_transform: bl_ui.properties_object.OBJECT_PT_transform

OBJECT_PT_visibility: bl_ui.properties_object.OBJECT_PT_visibility

OUTLINER_HT_header: bl_ui.space_outliner.OUTLINER_HT_header

OUTLINER_MT_asset: bl_ui.space_outliner.OUTLINER_MT_asset

OUTLINER_MT_collection: bl_ui.space_outliner.OUTLINER_MT_collection

OUTLINER_MT_collection_new: bl_ui.space_outliner.OUTLINER_MT_collection_new

OUTLINER_MT_collection_view_layer: bl_ui.space_outliner.OUTLINER_MT_collection_view_layer

OUTLINER_MT_collection_visibility: bl_ui.space_outliner.OUTLINER_MT_collection_visibility

OUTLINER_MT_context_menu: bl_ui.space_outliner.OUTLINER_MT_context_menu

OUTLINER_MT_context_menu_view: bl_ui.space_outliner.OUTLINER_MT_context_menu_view

OUTLINER_MT_edit_datablocks: bl_ui.space_outliner.OUTLINER_MT_edit_datablocks

OUTLINER_MT_editor_menus: bl_ui.space_outliner.OUTLINER_MT_editor_menus

OUTLINER_MT_id_data: bl_ui.space_outliner.OUTLINER_MT_id_data

OUTLINER_MT_liboverride: bl_ui.space_outliner.OUTLINER_MT_liboverride

OUTLINER_MT_object: bl_ui.space_outliner.OUTLINER_MT_object

OUTLINER_MT_view_pie: bl_ui.space_outliner.OUTLINER_MT_view_pie

OUTLINER_PT_filter: bl_ui.space_outliner.OUTLINER_PT_filter

PARTICLE_MT_context_menu: bl_ui.properties_particle.PARTICLE_MT_context_menu

PARTICLE_PT_animation: bl_ui.properties_particle.PARTICLE_PT_animation

PARTICLE_PT_boidbrain: bl_ui.properties_particle.PARTICLE_PT_boidbrain

PARTICLE_PT_cache: bl_ui.properties_particle.PARTICLE_PT_cache

PARTICLE_PT_children: bl_ui.properties_particle.PARTICLE_PT_children

PARTICLE_PT_children_clumping: bl_ui.properties_particle.PARTICLE_PT_children_clumping

PARTICLE_PT_children_clumping_noise: bl_ui.properties_particle.PARTICLE_PT_children_clumping_noise

PARTICLE_PT_children_kink: bl_ui.properties_particle.PARTICLE_PT_children_kink

PARTICLE_PT_children_parting: bl_ui.properties_particle.PARTICLE_PT_children_parting

PARTICLE_PT_children_roughness: bl_ui.properties_particle.PARTICLE_PT_children_roughness

PARTICLE_PT_context_particles: bl_ui.properties_particle.PARTICLE_PT_context_particles

PARTICLE_PT_custom_props: bl_ui.properties_particle.PARTICLE_PT_custom_props

PARTICLE_PT_draw: bl_ui.properties_particle.PARTICLE_PT_draw

PARTICLE_PT_emission: bl_ui.properties_particle.PARTICLE_PT_emission

PARTICLE_PT_emission_source: bl_ui.properties_particle.PARTICLE_PT_emission_source

PARTICLE_PT_field_weights: bl_ui.properties_particle.PARTICLE_PT_field_weights

PARTICLE_PT_force_fields: bl_ui.properties_particle.PARTICLE_PT_force_fields

PARTICLE_PT_force_fields_type1: bl_ui.properties_particle.PARTICLE_PT_force_fields_type1

PARTICLE_PT_force_fields_type1_falloff: bl_ui.properties_particle.PARTICLE_PT_force_fields_type1_falloff

PARTICLE_PT_force_fields_type2: bl_ui.properties_particle.PARTICLE_PT_force_fields_type2

PARTICLE_PT_force_fields_type2_falloff: bl_ui.properties_particle.PARTICLE_PT_force_fields_type2_falloff

PARTICLE_PT_hair_dynamics: bl_ui.properties_particle.PARTICLE_PT_hair_dynamics

PARTICLE_PT_hair_dynamics_collision: bl_ui.properties_particle.PARTICLE_PT_hair_dynamics_collision

PARTICLE_PT_hair_dynamics_presets: bl_ui.properties_particle.PARTICLE_PT_hair_dynamics_presets

PARTICLE_PT_hair_dynamics_structure: bl_ui.properties_particle.PARTICLE_PT_hair_dynamics_structure

PARTICLE_PT_hair_dynamics_volume: bl_ui.properties_particle.PARTICLE_PT_hair_dynamics_volume

PARTICLE_PT_hair_shape: bl_ui.properties_particle.PARTICLE_PT_hair_shape

PARTICLE_PT_physics: bl_ui.properties_particle.PARTICLE_PT_physics

PARTICLE_PT_physics_boids_battle: bl_ui.properties_particle.PARTICLE_PT_physics_boids_battle

PARTICLE_PT_physics_boids_misc: bl_ui.properties_particle.PARTICLE_PT_physics_boids_misc

PARTICLE_PT_physics_boids_movement: bl_ui.properties_particle.PARTICLE_PT_physics_boids_movement

PARTICLE_PT_physics_deflection: bl_ui.properties_particle.PARTICLE_PT_physics_deflection

PARTICLE_PT_physics_fluid_advanced: bl_ui.properties_particle.PARTICLE_PT_physics_fluid_advanced

PARTICLE_PT_physics_fluid_interaction: bl_ui.properties_particle.PARTICLE_PT_physics_fluid_interaction

PARTICLE_PT_physics_fluid_springs: bl_ui.properties_particle.PARTICLE_PT_physics_fluid_springs

PARTICLE_PT_physics_fluid_springs_advanced: bl_ui.properties_particle.PARTICLE_PT_physics_fluid_springs_advanced

PARTICLE_PT_physics_fluid_springs_viscoelastic: bl_ui.properties_particle.PARTICLE_PT_physics_fluid_springs_viscoelastic

PARTICLE_PT_physics_forces: bl_ui.properties_particle.PARTICLE_PT_physics_forces

PARTICLE_PT_physics_integration: bl_ui.properties_particle.PARTICLE_PT_physics_integration

PARTICLE_PT_physics_relations: bl_ui.properties_particle.PARTICLE_PT_physics_relations

PARTICLE_PT_render: bl_ui.properties_particle.PARTICLE_PT_render

PARTICLE_PT_render_collection: bl_ui.properties_particle.PARTICLE_PT_render_collection

PARTICLE_PT_render_collection_use_count: bl_ui.properties_particle.PARTICLE_PT_render_collection_use_count

PARTICLE_PT_render_extra: bl_ui.properties_particle.PARTICLE_PT_render_extra

PARTICLE_PT_render_object: bl_ui.properties_particle.PARTICLE_PT_render_object

PARTICLE_PT_render_path: bl_ui.properties_particle.PARTICLE_PT_render_path

PARTICLE_PT_render_path_timing: bl_ui.properties_particle.PARTICLE_PT_render_path_timing

PARTICLE_PT_rotation: bl_ui.properties_particle.PARTICLE_PT_rotation

PARTICLE_PT_rotation_angular_velocity: bl_ui.properties_particle.PARTICLE_PT_rotation_angular_velocity

PARTICLE_PT_textures: bl_ui.properties_particle.PARTICLE_PT_textures

PARTICLE_PT_velocity: bl_ui.properties_particle.PARTICLE_PT_velocity

PARTICLE_PT_vertexgroups: bl_ui.properties_particle.PARTICLE_PT_vertexgroups

PARTICLE_UL_particle_systems: bl_ui.properties_particle.PARTICLE_UL_particle_systems

PHYSICS_PT_adaptive_domain: bl_ui.properties_physics_fluid.PHYSICS_PT_adaptive_domain

PHYSICS_PT_add: bl_ui.properties_physics_common.PHYSICS_PT_add

PHYSICS_PT_borders: bl_ui.properties_physics_fluid.PHYSICS_PT_borders

PHYSICS_PT_cache: bl_ui.properties_physics_fluid.PHYSICS_PT_cache

PHYSICS_PT_cloth: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth

PHYSICS_PT_cloth_cache: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_cache

PHYSICS_PT_cloth_collision: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_collision

PHYSICS_PT_cloth_damping: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_damping

PHYSICS_PT_cloth_field_weights: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_field_weights

PHYSICS_PT_cloth_internal_springs: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_internal_springs

PHYSICS_PT_cloth_object_collision: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_object_collision

PHYSICS_PT_cloth_physical_properties: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_physical_properties

PHYSICS_PT_cloth_pressure: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_pressure

PHYSICS_PT_cloth_property_weights: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_property_weights

PHYSICS_PT_cloth_self_collision: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_self_collision

PHYSICS_PT_cloth_shape: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_shape

PHYSICS_PT_cloth_stiffness: bl_ui.properties_physics_cloth.PHYSICS_PT_cloth_stiffness

PHYSICS_PT_collections: bl_ui.properties_physics_fluid.PHYSICS_PT_collections

PHYSICS_PT_collision: bl_ui.properties_physics_field.PHYSICS_PT_collision

PHYSICS_PT_collision_particle: bl_ui.properties_physics_field.PHYSICS_PT_collision_particle

PHYSICS_PT_collision_softbody: bl_ui.properties_physics_field.PHYSICS_PT_collision_softbody

PHYSICS_PT_diffusion: bl_ui.properties_physics_fluid.PHYSICS_PT_diffusion

PHYSICS_PT_dp_brush_source: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_source

PHYSICS_PT_dp_brush_source_color_ramp: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_source_color_ramp

PHYSICS_PT_dp_brush_velocity: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_velocity

PHYSICS_PT_dp_brush_velocity_color_ramp: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_velocity_color_ramp

PHYSICS_PT_dp_brush_velocity_smudge: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_velocity_smudge

PHYSICS_PT_dp_brush_wave: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_brush_wave

PHYSICS_PT_dp_cache: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_cache

PHYSICS_PT_dp_canvas_initial_color: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_canvas_initial_color

PHYSICS_PT_dp_canvas_output: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_canvas_output

PHYSICS_PT_dp_canvas_output_paintmaps: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_canvas_output_paintmaps

PHYSICS_PT_dp_canvas_output_wetmaps: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_canvas_output_wetmaps

PHYSICS_PT_dp_effects: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_effects

PHYSICS_PT_dp_effects_drip: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_effects_drip

PHYSICS_PT_dp_effects_drip_weights: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_effects_drip_weights

PHYSICS_PT_dp_effects_shrink: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_effects_shrink

PHYSICS_PT_dp_effects_spread: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_effects_spread

PHYSICS_PT_dp_surface_canvas: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_surface_canvas

PHYSICS_PT_dp_surface_canvas_paint_dissolve: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_surface_canvas_paint_dissolve

PHYSICS_PT_dp_surface_canvas_paint_dry: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dp_surface_canvas_paint_dry

PHYSICS_PT_dynamic_paint: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dynamic_paint

PHYSICS_PT_dynamic_paint_settings: bl_ui.properties_physics_dynamicpaint.PHYSICS_PT_dynamic_paint_settings

PHYSICS_PT_export: bl_ui.properties_physics_fluid.PHYSICS_PT_export

PHYSICS_PT_field: bl_ui.properties_physics_field.PHYSICS_PT_field

PHYSICS_PT_field_falloff: bl_ui.properties_physics_field.PHYSICS_PT_field_falloff

PHYSICS_PT_field_falloff_angular: bl_ui.properties_physics_field.PHYSICS_PT_field_falloff_angular

PHYSICS_PT_field_falloff_radial: bl_ui.properties_physics_field.PHYSICS_PT_field_falloff_radial

PHYSICS_PT_field_settings: bl_ui.properties_physics_field.PHYSICS_PT_field_settings

PHYSICS_PT_field_settings_kink: bl_ui.properties_physics_field.PHYSICS_PT_field_settings_kink

PHYSICS_PT_field_settings_texture_select: bl_ui.properties_physics_field.PHYSICS_PT_field_settings_texture_select

PHYSICS_PT_field_weights: bl_ui.properties_physics_fluid.PHYSICS_PT_field_weights

PHYSICS_PT_fire: bl_ui.properties_physics_fluid.PHYSICS_PT_fire

PHYSICS_PT_flow_initial_velocity: bl_ui.properties_physics_fluid.PHYSICS_PT_flow_initial_velocity

PHYSICS_PT_flow_source: bl_ui.properties_physics_fluid.PHYSICS_PT_flow_source

PHYSICS_PT_flow_texture: bl_ui.properties_physics_fluid.PHYSICS_PT_flow_texture

PHYSICS_PT_fluid: bl_ui.properties_physics_fluid.PHYSICS_PT_fluid

PHYSICS_PT_fluid_domain_render: bl_ui.properties_physics_fluid.PHYSICS_PT_fluid_domain_render

PHYSICS_PT_geometry_nodes: bl_ui.properties_physics_geometry_nodes.PHYSICS_PT_geometry_nodes

PHYSICS_PT_guide: bl_ui.properties_physics_fluid.PHYSICS_PT_guide

PHYSICS_PT_liquid: bl_ui.properties_physics_fluid.PHYSICS_PT_liquid

PHYSICS_PT_mesh: bl_ui.properties_physics_fluid.PHYSICS_PT_mesh

PHYSICS_PT_noise: bl_ui.properties_physics_fluid.PHYSICS_PT_noise

PHYSICS_PT_particles: bl_ui.properties_physics_fluid.PHYSICS_PT_particles

PHYSICS_PT_rigid_body: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body

PHYSICS_PT_rigid_body_collisions: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_collisions

PHYSICS_PT_rigid_body_collisions_collections: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_collisions_collections

PHYSICS_PT_rigid_body_collisions_sensitivity: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_collisions_sensitivity

PHYSICS_PT_rigid_body_collisions_surface: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_collisions_surface

PHYSICS_PT_rigid_body_constraint: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint

PHYSICS_PT_rigid_body_constraint_limits: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_limits

PHYSICS_PT_rigid_body_constraint_limits_angular: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_limits_angular

PHYSICS_PT_rigid_body_constraint_limits_linear: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_limits_linear

PHYSICS_PT_rigid_body_constraint_motor: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_motor

PHYSICS_PT_rigid_body_constraint_motor_angular: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_motor_angular

PHYSICS_PT_rigid_body_constraint_motor_linear: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_motor_linear

PHYSICS_PT_rigid_body_constraint_objects: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_objects

PHYSICS_PT_rigid_body_constraint_override_iterations: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_override_iterations

PHYSICS_PT_rigid_body_constraint_settings: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_settings

PHYSICS_PT_rigid_body_constraint_springs: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_springs

PHYSICS_PT_rigid_body_constraint_springs_angular: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_springs_angular

PHYSICS_PT_rigid_body_constraint_springs_linear: bl_ui.properties_physics_rigidbody_constraint.PHYSICS_PT_rigid_body_constraint_springs_linear

PHYSICS_PT_rigid_body_dynamics: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_dynamics

PHYSICS_PT_rigid_body_dynamics_deactivation: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_dynamics_deactivation

PHYSICS_PT_rigid_body_settings: bl_ui.properties_physics_rigidbody.PHYSICS_PT_rigid_body_settings

PHYSICS_PT_settings: bl_ui.properties_physics_fluid.PHYSICS_PT_settings

PHYSICS_PT_smoke: bl_ui.properties_physics_fluid.PHYSICS_PT_smoke

PHYSICS_PT_smoke_dissolve: bl_ui.properties_physics_fluid.PHYSICS_PT_smoke_dissolve

PHYSICS_PT_softbody: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody

PHYSICS_PT_softbody_cache: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_cache

PHYSICS_PT_softbody_collision: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_collision

PHYSICS_PT_softbody_edge: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_edge

PHYSICS_PT_softbody_edge_aerodynamics: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_edge_aerodynamics

PHYSICS_PT_softbody_edge_stiffness: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_edge_stiffness

PHYSICS_PT_softbody_field_weights: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_field_weights

PHYSICS_PT_softbody_goal: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_goal

PHYSICS_PT_softbody_goal_settings: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_goal_settings

PHYSICS_PT_softbody_goal_strengths: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_goal_strengths

PHYSICS_PT_softbody_object: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_object

PHYSICS_PT_softbody_simulation: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_simulation

PHYSICS_PT_softbody_solver: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_solver

PHYSICS_PT_softbody_solver_diagnostics: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_solver_diagnostics

PHYSICS_PT_softbody_solver_helpers: bl_ui.properties_physics_softbody.PHYSICS_PT_softbody_solver_helpers

PHYSICS_PT_viewport_display: bl_ui.properties_physics_fluid.PHYSICS_PT_viewport_display

PHYSICS_PT_viewport_display_advanced: bl_ui.properties_physics_fluid.PHYSICS_PT_viewport_display_advanced

PHYSICS_PT_viewport_display_color: bl_ui.properties_physics_fluid.PHYSICS_PT_viewport_display_color

PHYSICS_PT_viewport_display_debug: bl_ui.properties_physics_fluid.PHYSICS_PT_viewport_display_debug

PHYSICS_PT_viewport_display_slicing: bl_ui.properties_physics_fluid.PHYSICS_PT_viewport_display_slicing

PHYSICS_PT_viscosity: bl_ui.properties_physics_fluid.PHYSICS_PT_viscosity

PHYSICS_UL_dynapaint_surfaces: bl_ui.properties_physics_dynamicpaint.PHYSICS_UL_dynapaint_surfaces

POINTCLOUD_MT_add_attribute: bl_ui.properties_data_pointcloud.POINTCLOUD_MT_add_attribute

POINTCLOUD_MT_attribute_context_menu: bl_ui.properties_data_pointcloud.POINTCLOUD_MT_attribute_context_menu

POINTCLOUD_UL_attributes: bl_ui.properties_data_pointcloud.POINTCLOUD_UL_attributes

POSE_MT_selection_set_create: bl_ui.properties_data_armature.POSE_MT_selection_set_create

POSE_MT_selection_sets_context_menu: bl_ui.properties_data_armature.POSE_MT_selection_sets_context_menu

POSE_MT_selection_sets_select: bl_ui.properties_data_armature.POSE_MT_selection_sets_select

POSE_OT_selection_set_add: bl_operators.bone_selection_sets.POSE_OT_selection_set_add

POSE_OT_selection_set_add_and_assign: bl_operators.bone_selection_sets.POSE_OT_selection_set_add_and_assign

POSE_OT_selection_set_assign: bl_operators.bone_selection_sets.POSE_OT_selection_set_assign

POSE_OT_selection_set_copy: bl_operators.bone_selection_sets.POSE_OT_selection_set_copy

POSE_OT_selection_set_delete_all: bl_operators.bone_selection_sets.POSE_OT_selection_set_delete_all

POSE_OT_selection_set_deselect: bl_operators.bone_selection_sets.POSE_OT_selection_set_deselect

POSE_OT_selection_set_move: bl_operators.bone_selection_sets.POSE_OT_selection_set_move

POSE_OT_selection_set_paste: bl_operators.bone_selection_sets.POSE_OT_selection_set_paste

POSE_OT_selection_set_remove: bl_operators.bone_selection_sets.POSE_OT_selection_set_remove

POSE_OT_selection_set_remove_bones: bl_operators.bone_selection_sets.POSE_OT_selection_set_remove_bones

POSE_OT_selection_set_select: bl_operators.bone_selection_sets.POSE_OT_selection_set_select

POSE_OT_selection_set_unassign: bl_operators.bone_selection_sets.POSE_OT_selection_set_unassign

POSE_PT_selection_sets: bl_ui.properties_data_armature.POSE_PT_selection_sets

POSE_UL_selection_set: bl_ui.properties_data_armature.POSE_UL_selection_set

PREFERENCES_OT_addon_disable: bl_operators.userpref.PREFERENCES_OT_addon_disable

PREFERENCES_OT_addon_enable: bl_operators.userpref.PREFERENCES_OT_addon_enable

PREFERENCES_OT_addon_expand: bl_operators.userpref.PREFERENCES_OT_addon_expand

PREFERENCES_OT_addon_install: bl_operators.userpref.PREFERENCES_OT_addon_install

PREFERENCES_OT_addon_refresh: bl_operators.userpref.PREFERENCES_OT_addon_refresh

PREFERENCES_OT_addon_remove: bl_operators.userpref.PREFERENCES_OT_addon_remove

PREFERENCES_OT_addon_show: bl_operators.userpref.PREFERENCES_OT_addon_show

PREFERENCES_OT_app_template_install: bl_operators.userpref.PREFERENCES_OT_app_template_install

PREFERENCES_OT_copy_prev: bl_operators.userpref.PREFERENCES_OT_copy_prev

PREFERENCES_OT_keyconfig_activate: bl_operators.userpref.PREFERENCES_OT_keyconfig_activate

PREFERENCES_OT_keyconfig_export: bl_operators.userpref.PREFERENCES_OT_keyconfig_export

PREFERENCES_OT_keyconfig_import: bl_operators.userpref.PREFERENCES_OT_keyconfig_import

PREFERENCES_OT_keyconfig_remove: bl_operators.userpref.PREFERENCES_OT_keyconfig_remove

PREFERENCES_OT_keyconfig_test: bl_operators.userpref.PREFERENCES_OT_keyconfig_test

PREFERENCES_OT_keyitem_add: bl_operators.userpref.PREFERENCES_OT_keyitem_add

PREFERENCES_OT_keyitem_remove: bl_operators.userpref.PREFERENCES_OT_keyitem_remove

PREFERENCES_OT_keyitem_restore: bl_operators.userpref.PREFERENCES_OT_keyitem_restore

PREFERENCES_OT_keymap_restore: bl_operators.userpref.PREFERENCES_OT_keymap_restore

PREFERENCES_OT_script_directory_remove: bl_operators.userpref.PREFERENCES_OT_script_directory_remove

PREFERENCES_OT_studiolight_copy_settings: bl_operators.userpref.PREFERENCES_OT_studiolight_copy_settings

PREFERENCES_OT_studiolight_install: bl_operators.userpref.PREFERENCES_OT_studiolight_install

PREFERENCES_OT_studiolight_new: bl_operators.userpref.PREFERENCES_OT_studiolight_new

PREFERENCES_OT_studiolight_uninstall: bl_operators.userpref.PREFERENCES_OT_studiolight_uninstall

PREFERENCES_OT_theme_install: bl_operators.userpref.PREFERENCES_OT_theme_install

PROPERTIES_HT_header: bl_ui.space_properties.PROPERTIES_HT_header

PROPERTIES_PT_navigation_bar: bl_ui.space_properties.PROPERTIES_PT_navigation_bar

PROPERTIES_PT_options: bl_ui.space_properties.PROPERTIES_PT_options

PROPERTIES_PT_visibility: bl_ui.space_properties.PROPERTIES_PT_visibility

RENDER_MT_framerate_presets: bl_ui.properties_output.RENDER_MT_framerate_presets

RENDER_MT_lineset_context_menu: bl_ui.properties_freestyle.RENDER_MT_lineset_context_menu

RENDER_MT_pixeldensity_presets: bl_ui.properties_output.RENDER_MT_pixeldensity_presets

RENDER_OT_swap_dimensions: bl_operators.render.RENDER_OT_swap_dimensions

RENDER_PT_color_management: bl_ui.properties_render.RENDER_PT_color_management

RENDER_PT_color_management_advanced: bl_ui.properties_render.RENDER_PT_color_management_advanced

RENDER_PT_color_management_curves: bl_ui.properties_render.RENDER_PT_color_management_curves

RENDER_PT_color_management_white_balance: bl_ui.properties_render.RENDER_PT_color_management_white_balance

RENDER_PT_color_management_white_balance_presets: bl_ui.properties_render.RENDER_PT_color_management_white_balance_presets

RENDER_PT_color_management_working_space: bl_ui.properties_render.RENDER_PT_color_management_working_space

RENDER_PT_context: bl_ui.properties_render.RENDER_PT_context

RENDER_PT_eevee_clamping: bl_ui.properties_render.RENDER_PT_eevee_clamping

RENDER_PT_eevee_clamping_surface: bl_ui.properties_render.RENDER_PT_eevee_clamping_surface

RENDER_PT_eevee_clamping_volume: bl_ui.properties_render.RENDER_PT_eevee_clamping_volume

RENDER_PT_eevee_denoise: bl_ui.properties_render.RENDER_PT_eevee_denoise

RENDER_PT_eevee_depth_of_field: bl_ui.properties_render.RENDER_PT_eevee_depth_of_field

RENDER_PT_eevee_film: bl_ui.properties_render.RENDER_PT_eevee_film

RENDER_PT_eevee_gi_approximation: bl_ui.properties_render.RENDER_PT_eevee_gi_approximation

RENDER_PT_eevee_hair: bl_ui.properties_render.RENDER_PT_eevee_hair

RENDER_PT_eevee_light_paths: bl_ui.properties_render.RENDER_PT_eevee_light_paths

RENDER_PT_eevee_light_paths_intensity: bl_ui.properties_render.RENDER_PT_eevee_light_paths_intensity

RENDER_PT_eevee_motion_blur: bl_ui.properties_render.RENDER_PT_eevee_motion_blur

RENDER_PT_eevee_motion_blur_curve: bl_ui.properties_render.RENDER_PT_eevee_motion_blur_curve

RENDER_PT_eevee_performance: bl_ui.properties_render.RENDER_PT_eevee_performance

RENDER_PT_eevee_performance_compositor: bl_ui.properties_render.RENDER_PT_eevee_performance_compositor

RENDER_PT_eevee_performance_compositor_denoise_settings: bl_ui.properties_render.RENDER_PT_eevee_performance_compositor_denoise_settings

RENDER_PT_eevee_performance_memory: bl_ui.properties_render.RENDER_PT_eevee_performance_memory

RENDER_PT_eevee_performance_viewport: bl_ui.properties_render.RENDER_PT_eevee_performance_viewport

RENDER_PT_eevee_raytracing: bl_ui.properties_render.RENDER_PT_eevee_raytracing

RENDER_PT_eevee_raytracing_presets: bl_ui.properties_render.RENDER_PT_eevee_raytracing_presets

RENDER_PT_eevee_sampling: bl_ui.properties_render.RENDER_PT_eevee_sampling

RENDER_PT_eevee_sampling_advanced: bl_ui.properties_render.RENDER_PT_eevee_sampling_advanced

RENDER_PT_eevee_sampling_render: bl_ui.properties_render.RENDER_PT_eevee_sampling_render

RENDER_PT_eevee_sampling_shadows: bl_ui.properties_render.RENDER_PT_eevee_sampling_shadows

RENDER_PT_eevee_sampling_viewport: bl_ui.properties_render.RENDER_PT_eevee_sampling_viewport

RENDER_PT_eevee_screen_trace: bl_ui.properties_render.RENDER_PT_eevee_screen_trace

RENDER_PT_eevee_volumes: bl_ui.properties_render.RENDER_PT_eevee_volumes

RENDER_PT_eevee_volumes_range: bl_ui.properties_render.RENDER_PT_eevee_volumes_range

RENDER_PT_encoding: bl_ui.properties_output.RENDER_PT_encoding

RENDER_PT_encoding_audio: bl_ui.properties_output.RENDER_PT_encoding_audio

RENDER_PT_encoding_video: bl_ui.properties_output.RENDER_PT_encoding_video

RENDER_PT_ffmpeg_presets: bl_ui.properties_output.RENDER_PT_ffmpeg_presets

RENDER_PT_format: bl_ui.properties_output.RENDER_PT_format

RENDER_PT_format_presets: bl_ui.properties_output.RENDER_PT_format_presets

RENDER_PT_frame_range: bl_ui.properties_output.RENDER_PT_frame_range

RENDER_PT_freestyle: bl_ui.properties_freestyle.RENDER_PT_freestyle

RENDER_PT_gpencil: bl_ui.properties_render.RENDER_PT_gpencil

RENDER_PT_grease_pencil_render: bl_ui.properties_render.RENDER_PT_grease_pencil_render

RENDER_PT_grease_pencil_viewport: bl_ui.properties_render.RENDER_PT_grease_pencil_viewport

RENDER_PT_hydra_debug: bl_ui.properties_render.RENDER_PT_hydra_debug

RENDER_PT_opengl_color: bl_ui.properties_render.RENDER_PT_opengl_color

RENDER_PT_opengl_film: bl_ui.properties_render.RENDER_PT_opengl_film

RENDER_PT_opengl_lighting: bl_ui.properties_render.RENDER_PT_opengl_lighting

RENDER_PT_opengl_options: bl_ui.properties_render.RENDER_PT_opengl_options

RENDER_PT_opengl_sampling: bl_ui.properties_render.RENDER_PT_opengl_sampling

RENDER_PT_output: bl_ui.properties_output.RENDER_PT_output

RENDER_PT_output_color_management: bl_ui.properties_output.RENDER_PT_output_color_management

RENDER_PT_output_pixel_density: bl_ui.properties_output.RENDER_PT_output_pixel_density

RENDER_PT_output_views: bl_ui.properties_output.RENDER_PT_output_views

RENDER_PT_post_processing: bl_ui.properties_output.RENDER_PT_post_processing

RENDER_PT_simplify: bl_ui.properties_render.RENDER_PT_simplify

RENDER_PT_simplify_greasepencil: bl_ui.properties_render.RENDER_PT_simplify_greasepencil

RENDER_PT_simplify_render: bl_ui.properties_render.RENDER_PT_simplify_render

RENDER_PT_simplify_viewport: bl_ui.properties_render.RENDER_PT_simplify_viewport

RENDER_PT_stamp: bl_ui.properties_output.RENDER_PT_stamp

RENDER_PT_stamp_burn: bl_ui.properties_output.RENDER_PT_stamp_burn

RENDER_PT_stamp_note: bl_ui.properties_output.RENDER_PT_stamp_note

RENDER_PT_stereoscopy: bl_ui.properties_output.RENDER_PT_stereoscopy

RENDER_PT_time_stretching: bl_ui.properties_output.RENDER_PT_time_stretching

RENDER_UL_renderviews: bl_ui.properties_output.RENDER_UL_renderviews

SCENE_OT_freestyle_add_edge_marks_to_keying_set: bl_operators.freestyle.SCENE_OT_freestyle_add_edge_marks_to_keying_set

SCENE_OT_freestyle_add_face_marks_to_keying_set: bl_operators.freestyle.SCENE_OT_freestyle_add_face_marks_to_keying_set

SCENE_OT_freestyle_fill_range_by_selection: bl_operators.freestyle.SCENE_OT_freestyle_fill_range_by_selection

SCENE_OT_freestyle_module_open: bl_operators.freestyle.SCENE_OT_freestyle_module_open

SCENE_PT_animation: bl_ui.properties_scene.SCENE_PT_animation

SCENE_PT_audio: bl_ui.properties_scene.SCENE_PT_audio

SCENE_PT_context_scene: bl_ui.properties_scene.SCENE_PT_context_scene

SCENE_PT_custom_props: bl_ui.properties_scene.SCENE_PT_custom_props

SCENE_PT_eevee_light_probes: bl_ui.properties_scene.SCENE_PT_eevee_light_probes

SCENE_PT_keyframing_settings: bl_ui.properties_scene.SCENE_PT_keyframing_settings

SCENE_PT_keying_set_paths: bl_ui.properties_scene.SCENE_PT_keying_set_paths

SCENE_PT_keying_sets: bl_ui.properties_scene.SCENE_PT_keying_sets

SCENE_PT_physics: bl_ui.properties_scene.SCENE_PT_physics

SCENE_PT_rigid_body_cache: bl_ui.properties_scene.SCENE_PT_rigid_body_cache

SCENE_PT_rigid_body_field_weights: bl_ui.properties_scene.SCENE_PT_rigid_body_field_weights

SCENE_PT_rigid_body_world: bl_ui.properties_scene.SCENE_PT_rigid_body_world

SCENE_PT_rigid_body_world_settings: bl_ui.properties_scene.SCENE_PT_rigid_body_world_settings

SCENE_PT_scene: bl_ui.properties_scene.SCENE_PT_scene

SCENE_PT_simulation: bl_ui.properties_scene.SCENE_PT_simulation

SCENE_PT_unit: bl_ui.properties_scene.SCENE_PT_unit

SCENE_UL_keying_set_paths: bl_ui.properties_scene.SCENE_UL_keying_set_paths

SEQUENCER_FH_image_strip: bl_operators.sequencer.SEQUENCER_FH_image_strip

SEQUENCER_FH_movie_strip: bl_operators.sequencer.SEQUENCER_FH_movie_strip

SEQUENCER_FH_sound_strip: bl_operators.sequencer.SEQUENCER_FH_sound_strip

SEQUENCER_HT_header: bl_ui.space_sequencer.SEQUENCER_HT_header

SEQUENCER_HT_playback_controls: bl_ui.space_sequencer.SEQUENCER_HT_playback_controls

SEQUENCER_HT_tool_header: bl_ui.space_sequencer.SEQUENCER_HT_tool_header

SEQUENCER_MT_add: bl_ui.space_sequencer.SEQUENCER_MT_add

SEQUENCER_MT_add_effect: bl_ui.space_sequencer.SEQUENCER_MT_add_effect

SEQUENCER_MT_add_empty: bl_ui.space_sequencer.SEQUENCER_MT_add_empty

SEQUENCER_MT_add_transitions: bl_ui.space_sequencer.SEQUENCER_MT_add_transitions

SEQUENCER_MT_change: bl_ui.space_sequencer.SEQUENCER_MT_change

SEQUENCER_MT_color_tag_picker: bl_ui.space_sequencer.SEQUENCER_MT_color_tag_picker

SEQUENCER_MT_context_menu: bl_ui.space_sequencer.SEQUENCER_MT_context_menu

SEQUENCER_MT_editor_menus: bl_ui.space_sequencer.SEQUENCER_MT_editor_menus

SEQUENCER_MT_image: bl_ui.space_sequencer.SEQUENCER_MT_image

SEQUENCER_MT_image_apply: bl_ui.space_sequencer.SEQUENCER_MT_image_apply

SEQUENCER_MT_image_clear: bl_ui.space_sequencer.SEQUENCER_MT_image_clear

SEQUENCER_MT_image_transform: bl_ui.space_sequencer.SEQUENCER_MT_image_transform

SEQUENCER_MT_marker: bl_ui.space_sequencer.SEQUENCER_MT_marker

SEQUENCER_MT_modifier_add: bl_ui.space_sequencer.SEQUENCER_MT_modifier_add

SEQUENCER_MT_navigation: bl_ui.space_sequencer.SEQUENCER_MT_navigation

SEQUENCER_MT_pivot_pie: bl_ui.space_sequencer.SEQUENCER_MT_pivot_pie

SEQUENCER_MT_preview_context_menu: bl_ui.space_sequencer.SEQUENCER_MT_preview_context_menu

SEQUENCER_MT_preview_view_pie: bl_ui.space_sequencer.SEQUENCER_MT_preview_view_pie

SEQUENCER_MT_preview_zoom: bl_ui.space_sequencer.SEQUENCER_MT_preview_zoom

SEQUENCER_MT_proxy: bl_ui.space_sequencer.SEQUENCER_MT_proxy

SEQUENCER_MT_range: bl_ui.space_sequencer.SEQUENCER_MT_range

SEQUENCER_MT_retiming: bl_ui.space_sequencer.SEQUENCER_MT_retiming

SEQUENCER_MT_select: bl_ui.space_sequencer.SEQUENCER_MT_select

SEQUENCER_MT_select_channel: bl_ui.space_sequencer.SEQUENCER_MT_select_channel

SEQUENCER_MT_select_handle: bl_ui.space_sequencer.SEQUENCER_MT_select_handle

SEQUENCER_MT_strip: bl_ui.space_sequencer.SEQUENCER_MT_strip

SEQUENCER_MT_strip_animation: bl_ui.space_sequencer.SEQUENCER_MT_strip_animation

SEQUENCER_MT_strip_effect: bl_ui.space_sequencer.SEQUENCER_MT_strip_effect

SEQUENCER_MT_strip_effect_change: bl_ui.space_sequencer.SEQUENCER_MT_strip_effect_change

SEQUENCER_MT_strip_input: bl_ui.space_sequencer.SEQUENCER_MT_strip_input

SEQUENCER_MT_strip_lock_mute: bl_ui.space_sequencer.SEQUENCER_MT_strip_lock_mute

SEQUENCER_MT_strip_mirror: bl_ui.space_sequencer.SEQUENCER_MT_strip_mirror

SEQUENCER_MT_strip_modifiers: bl_ui.space_sequencer.SEQUENCER_MT_strip_modifiers

SEQUENCER_MT_strip_movie: bl_ui.space_sequencer.SEQUENCER_MT_strip_movie

SEQUENCER_MT_strip_retiming: bl_ui.space_sequencer.SEQUENCER_MT_strip_retiming

SEQUENCER_MT_strip_show_hide: bl_ui.space_sequencer.SEQUENCER_MT_strip_show_hide

SEQUENCER_MT_strip_text: bl_ui.space_sequencer.SEQUENCER_MT_strip_text

SEQUENCER_MT_strip_transform: bl_ui.space_sequencer.SEQUENCER_MT_strip_transform

SEQUENCER_MT_view: bl_ui.space_sequencer.SEQUENCER_MT_view

SEQUENCER_MT_view_pie: bl_ui.space_sequencer.SEQUENCER_MT_view_pie

SEQUENCER_PT_active_tool: bl_ui.space_sequencer.SEQUENCER_PT_active_tool

SEQUENCER_PT_annotation: bl_ui.space_sequencer.SEQUENCER_PT_annotation

SEQUENCER_PT_annotation_onion: bl_ui.space_sequencer.SEQUENCER_PT_annotation_onion

SEQUENCER_PT_cache_settings: bl_ui.space_sequencer.SEQUENCER_PT_cache_settings

SEQUENCER_PT_cache_view_settings: bl_ui.space_sequencer.SEQUENCER_PT_cache_view_settings

SEQUENCER_PT_frame_overlay: bl_ui.space_sequencer.SEQUENCER_PT_frame_overlay

SEQUENCER_PT_gizmo_display: bl_ui.space_sequencer.SEQUENCER_PT_gizmo_display

SEQUENCER_PT_overlay: bl_ui.space_sequencer.SEQUENCER_PT_overlay

SEQUENCER_PT_preview: bl_ui.space_sequencer.SEQUENCER_PT_preview

SEQUENCER_PT_preview_overlay: bl_ui.space_sequencer.SEQUENCER_PT_preview_overlay

SEQUENCER_PT_preview_snapping: bl_ui.space_sequencer.SEQUENCER_PT_preview_snapping

SEQUENCER_PT_proxy_settings: bl_ui.space_sequencer.SEQUENCER_PT_proxy_settings

SEQUENCER_PT_sequencer_overlay: bl_ui.space_sequencer.SEQUENCER_PT_sequencer_overlay

SEQUENCER_PT_sequencer_overlay_strips: bl_ui.space_sequencer.SEQUENCER_PT_sequencer_overlay_strips

SEQUENCER_PT_sequencer_overlay_thumbnails: bl_ui.space_sequencer.SEQUENCER_PT_sequencer_overlay_thumbnails

SEQUENCER_PT_sequencer_overlay_waveforms: bl_ui.space_sequencer.SEQUENCER_PT_sequencer_overlay_waveforms

SEQUENCER_PT_sequencer_snapping: bl_ui.space_sequencer.SEQUENCER_PT_sequencer_snapping

SEQUENCER_PT_snapping: bl_ui.space_sequencer.SEQUENCER_PT_snapping

SEQUENCER_PT_strip_proxy: bl_ui.space_sequencer.SEQUENCER_PT_strip_proxy

SEQUENCER_PT_tools_active: bl_ui.space_toolsystem_toolbar.SEQUENCER_PT_tools_active

SEQUENCER_PT_view: bl_ui.space_sequencer.SEQUENCER_PT_view

SEQUENCER_PT_view_cursor: bl_ui.space_sequencer.SEQUENCER_PT_view_cursor

SEQUENCER_PT_view_safe_areas: bl_ui.space_sequencer.SEQUENCER_PT_view_safe_areas

SEQUENCER_PT_view_safe_areas_center_cut: bl_ui.space_sequencer.SEQUENCER_PT_view_safe_areas_center_cut

SPREADSHEET_HT_header: bl_ui.space_spreadsheet.SPREADSHEET_HT_header

SPREADSHEET_MT_editor_menus: bl_ui.space_spreadsheet.SPREADSHEET_MT_editor_menus

SPREADSHEET_MT_view: bl_ui.space_spreadsheet.SPREADSHEET_MT_view

SPREADSHEET_OT_toggle_pin: bl_operators.spreadsheet.SPREADSHEET_OT_toggle_pin

STATUSBAR_HT_header: bl_ui.space_statusbar.STATUSBAR_HT_header

STRIP_PT_adjust_color: bl_ui.properties_strip.STRIP_PT_adjust_color

STRIP_PT_adjust_comp: bl_ui.properties_strip.STRIP_PT_adjust_comp

STRIP_PT_adjust_crop: bl_ui.properties_strip.STRIP_PT_adjust_crop

STRIP_PT_adjust_sound: bl_ui.properties_strip.STRIP_PT_adjust_sound

STRIP_PT_adjust_transform: bl_ui.properties_strip.STRIP_PT_adjust_transform

STRIP_PT_adjust_video: bl_ui.properties_strip.STRIP_PT_adjust_video

STRIP_PT_color_tag_picker: bl_ui.properties_strip.STRIP_PT_color_tag_picker

STRIP_PT_custom_props: bl_ui.properties_strip.STRIP_PT_custom_props

STRIP_PT_effect: bl_ui.properties_strip.STRIP_PT_effect

STRIP_PT_effect_text_box: bl_ui.properties_strip.STRIP_PT_effect_text_box

STRIP_PT_effect_text_layout: bl_ui.properties_strip.STRIP_PT_effect_text_layout

STRIP_PT_effect_text_outline: bl_ui.properties_strip.STRIP_PT_effect_text_outline

STRIP_PT_effect_text_shadow: bl_ui.properties_strip.STRIP_PT_effect_text_shadow

STRIP_PT_effect_text_style: bl_ui.properties_strip.STRIP_PT_effect_text_style

STRIP_PT_mask: bl_ui.properties_strip.STRIP_PT_mask

STRIP_PT_modifiers: bl_ui.properties_strip_modifier.STRIP_PT_modifiers

STRIP_PT_movie_clip: bl_ui.properties_strip.STRIP_PT_movie_clip

STRIP_PT_scene: bl_ui.properties_strip.STRIP_PT_scene

STRIP_PT_scene_sound: bl_ui.properties_strip.STRIP_PT_scene_sound

STRIP_PT_source: bl_ui.properties_strip.STRIP_PT_source

STRIP_PT_strip: bl_ui.properties_strip.STRIP_PT_strip

STRIP_PT_time: bl_ui.properties_strip.STRIP_PT_time

TEXTURE_MT_context_menu: bl_ui.properties_texture.TEXTURE_MT_context_menu

TEXTURE_PT_animation: bl_ui.properties_texture.TEXTURE_PT_animation

TEXTURE_PT_blend: bl_ui.properties_texture.TEXTURE_PT_blend

TEXTURE_PT_clouds: bl_ui.properties_texture.TEXTURE_PT_clouds

TEXTURE_PT_colors: bl_ui.properties_texture.TEXTURE_PT_colors

TEXTURE_PT_colors_ramp: bl_ui.properties_texture.TEXTURE_PT_colors_ramp

TEXTURE_PT_context: bl_ui.properties_texture.TEXTURE_PT_context

TEXTURE_PT_custom_props: bl_ui.properties_texture.TEXTURE_PT_custom_props

TEXTURE_PT_distortednoise: bl_ui.properties_texture.TEXTURE_PT_distortednoise

TEXTURE_PT_image: bl_ui.properties_texture.TEXTURE_PT_image

TEXTURE_PT_image_alpha: bl_ui.properties_texture.TEXTURE_PT_image_alpha

TEXTURE_PT_image_mapping: bl_ui.properties_texture.TEXTURE_PT_image_mapping

TEXTURE_PT_image_mapping_crop: bl_ui.properties_texture.TEXTURE_PT_image_mapping_crop

TEXTURE_PT_image_sampling: bl_ui.properties_texture.TEXTURE_PT_image_sampling

TEXTURE_PT_image_settings: bl_ui.properties_texture.TEXTURE_PT_image_settings

TEXTURE_PT_influence: bl_ui.properties_texture.TEXTURE_PT_influence

TEXTURE_PT_magic: bl_ui.properties_texture.TEXTURE_PT_magic

TEXTURE_PT_mapping: bl_ui.properties_texture.TEXTURE_PT_mapping

TEXTURE_PT_marble: bl_ui.properties_texture.TEXTURE_PT_marble

TEXTURE_PT_musgrave: bl_ui.properties_texture.TEXTURE_PT_musgrave

TEXTURE_PT_node: bl_ui.properties_texture.TEXTURE_PT_node

TEXTURE_PT_preview: bl_ui.properties_texture.TEXTURE_PT_preview

TEXTURE_PT_stucci: bl_ui.properties_texture.TEXTURE_PT_stucci

TEXTURE_PT_voronoi: bl_ui.properties_texture.TEXTURE_PT_voronoi

TEXTURE_PT_voronoi_feature_weights: bl_ui.properties_texture.TEXTURE_PT_voronoi_feature_weights

TEXTURE_PT_wood: bl_ui.properties_texture.TEXTURE_PT_wood

TEXTURE_UL_texpaintslots: bl_ui.space_view3d_toolbar.TEXTURE_UL_texpaintslots

TEXTURE_UL_texslots: bl_ui.properties_texture.TEXTURE_UL_texslots

TEXT_HT_footer: bl_ui.space_text.TEXT_HT_footer

TEXT_HT_header: bl_ui.space_text.TEXT_HT_header

TEXT_MT_context_menu: bl_ui.space_text.TEXT_MT_context_menu

TEXT_MT_edit: bl_ui.space_text.TEXT_MT_edit

TEXT_MT_edit_to3d: bl_ui.space_text.TEXT_MT_edit_to3d

TEXT_MT_editor_menus: bl_ui.space_text.TEXT_MT_editor_menus

TEXT_MT_format: bl_ui.space_text.TEXT_MT_format

TEXT_MT_select: bl_ui.space_text.TEXT_MT_select

TEXT_MT_templates: bl_ui.space_text.TEXT_MT_templates

TEXT_MT_templates_osl: bl_ui.space_text.TEXT_MT_templates_osl

TEXT_MT_templates_py: bl_ui.space_text.TEXT_MT_templates_py

TEXT_MT_text: bl_ui.space_text.TEXT_MT_text

TEXT_MT_view: bl_ui.space_text.TEXT_MT_view

TEXT_MT_view_navigation: bl_ui.space_text.TEXT_MT_view_navigation

TEXT_PT_find: bl_ui.space_text.TEXT_PT_find

TEXT_PT_properties: bl_ui.space_text.TEXT_PT_properties

TIME_MT_view: bl_ui.space_time.TIME_MT_view

TIME_PT_auto_keyframing: bl_ui.space_time.TIME_PT_auto_keyframing

TIME_PT_jump: bl_ui.space_time.TIME_PT_jump

TIME_PT_keyframing_settings: bl_ui.space_time.TIME_PT_keyframing_settings

TIME_PT_playback: bl_ui.space_time.TIME_PT_playback

TIME_PT_playhead_snapping: bl_ui.space_time.TIME_PT_playhead_snapping

TOPBAR_HT_upper_bar: bl_ui.space_topbar.TOPBAR_HT_upper_bar

TOPBAR_MT_blender: bl_ui.space_topbar.TOPBAR_MT_blender

TOPBAR_MT_blender_system: bl_ui.space_topbar.TOPBAR_MT_blender_system

TOPBAR_MT_edit: bl_ui.space_topbar.TOPBAR_MT_edit

TOPBAR_MT_edit_armature_add: bl_ui.space_view3d.TOPBAR_MT_edit_armature_add

TOPBAR_MT_edit_curve_add: bl_ui.space_view3d.TOPBAR_MT_edit_curve_add

TOPBAR_MT_editor_menus: bl_ui.space_topbar.TOPBAR_MT_editor_menus

TOPBAR_MT_file: bl_ui.space_topbar.TOPBAR_MT_file

TOPBAR_MT_file_cleanup: bl_ui.space_topbar.TOPBAR_MT_file_cleanup

TOPBAR_MT_file_context_menu: bl_ui.space_topbar.TOPBAR_MT_file_context_menu

TOPBAR_MT_file_defaults: bl_ui.space_topbar.TOPBAR_MT_file_defaults

TOPBAR_MT_file_export: bl_ui.space_topbar.TOPBAR_MT_file_export

TOPBAR_MT_file_external_data: bl_ui.space_topbar.TOPBAR_MT_file_external_data

TOPBAR_MT_file_import: bl_ui.space_topbar.TOPBAR_MT_file_import

TOPBAR_MT_file_new: bl_ui.space_topbar.TOPBAR_MT_file_new

TOPBAR_MT_file_previews: bl_ui.space_topbar.TOPBAR_MT_file_previews

TOPBAR_MT_file_recover: bl_ui.space_topbar.TOPBAR_MT_file_recover

TOPBAR_MT_help: bl_ui.space_topbar.TOPBAR_MT_help

TOPBAR_MT_render: bl_ui.space_topbar.TOPBAR_MT_render

TOPBAR_MT_templates_more: bl_ui.space_topbar.TOPBAR_MT_templates_more

TOPBAR_MT_window: bl_ui.space_topbar.TOPBAR_MT_window

TOPBAR_MT_workspace_menu: bl_ui.space_topbar.TOPBAR_MT_workspace_menu

TOPBAR_PT_annotation_layers: bl_ui.space_view3d.TOPBAR_PT_annotation_layers

TOPBAR_PT_gpencil_primitive: bl_ui.space_topbar.TOPBAR_PT_gpencil_primitive

TOPBAR_PT_grease_pencil_layers: bl_ui.space_topbar.TOPBAR_PT_grease_pencil_layers

TOPBAR_PT_grease_pencil_materials: bl_ui.space_view3d.TOPBAR_PT_grease_pencil_materials

TOPBAR_PT_grease_pencil_vertex_color: bl_ui.space_view3d.TOPBAR_PT_grease_pencil_vertex_color

TOPBAR_PT_name: bl_ui.space_topbar.TOPBAR_PT_name

TOPBAR_PT_name_marker: bl_ui.space_topbar.TOPBAR_PT_name_marker

TOPBAR_PT_tool_fallback: bl_ui.space_topbar.TOPBAR_PT_tool_fallback

TOPBAR_PT_tool_settings_extra: bl_ui.space_topbar.TOPBAR_PT_tool_settings_extra

UILIST_OT_entry_add: bl_ui.generic_ui_list.UILIST_OT_entry_add

UILIST_OT_entry_move: bl_ui.generic_ui_list.UILIST_OT_entry_move

UILIST_OT_entry_remove: bl_ui.generic_ui_list.UILIST_OT_entry_remove

UI_MT_button_context_menu: bl_ui.UI_MT_button_context_menu

UI_MT_list_item_context_menu: bl_ui.UI_MT_list_item_context_menu

UI_UL_list: bl_ui.UI_UL_list

USERPREF_HT_header: bl_ui.space_userpref.USERPREF_HT_header

USERPREF_MT_editor_menus: bl_ui.space_userpref.USERPREF_MT_editor_menus

USERPREF_MT_extensions_active_repo: bl_ui.space_userpref.USERPREF_MT_extensions_active_repo

USERPREF_MT_extensions_active_repo_remove: bl_ui.space_userpref.USERPREF_MT_extensions_active_repo_remove

USERPREF_MT_interface_theme_presets: bl_ui.space_userpref.USERPREF_MT_interface_theme_presets

USERPREF_MT_keyconfigs: bl_ui.space_userpref.USERPREF_MT_keyconfigs

USERPREF_MT_save_load: bl_ui.space_userpref.USERPREF_MT_save_load

USERPREF_MT_view: bl_ui.space_userpref.USERPREF_MT_view

USERPREF_PT_addons: bl_ui.space_userpref.USERPREF_PT_addons

USERPREF_PT_addons_filter: bl_ui.space_userpref.USERPREF_PT_addons_filter

USERPREF_PT_animation_fcurves: bl_ui.space_userpref.USERPREF_PT_animation_fcurves

USERPREF_PT_animation_keyframes: bl_ui.space_userpref.USERPREF_PT_animation_keyframes

USERPREF_PT_animation_timeline: bl_ui.space_userpref.USERPREF_PT_animation_timeline

USERPREF_PT_assets: bl_ui.space_userpref.USERPREF_PT_assets

USERPREF_PT_assets_asset_libraries: bl_ui.space_userpref.USERPREF_PT_assets_asset_libraries

USERPREF_PT_developer_tools: bl_ui.space_userpref.USERPREF_PT_developer_tools

USERPREF_PT_edit_annotations: bl_ui.space_userpref.USERPREF_PT_edit_annotations

USERPREF_PT_edit_cursor: bl_ui.space_userpref.USERPREF_PT_edit_cursor

USERPREF_PT_edit_gpencil: bl_ui.space_userpref.USERPREF_PT_edit_gpencil

USERPREF_PT_edit_misc: bl_ui.space_userpref.USERPREF_PT_edit_misc

USERPREF_PT_edit_node_editor: bl_ui.space_userpref.USERPREF_PT_edit_node_editor

USERPREF_PT_edit_objects: bl_ui.space_userpref.USERPREF_PT_edit_objects

USERPREF_PT_edit_objects_duplicate_data: bl_ui.space_userpref.USERPREF_PT_edit_objects_duplicate_data

USERPREF_PT_edit_objects_new: bl_ui.space_userpref.USERPREF_PT_edit_objects_new

USERPREF_PT_edit_sequence_editor: bl_ui.space_userpref.USERPREF_PT_edit_sequence_editor

USERPREF_PT_edit_text_editor: bl_ui.space_userpref.USERPREF_PT_edit_text_editor

USERPREF_PT_edit_weight_paint: bl_ui.space_userpref.USERPREF_PT_edit_weight_paint

USERPREF_PT_experimental_new_features: bl_ui.space_userpref.USERPREF_PT_experimental_new_features

USERPREF_PT_experimental_prototypes: bl_ui.space_userpref.USERPREF_PT_experimental_prototypes

USERPREF_PT_extensions: bl_ui.space_userpref.USERPREF_PT_extensions

USERPREF_PT_extensions_repos: bl_ui.space_userpref.USERPREF_PT_extensions_repos

USERPREF_PT_file_paths_applications: bl_ui.space_userpref.USERPREF_PT_file_paths_applications

USERPREF_PT_file_paths_data: bl_ui.space_userpref.USERPREF_PT_file_paths_data

USERPREF_PT_file_paths_development: bl_ui.space_userpref.USERPREF_PT_file_paths_development

USERPREF_PT_file_paths_render: bl_ui.space_userpref.USERPREF_PT_file_paths_render

USERPREF_PT_file_paths_script_directories: bl_ui.space_userpref.USERPREF_PT_file_paths_script_directories

USERPREF_PT_input_keyboard: bl_ui.space_userpref.USERPREF_PT_input_keyboard

USERPREF_PT_input_mouse: bl_ui.space_userpref.USERPREF_PT_input_mouse

USERPREF_PT_input_ndof: bl_ui.space_userpref.USERPREF_PT_input_ndof

USERPREF_PT_input_tablet: bl_ui.space_userpref.USERPREF_PT_input_tablet

USERPREF_PT_input_touchpad: bl_ui.space_userpref.USERPREF_PT_input_touchpad

USERPREF_PT_interface_accessibility: bl_ui.space_userpref.USERPREF_PT_interface_accessibility

USERPREF_PT_interface_display: bl_ui.space_userpref.USERPREF_PT_interface_display

USERPREF_PT_interface_editors: bl_ui.space_userpref.USERPREF_PT_interface_editors

USERPREF_PT_interface_menus: bl_ui.space_userpref.USERPREF_PT_interface_menus

USERPREF_PT_interface_menus_mouse_over: bl_ui.space_userpref.USERPREF_PT_interface_menus_mouse_over

USERPREF_PT_interface_menus_pie: bl_ui.space_userpref.USERPREF_PT_interface_menus_pie

USERPREF_PT_interface_statusbar: bl_ui.space_userpref.USERPREF_PT_interface_statusbar

USERPREF_PT_interface_temporary_windows: bl_ui.space_userpref.USERPREF_PT_interface_temporary_windows

USERPREF_PT_interface_text: bl_ui.space_userpref.USERPREF_PT_interface_text

USERPREF_PT_interface_translation: bl_ui.space_userpref.USERPREF_PT_interface_translation

USERPREF_PT_keymap: bl_ui.space_userpref.USERPREF_PT_keymap

USERPREF_PT_navigation_bar: bl_ui.space_userpref.USERPREF_PT_navigation_bar

USERPREF_PT_navigation_fly_walk: bl_ui.space_userpref.USERPREF_PT_navigation_fly_walk

USERPREF_PT_navigation_fly_walk_gravity: bl_ui.space_userpref.USERPREF_PT_navigation_fly_walk_gravity

USERPREF_PT_navigation_fly_walk_navigation: bl_ui.space_userpref.USERPREF_PT_navigation_fly_walk_navigation

USERPREF_PT_navigation_orbit: bl_ui.space_userpref.USERPREF_PT_navigation_orbit

USERPREF_PT_navigation_zoom: bl_ui.space_userpref.USERPREF_PT_navigation_zoom

USERPREF_PT_ndof_settings: bl_ui.space_userpref.USERPREF_PT_ndof_settings

USERPREF_PT_save_preferences: bl_ui.space_userpref.USERPREF_PT_save_preferences

USERPREF_PT_saveload_autorun: bl_ui.space_userpref.USERPREF_PT_saveload_autorun

USERPREF_PT_saveload_blend: bl_ui.space_userpref.USERPREF_PT_saveload_blend

USERPREF_PT_saveload_file_browser: bl_ui.space_userpref.USERPREF_PT_saveload_file_browser

USERPREF_PT_studiolight_light_editor: bl_ui.space_userpref.USERPREF_PT_studiolight_light_editor

USERPREF_PT_studiolight_lights: bl_ui.space_userpref.USERPREF_PT_studiolight_lights

USERPREF_PT_studiolight_matcaps: bl_ui.space_userpref.USERPREF_PT_studiolight_matcaps

USERPREF_PT_studiolight_world: bl_ui.space_userpref.USERPREF_PT_studiolight_world

USERPREF_PT_system_cycles_devices: bl_ui.space_userpref.USERPREF_PT_system_cycles_devices

USERPREF_PT_system_display_graphics: bl_ui.space_userpref.USERPREF_PT_system_display_graphics

USERPREF_PT_system_memory: bl_ui.space_userpref.USERPREF_PT_system_memory

USERPREF_PT_system_network: bl_ui.space_userpref.USERPREF_PT_system_network

USERPREF_PT_system_os_settings: bl_ui.space_userpref.USERPREF_PT_system_os_settings

USERPREF_PT_system_sound: bl_ui.space_userpref.USERPREF_PT_system_sound

USERPREF_PT_system_video_sequencer: bl_ui.space_userpref.USERPREF_PT_system_video_sequencer

USERPREF_PT_text_editor: bl_ui.space_userpref.USERPREF_PT_text_editor

USERPREF_PT_text_editor_presets: bl_ui.space_userpref.USERPREF_PT_text_editor_presets

USERPREF_PT_theme: bl_ui.space_userpref.USERPREF_PT_theme

USERPREF_PT_theme_bone_color_sets: bl_ui.space_userpref.USERPREF_PT_theme_bone_color_sets

USERPREF_PT_theme_collection_colors: bl_ui.space_userpref.USERPREF_PT_theme_collection_colors

USERPREF_PT_theme_interface_gizmos: bl_ui.space_userpref.USERPREF_PT_theme_interface_gizmos

USERPREF_PT_theme_interface_icons: bl_ui.space_userpref.USERPREF_PT_theme_interface_icons

USERPREF_PT_theme_interface_panel: bl_ui.space_userpref.USERPREF_PT_theme_interface_panel

USERPREF_PT_theme_interface_state: bl_ui.space_userpref.USERPREF_PT_theme_interface_state

USERPREF_PT_theme_interface_styles: bl_ui.space_userpref.USERPREF_PT_theme_interface_styles

USERPREF_PT_theme_interface_transparent_checker: bl_ui.space_userpref.USERPREF_PT_theme_interface_transparent_checker

USERPREF_PT_theme_strip_colors: bl_ui.space_userpref.USERPREF_PT_theme_strip_colors

USERPREF_PT_theme_text_style: bl_ui.space_userpref.USERPREF_PT_theme_text_style

USERPREF_PT_theme_user_interface: bl_ui.space_userpref.USERPREF_PT_theme_user_interface

USERPREF_PT_viewport_display: bl_ui.space_userpref.USERPREF_PT_viewport_display

USERPREF_PT_viewport_quality: bl_ui.space_userpref.USERPREF_PT_viewport_quality

USERPREF_PT_viewport_subdivision: bl_ui.space_userpref.USERPREF_PT_viewport_subdivision

USERPREF_PT_viewport_textures: bl_ui.space_userpref.USERPREF_PT_viewport_textures

USERPREF_UL_asset_libraries: bl_ui.space_userpref.USERPREF_UL_asset_libraries

USERPREF_UL_extension_repos: bl_ui.space_userpref.USERPREF_UL_extension_repos

VIEW3D_AST_brush_gpencil_paint: bl_ui.space_view3d.VIEW3D_AST_brush_gpencil_paint

VIEW3D_AST_brush_gpencil_sculpt: bl_ui.space_view3d.VIEW3D_AST_brush_gpencil_sculpt

VIEW3D_AST_brush_gpencil_vertex: bl_ui.space_view3d.VIEW3D_AST_brush_gpencil_vertex

VIEW3D_AST_brush_gpencil_weight: bl_ui.space_view3d.VIEW3D_AST_brush_gpencil_weight

VIEW3D_AST_brush_sculpt: bl_ui.space_view3d.VIEW3D_AST_brush_sculpt

VIEW3D_AST_brush_sculpt_curves: bl_ui.space_view3d.VIEW3D_AST_brush_sculpt_curves

VIEW3D_AST_brush_texture_paint: bl_ui.space_view3d.VIEW3D_AST_brush_texture_paint

VIEW3D_AST_brush_vertex_paint: bl_ui.space_view3d.VIEW3D_AST_brush_vertex_paint

VIEW3D_AST_brush_weight_paint: bl_ui.space_view3d.VIEW3D_AST_brush_weight_paint

VIEW3D_FH_camera_background_image: bl_operators.view3d.VIEW3D_FH_camera_background_image

VIEW3D_FH_empty_image: bl_operators.view3d.VIEW3D_FH_empty_image

VIEW3D_FH_vdb_volume: bl_operators.view3d.VIEW3D_FH_vdb_volume

VIEW3D_HT_header: bl_ui.space_view3d.VIEW3D_HT_header

VIEW3D_HT_tool_header: bl_ui.space_view3d.VIEW3D_HT_tool_header

VIEW3D_MT_add: bl_ui.space_view3d.VIEW3D_MT_add

VIEW3D_MT_add_object: bl_ui.space_view3d.VIEW3D_MT_add_object

VIEW3D_MT_armature_add: bl_ui.space_view3d.VIEW3D_MT_armature_add

VIEW3D_MT_armature_context_menu: bl_ui.space_view3d.VIEW3D_MT_armature_context_menu

VIEW3D_MT_bone_collections: bl_ui.space_view3d.VIEW3D_MT_bone_collections

VIEW3D_MT_bone_options_disable: bl_ui.space_view3d.VIEW3D_MT_bone_options_disable

VIEW3D_MT_bone_options_enable: bl_ui.space_view3d.VIEW3D_MT_bone_options_enable

VIEW3D_MT_bone_options_toggle: bl_ui.space_view3d.VIEW3D_MT_bone_options_toggle

VIEW3D_MT_brush_context_menu: bl_ui.space_view3d_toolbar.VIEW3D_MT_brush_context_menu

VIEW3D_MT_camera_add: bl_ui.space_view3d.VIEW3D_MT_camera_add

VIEW3D_MT_curve_add: bl_ui.space_view3d.VIEW3D_MT_curve_add

VIEW3D_MT_edit_armature: bl_ui.space_view3d.VIEW3D_MT_edit_armature

VIEW3D_MT_edit_armature_delete: bl_ui.space_view3d.VIEW3D_MT_edit_armature_delete

VIEW3D_MT_edit_armature_names: bl_ui.space_view3d.VIEW3D_MT_edit_armature_names

VIEW3D_MT_edit_armature_parent: bl_ui.space_view3d.VIEW3D_MT_edit_armature_parent

VIEW3D_MT_edit_armature_roll: bl_ui.space_view3d.VIEW3D_MT_edit_armature_roll

VIEW3D_MT_edit_curve: bl_ui.space_view3d.VIEW3D_MT_edit_curve

VIEW3D_MT_edit_curve_clean: bl_ui.space_view3d.VIEW3D_MT_edit_curve_clean

VIEW3D_MT_edit_curve_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_curve_context_menu

VIEW3D_MT_edit_curve_ctrlpoints: bl_ui.space_view3d.VIEW3D_MT_edit_curve_ctrlpoints

VIEW3D_MT_edit_curve_delete: bl_ui.space_view3d.VIEW3D_MT_edit_curve_delete

VIEW3D_MT_edit_curve_segments: bl_ui.space_view3d.VIEW3D_MT_edit_curve_segments

VIEW3D_MT_edit_curve_showhide: bl_ui.space_view3d.VIEW3D_MT_edit_curve_showhide

VIEW3D_MT_edit_curves: bl_ui.space_view3d.VIEW3D_MT_edit_curves

VIEW3D_MT_edit_curves_add: bl_ui.space_view3d.VIEW3D_MT_edit_curves_add

VIEW3D_MT_edit_curves_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_curves_context_menu

VIEW3D_MT_edit_curves_control_points: bl_ui.space_view3d.VIEW3D_MT_edit_curves_control_points

VIEW3D_MT_edit_curves_segments: bl_ui.space_view3d.VIEW3D_MT_edit_curves_segments

VIEW3D_MT_edit_curves_select_more_less: bl_ui.space_view3d.VIEW3D_MT_edit_curves_select_more_less

VIEW3D_MT_edit_font: bl_ui.space_view3d.VIEW3D_MT_edit_font

VIEW3D_MT_edit_font_chars: bl_ui.space_view3d.VIEW3D_MT_edit_font_chars

VIEW3D_MT_edit_font_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_font_context_menu

VIEW3D_MT_edit_font_delete: bl_ui.space_view3d.VIEW3D_MT_edit_font_delete

VIEW3D_MT_edit_font_kerning: bl_ui.space_view3d.VIEW3D_MT_edit_font_kerning

VIEW3D_MT_edit_greasepencil: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil

VIEW3D_MT_edit_greasepencil_animation: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_animation

VIEW3D_MT_edit_greasepencil_cleanup: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_cleanup

VIEW3D_MT_edit_greasepencil_delete: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_delete

VIEW3D_MT_edit_greasepencil_point: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_point

VIEW3D_MT_edit_greasepencil_showhide: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_showhide

VIEW3D_MT_edit_greasepencil_stroke: bl_ui.space_view3d.VIEW3D_MT_edit_greasepencil_stroke

VIEW3D_MT_edit_lattice: bl_ui.space_view3d.VIEW3D_MT_edit_lattice

VIEW3D_MT_edit_lattice_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_lattice_context_menu

VIEW3D_MT_edit_mesh: bl_ui.space_view3d.VIEW3D_MT_edit_mesh

VIEW3D_MT_edit_mesh_clean: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_clean

VIEW3D_MT_edit_mesh_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_context_menu

VIEW3D_MT_edit_mesh_delete: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_delete

VIEW3D_MT_edit_mesh_edges: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_edges

VIEW3D_MT_edit_mesh_extrude: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_extrude

VIEW3D_MT_edit_mesh_faces: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_faces

VIEW3D_MT_edit_mesh_faces_data: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_faces_data

VIEW3D_MT_edit_mesh_merge: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_merge

VIEW3D_MT_edit_mesh_normals: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_normals

VIEW3D_MT_edit_mesh_normals_average: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_normals_average

VIEW3D_MT_edit_mesh_normals_select_strength: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_normals_select_strength

VIEW3D_MT_edit_mesh_normals_set_strength: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_normals_set_strength

VIEW3D_MT_edit_mesh_select_by_trait: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_by_trait

VIEW3D_MT_edit_mesh_select_linked: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_linked

VIEW3D_MT_edit_mesh_select_loops: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_loops

VIEW3D_MT_edit_mesh_select_mode: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_mode

VIEW3D_MT_edit_mesh_select_more_less: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_more_less

VIEW3D_MT_edit_mesh_select_similar: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_select_similar

VIEW3D_MT_edit_mesh_shading: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_shading

VIEW3D_MT_edit_mesh_showhide: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_showhide

VIEW3D_MT_edit_mesh_split: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_split

VIEW3D_MT_edit_mesh_vertices: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_vertices

VIEW3D_MT_edit_mesh_weights: bl_ui.space_view3d.VIEW3D_MT_edit_mesh_weights

VIEW3D_MT_edit_meta: bl_ui.space_view3d.VIEW3D_MT_edit_meta

VIEW3D_MT_edit_meta_showhide: bl_ui.space_view3d.VIEW3D_MT_edit_meta_showhide

VIEW3D_MT_edit_metaball_context_menu: bl_ui.space_view3d.VIEW3D_MT_edit_metaball_context_menu

VIEW3D_MT_edit_pointcloud: bl_ui.space_view3d.VIEW3D_MT_edit_pointcloud

VIEW3D_MT_edit_surface: bl_ui.space_view3d.VIEW3D_MT_edit_surface

VIEW3D_MT_editor_menus: bl_ui.space_view3d.VIEW3D_MT_editor_menus

VIEW3D_MT_empty_add: bl_ui.space_view3d.VIEW3D_MT_empty_add

VIEW3D_MT_face_sets: bl_ui.space_view3d.VIEW3D_MT_face_sets

VIEW3D_MT_face_sets_init: bl_ui.space_view3d.VIEW3D_MT_face_sets_init

VIEW3D_MT_grease_pencil_add: bl_ui.space_view3d.VIEW3D_MT_grease_pencil_add

VIEW3D_MT_grease_pencil_assign_material: bl_ui.space_view3d.VIEW3D_MT_grease_pencil_assign_material

VIEW3D_MT_grease_pencil_sculpt_automasking_pie: bl_ui.space_view3d.VIEW3D_MT_grease_pencil_sculpt_automasking_pie

VIEW3D_MT_greasepencil_edit_context_menu: bl_ui.space_view3d.VIEW3D_MT_greasepencil_edit_context_menu

VIEW3D_MT_greasepencil_material_active: bl_ui.space_view3d.VIEW3D_MT_greasepencil_material_active

VIEW3D_MT_greasepencil_vertex_group: bl_ui.space_view3d.VIEW3D_MT_greasepencil_vertex_group

VIEW3D_MT_hook: bl_ui.space_view3d.VIEW3D_MT_hook

VIEW3D_MT_image_add: bl_ui.space_view3d.VIEW3D_MT_image_add

VIEW3D_MT_lattice_add: bl_ui.space_view3d.VIEW3D_MT_lattice_add

VIEW3D_MT_light_add: bl_ui.space_view3d.VIEW3D_MT_light_add

VIEW3D_MT_lightprobe_add: bl_ui.space_view3d.VIEW3D_MT_lightprobe_add

VIEW3D_MT_make_links: bl_ui.space_view3d.VIEW3D_MT_make_links

VIEW3D_MT_make_single_user: bl_ui.space_view3d.VIEW3D_MT_make_single_user

VIEW3D_MT_mask: bl_ui.space_view3d.VIEW3D_MT_mask

VIEW3D_MT_mesh_add: bl_ui.space_view3d.VIEW3D_MT_mesh_add

VIEW3D_MT_metaball_add: bl_ui.space_view3d.VIEW3D_MT_metaball_add

VIEW3D_MT_mirror: bl_ui.space_view3d.VIEW3D_MT_mirror

VIEW3D_MT_object: bl_ui.space_view3d.VIEW3D_MT_object

VIEW3D_MT_object_animation: bl_ui.space_view3d.VIEW3D_MT_object_animation

VIEW3D_MT_object_apply: bl_ui.space_view3d.VIEW3D_MT_object_apply

VIEW3D_MT_object_asset: bl_ui.space_view3d.VIEW3D_MT_object_asset

VIEW3D_MT_object_cleanup: bl_ui.space_view3d.VIEW3D_MT_object_cleanup

VIEW3D_MT_object_clear: bl_ui.space_view3d.VIEW3D_MT_object_clear

VIEW3D_MT_object_collection: bl_ui.space_view3d.VIEW3D_MT_object_collection

VIEW3D_MT_object_constraints: bl_ui.space_view3d.VIEW3D_MT_object_constraints

VIEW3D_MT_object_context_menu: bl_ui.space_view3d.VIEW3D_MT_object_context_menu

VIEW3D_MT_object_convert: bl_ui.space_view3d.VIEW3D_MT_object_convert

VIEW3D_MT_object_liboverride: bl_ui.space_view3d.VIEW3D_MT_object_liboverride

VIEW3D_MT_object_mode_pie: bl_ui.space_view3d.VIEW3D_MT_object_mode_pie

VIEW3D_MT_object_modifiers: bl_ui.space_view3d.VIEW3D_MT_object_modifiers

VIEW3D_MT_object_parent: bl_ui.space_view3d.VIEW3D_MT_object_parent

VIEW3D_MT_object_quick_effects: bl_ui.space_view3d.VIEW3D_MT_object_quick_effects

VIEW3D_MT_object_relations: bl_ui.space_view3d.VIEW3D_MT_object_relations

VIEW3D_MT_object_rigid_body: bl_ui.space_view3d.VIEW3D_MT_object_rigid_body

VIEW3D_MT_object_shading: bl_ui.space_view3d.VIEW3D_MT_object_shading

VIEW3D_MT_object_showhide: bl_ui.space_view3d.VIEW3D_MT_object_showhide

VIEW3D_MT_object_track: bl_ui.space_view3d.VIEW3D_MT_object_track

VIEW3D_MT_orientations_pie: bl_ui.space_view3d.VIEW3D_MT_orientations_pie

VIEW3D_MT_paint_grease_pencil: bl_ui.space_view3d.VIEW3D_MT_paint_grease_pencil

VIEW3D_MT_paint_vertex: bl_ui.space_view3d.VIEW3D_MT_paint_vertex

VIEW3D_MT_paint_vertex_grease_pencil: bl_ui.space_view3d.VIEW3D_MT_paint_vertex_grease_pencil

VIEW3D_MT_paint_weight: bl_ui.space_view3d.VIEW3D_MT_paint_weight

VIEW3D_MT_paint_weight_lock: bl_ui.space_view3d.VIEW3D_MT_paint_weight_lock

VIEW3D_MT_particle: bl_ui.space_view3d.VIEW3D_MT_particle

VIEW3D_MT_particle_context_menu: bl_ui.space_view3d.VIEW3D_MT_particle_context_menu

VIEW3D_MT_particle_showhide: bl_ui.space_view3d.VIEW3D_MT_particle_showhide

VIEW3D_MT_pivot_pie: bl_ui.space_view3d.VIEW3D_MT_pivot_pie

VIEW3D_MT_pose: bl_ui.space_view3d.VIEW3D_MT_pose

VIEW3D_MT_pose_apply: bl_ui.space_view3d.VIEW3D_MT_pose_apply

VIEW3D_MT_pose_constraints: bl_ui.space_view3d.VIEW3D_MT_pose_constraints

VIEW3D_MT_pose_context_menu: bl_ui.space_view3d.VIEW3D_MT_pose_context_menu

VIEW3D_MT_pose_ik: bl_ui.space_view3d.VIEW3D_MT_pose_ik

VIEW3D_MT_pose_motion: bl_ui.space_view3d.VIEW3D_MT_pose_motion

VIEW3D_MT_pose_names: bl_ui.space_view3d.VIEW3D_MT_pose_names

VIEW3D_MT_pose_propagate: bl_ui.space_view3d.VIEW3D_MT_pose_propagate

VIEW3D_MT_pose_showhide: bl_ui.space_view3d.VIEW3D_MT_pose_showhide

VIEW3D_MT_pose_slide: bl_ui.space_view3d.VIEW3D_MT_pose_slide

VIEW3D_MT_pose_transform: bl_ui.space_view3d.VIEW3D_MT_pose_transform

VIEW3D_MT_proportional_editing_falloff_pie: bl_ui.space_view3d.VIEW3D_MT_proportional_editing_falloff_pie

VIEW3D_MT_random_mask: bl_ui.space_view3d.VIEW3D_MT_random_mask

VIEW3D_MT_sculpt: bl_ui.space_view3d.VIEW3D_MT_sculpt

VIEW3D_MT_sculpt_automasking_pie: bl_ui.space_view3d.VIEW3D_MT_sculpt_automasking_pie

VIEW3D_MT_sculpt_curves: bl_ui.space_view3d.VIEW3D_MT_sculpt_curves

VIEW3D_MT_sculpt_face_sets_edit_pie: bl_ui.space_view3d.VIEW3D_MT_sculpt_face_sets_edit_pie

VIEW3D_MT_sculpt_mask_edit_pie: bl_ui.space_view3d.VIEW3D_MT_sculpt_mask_edit_pie

VIEW3D_MT_sculpt_set_pivot: bl_ui.space_view3d.VIEW3D_MT_sculpt_set_pivot

VIEW3D_MT_sculpt_showhide: bl_ui.space_view3d.VIEW3D_MT_sculpt_showhide

VIEW3D_MT_sculpt_transform: bl_ui.space_view3d.VIEW3D_MT_sculpt_transform

VIEW3D_MT_sculpt_trim: bl_ui.space_view3d.VIEW3D_MT_sculpt_trim

VIEW3D_MT_select_edit_armature: bl_ui.space_view3d.VIEW3D_MT_select_edit_armature

VIEW3D_MT_select_edit_curve: bl_ui.space_view3d.VIEW3D_MT_select_edit_curve

VIEW3D_MT_select_edit_curves: bl_ui.space_view3d.VIEW3D_MT_select_edit_curves

VIEW3D_MT_select_edit_grease_pencil: bl_ui.space_view3d.VIEW3D_MT_select_edit_grease_pencil

VIEW3D_MT_select_edit_lattice: bl_ui.space_view3d.VIEW3D_MT_select_edit_lattice

VIEW3D_MT_select_edit_mesh: bl_ui.space_view3d.VIEW3D_MT_select_edit_mesh

VIEW3D_MT_select_edit_metaball: bl_ui.space_view3d.VIEW3D_MT_select_edit_metaball

VIEW3D_MT_select_edit_pointcloud: bl_ui.space_view3d.VIEW3D_MT_select_edit_pointcloud

VIEW3D_MT_select_edit_surface: bl_ui.space_view3d.VIEW3D_MT_select_edit_surface

VIEW3D_MT_select_edit_text: bl_ui.space_view3d.VIEW3D_MT_select_edit_text

VIEW3D_MT_select_object: bl_ui.space_view3d.VIEW3D_MT_select_object

VIEW3D_MT_select_object_more_less: bl_ui.space_view3d.VIEW3D_MT_select_object_more_less

VIEW3D_MT_select_paint_mask: bl_ui.space_view3d.VIEW3D_MT_select_paint_mask

VIEW3D_MT_select_paint_mask_vertex: bl_ui.space_view3d.VIEW3D_MT_select_paint_mask_vertex

VIEW3D_MT_select_particle: bl_ui.space_view3d.VIEW3D_MT_select_particle

VIEW3D_MT_select_pose: bl_ui.space_view3d.VIEW3D_MT_select_pose

VIEW3D_MT_select_pose_more_less: bl_ui.space_view3d.VIEW3D_MT_select_pose_more_less

VIEW3D_MT_select_sculpt_curves: bl_ui.space_view3d.VIEW3D_MT_select_sculpt_curves

VIEW3D_MT_shading_ex_pie: bl_ui.space_view3d.VIEW3D_MT_shading_ex_pie

VIEW3D_MT_shading_pie: bl_ui.space_view3d.VIEW3D_MT_shading_pie

VIEW3D_MT_snap: bl_ui.space_view3d.VIEW3D_MT_snap

VIEW3D_MT_snap_pie: bl_ui.space_view3d.VIEW3D_MT_snap_pie

VIEW3D_MT_surface_add: bl_ui.space_view3d.VIEW3D_MT_surface_add

VIEW3D_MT_tools_projectpaint_clone: bl_ui.properties_paint_common.VIEW3D_MT_tools_projectpaint_clone

VIEW3D_MT_tools_projectpaint_stencil: bl_ui.space_view3d_toolbar.VIEW3D_MT_tools_projectpaint_stencil

VIEW3D_MT_tools_projectpaint_uvlayer: bl_ui.space_view3d_toolbar.VIEW3D_MT_tools_projectpaint_uvlayer

VIEW3D_MT_transform: bl_ui.space_view3d.VIEW3D_MT_transform

VIEW3D_MT_transform_armature: bl_ui.space_view3d.VIEW3D_MT_transform_armature

VIEW3D_MT_transform_gizmo_pie: bl_ui.space_view3d.VIEW3D_MT_transform_gizmo_pie

VIEW3D_MT_transform_object: bl_ui.space_view3d.VIEW3D_MT_transform_object

VIEW3D_MT_uv_map: bl_ui.space_view3d.VIEW3D_MT_uv_map

VIEW3D_MT_vertex_group: bl_ui.space_view3d.VIEW3D_MT_vertex_group

VIEW3D_MT_view: bl_ui.space_view3d.VIEW3D_MT_view

VIEW3D_MT_view_align: bl_ui.space_view3d.VIEW3D_MT_view_align

VIEW3D_MT_view_align_selected: bl_ui.space_view3d.VIEW3D_MT_view_align_selected

VIEW3D_MT_view_cameras: bl_ui.space_view3d.VIEW3D_MT_view_cameras

VIEW3D_MT_view_local: bl_ui.space_view3d.VIEW3D_MT_view_local

VIEW3D_MT_view_navigation: bl_ui.space_view3d.VIEW3D_MT_view_navigation

VIEW3D_MT_view_pie: bl_ui.space_view3d.VIEW3D_MT_view_pie

VIEW3D_MT_view_regions: bl_ui.space_view3d.VIEW3D_MT_view_regions

VIEW3D_MT_view_viewpoint: bl_ui.space_view3d.VIEW3D_MT_view_viewpoint

VIEW3D_MT_volume_add: bl_ui.space_view3d.VIEW3D_MT_volume_add

VIEW3D_MT_weight_grease_pencil: bl_ui.space_view3d.VIEW3D_MT_weight_grease_pencil

VIEW3D_MT_wpaint_vgroup_lock_pie: bl_ui.space_view3d.VIEW3D_MT_wpaint_vgroup_lock_pie

VIEW3D_OT_edit_mesh_extrude_individual_move: bl_operators.view3d.VIEW3D_OT_edit_mesh_extrude_individual_move

VIEW3D_OT_edit_mesh_extrude_manifold_normal: bl_operators.view3d.VIEW3D_OT_edit_mesh_extrude_manifold_normal

VIEW3D_OT_transform_gizmo_set: bl_operators.view3d.VIEW3D_OT_transform_gizmo_set

VIEW3D_PT_active_spline: bl_ui.space_view3d.VIEW3D_PT_active_spline

VIEW3D_PT_active_tool: bl_ui.space_view3d.VIEW3D_PT_active_tool

VIEW3D_PT_active_tool_duplicate: bl_ui.space_view3d.VIEW3D_PT_active_tool_duplicate

VIEW3D_PT_annotation_onion: bl_ui.space_view3d.VIEW3D_PT_annotation_onion

VIEW3D_PT_collections: bl_ui.space_view3d.VIEW3D_PT_collections

VIEW3D_PT_context_properties: bl_ui.space_view3d.VIEW3D_PT_context_properties

VIEW3D_PT_copy_global_transform: bl_ui.space_view3d_sidebar.VIEW3D_PT_copy_global_transform

VIEW3D_PT_copy_global_transform_fix_to_camera: bl_ui.space_view3d_sidebar.VIEW3D_PT_copy_global_transform_fix_to_camera

VIEW3D_PT_copy_global_transform_mirror: bl_ui.space_view3d_sidebar.VIEW3D_PT_copy_global_transform_mirror

VIEW3D_PT_copy_global_transform_relative: bl_ui.space_view3d_sidebar.VIEW3D_PT_copy_global_transform_relative

VIEW3D_PT_curves_sculpt_add_shape: bl_ui.space_view3d.VIEW3D_PT_curves_sculpt_add_shape

VIEW3D_PT_curves_sculpt_grow_shrink_scaling: bl_ui.space_view3d.VIEW3D_PT_curves_sculpt_grow_shrink_scaling

VIEW3D_PT_curves_sculpt_parameter_falloff: bl_ui.space_view3d.VIEW3D_PT_curves_sculpt_parameter_falloff

VIEW3D_PT_curves_sculpt_symmetry: bl_ui.space_view3d_toolbar.VIEW3D_PT_curves_sculpt_symmetry

VIEW3D_PT_curves_sculpt_symmetry_for_topbar: bl_ui.space_view3d_toolbar.VIEW3D_PT_curves_sculpt_symmetry_for_topbar

VIEW3D_PT_gizmo_display: bl_ui.space_view3d.VIEW3D_PT_gizmo_display

VIEW3D_PT_gpencil_brush_presets: bl_ui.space_view3d_toolbar.VIEW3D_PT_gpencil_brush_presets

VIEW3D_PT_grease_pencil: bl_ui.space_view3d.VIEW3D_PT_grease_pencil

VIEW3D_PT_grease_pencil_guide: bl_ui.space_view3d.VIEW3D_PT_grease_pencil_guide

VIEW3D_PT_grease_pencil_lock: bl_ui.space_view3d.VIEW3D_PT_grease_pencil_lock

VIEW3D_PT_grease_pencil_multi_frame: bl_ui.space_view3d.VIEW3D_PT_grease_pencil_multi_frame

VIEW3D_PT_grease_pencil_origin: bl_ui.space_view3d.VIEW3D_PT_grease_pencil_origin

VIEW3D_PT_grease_pencil_sculpt_automasking: bl_ui.space_view3d.VIEW3D_PT_grease_pencil_sculpt_automasking

VIEW3D_PT_greasepencil_draw_context_menu: bl_ui.space_view3d.VIEW3D_PT_greasepencil_draw_context_menu

VIEW3D_PT_greasepencil_sculpt_context_menu: bl_ui.space_view3d.VIEW3D_PT_greasepencil_sculpt_context_menu

VIEW3D_PT_greasepencil_vertex_paint_context_menu: bl_ui.space_view3d.VIEW3D_PT_greasepencil_vertex_paint_context_menu

VIEW3D_PT_greasepencil_weight_context_menu: bl_ui.space_view3d.VIEW3D_PT_greasepencil_weight_context_menu

VIEW3D_PT_mask: bl_ui.space_view3d_toolbar.VIEW3D_PT_mask

VIEW3D_PT_object_type_visibility: bl_ui.space_view3d.VIEW3D_PT_object_type_visibility

VIEW3D_PT_overlay: bl_ui.space_view3d.VIEW3D_PT_overlay

VIEW3D_PT_overlay_bones: bl_ui.space_view3d.VIEW3D_PT_overlay_bones

VIEW3D_PT_overlay_edit_curve: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_curve

VIEW3D_PT_overlay_edit_curves: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_curves

VIEW3D_PT_overlay_edit_mesh: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_mesh

VIEW3D_PT_overlay_edit_mesh_freestyle: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_mesh_freestyle

VIEW3D_PT_overlay_edit_mesh_measurement: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_mesh_measurement

VIEW3D_PT_overlay_edit_mesh_normals: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_mesh_normals

VIEW3D_PT_overlay_edit_mesh_shading: bl_ui.space_view3d.VIEW3D_PT_overlay_edit_mesh_shading

VIEW3D_PT_overlay_geometry: bl_ui.space_view3d.VIEW3D_PT_overlay_geometry

VIEW3D_PT_overlay_grease_pencil_canvas_options: bl_ui.space_view3d.VIEW3D_PT_overlay_grease_pencil_canvas_options

VIEW3D_PT_overlay_grease_pencil_options: bl_ui.space_view3d.VIEW3D_PT_overlay_grease_pencil_options

VIEW3D_PT_overlay_guides: bl_ui.space_view3d.VIEW3D_PT_overlay_guides

VIEW3D_PT_overlay_motion_tracking: bl_ui.space_view3d.VIEW3D_PT_overlay_motion_tracking

VIEW3D_PT_overlay_object: bl_ui.space_view3d.VIEW3D_PT_overlay_object

VIEW3D_PT_overlay_sculpt: bl_ui.space_view3d.VIEW3D_PT_overlay_sculpt

VIEW3D_PT_overlay_sculpt_curves: bl_ui.space_view3d.VIEW3D_PT_overlay_sculpt_curves

VIEW3D_PT_overlay_text: bl_ui.space_view3d.VIEW3D_PT_overlay_text

VIEW3D_PT_overlay_texture_paint: bl_ui.space_view3d.VIEW3D_PT_overlay_texture_paint

VIEW3D_PT_overlay_vertex_paint: bl_ui.space_view3d.VIEW3D_PT_overlay_vertex_paint

VIEW3D_PT_overlay_viewer_node: bl_ui.space_view3d.VIEW3D_PT_overlay_viewer_node

VIEW3D_PT_overlay_weight_paint: bl_ui.space_view3d.VIEW3D_PT_overlay_weight_paint

VIEW3D_PT_paint_texture_context_menu: bl_ui.space_view3d.VIEW3D_PT_paint_texture_context_menu

VIEW3D_PT_paint_vertex_context_menu: bl_ui.space_view3d.VIEW3D_PT_paint_vertex_context_menu

VIEW3D_PT_paint_weight_context_menu: bl_ui.space_view3d.VIEW3D_PT_paint_weight_context_menu

VIEW3D_PT_proportional_edit: bl_ui.space_view3d.VIEW3D_PT_proportional_edit

VIEW3D_PT_quad_view: bl_ui.space_view3d.VIEW3D_PT_quad_view

VIEW3D_PT_sculpt_automasking: bl_ui.space_view3d.VIEW3D_PT_sculpt_automasking

VIEW3D_PT_sculpt_context_menu: bl_ui.space_view3d.VIEW3D_PT_sculpt_context_menu

VIEW3D_PT_sculpt_dyntopo: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_dyntopo

VIEW3D_PT_sculpt_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_options

VIEW3D_PT_sculpt_options_gravity: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_options_gravity

VIEW3D_PT_sculpt_snapping: bl_ui.space_view3d.VIEW3D_PT_sculpt_snapping

VIEW3D_PT_sculpt_symmetry: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_symmetry

VIEW3D_PT_sculpt_symmetry_for_topbar: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_symmetry_for_topbar

VIEW3D_PT_sculpt_voxel_remesh: bl_ui.space_view3d_toolbar.VIEW3D_PT_sculpt_voxel_remesh

VIEW3D_PT_shading: bl_ui.space_view3d.VIEW3D_PT_shading

VIEW3D_PT_shading_cavity: bl_ui.space_view3d.VIEW3D_PT_shading_cavity

VIEW3D_PT_shading_color: bl_ui.space_view3d.VIEW3D_PT_shading_color

VIEW3D_PT_shading_compositor: bl_ui.space_view3d.VIEW3D_PT_shading_compositor

VIEW3D_PT_shading_lighting: bl_ui.space_view3d.VIEW3D_PT_shading_lighting

VIEW3D_PT_shading_options: bl_ui.space_view3d.VIEW3D_PT_shading_options

VIEW3D_PT_shading_options_shadow: bl_ui.space_view3d.VIEW3D_PT_shading_options_shadow

VIEW3D_PT_shading_options_ssao: bl_ui.space_view3d.VIEW3D_PT_shading_options_ssao

VIEW3D_PT_shading_render_pass: bl_ui.space_view3d.VIEW3D_PT_shading_render_pass

VIEW3D_PT_slots_color_attributes: bl_ui.space_view3d_toolbar.VIEW3D_PT_slots_color_attributes

VIEW3D_PT_slots_paint_canvas: bl_ui.space_view3d_toolbar.VIEW3D_PT_slots_paint_canvas

VIEW3D_PT_slots_projectpaint: bl_ui.space_view3d_toolbar.VIEW3D_PT_slots_projectpaint

VIEW3D_PT_slots_vertex_groups: bl_ui.space_view3d_toolbar.VIEW3D_PT_slots_vertex_groups

VIEW3D_PT_snapping: bl_ui.space_view3d.VIEW3D_PT_snapping

VIEW3D_PT_stencil_projectpaint: bl_ui.space_view3d_toolbar.VIEW3D_PT_stencil_projectpaint

VIEW3D_PT_tools_active: bl_ui.space_toolsystem_toolbar.VIEW3D_PT_tools_active

VIEW3D_PT_tools_armatureedit_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_armatureedit_options

VIEW3D_PT_tools_brush_clone: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_clone

VIEW3D_PT_tools_brush_color: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_color

VIEW3D_PT_tools_brush_display: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_display

VIEW3D_PT_tools_brush_falloff: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_falloff

VIEW3D_PT_tools_brush_falloff_frontface: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_falloff_frontface

VIEW3D_PT_tools_brush_falloff_normal: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_falloff_normal

VIEW3D_PT_tools_brush_select: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_select

VIEW3D_PT_tools_brush_settings: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_settings

VIEW3D_PT_tools_brush_settings_advanced: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_settings_advanced

VIEW3D_PT_tools_brush_stroke: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_stroke

VIEW3D_PT_tools_brush_stroke_smooth_stroke: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_stroke_smooth_stroke

VIEW3D_PT_tools_brush_swatches: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_swatches

VIEW3D_PT_tools_brush_texture: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_brush_texture

VIEW3D_PT_tools_grease_pencil_brush_vertex_color: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_brush_vertex_color

VIEW3D_PT_tools_grease_pencil_brush_vertex_falloff: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_brush_vertex_falloff

VIEW3D_PT_tools_grease_pencil_brush_vertex_palette: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_brush_vertex_palette

VIEW3D_PT_tools_grease_pencil_brush_weight_falloff: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_brush_weight_falloff

VIEW3D_PT_tools_grease_pencil_paint_appearance: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_paint_appearance

VIEW3D_PT_tools_grease_pencil_sculpt_appearance: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_sculpt_appearance

VIEW3D_PT_tools_grease_pencil_sculpt_brush_popover: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_sculpt_brush_popover

VIEW3D_PT_tools_grease_pencil_v3_brush_advanced: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_advanced

VIEW3D_PT_tools_grease_pencil_v3_brush_eraser: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_eraser

VIEW3D_PT_tools_grease_pencil_v3_brush_fill_advanced: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_fill_advanced

VIEW3D_PT_tools_grease_pencil_v3_brush_gap_closure: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_gap_closure

VIEW3D_PT_tools_grease_pencil_v3_brush_mix_palette: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_mix_palette

VIEW3D_PT_tools_grease_pencil_v3_brush_mixcolor: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_mixcolor

VIEW3D_PT_tools_grease_pencil_v3_brush_post_processing: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_post_processing

VIEW3D_PT_tools_grease_pencil_v3_brush_random: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_random

VIEW3D_PT_tools_grease_pencil_v3_brush_select: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_select

VIEW3D_PT_tools_grease_pencil_v3_brush_settings: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_settings

VIEW3D_PT_tools_grease_pencil_v3_brush_stabilizer: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_stabilizer

VIEW3D_PT_tools_grease_pencil_v3_brush_stroke: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_v3_brush_stroke

VIEW3D_PT_tools_grease_pencil_vertex_appearance: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_vertex_appearance

VIEW3D_PT_tools_grease_pencil_vertex_paint_select: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_vertex_paint_select

VIEW3D_PT_tools_grease_pencil_vertex_paint_settings: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_vertex_paint_settings

VIEW3D_PT_tools_grease_pencil_weight_appearance: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_weight_appearance

VIEW3D_PT_tools_grease_pencil_weight_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_weight_options

VIEW3D_PT_tools_grease_pencil_weight_paint_select: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_weight_paint_select

VIEW3D_PT_tools_grease_pencil_weight_paint_settings: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_grease_pencil_weight_paint_settings

VIEW3D_PT_tools_imagepaint_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_imagepaint_options

VIEW3D_PT_tools_imagepaint_options_cavity: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_imagepaint_options_cavity

VIEW3D_PT_tools_imagepaint_options_external: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_imagepaint_options_external

VIEW3D_PT_tools_imagepaint_symmetry: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_imagepaint_symmetry

VIEW3D_PT_tools_mask_texture: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_mask_texture

VIEW3D_PT_tools_meshedit_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_meshedit_options

VIEW3D_PT_tools_meshedit_options_transform: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_meshedit_options_transform

VIEW3D_PT_tools_meshedit_options_uvs: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_meshedit_options_uvs

VIEW3D_PT_tools_object_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_object_options

VIEW3D_PT_tools_object_options_transform: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_object_options_transform

VIEW3D_PT_tools_particlemode: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_particlemode

VIEW3D_PT_tools_particlemode_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_particlemode_options

VIEW3D_PT_tools_particlemode_options_display: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_particlemode_options_display

VIEW3D_PT_tools_particlemode_options_shapecut: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_particlemode_options_shapecut

VIEW3D_PT_tools_posemode_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_posemode_options

VIEW3D_PT_tools_vertexpaint_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_vertexpaint_options

VIEW3D_PT_tools_vertexpaint_symmetry: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_vertexpaint_symmetry

VIEW3D_PT_tools_vertexpaint_symmetry_for_topbar: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_vertexpaint_symmetry_for_topbar

VIEW3D_PT_tools_weight_gradient: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_weight_gradient

VIEW3D_PT_tools_weightpaint_options: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_weightpaint_options

VIEW3D_PT_tools_weightpaint_symmetry: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_weightpaint_symmetry

VIEW3D_PT_tools_weightpaint_symmetry_for_topbar: bl_ui.space_view3d_toolbar.VIEW3D_PT_tools_weightpaint_symmetry_for_topbar

VIEW3D_PT_transform_orientations: bl_ui.space_view3d.VIEW3D_PT_transform_orientations

VIEW3D_PT_view3d_cursor: bl_ui.space_view3d.VIEW3D_PT_view3d_cursor

VIEW3D_PT_view3d_lock: bl_ui.space_view3d.VIEW3D_PT_view3d_lock

VIEW3D_PT_view3d_properties: bl_ui.space_view3d.VIEW3D_PT_view3d_properties

VIEW3D_PT_view3d_stereo: bl_ui.space_view3d.VIEW3D_PT_view3d_stereo

VIEW3D_PT_viewport_debug: bl_ui.space_view3d.VIEW3D_PT_viewport_debug

VIEWLAYER_MT_lightgroup_sync: bl_ui.properties_view_layer.VIEWLAYER_MT_lightgroup_sync

VIEWLAYER_PT_context_layer: bl_ui.properties_view_layer.VIEWLAYER_PT_context_layer

VIEWLAYER_PT_eevee_layer_passes_data: bl_ui.properties_view_layer.VIEWLAYER_PT_eevee_layer_passes_data

VIEWLAYER_PT_eevee_layer_passes_light: bl_ui.properties_view_layer.VIEWLAYER_PT_eevee_layer_passes_light

VIEWLAYER_PT_filter: bl_ui.properties_view_layer.VIEWLAYER_PT_filter

VIEWLAYER_PT_freestyle: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle

VIEWLAYER_PT_freestyle_animation: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_animation

VIEWLAYER_PT_freestyle_edge_detection: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_edge_detection

VIEWLAYER_PT_freestyle_lineset: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_lineset

VIEWLAYER_PT_freestyle_lineset_collection: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_lineset_collection

VIEWLAYER_PT_freestyle_lineset_edgetype: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_lineset_edgetype

VIEWLAYER_PT_freestyle_lineset_facemarks: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_lineset_facemarks

VIEWLAYER_PT_freestyle_lineset_visibilty: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_lineset_visibilty

VIEWLAYER_PT_freestyle_linestyle_alpha: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_alpha

VIEWLAYER_PT_freestyle_linestyle_color: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_color

VIEWLAYER_PT_freestyle_linestyle_geometry: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_geometry

VIEWLAYER_PT_freestyle_linestyle_strokes: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes

VIEWLAYER_PT_freestyle_linestyle_strokes_chaining: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_chaining

VIEWLAYER_PT_freestyle_linestyle_strokes_dashedline: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_dashedline

VIEWLAYER_PT_freestyle_linestyle_strokes_selection: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_selection

VIEWLAYER_PT_freestyle_linestyle_strokes_sorting: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_sorting

VIEWLAYER_PT_freestyle_linestyle_strokes_splitting: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_splitting

VIEWLAYER_PT_freestyle_linestyle_strokes_splitting_pattern: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_strokes_splitting_pattern

VIEWLAYER_PT_freestyle_linestyle_texture: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_texture

VIEWLAYER_PT_freestyle_linestyle_thickness: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_linestyle_thickness

VIEWLAYER_PT_freestyle_style_modules: bl_ui.properties_freestyle.VIEWLAYER_PT_freestyle_style_modules

VIEWLAYER_PT_layer: bl_ui.properties_view_layer.VIEWLAYER_PT_layer

VIEWLAYER_PT_layer_custom_props: bl_ui.properties_view_layer.VIEWLAYER_PT_layer_custom_props

VIEWLAYER_PT_layer_passes: bl_ui.properties_view_layer.VIEWLAYER_PT_layer_passes

VIEWLAYER_PT_layer_passes_aov: bl_ui.properties_view_layer.VIEWLAYER_PT_layer_passes_aov

VIEWLAYER_PT_layer_passes_cryptomatte: bl_ui.properties_view_layer.VIEWLAYER_PT_layer_passes_cryptomatte

VIEWLAYER_PT_layer_passes_lightgroups: bl_ui.properties_view_layer.VIEWLAYER_PT_layer_passes_lightgroups

VIEWLAYER_PT_override: bl_ui.properties_view_layer.VIEWLAYER_PT_override

VIEWLAYER_PT_workbench_layer_passes_data: bl_ui.properties_view_layer.VIEWLAYER_PT_workbench_layer_passes_data

VIEWLAYER_UL_aov: bl_ui.properties_view_layer.VIEWLAYER_UL_aov

VIEWLAYER_UL_linesets: bl_ui.properties_freestyle.VIEWLAYER_UL_linesets

VOLUME_UL_grids: bl_ui.properties_data_volume.VOLUME_UL_grids

WM_MT_operator_presets: bl_operators.presets.WM_MT_operator_presets

WM_MT_region_toggle_pie: bl_operators.wm.WM_MT_region_toggle_pie

WM_MT_splash: bl_operators.wm.WM_MT_splash

WM_MT_splash_about: bl_operators.wm.WM_MT_splash_about

WM_MT_splash_quick_setup: bl_operators.wm.WM_MT_splash_quick_setup

WM_MT_toolsystem_submenu: bl_ui.space_toolsystem_common.WM_MT_toolsystem_submenu

WM_OT_batch_rename: bl_operators.wm.WM_OT_batch_rename

WM_OT_blend_strings_utf8_validate: bl_operators.file.WM_OT_blend_strings_utf8_validate

WM_OT_context_collection_boolean_set: bl_operators.wm.WM_OT_context_collection_boolean_set

WM_OT_context_cycle_array: bl_operators.wm.WM_OT_context_cycle_array

WM_OT_context_cycle_enum: bl_operators.wm.WM_OT_context_cycle_enum

WM_OT_context_cycle_int: bl_operators.wm.WM_OT_context_cycle_int

WM_OT_context_menu_enum: bl_operators.wm.WM_OT_context_menu_enum

WM_OT_context_modal_mouse: bl_operators.wm.WM_OT_context_modal_mouse

WM_OT_context_pie_enum: bl_operators.wm.WM_OT_context_pie_enum

WM_OT_context_scale_float: bl_operators.wm.WM_OT_context_scale_float

WM_OT_context_scale_int: bl_operators.wm.WM_OT_context_scale_int

WM_OT_context_set_boolean: bl_operators.wm.WM_OT_context_set_boolean

WM_OT_context_set_enum: bl_operators.wm.WM_OT_context_set_enum

WM_OT_context_set_float: bl_operators.wm.WM_OT_context_set_float

WM_OT_context_set_id: bl_operators.wm.WM_OT_context_set_id

WM_OT_context_set_int: bl_operators.wm.WM_OT_context_set_int

WM_OT_context_set_string: bl_operators.wm.WM_OT_context_set_string

WM_OT_context_set_value: bl_operators.wm.WM_OT_context_set_value

WM_OT_context_toggle: bl_operators.wm.WM_OT_context_toggle

WM_OT_context_toggle_enum: bl_operators.wm.WM_OT_context_toggle_enum

WM_OT_doc_view: bl_operators.wm.WM_OT_doc_view

WM_OT_doc_view_manual: bl_operators.wm.WM_OT_doc_view_manual

WM_OT_drop_blend_file: bl_operators.wm.WM_OT_drop_blend_file

WM_OT_operator_cheat_sheet: bl_operators.wm.WM_OT_operator_cheat_sheet

WM_OT_operator_pie_enum: bl_operators.wm.WM_OT_operator_pie_enum

WM_OT_operator_presets_cleanup: bl_operators.presets.WM_OT_operator_presets_cleanup

WM_OT_owner_disable: bl_operators.wm.WM_OT_owner_disable

WM_OT_owner_enable: bl_operators.wm.WM_OT_owner_enable

WM_OT_path_open: bl_operators.wm.WM_OT_path_open

WM_OT_previews_batch_clear: bl_operators.file.WM_OT_previews_batch_clear

WM_OT_previews_batch_generate: bl_operators.file.WM_OT_previews_batch_generate

WM_OT_properties_add: bl_operators.wm.WM_OT_properties_add

WM_OT_properties_context_change: bl_operators.wm.WM_OT_properties_context_change

WM_OT_properties_edit: bl_operators.wm.WM_OT_properties_edit

WM_OT_properties_edit_value: bl_operators.wm.WM_OT_properties_edit_value

WM_OT_properties_remove: bl_operators.wm.WM_OT_properties_remove

WM_OT_sysinfo: bl_operators.wm.WM_OT_sysinfo

WM_OT_tool_set_by_brush_type: bl_operators.wm.WM_OT_tool_set_by_brush_type

WM_OT_tool_set_by_id: bl_operators.wm.WM_OT_tool_set_by_id

WM_OT_tool_set_by_index: bl_operators.wm.WM_OT_tool_set_by_index

WM_OT_toolbar: bl_operators.wm.WM_OT_toolbar

WM_OT_toolbar_fallback_pie: bl_operators.wm.WM_OT_toolbar_fallback_pie

WM_OT_toolbar_prompt: bl_operators.wm.WM_OT_toolbar_prompt

WM_OT_url_open: bl_operators.wm.WM_OT_url_open

WM_OT_url_open_preset: bl_operators.wm.WM_OT_url_open_preset

WM_PT_operator_presets: bl_operators.presets.WM_PT_operator_presets

WORKSPACE_PT_addons: bl_ui.properties_workspace.WORKSPACE_PT_addons

WORKSPACE_PT_custom_props: bl_ui.properties_workspace.WORKSPACE_PT_custom_props

WORKSPACE_PT_main: bl_ui.properties_workspace.WORKSPACE_PT_main

WORKSPACE_UL_addons_items: bl_ui.properties_workspace.WORKSPACE_UL_addons_items

WORLD_OT_convert_volume_to_mesh: bl_operators.world.WORLD_OT_convert_volume_to_mesh

WORLD_PT_animation: bl_ui.properties_world.WORLD_PT_animation

WORLD_PT_context_world: bl_ui.properties_world.WORLD_PT_context_world

WORLD_PT_custom_props: bl_ui.properties_world.WORLD_PT_custom_props

WORLD_PT_viewport_display: bl_ui.properties_world.WORLD_PT_viewport_display
